OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Zadaná e-mailová adresa je príliš dlhá",
    "User-Session unexpectedly expired" : "Používateľská relácia sa neočakávane prerušila",
    "Provided email-address is not valid" : "Zadaná e-mailová adresa je neplatná",
    "%s has published the calendar »%s«" : "Používateľ %s zverejnil kalendár %s",
    "Unexpected error sending email. Please contact your administrator." : "Neočakávaná chyba počas odosielania e-mailu. Obráťte sa na správcu",
    "Successfully sent email to %1$s" : "E-mail bol úspešne odoslaný pre %1$s",
    "Hello," : "Ahoj,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Chceme vás upozorniť, že používateľ %s zverejnil kalendár %s",
    "Open »%s«" : "Otvoriť »%s«",
    "Cheers!" : "Pekný deň!",
    "Upcoming events" : "Nadchádzajúce udalosti",
    "No more events today" : "Dnes žiadne ďalšie udalosti",
    "No upcoming events" : "Žiadne nadchádzajúce udalosti",
    "More events" : "Viac udalostí",
    "%1$s with %2$s" : "%1$s s %2$s",
    "Calendar" : "Kalendár",
    "New booking {booking}" : "Nová rezervácia {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) rezervoval(a) stretnutie \"{config_display_name}\" dňa {date_time}.",
    "Appointments" : "Stretnutia",
    "Schedule appointment \"%s\"" : "Naplánovať stretnutie \"%s\"",
    "Schedule an appointment" : "Naplánovať stretnutie",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : "Pripraviť na %s",
    "Follow up for %s" : "Sledovať pre %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Vaše stretnutie „%s“ s %s vyžaduje potvrdenie",
    "Dear %s, please confirm your booking" : "Vážený %s, potvrďte svoju rezerváciu",
    "Confirm" : "Potvrdiť",
    "Appointment with:" : "Stretnutie s:",
    "Description:" : "Popis:",
    "This confirmation link expires in %s hours." : "Platnosť tohto potvrdzovacieho odkazu vyprší o %s hodín.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Ak predsa len chcete stretnutie zrušiť, kontaktujte organizátora odpoveďou na tento e-mail alebo návštevou jeho profilovej stránky.",
    "Your appointment \"%s\" with %s has been accepted" : "Vaše stretnutie „%s“ s %s bolo potvrdené",
    "Dear %s, your booking has been accepted." : "Vážený/á %s, vaša rezervácia bola prijatá.",
    "Appointment for:" : "Termín pre:",
    "Date:" : "Dátum:",
    "You will receive a link with the confirmation email" : "Dostanete odkaz s potvrzovacím e-mailom",
    "Where:" : "Kde:",
    "Comment:" : "Komentár.",
    "You have a new appointment booking \"%s\" from %s" : "Máte novú rezerváciu stretnutia \"%s\" od %s",
    "Dear %s, %s (%s) booked an appointment with you." : "Vážený/á %s, %s (%s) si u vás objednal stretnutie.",
    "Location:" : "Miesto:",
    "Duration:" : "Trvanie",
    "A Calendar app for Nextcloud" : "Aplikácia Kalendár pre Nextcloud",
    "A Calendar app for Nextcloud. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Like Contacts, Talk, Tasks, Deck and Circles\n* 🌐 **WebCal Support!** Want to see your favorite team's matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 **Search!** Find your events at ease\n* ☑️ **Tasks!** See tasks or Deck cards with a due date directly in the calendar\n* 🔈 **Talk rooms!** Create an associated Talk room when booking a meeting with just one click\n* 📆 **Appointment booking** Send people a link so they can book an appointment with you [using this app](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Attachments!** Add, upload and view event attachments\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Aplikácia Kalendár pre Nextcloud. Jednoducho synchronizujte udalosti z rôznych zariadení s vaším Nextcloudom a upravujte ich online.\n\n* 🚀 **Integrácia s inými aplikáciami Nextcloud!** Ako Kontakty, Talk, Úlohy, Deck a Kruhy\n* 🌐 **Podpora WebCal!** Chcete vidieť zápasy svojho obľúbeného tímu v kalendári? Žiadny problém!\n* 🙋 **Účastníci!** Pozvite ľudí na svoje udalosti\n* ⌚ **Voľný/Zaneprázdnený!** Pozrite sa, kedy sú vaši účastníci k dispozícii na stretnutie\n* ⏰ **Pripomienky!** Získajte upozornenia na udalosti priamo v prehliadači a prostredníctvom e-mailu\n* 🔍 **Vyhľadávanie!** Nájdite svoje udalosti v pohodlí\n* ☑️ **Úlohy!** Pozrite si úlohy alebo karty balíčkov s dátumom dokončenia priamo v kalendári\n* 🔈 **Diskusné miestnosti!** Vytvorte priradenú diskusnú miestnosť pri rezervácii stretnutia jediným kliknutím\n* 📆 **Rezervácia stretnutia** Pošlite ľuďom odkaz, aby si mohli rezervovať stretnutie s vami [pomocou tejto aplikácie](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Prílohy!** Pridávajte, nahrávajte a zobrazujte prílohy udalostí\n* 🙈 **Nevynájdeme koleso!** Na základe skvelého [c-dav knižnice](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) a [fullcalendar](https://github.com/fullcalendar/fullcalendar).",
    "Previous day" : "Predchádzajúci deň",
    "Previous week" : "Predchádzajúci týždeň",
    "Previous year" : "Minulý rok",
    "Previous month" : "Predchádzajúci mesiac",
    "Next day" : "Nasledujúci deň",
    "Next week" : "Nasledujúci týždeň",
    "Next year" : "Nasledujúci rok",
    "Next month" : "Nasledujúci mesiac",
    "Create new event" : "Vytvoriť novú udalosť",
    "Event" : "Udalosť",
    "Today" : "Dnes",
    "Day" : "Deň",
    "Week" : "Týždeň",
    "Month" : "Mesiac",
    "Year" : "Rok",
    "List" : "Zoznam",
    "Appointment link was copied to clipboard" : "Odkaz na stretnutie bol skopírovaný do schránky",
    "Appointment link could not be copied to clipboard" : "Odkaz na stretnutie nemohol byť skopírovaný do schránky",
    "Preview" : "Náhľad",
    "Copy link" : "Kopírovať odkaz",
    "Edit" : "Upraviť",
    "Delete" : "Zmazať",
    "Appointment schedules" : "Harmonogramy stretnutí",
    "Create new" : "Vytvoriť nový",
    "Disable calendar \"{calendar}\"" : "Zakázať kalendár „{calendar}“",
    "Disable untitled calendar" : "Zakázať nepomenovaný kalendár",
    "Enable calendar \"{calendar}\"" : "Povoliť kalendár „{calendar}“",
    "Enable untitled calendar" : "Povoliť nepomenovaný kalendár",
    "An error occurred, unable to change visibility of the calendar." : "Vyskytla sa chyba, nie je možné zmeniť viditeľnosť kalendára.",
    "Untitled calendar" : "Kalendár bez názvu",
    "Shared with you by" : "Sprístupnené vám používateľom",
    "Edit and share calendar" : "Upraviť a zdieľať kalendár",
    "Edit calendar" : "Upraviť kalendár",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Zdieľanie kalendára bude zmazané za {countdown} sekundu","Zdieľanie kalendára bude zmazané za {countdown} sekundy","Zdieľanie kalendára bude zmazané za {countdown} sekúnd","Zdieľanie kalendára bude zmazané za {countdown} sekúnd"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Kalendár bude zmazaný za {countdown} sekundu","Kalendár bude zmazaný za {countdown} sekundy","Kalendár bude zmazaný za {countdown} sekúnd","Kalendár bude zmazaný za {countdown} sekúnd"],
    "An error occurred, unable to create the calendar." : "Vyskytla sa chyba, nie je možné vytvoriť kalendár.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Vkladajte platné odkazy (musia sa začínať http://, https://, webcal:// alebo webcals://)",
    "Calendars" : "Kalendáre",
    "Add new" : "Pridať nový",
    "New calendar" : "Nový kalendár",
    "Name for new calendar" : "Názov nového kalendára",
    "Creating calendar …" : "Vytváranie kalendára …",
    "New calendar with task list" : "Nový kalendár so zoznamom úloh",
    "New subscription from link (read-only)" : "Nový odber z odkazu (iba na čítanie)",
    "Creating subscription …" : "Vytvára sa odber …",
    "Add public holiday calendar" : "Pridať kalendár verejných sviatokov",
    "Add custom public calendar" : "Pridať vlastný verejný kalendár",
    "Calendar link copied to clipboard." : "Odkaz na kalendár skopírovaný do schránky.",
    "Calendar link could not be copied to clipboard." : "Odkaz na kalendár nebolo možné  skopírovať do schránky.",
    "Copy subscription link" : "Kopírovať odkaz na odber",
    "Copying link …" : "Kopírovanie odkazu …",
    "Copied link" : "Kopírovaný odkaz",
    "Could not copy link" : "Nie je možné skopírovať odkaz",
    "Export" : "Export",
    "Untitled item" : "Položka bez názvu",
    "Unknown calendar" : "Neznámy kalendár",
    "Could not load deleted calendars and objects" : "Nie je možné načítať zmazané kalendáre a objekty",
    "Could not delete calendar or event" : "Nie je možné vymazať kalendár alebo udalosť",
    "Could not restore calendar or event" : "Nie je možné obnoviť kalendár alebo udalosť",
    "Do you really want to empty the trash bin?" : "Naozaj chcete vyprázdniť kôš?",
    "Empty trash bin" : "Vyprázdniť kôš",
    "Trash bin" : "Kôš",
    "Loading deleted items." : "Nahrávam zmazané položky.",
    "You do not have any deleted items." : "Nemáte žiadne zmazané položky.",
    "Name" : "Názov",
    "Deleted" : "Zmazané",
    "Restore" : "Obnoviť",
    "Delete permanently" : "Zmazať  natrvalo",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Položky v odpadkovom koši budú odstránené po {numDays} dni","Položky v odpadkovom koši budú odstránené po {numDays} dňoch","Položky v odpadkovom koši budú odstránené po {numDays} dňoch","Položky v odpadkovom koši budú odstránené po {numDays} dňoch"],
    "Could not update calendar order." : "Poradie kalendára sa nepodarilo aktualizovať.",
    "Shared calendars" : "Zdieľané kalendáre",
    "Deck" : "Nástenka",
    "Internal link" : "Interný odkaz",
    "A private link that can be used with external clients" : "Súkromný odkaz, ktorý môže byť použitý s externými klientmi.",
    "Copy internal link" : "Kopírovať interný odkaz",
    "An error occurred, unable to publish calendar." : "Vyskytla sa chyba, nie je možné zverejniť kalendár.",
    "An error occurred, unable to send email." : "Vyskytla sa chyba, nepodarilo sa odoslať e-mail.",
    "Embed code copied to clipboard." : "Vložený kód skopírovaný do schránky",
    "Embed code could not be copied to clipboard." : "Vložený kód nebolo možné  skopírovať do schránky.",
    "Unpublishing calendar failed" : "Zrušenie zverejnenia kalendára zlyhalo",
    "Share link" : "Sprístupniť odkaz",
    "Copy public link" : "Kopírovať verejný odkaz",
    "Send link to calendar via email" : "Odoslať odkaz na kalendár emailom",
    "Enter one address" : "Zadajte jednu adresu",
    "Sending email …" : "Odosielanie e-mailu …",
    "Copy embedding code" : "Kopírovať vložený kód",
    "Copying code …" : "Kopírovanie kódu …",
    "Copied code" : "Skopírovaný kód",
    "Could not copy code" : "Nie je možné skopírovať kód",
    "Delete share link" : "Zmazať sprístupnený odkaz",
    "Deleting share link …" : "Mazanie odkazu pre zdieľanie …",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Tím)",
    "An error occurred while unsharing the calendar." : "Počas rušenia zdieľania kalendára sa vyskytla chyba.",
    "An error occurred, unable to change the permission of the share." : "Vyskytla sa chyba, nie je možné zmeniť práva na zdieľanie kalendára.",
    "Unshare with {displayName}" : "Zrušiť zdieľanie s {displayName}",
    "Share with users or groups" : "Sprístupniť používateľom alebo skupinám",
    "No users or groups" : "Žiadni používatelia alebo skupiny",
    "Failed to save calendar name and color" : "Nepodarilo sa uložiť názov kalendára a jeho farbu.",
    "Never show me as busy (set this calendar to transparent)" : "Nikdy ma nezobrazovať ako zaneprázdneného (nastaviť tento kalendár na priehľadný)",
    "Share calendar" : "Zdieľať kalendár",
    "Unshare from me" : "Zrušiť zdieľanie so mnou",
    "Save" : "Uložiť",
    "Are you sure you want to delete \"{title}\"?" : "Ste si istý, že chcete odstrániť \"{title}\"?",
    "View" : "Zobraziť",
    "Import calendars" : "Import kalendára",
    "Please select a calendar to import into …" : "Vyberte kalendár do ktorého importovať …",
    "Filename" : "Názov súboru",
    "Calendar to import into" : "Kalendár na import do ...",
    "Cancel" : "Zrušiť",
    "_Import calendar_::_Import calendars_" : ["Import kalendára","Import kalendárov","Import kalendárov","Import kalendárov"],
    "Select the default location for attachments" : "Vyberte predvolené umiestnenie príloh",
    "Pick" : "Vybrať",
    "Invalid location selected" : "Bolo vybrané neplatné umiestnenie",
    "Attachments folder successfully saved." : "Adresár príloh úspešne uložený.",
    "Error on saving attachments folder." : "Chyba pri ukladaní adresára príloh.",
    "Attachments folder" : "Priečinok s prílohami",
    "{filename} could not be parsed" : "{filename} nie je možné spracovať",
    "No valid files found, aborting import" : "Nenašli sa žiadne platné súbory, import sa prerušuje",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Úspešne naimportovaná %n udalosť","Úspešne naimportované %n udalosti","Úspešne naimportovaných %n udalostí","Úspešne naimportovaných %n udalostí"],
    "Import partially failed. Imported {accepted} out of {total}." : "Import čiastočne zlyhal. Importované {accepted} z {total}.",
    "Automatic" : "Automaticky",
    "Automatic ({timezone})" : "Automatická ({timezone})",
    "New setting was not saved successfully." : "Nové nastavenie nebolo možné uložiť.",
    "Timezone" : "Časová zóna",
    "Navigation" : "Navigácia",
    "Previous period" : "Predchádzajúce obdobie",
    "Next period" : "Nadchádzajúce obdobie",
    "Views" : "Zobrazenia",
    "Day view" : "Denné zobrazenie",
    "Week view" : "Týždenné zobrazenie",
    "Month view" : "Mesačné zobrazenie",
    "Year view" : "Ročný pohľad",
    "List view" : "Zobraziť ako zoznam",
    "Actions" : "Akcie",
    "Create event" : "Vytvoriť udalosť",
    "Show shortcuts" : "Zobraziť skratky",
    "Editor" : "Editor",
    "Close editor" : "Zavrieť editor",
    "Save edited event" : "Uložiť upravenú udalosť",
    "Delete edited event" : "Zmazať upravenú udalosť",
    "Duplicate event" : "Duplicitná udalosť",
    "or" : "alebo",
    "Calendar settings" : "Nastavenia kalendára",
    "At event start" : "Na začiatku udalosti",
    "No reminder" : "Žiadna pripomienka",
    "Failed to save default calendar" : "Nepodarilo sa uložiť predvolený kalendár.",
    "General" : "Všeobecné",
    "Appearance" : "Vzhľad",
    "Editing" : "Úprava",
    "Default reminder" : "Predvolená pripomienka",
    "Files" : "Súbory",
    "Appointment schedule successfully created" : "Plán stretnutia bol úspešne vytvorený",
    "Appointment schedule successfully updated" : "Plán stretnutia bol úspešne upravený",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minúta","{duration} minút","{duration} minút","{duration} minút"],
    "0 minutes" : "0 minút",
    "_{duration} hour_::_{duration} hours_" : ["{duration} hodina","{duration} hodiny","{duration} hodín","{duration} hodín"],
    "_{duration} day_::_{duration} days_" : ["{duration} deň","{duration} dni","{duration} dní","{duration} dní"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} týždeň","{duration} týždne","{duration} týždňov","{duration} týždňov"],
    "_{duration} month_::_{duration} months_" : ["{duration} mesiac","{duration} mesiace","{duration} mesiacov","{duration} mesiacov"],
    "_{duration} year_::_{duration} years_" : ["{duration} rok","{duration} roky","{duration} rokov","{duration} rokov"],
    "To configure appointments, add your email address in personal settings." : "Pre nastavenie stretnutia, pridajte svoju e-mail adresu v osobných nastaveniach.",
    "Public – shown on the profile page" : "Verejné – zobrazí sa na stránke profilu",
    "Private – only accessible via secret link" : "Súkromné ​​– prístupné iba cez tajný odkaz",
    "Appointment schedule saved" : "Plán stretnutia bol uložený",
    "Create appointment schedule" : "Vytvoriť plán stretnutia",
    "Edit appointment schedule" : "Upraviť plán stretnutia",
    "Update" : "Aktualizovať",
    "Appointment name" : "Názov stretnutia",
    "Location" : "Umiestnenie",
    "Create a Talk room" : "Vytvoriť miestnosť v Talk /Rozhovore/",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Bude vygenerovaný jedinečný odkaz pre každú rezervovanú schôdzku a bude zaslaný prostredníctvom potvrdzovacieho e-mailu.",
    "Description" : "Popis",
    "Visibility" : "Viditeľnosť",
    "Duration" : "Trvanie",
    "Increments" : "Prírastky",
    "Additional calendars to check for conflicts" : "Ďalšie kalendáre pre kontrolu konfliktov",
    "Pick time ranges where appointments are allowed" : "Vyberte časové rozsahy, v ktorých sú povolené stretnutia",
    "to" : "do",
    "Delete slot" : "Odstrániť slot",
    "No times set" : "Nie sú nastavené žiadne časy",
    "Add" : "Pridať",
    "Monday" : "Pondelok",
    "Tuesday" : "Utorok",
    "Wednesday" : "Streda",
    "Thursday" : "Štvrtok",
    "Friday" : "Piatok",
    "Saturday" : "Sobota",
    "Sunday" : "Nedeľa",
    "Weekdays" : "Pracovné dni",
    "Add time before and after the event" : "Pridajte čas pred a po udalosti",
    "Before the event" : "Pred udalosťou",
    "After the event" : "Po udalosti",
    "Planning restrictions" : "Obmedzenia plánovania",
    "Minimum time before next available slot" : "Minimálny čas do ďalšieho dostupného slotu",
    "Max slots per day" : "Max. počet slotov na deň",
    "Limit how far in the future appointments can be booked" : "Obmedzte, ako ďaleko v budúcnosti je možné rezervovať schôdzky",
    "It seems a rate limit has been reached. Please try again later." : "Zdá sa, že bol dosiahnutý limit rýchlosti. Skúste to prosím neskôr znova.",
    "Please confirm your reservation" : "Prosím, potvrďte vašu rezerváciu",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Poslali sme vám e-mail s podrobnosťami. Potvrďte svoj termín pomocou odkazu v e-maili. Teraz môžete túto stránku zatvoriť.",
    "Your name" : "Vaše meno",
    "Your email address" : "Vaša e-mailová adresa",
    "Please share anything that will help prepare for our meeting" : "Zdieľajte čokoľvek, čo vám pomôže pripraviť sa na naše stretnutie",
    "Could not book the appointment. Please try again later or contact the organizer." : "Termín sa nepodarilo zarezervovať. Skúste to znova neskôr alebo kontaktujte organizátora.",
    "Back" : "Späť",
    "Book appointment" : "Rezervovať stretnutie",
    "Error fetching Talk conversations." : "Chyba pri načítavaní konverzácií Talk.",
    "Conversation does not have a valid URL." : "Konverzácia nemá platné URL.",
    "Successfully added Talk conversation link to location." : "Odkaz na konverzáciu Talk bol úspešne pridaný k miestu.",
    "Successfully added Talk conversation link to description." : "Odkaz na miestnosť Talk bol úspešne pridaný do popisu.",
    "Failed to apply Talk room." : "Nepodarilo sa aplikovať miestnost pre rozhovor.",
    "Talk conversation for event" : "Konverzácia Talk pre udalosť",
    "Error creating Talk conversation" : "Chyba pri vytváraní novej konverzácie Talk",
    "Select a Talk Room" : "Vybrať miestnosť pre rozhovor",
    "Add Talk conversation" : "Pridať konverzáciu v aplikacií Rozhovor/Talk",
    "Fetching Talk rooms…" : "Získavam miestnosti pre Rozhovor...",
    "No Talk room available" : "Neboli nájdené žiadne miestnosti",
    "Select conversation" : "Vybrať konveráciu",
    "on" : "o",
    "at" : "na",
    "before at" : "pred o",
    "Notification" : "Hlásenie",
    "Email" : "E-mail",
    "Audio notification" : "Hlasový oznam",
    "Other notification" : "Ostatné hlásenia",
    "Relative to event" : "Prislúchajúci k udalosti",
    "On date" : "Dňa",
    "Edit time" : "Zmeniť čas pripomienky",
    "Save time" : "Uložiť zmenený čas pripomienky",
    "Remove reminder" : "Odstrániť pripomienku",
    "Add reminder" : "Pridať pripomienku",
    "seconds" : "sekúnd",
    "minutes" : "minúty",
    "hours" : "hodiny",
    "days" : "dni",
    "weeks" : "týždňov",
    "Choose a file to add as attachment" : "Vyberte súbor, ktorý chcete pridať ako prílohu.",
    "Choose a file to share as a link" : "Vyberte súbor, ktorý chcete sprístupniť pomocou odkazu",
    "Attachment {name} already exist!" : "Príloha {name} už existuje!",
    "Could not upload attachment(s)" : "Nepodarilo sa nahrať prílohu(y)",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Chystáte sa prejsť na {host}. Naozaj chcete pokračovať? Odkaz: {link}",
    "Proceed" : "Pokračovať",
    "No attachments" : "Žiadne prílohy",
    "Add from Files" : "Pridať zo Súborov",
    "Upload from device" : "Nahrať zo zariadenia",
    "Delete file" : "Zmazať súbor",
    "Confirmation" : "Potvrdenie",
    "_{count} attachment_::_{count} attachments_" : ["{count} príloha","{count} prílohy","{count} príloh","{count} prílohy"],
    "Suggested" : "Navrhované",
    "Available" : "Dostupné",
    "Invitation accepted" : "Pozvánka prijatá",
    "Accepted {organizerName}'s invitation" : "Prijaté pozvanie od {organizerName}",
    "Participation marked as tentative" : "Účasť označená ako predbežná",
    "Invitation is delegated" : "Pozvánka je delegovaná",
    "Not available" : "Nie je k dispozícií",
    "Invitation declined" : "Pozvánka odmietnutá",
    "Declined {organizerName}'s invitation" : "Pozvánka od {organizerName} bola odmietnutá",
    "Availability will be checked" : "Dostupnosť bude overená",
    "Invitation will be sent" : "Pozvánka bude odoslaná",
    "Failed to check availability" : "Nepodarilo sa skontrolovať dostupnosť",
    "Failed to deliver invitation" : "Nepodarilo sa doručiť pozvánku",
    "Awaiting response" : "Čaká sa na odpoveď",
    "Checking availability" : "Kontrolujem dostupnosť",
    "Has not responded to {organizerName}'s invitation yet" : "Zatiaľ neodpovedal na pozvanie od {organizerName}",
    "chairperson" : "predseda",
    "required participant" : "požadovaná účasť",
    "non-participant" : "bez účasti",
    "optional participant" : "nepovinná účasť",
    "{organizer} (organizer)" : "{organizer} (organizátor)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Availability of attendees, resources and rooms" : "Dostupnosť účastníkov, zdrojov a miestností",
    "Suggestion accepted" : "Návrh bol prijatý",
    "Legend" : "Legenda",
    "Out of office" : "Mimo kancelárie",
    "Attendees:" : "Účastníci:",
    "Done" : "Hotovo",
    "Search room" : "Vyhľadať miestnosť",
    "Room name" : "Názov miestnosti",
    "Check room availability" : "Skontrolovať obsadenosť miestnosti",
    "Free" : "Voľný",
    "Busy (tentative)" : "Zaneprázdnený (predbežne)",
    "Busy" : "Zaneprázdnený",
    "Unknown" : "Neznámy",
    "Find a time" : "Nájisť čas",
    "The invitation has been accepted successfully." : "Pozvánka bola úspešne prijatá.",
    "Failed to accept the invitation." : "Prijatie pozvánky zlyhalo.",
    "The invitation has been declined successfully." : "Pozvánka bola odmietnutá.",
    "Failed to decline the invitation." : "Odmietnutie pozvánky zlyhalo.",
    "Your participation has been marked as tentative." : "Vaša účasť bola označená ako predbežná.",
    "Failed to set the participation status to tentative." : "Zlyhalo nastavenie vašej účasti ako predbežnej.",
    "Accept" : "Prijať",
    "Decline" : "Odmietnuť",
    "Tentative" : "Neistý",
    "No attendees yet" : "Zatiaľ žiadni účastníci",
    "Attendees" : "Účastníci",
    "Remove group" : "Odstrániť skupinu",
    "Remove attendee" : "Odstrániť účastníka",
    "Request reply" : "Odpoveď na žiadosť",
    "Chairperson" : "Predseda",
    "Required participant" : "Požadovaná účasť",
    "Optional participant" : "Nepovinná účasť",
    "Non-participant" : "Bez účasti",
    "_%n member_::_%n members_" : ["%n člen","%n členovia","%n členov","%n členov"],
    "Search for emails, users, contacts, contact groups or teams" : "Hľadať e-maily, užívateľov, kontakty, skupiny kontaktov alebo tímy",
    "No match found" : "Nenašla sa žiadna zhoda",
    "Note that members of circles get invited but are not synced yet." : "Všimnite si, že členovia kruhov dostávajú pozvánky, ale ešte nie sú synchronizovaní.",
    "Note that members of contact groups get invited but are not synced yet." : "Upozorňujeme, že členovia skupín kontaktov sú pozvaní, ale ešte nie sú synchronizovaní.",
    "(organizer)" : "(organizátor)",
    "Make {label} the organizer" : "Urobiť z {label} organizátora",
    "Make {label} the organizer and attend" : "Urobiť z {label} organizátora a zúčastniť sa",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Ak chcete posielať pozvánky a vybavovať odpovede, [linkopen] pridajte svoju e-mailovú adresu do osobných nastavení [linkclose].",
    "Remove color" : "Odobrať farbu",
    "Event title" : "Názov udalosti",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "U opakovaných udalostí nie je možné u jednotlivého výskytu zvlášť meniť, či je udalosť celodenná alebo ne.",
    "From" : "Od",
    "To" : "Pre",
    "Repeat" : "Opakovať",
    "_time_::_times_" : ["krát","krát","krát","krát"],
    "never" : "nikdy",
    "on date" : "dňa",
    "after" : "po",
    "End repeat" : "Koniec opakovania",
    "Select to end repeat" : "Vyberte koniec opakovania",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Táto udalosť je výnimkou v opakovanej udalosti. Nie je možné k nej pridať opakovanie.",
    "first" : "prvý",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Zmeny v opakovanej udalosti budú mať vplyv len na túto a budúce udalosti.",
    "Repeat every" : "Opakovať každý",
    "By day of the month" : "Podľa dňa v mesiaci",
    "On the" : "V",
    "_day_::_days_" : ["deň","dni","dní","dní"],
    "_week_::_weeks_" : ["týždeň","týždne","týždňov","týždňov"],
    "_month_::_months_" : ["mesiac","mesiace","mesiacov","mesiacov"],
    "_year_::_years_" : ["rok","roky","rokov","rokov"],
    "On specific day" : "V zadaný deň",
    "weekday" : "deň v týždni",
    "weekend day" : "deň cez víkend",
    "Does not repeat" : "Neopakuje sa",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Definícia opakovania tejto udalosti nie je Nextcloud plne podporovaná. Ak upravíte možnosti opakovania, niektoré opakovania sa môžu stratiť.",
    "No rooms or resources yet" : "Žiadne miestnosti alebo zdroje",
    "Resources" : "Zdroje",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} miesto","{seatingCapacity} miest","{seatingCapacity} miest","{seatingCapacity} miest"],
    "Add resource" : "Pridať zdroj",
    "Has a projector" : "Má projektor",
    "Has a whiteboard" : "Má tabuľu",
    "Wheelchair accessible" : "Bezbariérový prístup",
    "Remove resource" : "Odstrániť zdroj",
    "Search for resources or rooms" : "Hľadať zdroje alebo miestnosti",
    "available" : "dostupné",
    "unavailable" : "nedostupné",
    "Show all rooms" : "Zobraziť všetky miestnosti",
    "Projector" : "Projektor",
    "Whiteboard" : "Tabuľa",
    "Room type" : "Typ miestnosti",
    "Any" : "Akékoľvek",
    "Minimum seating capacity" : "Minimálna kapacita miest na sedenie",
    "More details" : "Viac podrobností",
    "Update this and all future" : "Aktualizovať tento a všetky budúce",
    "Update this occurrence" : "Aktualizovať tento výskyt",
    "Public calendar does not exist" : "Verejný kalendár neexistuje",
    "Maybe the share was deleted or has expired?" : "Možno bolo zrušené zdieľanie alebo skončila jeho platnosť?",
    "Remove participant" : "Odstrániť účastníka",
    "Yes" : "Áno",
    "No" : "Nie",
    "Maybe" : "Možno",
    "None" : "Žiadne",
    "Create" : "Vytvoriť",
    "from {formattedDate}" : "od {formattedDate}",
    "to {formattedDate}" : "do {formattedDate}",
    "on {formattedDate}" : "{formattedDate}",
    "from {formattedDate} at {formattedTime}" : "od {formattedDate} o {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "do {formattedDate} o {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "{formattedDate} o {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} o {formattedTime}",
    "Please enter a valid date" : "Zadajte platný dátum",
    "Please enter a valid date and time" : "Zadajte platný dátum a čas",
    "Select a time zone" : "Vybrať časové pásmo",
    "Please select a time zone:" : "Prosím vyberte časovú zónu:",
    "Pick a time" : "Vyberte čas",
    "Pick a date" : "Vyberte dátum",
    "Type to search time zone" : "Písaním nájdete časovú zónu",
    "Global" : "Globálne",
    "Holidays in {region}" : "Sviatky v/na {region}",
    "An error occurred, unable to read public calendars." : "Vyskytla sa chyba, nie je možné načítať verejné kalendáre.",
    "An error occurred, unable to subscribe to calendar." : "Vyskytla sa chyba, nie je možné prihlásiť sa ku kalendáru.",
    "Public holiday calendars" : "Kalendár verejných sviatkov",
    "Public calendars" : "Verejné kalendáre",
    "No valid public calendars configured" : "Žiadne platné verejné kalendáre nie sú nakonfigurované.",
    "Speak to the server administrator to resolve this issue." : "Kontaktuje administrátora servera, aby ste vyriešili túto situáciu.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Verejné sviatky sú poskytované Thunderbirdom. Kalendárne údaje budú stiahnuté z {website}.",
    "By {authors}" : "Od {authors}",
    "Subscribed" : "Prihlásený na odber",
    "Subscribe" : "Odoberať",
    "Could not fetch slots" : "Nepodarilo sa získať sloty",
    "Select a date" : "Vybrať dátum",
    "Select slot" : "Vybrať slot",
    "No slots available" : "Žiadny slot nie je k dispozícii",
    "The slot for your appointment has been confirmed" : "Slot pre váš termín bol potvrdený",
    "Appointment Details:" : "Podrobnosti o stretnutí",
    "Time:" : "Čas:",
    "Booked for:" : "Rezervované na:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Ďakujem. Vaša rezervácia od {startDate} do {endDate} bola potvrdená.",
    "Book another appointment:" : "Rezervovať ďalšie stretnutie:",
    "See all available slots" : "Zobraziť všetky dostupné sloty",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Časový úsek pre vaše stretnutie od {startDate} do {endDate} už nie je k dispozícii.",
    "Please book a different slot:" : "Prosím rezervujte si iný slot:",
    "Book an appointment with {name}" : "Rezervovať stretnutie s názvom {name}",
    "No public appointments found for {name}" : "Nenašli sa žiadne verejné stretnutia pre {name}",
    "Personal" : "Osobné",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Automatická detekcia časového pásma určila, že vaše časové pásmo je UTC.\nJe to pravdepodobne výsledok bezpečnostných opatrení vášho webového prehliadača.\nNastavte časové pásmo manuálne v nastaveniach kalendára.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Vami nastavené časové pásmo ({timezoneId}) sa nenašlo. Nastavené bolo UTC.\nZmeňte v nastaveniach svoje časové pásmo a nahláste tento problém.",
    "Availability of {displayName}" : "Dostupnosť {displayName}",
    "Edit event" : "Upraviť udalosť",
    "Event does not exist" : "Udalosť neexistuje",
    "Duplicate" : "Duplikát",
    "Delete this occurrence" : "Vymazať tento výskyt",
    "Delete this and all future" : "Vymazať toto a všetko budúce",
    "All day" : "Celý deň",
    "Modifications wont get propagated to the organizer and other attendees" : "Úpravy sa nedostanú k organizátorovi a ostatným účastníkom",
    "Managing shared access" : "Spravovanie zdieľaného prístupu",
    "Deny access" : "Odmietnuť prístup",
    "Invite" : "Pozvať",
    "_User requires access to your file_::_Users require access to your file_" : ["Užívateľ žiada prístup k vášmu súboru.","Užívatelia žiadajú prístup k vášmu súboru.","Užívatelia žiadajú prístup k vášmu súboru.","Užívatelia žiadajú prístup k vášmu súboru."],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Príloha vyžadujúca zdieľaný prístup","Prílohy vyžadujúce zdieľaný prístup","Prílohy vyžadujúce zdieľaný prístup","Prílohy vyžadujúce zdieľaný prístup"],
    "Untitled event" : "Udalosť bez názvu",
    "Close" : "Zavrieť",
    "Modifications will not get propagated to the organizer and other attendees" : "Úpravy sa nedostanú medzi organizátorov a ostatných účastníkov",
    "Selected" : "Vybrané",
    "Title" : "Názov",
    "30 min" : "30 minút",
    "Participants" : "Účastníci",
    "Submit" : "Odoslať",
    "Subscribe to {name}" : "Prihlásiť sa na odber {name}",
    "Export {name}" : "Exportovať {name}",
    "Show availability" : "Zobraziť dostupnosť",
    "Anniversary" : "Výročie",
    "Appointment" : "Stretnutie",
    "Business" : "Služobné",
    "Education" : "Výuka",
    "Holiday" : "Sviatok",
    "Meeting" : "Porada",
    "Miscellaneous" : "Rôzne",
    "Non-working hours" : "Mimopracovné hodiny",
    "Not in office" : "Mimo kancelárie",
    "Phone call" : "Telefonát",
    "Sick day" : "Práceneschopnosť",
    "Special occasion" : "Špeciálna príležitosť",
    "Travel" : "Cestovanie",
    "Vacation" : "Dovolenka",
    "Midnight on the day the event starts" : "Najbližšia polnoc pred začiatkom udalosti",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n deň pred udalosťou o {formattedHourMinute}","%n dni pred udalosťou o {formattedHourMinute}","%n dní pred udalosťou o {formattedHourMinute}","%n dní pred udalosťou o {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n týždeň pred udalosťou o {formattedHourMinute}","%n týždne pred udalosťou o {formattedHourMinute}","%n týždňov pred udalosťou o {formattedHourMinute}","%n týždňov pred udalosťou o {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "v deň udalosti o {formattedHourMinute}",
    "at the event's start" : "na začiatku udalosti",
    "at the event's end" : "na konci udalosti",
    "{time} before the event starts" : "{time} pred začiatkom udalosti",
    "{time} before the event ends" : "{time} pred koncom udalosti",
    "{time} after the event starts" : "{time} po začiatku udalosti",
    "{time} after the event ends" : "{time} po skončení udalosti",
    "on {time}" : "o {time}",
    "on {time} ({timezoneId})" : "o {time} ({timezoneId})",
    "Week {number} of {year}" : "Týždeň {number} roku {year}",
    "Daily" : "Denne",
    "Weekly" : "Týždenne",
    "Monthly" : "Mesačne",
    "Yearly" : "Ročne",
    "_Every %n day_::_Every %n days_" : ["Každý deň","Každé %n dni","Každých %n dní","Každých %n dní"],
    "_Every %n week_::_Every %n weeks_" : ["Každý týždeň","Každé %n týždne","Každých %n týždňov","Každých %n týždňov"],
    "_Every %n month_::_Every %n months_" : ["Každý mesiac","Každé %n mesiace","Každých %n mesiacov","Každých %n mesiacov"],
    "_Every %n year_::_Every %n years_" : ["Každý rok","Každé %n rokov","Každých %n rokov","Každých %n rokov"],
    "_on {weekday}_::_on {weekdays}_" : ["v {weekday}","v {weekday}","v {weekday}","v {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["v dni {dayOfMonthList}","v dňoch {dayOfMonthList}","v dňoch {dayOfMonthList}","v dňoch {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "každý mesiac {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {dayOfMonthList}" : "v {monthNames} dňa {dayOfMonthList}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "v {monthNames} v {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "do {untilDate}",
    "_%n time_::_%n times_" : ["%n raz","%n raz","%n raz","%n raz"],
    "second" : "druhý",
    "third" : "tretie",
    "fourth" : "štvrté",
    "fifth" : "piate",
    "second to last" : "po koľko sekúnd",
    "last" : "posledné",
    "Untitled task" : "Úloha bez názvu",
    "Please ask your administrator to enable the Tasks App." : "Požiadajte svojho správcu, aby povolil aplikáciu Úlohy.",
    "You are not allowed to edit this event as an attendee." : "Ako účastník nemáte povolené upravovať túto udalosť.",
    "W" : "T",
    "%n more" : "%n ďalších",
    "No events to display" : "Žiadne udalosti k zobrazeniu",
    "All participants declined" : "Všetci účastníci odmietli",
    "Please confirm your participation" : "Prosím, potvrďte svoju účasť",
    "You declined this event" : "Odmietli ste túto udalosť",
    "Your participation is tentative" : "Vaša účasť je predbežná",
    "_+%n more_::_+%n more_" : ["+%n ďalší","+%n ďalší","+%n ďalší","+%n ďalších"],
    "No events" : "Žiadne udalosti",
    "Create a new event or change the visible time-range" : "Vytvorte novú udalosť alebo zmeňte viditeľný časový rozsah",
    "Failed to save event" : "Nepodarilo sa uložiť udalosť.",
    "It might have been deleted, or there was a typo in a link" : "Buď to bolo zmazané, alebo je chyba v odkaze",
    "It might have been deleted, or there was a typo in the link" : "Buď to bolo zmazané, alebo je chyba v odkaze",
    "Meeting room" : "Zasadacia miestnosť",
    "Lecture hall" : "Školiaca miestnosť",
    "Seminar room" : "Seminárna miestnosť",
    "Other" : "Iné",
    "When shared show" : "Pri zdieľaní zobraziť",
    "When shared show full event" : "Pri zdieľaní zobraziť udalosť úplne",
    "When shared show only busy" : "Pri zdieľaní zobraziť len zaneprázdnený",
    "When shared hide this event" : "Pri zdieľaní skryť udalosť",
    "Add a location" : "Zadajte umiestnenie",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Pridať popis\n\n- O čom je toto stretnutie\n- Body programu\n- Všetko, čo si účastníci musia pripraviť",
    "Status" : "Stav",
    "Confirmed" : "Potvrdené",
    "Canceled" : "Zrušené",
    "Confirmation about the overall status of the event." : "Potvrdenie o celkovom stave udalosti.",
    "Show as" : "Zobrazovať ako",
    "Take this event into account when calculating free-busy information." : "Zohľadniť túto udalosť pri určovaní zaneprázdnených/voľných hodín. ",
    "Categories" : "Kategórie",
    "Categories help you to structure and organize your events." : "Kategórie pomáhajú udržiavať prehľad v udalostiach a štruktúrovať ich.",
    "Search or add categories" : "Hľadať alebo pridať kategórie",
    "Add this as a new category" : "Pridať ako novú kategóriu",
    "Custom color" : "Vlastná farba",
    "Special color of this event. Overrides the calendar-color." : "Špeciálna farba tejto udalosti. Prepíše farbu kalendára.",
    "Error while sharing file" : "Pri zdieľaní súboru došlo k chybe",
    "Error while sharing file with user" : "Chyba pri zdieľaní súboru používateľovi",
    "Attachment {fileName} already exists!" : "Príloha {fileName} už existuje!",
    "An error occurred during getting file information" : "Vyskytla sa chyba pri získavaní informácií o súbore.",
    "An error occurred, unable to delete the calendar." : "Vyskytla sa chyba, nie je možné zmazať kalendár.",
    "Imported {filename}" : "Importované {filename}",
    "This is an event reminder." : "Toto je pripomienka udalosti.",
    "Error while parsing a PROPFIND error" : "Chyba pri parsovaní chyby PROPFIND",
    "Appointment not found" : "Stretnutie nebolo nájdené",
    "User not found" : "Užívateľ nebol nájdený",
    "Hidden" : "Skryté",
    "can edit" : "môže upraviť",
    "Calendar name …" : "Názov kalendára ...",
    "Default attachments location" : "Predvolené umiestnenie príloh",
    "Automatic ({detected})" : "Automaticky ({detected})",
    "Shortcut overview" : "Stručný prehľad",
    "CalDAV link copied to clipboard." : "Odkaz CalDAV skopírovaný do schránky.",
    "CalDAV link could not be copied to clipboard." : "Odkaz CalDAV nebolo možné skopírovať do schránky.",
    "Enable birthday calendar" : "Povoliť narodeninový kalendár",
    "Show tasks in calendar" : "Zobraziť úlohy v kalendári",
    "Enable simplified editor" : "Povoliť zjednodušený editor",
    "Limit the number of events displayed in the monthly view" : "Obmedziť počet udalostí zobrazených v mesačnom pohľade",
    "Show weekends" : "Zobraziť víkendy",
    "Show week numbers" : "Zobraziť čísla týždňov",
    "Time increments" : "Časové prírastky",
    "Default calendar for incoming invitations" : "Predvolený kalendár pre prichádzajúce pozvánky",
    "Copy primary CalDAV address" : "Kopírovať primárnu CalDAV adresu",
    "Copy iOS/macOS CalDAV address" : "Kopírovať iOS/macOS CalDAV adresu",
    "Personal availability settings" : "Osobné nastavenia dostupnosti",
    "Show keyboard shortcuts" : "Zobraziť klávesové skratky",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} pozvaných, {confirmedCount} potvrdených",
    "Successfully appended link to talk room to location." : "Do popisu bol úspešne pridaný odkaz na miestnosť v Talk /Rozhovore/.",
    "Successfully appended link to talk room to description." : "Do popisu bol úspešne pridaný odkaz na miestnosť v Talk /Rozhovore/",
    "Error creating Talk room" : "Chyba pri vytváraní miestnosti v Talk /Rozhovore/",
    "_%n more guest_::_%n more guests_" : ["%n ďalší hosť","%n ďalší hostia","%n ďalších hostí","%n ďalších hostí"],
    "The visibility of this event in shared calendars." : "Viditeľnosť tejto udalosti v zdieľaných kalendároch."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
