OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "Korisnička sesija neočekivano je istekla",
    "Provided email-address is not valid" : "Unesena adresa e-pošte nije važeća",
    "%s has published the calendar »%s«" : "%s je objavio kalendar »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Došlo je do pogreške pri slanju poruke e-pošte. Obratite se svom administratoru.",
    "Successfully sent email to %1$s" : "Poruka e-pošte uspješno je poslana na %1$s",
    "Hello," : "Pozdrav,",
    "We wanted to inform you that %s has published the calendar »%s«." : "htjeli bismo vas obavijestiti da je %s objavio kalendar »%s«.",
    "Open »%s«" : "Otvori »%s«",
    "Cheers!" : "Bok!",
    "Upcoming events" : "Nadolazeći događaji",
    "No more events today" : "Danas više nema događaja",
    "No upcoming events" : "Nema nadolazećih događaja",
    "Calendar" : "Kalendar",
    "Appointments" : "Dogovori",
    "Confirm" : "Potvrdi",
    "Description:" : "Opis:",
    "Date:" : "Datum:",
    "Where:" : "Gdje:",
    "Location:" : "Lokacija:",
    "Duration:" : "Trajanje:",
    "A Calendar app for Nextcloud" : "Aplikacija Kalendar za Nextcloud",
    "Previous day" : "Prethodni dan",
    "Previous week" : "Prethodni tjedan",
    "Previous month" : "Prethodni mjesec",
    "Next day" : "Sljedeći dan",
    "Next week" : "Sljedeći tjedan",
    "Next year" : "Sljedeće godine",
    "Next month" : "Sljedeći mjesec",
    "Today" : "Danas",
    "Day" : "Dan",
    "Week" : "Tjedan",
    "Month" : "Mjesec",
    "Year" : "Godina",
    "List" : "Popis",
    "Preview" : "Pretpregled",
    "Copy link" : "Kopiraj poveznicu",
    "Edit" : "Uredi",
    "Delete" : "Izbriši",
    "Create new" : "Stvori novi",
    "An error occurred, unable to change visibility of the calendar." : "Došlo je do pogreške, nije moguće promijeniti vidljivost kalendara.",
    "Untitled calendar" : "Kalendar bez naslova",
    "Shared with you by" : "S vama podijelio",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Prekid dijeljenja kalendara za {countdown} sekundu","Prekid dijeljenja kalendara za {countdown} sekundi","Prekid dijeljenja kalendara za {countdown} sekundi"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Brisanje kalendara za {countdown} sekundu","Brisanje kalendara za {countdown} sekundi","Brisanje kalendara za {countdown} sekundi"],
    "An error occurred, unable to create the calendar." : "Došlo je do pogreške, nije moguće stvoriti kalendar.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Unesite valjanu poveznicu (mora početi s http://, https://, webcal:// ili webcals://)",
    "Calendars" : "Kalendari",
    "New calendar" : "Novi kalendar",
    "Creating calendar …" : "Stvaranje kalendara...",
    "New calendar with task list" : "Novi kalendar s popisom zadataka",
    "New subscription from link (read-only)" : "Nova pretplata putem poveznice (samo za čitanje)",
    "Creating subscription …" : "Stvaranje pretplate...",
    "Calendar link copied to clipboard." : "Poveznica kalendara kopirana je u međuspremnik.",
    "Calendar link could not be copied to clipboard." : "Poveznica kalendara nije kopirana u međuspremnik.",
    "Copy subscription link" : "Kopiraj poveznicu pretplate",
    "Copying link …" : "Kopiranje poveznice...",
    "Copied link" : "Poveznica je kopirana",
    "Could not copy link" : "Kopiranje poveznice nije uspjelo",
    "Export" : "Izvoz",
    "Untitled item" : "Stavka bez naslova",
    "Could not load deleted calendars and objects" : "Učitavanje izbrisanih kalendara i objekata nije uspjelo",
    "Could not restore calendar or event" : "Vraćanje kalendara ili događaja nije uspjelo",
    "Do you really want to empty the trash bin?" : "Želite li zaista isprazniti kantu za smeće?",
    "Empty trash bin" : "Isprazni kantu za smeće",
    "Trash bin" : "Kanta za smeće",
    "Name" : "Naziv",
    "Deleted" : "Izbrisano",
    "Restore" : "Vrati",
    "Delete permanently" : "Trajno izbrišite",
    "Could not update calendar order." : "Ažuriranje redoslijeda kalendara nije uspjelo.",
    "Deck" : "Deck",
    "Internal link" : "Interna poveznica",
    "Copy internal link" : "Kopiraj internu poveznicu",
    "An error occurred, unable to publish calendar." : "Došlo je do pogreške, nije moguće objaviti kalendar.",
    "An error occurred, unable to send email." : "Došlo je do pogreške, nije moguće poslati poruku e-pošte.",
    "Embed code copied to clipboard." : "Šifra za ugradnju kopirana je u međuspremnik.",
    "Embed code could not be copied to clipboard." : "Šifru za ugradnju nije moguće kopirati u međuspremnik.",
    "Unpublishing calendar failed" : "Neuspješan prekid objave kalendara",
    "Share link" : "Dijeli poveznicu",
    "Copy public link" : "Kopiraj javnu poveznicu",
    "Send link to calendar via email" : "Pošalji poveznicu na kalendar putem e-pošte",
    "Enter one address" : "Unesi jednu adresu",
    "Sending email …" : "Slanje e-pošte u tijeku...",
    "Copy embedding code" : "Kopiraj šifru za ugradnju",
    "Copying code …" : "Kopiranje šifre...",
    "Copied code" : "Šifra je kopirana",
    "Could not copy code" : "Kopiranje šifre nije uspjelo",
    "Delete share link" : "Izbriši poveznicu dijeljenja",
    "Deleting share link …" : "Brisanje poveznice dijeljenja...",
    "An error occurred, unable to change the permission of the share." : "Došlo je do pogreške, nije moguće promijeniti dopuštenje dijeljenja.",
    "Unshare with {displayName}" : "Prekid dijeljenja s {displayName}",
    "Share with users or groups" : "Dijelite s korisnicima ili grupama",
    "No users or groups" : "Nema korisnika ili grupa",
    "Unshare from me" : "Prekid dijeljenja sa mnom",
    "Save" : "Spremi",
    "View" : "Pregledaj",
    "Import calendars" : "Uvezi kalendare",
    "Please select a calendar to import into …" : "Odaberite kalendar za uvoz...",
    "Filename" : "Naziv datoteke",
    "Calendar to import into" : "Kalendar za uvoz",
    "Cancel" : "Odustani",
    "_Import calendar_::_Import calendars_" : ["Uvezi kalendar","Uvezi kalendare","Uvezi kalendare"],
    "Attachments folder" : "Mapa s privicima",
    "{filename} could not be parsed" : "Nije moguće parsirati {filename}",
    "No valid files found, aborting import" : "Nisu pronađene važeće datoteke, uvoz je otkazan",
    "Import partially failed. Imported {accepted} out of {total}." : "Djelomično neuspješan uvoz. Uvezeno {accepted} od {total}.",
    "Automatic" : "Automatsko",
    "Automatic ({timezone})" : "Automatski ({timezone})",
    "New setting was not saved successfully." : "Nova postavka nije uspješno spremljena.",
    "Timezone" : "Vremenska zona",
    "Navigation" : "Navigacija",
    "Previous period" : "Prethodno razdoblje",
    "Next period" : "Sljedeće razdoblje",
    "Views" : "Prikazi",
    "Day view" : "Dnevni prikaz",
    "Week view" : "Tjedni prikaz",
    "Month view" : "Mjesečni prikaz",
    "List view" : "Prikaz popisa",
    "Actions" : "Radnje",
    "Create event" : "Stvori događaj",
    "Show shortcuts" : "Prikaži prečace",
    "or" : "ili",
    "No reminder" : "Nema podsjetnika",
    "General" : "Općenito",
    "Appearance" : "Izgled",
    "Editing" : "Uređivanje",
    "Default reminder" : "Zadani podsjetnik",
    "Files" : "Datoteke",
    "Update" : "Ažuriraj",
    "Location" : "Lokacija",
    "Description" : "Opis",
    "Visibility" : "Vidljivost",
    "Duration" : "Trajanje",
    "to" : "do",
    "Delete slot" : "Izbriši mjesto",
    "Add" : "Dodaj",
    "Monday" : "Ponedjeljak",
    "Tuesday" : "Utorak",
    "Wednesday" : "Srijeda",
    "Thursday" : "Četvrtak",
    "Friday" : "Petak",
    "Saturday" : "Subota",
    "Sunday" : "Nedjelja",
    "Your email address" : "Vaša adresa e-pošte",
    "Select conversation" : "Odaberi razgovor",
    "on" : "na",
    "at" : "u",
    "before at" : "prije u",
    "Notification" : "Obavijest",
    "Email" : "E-pošta",
    "Audio notification" : "Zvučna obavijest",
    "Other notification" : "Druga obavijest",
    "Relative to event" : "Povezano s događajem",
    "On date" : "Na datum",
    "Edit time" : "Uredi vrijeme",
    "Save time" : "Spremi vrijeme",
    "Remove reminder" : "Ukloni podsjetnik",
    "Add reminder" : "Dodaj podsjetnik",
    "seconds" : "sekunda",
    "minutes" : "minuta",
    "hours" : "sati",
    "days" : "dani",
    "weeks" : "tjedana",
    "Choose a file to add as attachment" : "Izaberi datoteku kao privitak",
    "Choose a file to share as a link" : "Izaberi datoteku za dijeljenje putem poveznice",
    "Proceed" : "Nastavi",
    "Delete file" : "Izbriši datoteku",
    "Available" : "Dostupno",
    "Not available" : "Nije dostupno",
    "{organizer} (organizer)" : "{organizer} (organizator)",
    "Availability of attendees, resources and rooms" : "Raspoloživost sudionika, resursa i soba",
    "Out of office" : "Izvan ureda",
    "Attendees:" : "Polaznici:",
    "Room name" : "Naziv sobe",
    "Free" : "Dostupno",
    "Busy (tentative)" : "Zauzeto (uvjetno)",
    "Busy" : "Zauzeto",
    "Unknown" : "Nepoznato",
    "Accept" : "Prihvati",
    "Decline" : "Odbij",
    "Tentative" : "Uvjetno",
    "No attendees yet" : "Još nema sudionika",
    "Attendees" : "Sudionici",
    "Remove group" : "Ukloni grupu",
    "Remove attendee" : "Ukloni sudionika",
    "Chairperson" : "Predsjednik",
    "Required participant" : "Obavezan sudionik",
    "Optional participant" : "Neobavezan sudionik",
    "Non-participant" : "Nije sudionik",
    "No match found" : "Nema podudaranja",
    "(organizer)" : "(organizator)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "[linkopen]Dodajte svoju adresu e-pošte u osobne postavke[linkclose] za slanje pozivnica i upravljanje odgovorima.",
    "Remove color" : "Ukloni boju",
    "Event title" : "Naslov događaja",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Nije moguće mijenjati cjelodnevne postavke za događaje koji su dio skupa ponavljanja.",
    "From" : "Od",
    "To" : "Do",
    "Repeat" : "Ponovi",
    "_time_::_times_" : ["put","puta","puta"],
    "never" : "nikad",
    "on date" : "na datum",
    "after" : "nakon",
    "End repeat" : "Završi ponavljanje",
    "Select to end repeat" : "Odaberi za završetak ponavljanja",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Ovaj događaj je iznimka ponavljanja skupa ponavljanja. Ne možete mu dodati pravilo ponavljanja.",
    "first" : "prvi",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Promjene pravila ponavljanja primjenjuju se na ovo i sva buduća ponavljanja.",
    "Repeat every" : "Ponovi svakih",
    "By day of the month" : "Do dana u mjesecu",
    "On the" : "Na",
    "_day_::_days_" : ["dan","dana","dana"],
    "_week_::_weeks_" : ["tjedan","tjedana","tjedana"],
    "_month_::_months_" : ["mjesec","mjeseci","mjeseci"],
    "_year_::_years_" : ["godinu","godina","godina"],
    "weekday" : "dan u tjednu",
    "weekend day" : "dan vikendom",
    "Does not repeat" : "Ne ponavlja se",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Nextcloud ne podržava u potpunosti definiciju ponavljanja za ovaj događaj. Ako uredite mogućnosti ponavljanja, može doći do gubitka određenih ponavljanja.",
    "No rooms or resources yet" : "Još nema soba ili resursa",
    "Resources" : "Resursi",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} sjedalo","{seatingCapacity} sjedala","{seatingCapacity} sjedala"],
    "Add resource" : "Dodaj resurs",
    "Has a projector" : "Ima projektor",
    "Has a whiteboard" : "Ima ploču za pisanje",
    "Wheelchair accessible" : "Pristupačno za invalidska kolica",
    "Remove resource" : "Ukloni resurs",
    "Search for resources or rooms" : "Potražite resurse ili sobe",
    "available" : "dostupno",
    "unavailable" : "nedostupno",
    "Projector" : "Projektor",
    "Whiteboard" : "Ploča za pisanje",
    "Room type" : "Vrsta sobe",
    "Any" : "Bilo koji",
    "Minimum seating capacity" : "Minimalni broj sjedala",
    "Update this and all future" : "Ažuriraj ovo i sva buduća ponavljanja",
    "Update this occurrence" : "Ažuriraj ovo ponavljanje",
    "Public calendar does not exist" : "Javni kalendar ne postoji",
    "Maybe the share was deleted or has expired?" : "Možda je dijeljenje izbrisano ili je isteklo?",
    "Yes" : "Da",
    "No" : "Ne",
    "None" : "Nema",
    "Create" : "Stvori",
    "from {formattedDate}" : "od {formattedDate}",
    "to {formattedDate}" : "do {formattedDate}",
    "on {formattedDate}" : "{formattedDate}",
    "from {formattedDate} at {formattedTime}" : "od {formattedDate} u {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "do {formattedDate} u {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "dana {formattedDate} u {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} u {formattedTime}",
    "Please enter a valid date" : "Unesite važeći datum",
    "Please enter a valid date and time" : "Unesite važeći datum i vrijeme",
    "Please select a time zone:" : "Odaberite vremensku zonu:",
    "Pick a time" : "Odaberi vrijeme",
    "Pick a date" : "Odaberi datum",
    "Type to search time zone" : "Upišite za pretraživanje vremenskih zona",
    "Global" : "Globalno",
    "Subscribed" : "Pretplaćen",
    "Subscribe" : "Preplata",
    "Time:" : "Vrijeme:",
    "Personal" : "Osobno",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Značajka automatskog otkrivanja vremenske zone utvrdila je vašu vremensku zonu kao UTC.\nVjerojatno zbog sigurnosnih mjera vašeg internetskog preglednika.\nRučno postavite vremensku zonu u postavkama kalendara.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Nije pronađena vaša konfigurirana vremenska zona ({timezoneId}). Postavka vremenske zone vraćena je na UTC.\nPromijenite vremensku zonu u postavkama i prijavite ovu poteškoću.",
    "Edit event" : "Uredi događaj",
    "Event does not exist" : "Događaj ne postoji",
    "Delete this occurrence" : "Izbriši ovo ponavljanje",
    "Delete this and all future" : "Izbriši ovo i sva buduća ponavljanja",
    "All day" : "Cijeli dan",
    "Invite" : "Poziv",
    "Untitled event" : "Događaj bez naslova",
    "Close" : "Zatvori",
    "Selected" : "Odabrano",
    "Title" : "Naslov",
    "Participants" : "Sudionici",
    "Submit" : "Šalji",
    "Subscribe to {name}" : "Pretplati se na {name}",
    "Anniversary" : "Godišnjica",
    "Appointment" : "Dogovor",
    "Business" : "Poslovno",
    "Education" : "Obrazovno",
    "Holiday" : "Blagdan/praznik",
    "Meeting" : "Sastanak",
    "Miscellaneous" : "Razno",
    "Non-working hours" : "Neradni sati",
    "Not in office" : "Nije u uredu",
    "Phone call" : "Telefonski poziv",
    "Sick day" : "Bolovanje",
    "Special occasion" : "Poseban događaj",
    "Travel" : "Putovanje",
    "Vacation" : "Odmor",
    "Midnight on the day the event starts" : "Ponoć na dan početka događaja",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n dan prije početka događaja u {formattedHourMinute}","%n dana prije početka događaja u {formattedHourMinute}","%n dana prije početka događaja u {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n tjedan prije početka događaja u {formattedHourMinute}","%n tjedana prije početka događaja u {formattedHourMinute}","%n tjedana prije početka događaja u {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "na dan događaja u {formattedHourMinute}",
    "at the event's start" : "na početku događaja",
    "at the event's end" : "na završetku događaja",
    "{time} before the event starts" : "{time} prije početka događaja",
    "{time} before the event ends" : "{time} prije završetka događaja",
    "{time} after the event starts" : "{time} nakon početka događaja",
    "{time} after the event ends" : "{time} nakon završetka događaja",
    "on {time}" : "u {time}",
    "on {time} ({timezoneId})" : "u {time} ({timezoneId})",
    "Week {number} of {year}" : "{number} tjedan {year}",
    "Daily" : "Svaki dan",
    "Weekly" : "Svaki tjedan",
    "Monthly" : "Svaki mjesec",
    "Yearly" : "Svake godine",
    "_Every %n day_::_Every %n days_" : ["Svaki %n dan","Svakih %n dana","Svakih %n dana"],
    "_Every %n week_::_Every %n weeks_" : ["Svaki %n tjedan","Svakih %n tjedana","Svakih %n tjedana"],
    "_Every %n month_::_Every %n months_" : ["Svaki %n mjesec","Svakih %n mjeseci","Svakih %n mjeseci"],
    "_Every %n year_::_Every %n years_" : ["Svake %n godine","Svakih %n godina","Svakih %n godina"],
    "_on {weekday}_::_on {weekdays}_" : ["{weekday}","{weekdays}","{weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["na dan {dayOfMonthList}","na dane {dayOfMonthList}","na dane {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "{ordinalNumber} {byDaySet}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "u {monthNames} {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "do {untilDate}",
    "_%n time_::_%n times_" : ["%n put","%n puta","%n puta"],
    "second" : "drugi",
    "third" : "treći",
    "fourth" : "četvrti",
    "fifth" : "peti",
    "second to last" : "predzadnji",
    "last" : "zadnji",
    "Untitled task" : "Zadatak bez naslova",
    "Please ask your administrator to enable the Tasks App." : "Zatražite od administratora da omogući aplikaciju Tasks.",
    "W" : "W",
    "%n more" : "još %n",
    "No events to display" : "Nema događaja za prikaz",
    "_+%n more_::_+%n more_" : ["+%n više","+%n više","+%n više"],
    "No events" : "Nema događaja",
    "Create a new event or change the visible time-range" : "Stvorite novi događaj ili promijenite vidljivi vremenski raspon",
    "It might have been deleted, or there was a typo in a link" : "Možda je izbrisan ili postoji tipfeler u poveznici",
    "It might have been deleted, or there was a typo in the link" : "Možda je izbrisan ili postoji tipfeler u poveznici",
    "Meeting room" : "Soba za sastanke",
    "Lecture hall" : "Predavaonica",
    "Seminar room" : "Soba za seminare",
    "Other" : "Drugo",
    "When shared show" : "Kada se dijeli, prikaži",
    "When shared show full event" : "Kada se dijeli, prikaži cijeli događaj",
    "When shared show only busy" : "Kada se dijeli, prikaži samo zauzeto",
    "When shared hide this event" : "Kada se dijeli, sakrij događaj",
    "Add a location" : "Dodaj lokaciju",
    "Status" : "Status",
    "Confirmed" : "Potvrđeno",
    "Canceled" : "Otkazano",
    "Confirmation about the overall status of the event." : "Potvrda cjelokupnog statusa događaja.",
    "Show as" : "Prikaži kao",
    "Take this event into account when calculating free-busy information." : "Uzmite ovaj događaj u obzir pri izračunu informacija o dostupnosti i zauzeću.",
    "Categories" : "Kategorije",
    "Categories help you to structure and organize your events." : "Kategorije vam pomažu odrediti strukturu i organizirati događaj.",
    "Search or add categories" : "Pretraži ili dodaj kategorije",
    "Add this as a new category" : "Dodaj kao novu kategoriju",
    "Custom color" : "Prilagođena boja",
    "Special color of this event. Overrides the calendar-color." : "Posebna boja ovog događaja. Primjenjuje se umjesto boje kalendara.",
    "Error while sharing file" : "Pogreška pri dijeljenju datoteke",
    "An error occurred, unable to delete the calendar." : "Došlo je do pogreške, nije moguće izbrisati kalendar.",
    "Imported {filename}" : "Uvezena datoteka {filename}",
    "User not found" : "Korisnik nije pronađen",
    "Hidden" : "Skriveno",
    "can edit" : "uređivanje moguće",
    "Automatic ({detected})" : "Automatsko ({detected})",
    "Shortcut overview" : "Pregled prečaca",
    "CalDAV link copied to clipboard." : "Poveznica kalendara CalDAV kopirana je u međuspremnik.",
    "CalDAV link could not be copied to clipboard." : "Poveznica kalendara CalDAV nije kopirana u međuspremnik.",
    "Enable birthday calendar" : "Omogući kalendar rođendana",
    "Show tasks in calendar" : "Prikaži zadatke u kalendaru",
    "Enable simplified editor" : "Omogući jednostavan uređivač",
    "Show weekends" : "Prikaži vikende",
    "Show week numbers" : "Prikaži brojeve tjedana",
    "Time increments" : "Vremenski prirasti",
    "Copy primary CalDAV address" : "Kopiraj primarnu CalDAV adresu",
    "Copy iOS/macOS CalDAV address" : "Kopiraj iOS/macOS CalDAV adresu",
    "Show keyboard shortcuts" : "Prikaži tipkovne prečace",
    "Successfully appended link to talk room to description." : "Uspješno dodana poveznica na Talk sobu u opis.",
    "Error creating Talk room" : "Pogreška pri stvaranju Talk sobe",
    "The visibility of this event in shared calendars." : "Vidljivost ovog događaja u dijeljenim kalendarima."
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
