<?php return array(
    'root' => array(
        'name' => '__root__',
        'pretty_version' => 'v6.1.4',
        'version' => '6.1.4.0',
        'reference' => '58ef58674e25770e8a3849c0eafccea4e2745561',
        'type' => 'library',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => false,
    ),
    'versions' => array(
        '__root__' => array(
            'pretty_version' => 'v6.1.4',
            'version' => '6.1.4.0',
            'reference' => '58ef58674e25770e8a3849c0eafccea4e2745561',
            'type' => 'library',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'bamarni/composer-bin-plugin' => array(
            'pretty_version' => '1.8.2',
            'version' => '1.8.2.0',
            'reference' => '92fd7b1e6e9cdae19b0d57369d8ad31a37b6a880',
            'type' => 'composer-plugin',
            'install_path' => __DIR__ . '/../bamarni/composer-bin-plugin',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
