OC.L10N.register(
    "calendar",
    {
    "Calendar" : "நாட்காட்டி",
    "Location:" : "இடம்:",
    "Today" : "இன்று",
    "Week" : "வாரம்",
    "Month" : "மாதம்",
    "List" : "List",
    "Edit" : "தொகுக்க",
    "Delete" : "நீக்குக",
    "New calendar" : "புதிய நாட்காட்டி",
    "Export" : "ஏற்றுமதி",
    "Name" : "பெயர்",
    "Restore" : "மீட்டெடு",
    "Delete permanently" : "நிரந்தரமாக நீக்கவும்",
    "Share link" : "Share link",
    "Save" : "சேமிக்க ",
    "Cancel" : "இரத்து செய்க",
    "Actions" : "செயல்கள்",
    "General" : "பொதுவான",
    "Update" : "இற்றைப்படுத்தல்",
    "Location" : "இடம்",
    "Description" : "விவரிப்பு",
    "Add" : "சேர்க்க",
    "Monday" : "திங்கட்கிழமை",
    "Tuesday" : "செவ்வாய்க்கிழமை",
    "Wednesday" : "புதன்கிழமை",
    "Thursday" : "வியாழக்கிழமை",
    "Friday" : "வெள்ளிக்கிழமை",
    "Saturday" : "சனிக்கிழமை",
    "Sunday" : "ஞாயிற்றுக்கிழமை",
    "Your email address" : "உங்களுடைய மின்னஞ்சல் முகவரி",
    "Back" : "பின்னுக்கு",
    "Email" : "மின்னஞ்சல்",
    "Done" : "Done",
    "Unknown" : "தெரியாத",
    "Attendees" : "பங்கேற்பாளர்கள்",
    "Repeat" : "மீண்டும்",
    "never" : "ஒருபோதும்",
    "Yes" : "ஆம்",
    "No" : "இல்லை",
    "None" : "ஒன்றுமில்லை",
    "Personal" : "தனிப்பட்ட",
    "Close" : "மூடுக",
    "Selected" : "Selected",
    "Title" : "தலைப்பு",
    "Other" : "மற்றவை",
    "can edit" : "தொகுக்க முடியும்"
},
"nplurals=2; plural=(n != 1);");
