OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Внесената адреса на е-пошта е премногу долга",
    "User-Session unexpectedly expired" : "Корисничката-сесија е застарена",
    "Provided email-address is not valid" : "Адресата на е-пошта не е правилно внесена",
    "%s has published the calendar »%s«" : "%s Објави календар »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Неочекувана грешка при испраќање на е-пошта. Контактирајте го администраторот.",
    "Successfully sent email to %1$s" : "Успешно испратена е-пошта до %1$s",
    "Hello," : "Здраво,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Сакаме да те информираме дека %s објави календар »%s«.",
    "Open »%s«" : "Отвори »%s«",
    "Cheers!" : "Поздрав!",
    "Upcoming events" : "Престојни настани",
    "No more events today" : "Нема настани за денес",
    "No upcoming events" : "Нема престојни настани",
    "More events" : "Повеќе настани",
    "%1$s with %2$s" : "%1$s со %2$s",
    "Calendar" : "Календар",
    "New booking {booking}" : "Нова резервација {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) закажа состанок \"{config_display_name}\" на {date_time}.",
    "Appointments" : "Состаноци",
    "Schedule appointment \"%s\"" : "Закажан состанок \"%s\"",
    "Schedule an appointment" : "Закажи состанок",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : "Подготовки за %s",
    "Follow up for %s" : "Следи за %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Потребна е потврда за состанокот \"%s\" со %s",
    "Dear %s, please confirm your booking" : "Поритуван/а %s, ве молиме потврдете ја вашата резервација",
    "Confirm" : "Потврди",
    "Appointment with:" : "Состанок со:",
    "Description:" : "Опис:",
    "This confirmation link expires in %s hours." : "Овој линк за потврда истекува за %s часа.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "И покрај се, ако сакате да го откажете состанокот, контактирајте го организаторот со тоа што ќе одговорите на оваа е-пошта или посетете го неговиот профил",
    "Your appointment \"%s\" with %s has been accepted" : "Состанокот \"%s\" со %s е прифатен",
    "Dear %s, your booking has been accepted." : "Почитуван/а %s, Вашата резервација е прифатена.",
    "Appointment for:" : "Состанок за:",
    "Date:" : "Датум:",
    "You will receive a link with the confirmation email" : "Ќе добиете линк со потврда на е-пошта",
    "Where:" : "Каде: ",
    "Comment:" : "Коментар:",
    "You have a new appointment booking \"%s\" from %s" : "Имате нов закажан состанок \"%s\" од %s",
    "Dear %s, %s (%s) booked an appointment with you." : "Почитуван/а %s, %s (%s) закажа состанок со вас.",
    "%s has proposed a meeting" : "%s предложи состанок",
    "%s has updated a proposed meeting" : "%s го ажурираше предложениот состанок",
    "%s has canceled a proposed meeting" : "%s го откажа предложениот состанок",
    "Dear %s, a new meeting has been proposed" : "Почитуван/а %s, предложен е нов состанок",
    "Dear %s, a proposed meeting has been updated" : "Почитуван/а %s, предложениот состанок е ажуриран",
    "Dear %s, a proposed meeting has been cancelled" : "Почитуван/а %s, предложениот состанок е откажан",
    "Location:" : "Локација:",
    "Duration:" : "Времетраење:",
    "%1$s from %2$s to %3$s" : "%1$s од %2$s до %3$s",
    "Dates:" : "Датуми:",
    "Respond" : "Одговори",
    "A Calendar app for Nextcloud" : "Календар апликација за Nextcloud",
    "Previous day" : "Предходен ден",
    "Previous week" : "Предходна недела",
    "Previous year" : "Предходна година",
    "Previous month" : "Предходен месец",
    "Next day" : "Следен ден",
    "Next week" : "Следна недела",
    "Next year" : "Следна година",
    "Next month" : "Следен месец",
    "Create new event" : "Креирај нов настан",
    "Event" : "Настан",
    "Today" : "Денес",
    "Day" : "Ден",
    "Week" : "Недела",
    "Month" : "Месец",
    "Year" : "Година",
    "List" : "Лист",
    "Appointment link was copied to clipboard" : "Линкот за состанокот е копиран во клипборд",
    "Appointment link could not be copied to clipboard" : "Линкот за состанокот неможе за се копира во клипборд",
    "Preview" : "Преглед",
    "Copy link" : "Копирај линк",
    "Edit" : "Уреди",
    "Delete" : "Избриши",
    "Appointment schedules" : "Распоред на состаноци",
    "Create new" : "Креирај нова",
    "Disable calendar \"{calendar}\"" : "Оневозможи календар \"{calendar}\"",
    "Disable untitled calendar" : "Оневозможи неименуван календар",
    "Enable calendar \"{calendar}\"" : "Овозможи календар \"{calendar}\"",
    "Enable untitled calendar" : "Овозможи неименуван календар",
    "An error occurred, unable to change visibility of the calendar." : "Настана грешка, неможе да се промени видливоста на календарот.",
    "Untitled calendar" : "Неименуван календар",
    "Shared with you by" : "Споделено со вас од",
    "Edit and share calendar" : "Уреди и сподели календар",
    "Edit calendar" : "Уреди календар",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Отстранување на споделување на календар за 1 секунда","Отстранување на споделување на календар за {countdown} секунди"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Бришење на календарот за 1 секунда","Бришење на календарот за {countdown} секунди"],
    "An error occurred, unable to create the calendar." : "Настана грешка, неможе да се креира календар.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Внесете валиден линк (започнувајчи со http://, https://, webcal://, или webcals://)",
    "Calendars" : "Календари",
    "Add new" : "Додади нов",
    "New calendar" : "Нов календар",
    "Name for new calendar" : "Име за нов календар",
    "Creating calendar …" : "Креирање календар …",
    "New calendar with task list" : "Нов календар со листа на задачи",
    "New subscription from link (read-only)" : "Нова претплата од линк (само за читање)",
    "Creating subscription …" : "Креирање претплата  …",
    "Add public holiday calendar" : "Додади календар со државни празници",
    "Add custom public calendar" : "Додади сопствен јавен календар",
    "Calendar link copied to clipboard." : "Линк до календарот е копиран во клипборд.",
    "Calendar link could not be copied to clipboard." : "Линк до календарот неможе да се копира во клипборд.",
    "Copy subscription link" : "Копирај линк за претплата",
    "Copying link …" : "Копирање линк …",
    "Copied link" : "Линкот е копиран",
    "Could not copy link" : "Неможе да се копира линкот",
    "Export" : "Извези",
    "Untitled item" : "Неименуваи работи",
    "Unknown calendar" : "Непознат календар",
    "Could not load deleted calendars and objects" : "Неможат да се вчитаат избришаните календари и елементи",
    "Could not delete calendar or event" : "Неможе да избришете календар или настан",
    "Could not restore calendar or event" : "Неможе да се врати календар или настан",
    "Do you really want to empty the trash bin?" : "Дали навистина сакате да ја испразните kорпаta за отпадоци?",
    "Empty trash bin" : "Испразни ја корпата со отпадоци",
    "Trash bin" : "Корпа за отпадоци",
    "Loading deleted items." : "Вчитување на избришаните работи.",
    "You do not have any deleted items." : "Немате избришани работи.",
    "Name" : "Име",
    "Deleted" : "Избришани",
    "Restore" : "Врати",
    "Delete permanently" : "Избриши",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Работите од корпата за отпадоци ќе бидат избришани после {numDays} ден","Работите од корпата за отпадоци ќе бидат избришани после  {numDays} дена"],
    "Could not update calendar order." : "Неможе да се ажурира редоследот на календарите.",
    "Shared calendars" : "Споделени календари",
    "Deck" : "Deck",
    "Internal link" : "Внатрешен линк",
    "A private link that can be used with external clients" : "Приватен линк што може да се користи со надворешни клиенти",
    "Copy internal link" : "Копирај внатрешен линк",
    "An error occurred, unable to publish calendar." : "Настана грешка, неможе да се објави календарот.",
    "An error occurred, unable to send email." : "Настана грешка, неможе да се испрати е-пошта.",
    "Embed code copied to clipboard." : "Кодот за вградување е копиран во клипборд.",
    "Embed code could not be copied to clipboard." : "Кодот за вградување неможе да се копира во клипборд.",
    "Unpublishing calendar failed" : "Неуспешно од-објавување на календар",
    "Share link" : "Сподели линк",
    "Copy public link" : "Копирај јавен линк",
    "Send link to calendar via email" : "Испрати линк до календарот преку е-пошта",
    "Enter one address" : "Внеси една адреса",
    "Sending email …" : "Испраќање е-пошта …",
    "Copy embedding code" : "Копирај код за вградување",
    "Copying code …" : "Копирање код …",
    "Copied code" : "Кодот е копиран",
    "Could not copy code" : "Неможе да се копира кодот",
    "Delete share link" : "Избриши го линкот за споделување",
    "Deleting share link …" : "Се брише линкот за споделување …",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Тим)",
    "An error occurred while unsharing the calendar." : "Настана грешка при откажување на споделување на календар.",
    "An error occurred, unable to change the permission of the share." : "Настана грешка, неможе да се променат дозволите за споделување.",
    "can edit and see confidential events" : "може да уредува и гледа доверливи настани",
    "Unshare with {displayName}" : "Не споделувај со {displayName}",
    "Share with users or groups" : "Сподели со корисници или групи",
    "No users or groups" : "Нема корисници или групи",
    "Failed to save calendar name and color" : "Неуспешно зачувување на име на календар и боја",
    "Calendar name …" : "Име на календар …",
    "Never show me as busy (set this calendar to transparent)" : "Никогаш не ме прикажувај зафатен (постави го овој календар транспарентен)",
    "Share calendar" : "Сподели календар",
    "Unshare from me" : "Не споделувај со мене",
    "Save" : "Зачувај",
    "No title" : "Нема наслов",
    "Are you sure you want to delete \"{title}\"?" : "Дали сте сигурни дека сакате да го избришете \"{title}\"?",
    "Deleting proposal \"{title}\"" : "Бришење на предлогот \"{title}\"",
    "Successfully deleted proposal" : "Успешно бришење на предлог",
    "Failed to delete proposal" : "Неуспешно бришење на предлог",
    "Failed to retrieve proposals" : "Не успеа да се преземат предлозите",
    "Meeting proposals" : "Предлози за состаноци",
    "A configured email address is required to use meeting proposals" : "Потребно е да имате поставено е-пошта адреса за користење на предлози за состаноци",
    "No active meeting proposals" : "Нема активен предлог за состаноци",
    "View" : "Поглед",
    "Import calendars" : "Увези календари",
    "Please select a calendar to import into …" : "Изберете календар за да направите увоз во него …",
    "Filename" : "Име на датотека",
    "Calendar to import into" : "Календар за да направите увоз во него",
    "Cancel" : "Откажи",
    "_Import calendar_::_Import calendars_" : ["Увези календар","Увези календари"],
    "Select the default location for attachments" : "Избери стандардна локација за прилози",
    "Pick" : "Избери",
    "Invalid location selected" : "Избрана невалидна локација",
    "Attachments folder successfully saved." : "Папката за прилози е успешно зачувана.",
    "Error on saving attachments folder." : "Грешка при зачувување на папка за прилози.",
    "Attachments folder" : "Папка со прилози",
    "{filename} could not be parsed" : "Датотеката {filename} не може да се анализира",
    "No valid files found, aborting import" : "Не е пронајдена валидна датотека, увозот е откажан",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Успешно увезен 1 настан","Успешно увезени %n настани"],
    "Import partially failed. Imported {accepted} out of {total}." : "Увозот е делумно неуспешен. Увезени {accepted} од вкупно {total}.",
    "Automatic" : "Автоматски",
    "Automatic ({timezone})" : "Автоматски ({timezone})",
    "New setting was not saved successfully." : "Неуспешно зачувување на промените.",
    "Timezone" : "Временска зона",
    "Navigation" : "Навигација",
    "Previous period" : "Предходен период",
    "Next period" : "Следен период",
    "Views" : "Прегледи",
    "Day view" : "Дневен преглед",
    "Week view" : "Неделен преглед",
    "Month view" : "Месечен преглед",
    "Year view" : "Годишен преглед",
    "List view" : "Листа",
    "Actions" : "Акции",
    "Create event" : "Креирај настан",
    "Show shortcuts" : "Прикажи кратенки",
    "Editor" : "Уредник",
    "Close editor" : "Затвори го уредникот",
    "Save edited event" : "Зачувај го изменетиот настан",
    "Delete edited event" : "Избриши го изменетиот настан",
    "Duplicate event" : "Дуплирај настај",
    "or" : "или",
    "Calendar settings" : "Параметри за календар",
    "At event start" : "На почетокот на настанот",
    "No reminder" : "Нема потсетник",
    "Failed to save default calendar" : "Неуспешно зачувување на стандарден календар",
    "General" : "Општо",
    "Availability settings" : "Поставки за достапност",
    "CalDAV" : "CalDAV",
    "Access Nextcloud calendars from other apps and devices" : "Пристапете до Nextcloud календарите од други апликации и уреди",
    "CalDAV URL" : "CalDAV URL",
    "Appearance" : "Изглед",
    "Birthday calendar" : "Календар со родендени",
    "Tasks in calendar" : "Задачи во календарот",
    "Weekends" : "Викенди",
    "Week numbers" : "Броеви на недели",
    "Limit number of events shown in Month view" : "Ограничи го бројот на прикажани настани во преглед по месец",
    "Density in Day and Week View" : "Густина во дневен и неделен преглед",
    "Editing" : "Уредување",
    "Default reminder" : "Стандарден потсетник",
    "Simple event editor" : "Едноставен уредувач на настани",
    "\"More details\" opens the detailed editor" : "\"Повеќе детали\" го отвора деталниот уредувач",
    "Files" : "Датотеки",
    "Appointment schedule successfully created" : "Распоред за состаноци е успешно креиран",
    "Appointment schedule successfully updated" : "Распоред за состаноци е успешно ажуриран",
    "_{duration} minute_::_{duration} minutes_" : ["1 минута","{duration} минути"],
    "0 minutes" : "0 минути",
    "_{duration} hour_::_{duration} hours_" : ["1 час","{duration} часа"],
    "_{duration} day_::_{duration} days_" : ["1 ден","{duration} дена"],
    "_{duration} week_::_{duration} weeks_" : ["1 недела","{duration} недели"],
    "_{duration} month_::_{duration} months_" : ["{duration} месец","{duration} месеци"],
    "_{duration} year_::_{duration} years_" : ["1 година","{duration} години"],
    "To configure appointments, add your email address in personal settings." : "За да ги конфигурирате состаноците, додајте ја вашата адреса за е-пошта во личните поставки.",
    "Public – shown on the profile page" : "Јавен - Прикажи на профилната страница",
    "Private – only accessible via secret link" : "Приватен - пристап само со безбедносен линк",
    "Appointment schedule saved" : "Распоред за состаноци е зачуван",
    "Create appointment schedule" : "Креирај распоред за состаноци",
    "Edit appointment schedule" : "Уреди распоред за состаноци",
    "Update" : "Ажурирај",
    "Appointment name" : "Име на состанокот",
    "Location" : "Локација",
    "Create a Talk room" : "Креирај соба за разговор",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Уникатен линк ќе се генерира за секој резервиран термин и ќе се испрати потврда преку е-пошта",
    "Description" : "Опис",
    "Visibility" : "Видливост",
    "Duration" : "Времетраење",
    "Increments" : "Зголемување",
    "Additional calendars to check for conflicts" : "Дополнителни календари за проверка на конфликти",
    "Pick time ranges where appointments are allowed" : "Изберете временски интервал кога термините се дозволени",
    "to" : "до",
    "Delete slot" : "Избриши термин",
    "No times set" : "Нема поставени времиња",
    "Add" : "Додади",
    "Monday" : "Понеделник",
    "Tuesday" : "Вторник",
    "Wednesday" : "Среда",
    "Thursday" : "Четврток",
    "Friday" : "Петок",
    "Saturday" : "Сабота",
    "Sunday" : "Недела",
    "Weekdays" : "Работни денови",
    "Add time before and after the event" : "Додадете време пред и по настанот",
    "Before the event" : "Пред настанот",
    "After the event" : "После настанот",
    "Planning restrictions" : "Планирани рестрикции",
    "Minimum time before next available slot" : "Минимално време пред следниот достапен термин",
    "Max slots per day" : "Максимален број термини на ден",
    "Limit how far in the future appointments can be booked" : "Ограничете колку во иднина може да се резервираат термини",
    "It seems a rate limit has been reached. Please try again later." : "Изгледа е достигнат лимит на барања. Обидете се повторно подоцна.",
    "Please confirm your reservation" : "Ве молиме потврдете ја вашата резервација",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Ви испративме е-пошта со детали. Ве молиме потврдете го вашиот термин користејќи ја врската во е-поштата. Можете да ја затворите оваа страница сега.",
    "Your name" : "Вашето име",
    "Your email address" : "Вашата адреса за е-пошта",
    "Please share anything that will help prepare for our meeting" : "Ве молиме споделете сè што ќе помогне да се подготвиме за нашиот состанок",
    "Could not book the appointment. Please try again later or contact the organizer." : "Не може да се резервира термин. Обидете се повторно подоцна или контактирајте со организаторот.",
    "Back" : "Назад",
    "Book appointment" : "Резервирај состанок",
    "Error fetching Talk conversations." : "Грешка при преземање на Talk разговорите.",
    "Conversation does not have a valid URL." : "Разговорот нема важечка URL адреса.",
    "Successfully added Talk conversation link to location." : "Успешно додадена врска до Talk разговор во локацијата.",
    "Successfully added Talk conversation link to description." : "Успешно додадена врска до Talk разговор во описот.",
    "Failed to apply Talk room." : "Не успеа примената на Talk собата.",
    "Talk conversation for event" : "Talk разговор за настанот",
    "Error creating Talk conversation" : "Грешка при создавање на Talk разговор.",
    "Select a Talk Room" : "Изберете Talk соба",
    "Add Talk conversation" : "Додај Talk разговор",
    "Fetching Talk rooms…" : "Се преземаат Talk соби…",
    "No Talk room available" : "Нема достапни Talk соби",
    "Create public conversation" : "Создај јавен разговор",
    "Select conversation" : "Избери разговор",
    "on" : "во",
    "at" : "во",
    "before at" : "пред",
    "Notification" : "Известување",
    "Email" : "Е-пошта",
    "Audio notification" : "Аудио известување",
    "Other notification" : "Друго и звестување",
    "Relative to event" : "Релативно на настан",
    "On date" : "На датум",
    "Edit time" : "Удери време",
    "Save time" : "Зачувај време",
    "Remove reminder" : "Отстрани потсетник",
    "Add reminder" : "Додади потсетник",
    "seconds" : "секунди",
    "minutes" : "минути",
    "hours" : "часови",
    "days" : "денови",
    "weeks" : "недели",
    "Choose a file to add as attachment" : "Избери датотека за да додадете прилог",
    "Choose a file to share as a link" : "Избери датотека за да се сподели како линк",
    "Attachment {name} already exist!" : "Прилогот {name} веќе постои!",
    "Could not upload attachment(s)" : "Неможе да се прикачи прилог",
    "You are about to navigate to {link}. Are you sure to proceed?" : "Ќе се пренасочите кон {link}. Дали сте сигурни дека сакате да продолжите?",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Ќе се пренасочите кон {host}. Дали сте сигурни дека сакате да продолжите? Врска: {link}",
    "Proceed" : "Продолжи",
    "No attachments" : "Нема прилози",
    "Add from Files" : "Додади од датотеките",
    "Upload from device" : "Прикачи од уред",
    "Delete file" : "Избриши датотека",
    "Confirmation" : "Потврда",
    "_{count} attachment_::_{count} attachments_" : ["{count} прилог","{count} прилози"],
    "Suggested" : "Предложено",
    "Available" : "Достапно",
    "Invitation accepted" : "Поканата е прифатена",
    "Accepted {organizerName}'s invitation" : "Прифатена е покана од {organizerName}",
    "Participation marked as tentative" : "Учеството е означено како пробно",
    "Invitation is delegated" : "Поканата е делегирана",
    "Not available" : "Недостапно",
    "Invitation declined" : "Поканата е одбиена",
    "Declined {organizerName}'s invitation" : "Одбиена е покана од {organizerName}",
    "Availability will be checked" : "Достапноста ќе биде проверена",
    "Invitation will be sent" : "Поканата ќе се испрати",
    "Failed to check availability" : "Неуспешно проверување на достапноста",
    "Failed to deliver invitation" : "Неуспешно доставување на поканата",
    "Awaiting response" : "Чекање на одговор",
    "Checking availability" : "Проверување на достапност",
    "Has not responded to {organizerName}'s invitation yet" : "Сè уште не одговорил на поканата на {organizerName}",
    "Suggested times" : "Предложено време",
    "chairperson" : "претседавач",
    "required participant" : "задолжителен учесник",
    "non-participant" : "не-учесник",
    "optional participant" : "незадолжителен учесник",
    "{organizer} (organizer)" : "{organizer} (organizer)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Selected slot" : "Избран термин",
    "Availability of attendees, resources and rooms" : "Достапност на присутните, ресурси и соби",
    "Suggestion accepted" : "Сугестијата е прифатена",
    "Previous date" : "Предходен датум",
    "Next date" : "Следен датум",
    "Legend" : "Легенда",
    "Out of office" : "Надвор од канцеларија",
    "Attendees:" : "Присутни:",
    "local time" : "локално време",
    "Done" : "Готово",
    "Search room" : "Пребарај соба",
    "Room name" : "Име на соба",
    "Check room availability" : "Провери достапност на соба",
    "Free" : "Слободен",
    "Busy (tentative)" : "Зафатен (привремено)",
    "Busy" : "Зафатен",
    "Unknown" : "Непознат",
    "Find a time" : "Пронајди термин",
    "The invitation has been accepted successfully." : "Поканата е успешно прифатена.",
    "Failed to accept the invitation." : "Неуспешно прифаќање на поканата.",
    "The invitation has been declined successfully." : "Поканата е успешно одбиена.",
    "Failed to decline the invitation." : "Неуспешно одбивање на поканата.",
    "Your participation has been marked as tentative." : "Вашето учество е означено како пробно.",
    "Failed to set the participation status to tentative." : "Неуспешно поставување на статус за учество како пробен.",
    "Accept" : "Прифати",
    "Decline" : "Одбиј",
    "Tentative" : "Пробно",
    "No attendees yet" : "Сè уште нема присутни",
    "Please add at least one attendee to use the \"Find a time\" feature." : "Додајте барем еден учесник за да ја користите функцијата \"Пронајди време\".",
    "Attendees" : "Присутни",
    "Remove group" : "Отстрани група",
    "Remove attendee" : "Откажи присутност",
    "Request reply" : "Побарај одговор",
    "Chairperson" : "Претседавач",
    "Required participant" : "Задолжителен учесник",
    "Optional participant" : "Незадолжителен учесник",
    "Non-participant" : "Не-учесник",
    "_%n member_::_%n members_" : ["%n член","%n членови"],
    "Search for emails, users, contacts, contact groups or teams" : "Пребарувај за е-пошти, корисници, контакти, групи или тимови",
    "No match found" : "Нема совпаѓања",
    "Note that members of circles get invited but are not synced yet." : "Забелешка: членовите на тимовите се поканети, но сè уште не се синхронизирани.",
    "Note that members of contact groups get invited but are not synced yet." : "Забелешка: членовите на групите за контакти се поканети, но сè уште не се синхронизирани.",
    "(organizer)" : "(organizer)",
    "Make {label} the organizer" : "Направи го {label} организатор",
    "Make {label} the organizer and attend" : "Постави го {label} како организатор и учествувај",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "За да испратите покана и да можете да добивате одговори,  [linkopen]додадете ја вашата е-пошта адреса во личните податоци на сметката[linkclose].",
    "Remove color" : "Отстрани боја",
    "Event title" : "Наслов на настанот",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Не може да се менуваат целодневните параметри за настани што се дел од множество за повторување.",
    "From" : "Од",
    "To" : "До",
    "Your Time" : "Твоето време",
    "Repeat" : "Повтори",
    "Repeat event" : "Повтори настан",
    "_time_::_times_" : ["еднаш","пати"],
    "never" : "никогаш",
    "on date" : "на датум",
    "after" : "после",
    "End repeat" : "Крај на повторувањето",
    "Select to end repeat" : "Избери крај на повторувањето",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Овој настан е повторување-исклучок на множество повторување. Не можете да додадете правило за повторување на него.",
    "first" : "прв",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Промените на правилото за повторување ќе важат само за оваа и за сите идни појави.",
    "Repeat every" : "Повтори секој",
    "By day of the month" : "По ден во месецот",
    "On the" : "На",
    "_day_::_days_" : ["ден","дена"],
    "_week_::_weeks_" : ["недела","недели"],
    "_month_::_months_" : ["месец","месеци"],
    "_year_::_years_" : ["година","години"],
    "On specific day" : "На одреден ден",
    "weekday" : "работен ден",
    "weekend day" : "ден од викенд",
    "Does not repeat" : "Не повторувај",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Дефиницијата за повторување на овој настан не е целосно поддржана од Nextcloud. Ако ги уредите опциите за повторување, одредени повторувања може да се изгубат.",
    "No rooms or resources yet" : "Сè уште нема простории или ресурси",
    "Resources" : "Ресурси",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["1 седиште","{seatingCapacity} седишта"],
    "Add resource" : "Додади ресурс",
    "Has a projector" : "Има проектор",
    "Has a whiteboard" : "Има табла",
    "Wheelchair accessible" : "Достапно за инвалидска количка",
    "Remove resource" : "Отстрани ресурс",
    "Search for resources or rooms" : "Пребарајте ресурси или простории",
    "available" : "достапно",
    "unavailable" : "недостапно",
    "Show all rooms" : "Прикажи ги сите соби",
    "Projector" : "Проектор",
    "Whiteboard" : "Табла",
    "Room type" : "Вид на соба",
    "Any" : "Било кој",
    "Minimum seating capacity" : "Минимален капацитет за седење",
    "More details" : "Повеќе детали",
    "Update this and all future" : "Ажурирајте го овој и сите во иднина",
    "Update this occurrence" : "Ажурирајте ја оваа можност",
    "Public calendar does not exist" : "Јавниот календар не постои",
    "Maybe the share was deleted or has expired?" : "Можеби споделувањето е избришано ики рокот му е поминат?",
    "Remove date" : "Избриши датум",
    "Attendance required" : "Потребно е присуство",
    "Attendance optional" : "Присуството е опционално",
    "Remove participant" : "Одстрани учесник",
    "Yes" : "Да",
    "No" : "Не",
    "Maybe" : "Можеби",
    "None" : "Ништо",
    "Select your meeting availability" : "Изберете ја вашата достапност за состанок",
    "Create a meeting for this date and time" : "Креирај состанок за овој датум и време",
    "Create" : "Креирај",
    "No participants or dates available" : "Нема достапни учесници или датуми.",
    "from {formattedDate}" : "од {formattedDate}",
    "to {formattedDate}" : "до {formattedDate}",
    "on {formattedDate}" : "на {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "од {formattedDate} во {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "до {formattedDate} во {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "на {formattedDate} во {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} во {formattedTime}",
    "Please enter a valid date" : "Внесете валиден датум",
    "Please enter a valid date and time" : "Внесете валиден датум и време",
    "Select a time zone" : "Избери временска зона",
    "Please select a time zone:" : "Изберете временска зона:",
    "Pick a time" : "Избери време",
    "Pick a date" : "Избери датум",
    "Type to search time zone" : "Пребарај временски зони",
    "Global" : "Глобално",
    "Holidays in {region}" : "Празници во {region}",
    "An error occurred, unable to read public calendars." : "Настана грешка, неможе да се прочитаат јавниоте календари.",
    "An error occurred, unable to subscribe to calendar." : "Се појави грешка — не може да се претплати на календарот.",
    "Public holiday calendars" : "Календар со државни празници",
    "Public calendars" : "Јавни календари",
    "No valid public calendars configured" : "Нема конфигурирани важечки јавни календари",
    "Speak to the server administrator to resolve this issue." : "Разговарајте со администраторот на серверот за да го решите овој проблем.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Календарите за државни празници се обезбедени од Thunderbird. Податоците од календарот ќе се преземат од {website}",
    "These public calendars are suggested by the server administrator. Calendar data will be downloaded from the respective website." : "Овие јавни календари се предложени од администраторот на серверот. Податоците од календарот ќе се преземат од соодветната веб-страница.",
    "By {authors}" : "Од {authors}",
    "Subscribed" : "Претплатени",
    "Subscribe" : "Претплата",
    "Could not fetch slots" : "Не може да се преземат термините",
    "Select a date" : "Избери датум",
    "Select slot" : "Избери термин",
    "No slots available" : "Нема достапни термини",
    "The slot for your appointment has been confirmed" : "Времето за вашиот термин е потврден",
    "Appointment Details:" : "Детали за терминот:",
    "Time:" : "Време:",
    "Booked for:" : "Резервирано за:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Ви благодариме. Вашата резервација од {startDate} до {endDate} е потврдена.",
    "Book another appointment:" : "Резервирај друг термин:",
    "See all available slots" : "Прегледај ги сите слободни термини",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Времето за вашиот термин од {startDate} до {endDate} не е достапен повеќе.",
    "Please book a different slot:" : "Ве молиме резервирајте друг термин:",
    "Book an appointment with {name}" : "Закажан е термин со {name}",
    "No public appointments found for {name}" : "Нема пронајдено јавни термини за {name}",
    "Personal" : "Лично",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Автоматското откривање на временската зона утврди дека вашата временска зона е UTC.\nОва е најверојатно резултат на безбедносните мерки на вашиот веб прелистувач\nПоставете ја вашата временска зона во подесувањата за календарот.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Вашата временска зона ({timezoneId}) не е пронајдена. Поставена е  (Координирано универзално време) UTC.\nПоставете ја вашата временска зона во подесувањата за календарот или пријавете го овој проблем.",
    "Show unscheduled tasks" : "Прикажи незададени задачи",
    "Unscheduled tasks" : "Нездадени задачи",
    "Availability of {displayName}" : "Достапност на {displayName}",
    "Discard event" : "Отфрли настан",
    "Edit event" : "Уреди го настанот",
    "Event does not exist" : "Настанот не постои",
    "Duplicate" : "Дуплирај",
    "Delete this occurrence" : "Избришете ја оваа можност",
    "Delete this and all future" : "Избришете го овој и сите во иднина",
    "All day" : "Цели денови",
    "Modifications wont get propagated to the organizer and other attendees" : "Измените нема да се применат кај организаторот и другите учесници",
    "Managing shared access" : "Управување со споделен пристап",
    "Deny access" : "Забрани пристап",
    "Invite" : "Покани",
    "Discard changes?" : "Да се отфрлат промените?",
    "Are you sure you want to discard the changes made to this event?" : "Дали сте сигурни дека сакате да ги отфрлите промените направени во овој настан?",
    "_User requires access to your file_::_Users require access to your file_" : ["Корисник бара пристап до вашата датотека","Корисници бараат пристап до вашата датотека"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Прилог за кој е потребен пристап","Прилози за кои е потребен пристап"],
    "Untitled event" : "Неименуван настан",
    "Close" : "Затвори",
    "Modifications will not get propagated to the organizer and other attendees" : "Измените нема да бидат применети кај организаторот и другите учесници",
    "Meeting proposals overview" : "Преглед на предлози за состаноци",
    "Edit meeting proposal" : "Измени предлог за состанок",
    "Create meeting proposal" : "Креирај предлог за состанок",
    "Update meeting proposal" : "Ажурирај предлог за состанок",
    "Saving proposal \"{title}\"" : "Зачуван предлог \"{title}\"",
    "Successfully saved proposal" : "Успешно зачуван предлог",
    "Failed to save proposal" : "Неуспешно зачувување на предлог",
    "Create a meeting for \"{date}\"? This will create a calendar event with all participants." : "Креирај состанок за \"{date}\"? Ова ќе креира настан во календарот со сите учесници.",
    "Creating meeting for {date}" : "Креирање состанок за {date}",
    "Successfully created meeting for {date}" : "Успешно креиран состанок за {date}",
    "Failed to create a meeting for {date}" : "Неуспешно креиран состанок за {date}",
    "Please enter a valid duration in minutes." : "Внесете валидно времетраење во минути.",
    "Failed to fetch proposals" : "Не успеа да се преземат предлозите",
    "Failed to fetch free/busy data" : "Не успеа да се преземат податоците за достапност",
    "Selected" : "Избрани",
    "No Description" : "Нема опис",
    "No Location" : "Нема локација",
    "Edit this meeting proposal" : "Измени го овој предлог за состанок",
    "Delete this meeting proposal" : "Избриши го овој предлог за состанок",
    "Title" : "Наслов",
    "15 min" : "15 мин",
    "30 min" : "30 мин",
    "60 min" : "60 мин",
    "90 min" : "90 мин",
    "Participants" : "Учесници",
    "Selected times" : "Избрани времиња",
    "Previous span" : "Претходен период",
    "Next span" : "Следен период",
    "Less days" : "Помалку денови",
    "More days" : "Повеќе денови",
    "Loading meeting proposal" : "Се вчитува предлог за состанок",
    "No meeting proposal found" : "Не е пронајден предлог за состанок",
    "Please wait while we load the meeting proposal." : "Почекајте додека се вчита предлогот за состанок.",
    "The link you followed may be broken, or the meeting proposal may no longer exist." : "Врската што ја следевте можеби е невалидна, или предлогот за состанок повеќе не постои.",
    "Thank you for your response!" : "Благодариме на вашиот одговор.",
    "Your vote has been recorded. Thank you for participating!" : "Вашиот глас е регистриран. Благодариме за учеството!",
    "Unknown User" : "Непознат корисник",
    "No Title" : "Нема наслов",
    "No Duration" : "Нема времетраење",
    "Select a different time zone" : "Избери различна временска зона",
    "Submit" : "Испрати",
    "Subscribe to {name}" : "Претплатете се на {name}",
    "Export {name}" : "Извези {name}",
    "Show availability" : "Прикажи достапност",
    "Anniversary" : "Годишнина",
    "Appointment" : "Состанок",
    "Business" : "Бизнис",
    "Education" : "Образование",
    "Holiday" : "Празник",
    "Meeting" : "Средба",
    "Miscellaneous" : "Разно",
    "Non-working hours" : "Неработни часови",
    "Not in office" : "Не во канцеларија",
    "Phone call" : "Телефонски повик",
    "Sick day" : "Боледување",
    "Special occasion" : "Посебна пригода",
    "Travel" : "Патување",
    "Vacation" : "Одмор",
    "Midnight on the day the event starts" : "На полноќ на денот кога започнува настанот",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n ден пред настанот во {formattedHourMinute}","%n дена пред настанот во {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["Една недела пред настанот во {formattedHourMinute}","%n недели пред настанот во {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "На денот на настанот во {formattedHourMinute}",
    "at the event's start" : "на почетокот на настанот",
    "at the event's end" : "на kraj на настанот",
    "{time} before the event starts" : "{time} пред да започне настанот",
    "{time} before the event ends" : "{time} пред да заврши настанот",
    "{time} after the event starts" : "{time} откако ќе започне настанот",
    "{time} after the event ends" : "{time} одкако ќе заврши настанот",
    "on {time}" : "во {time}",
    "on {time} ({timezoneId})" : "во {time} ({timezoneId})",
    "Week {number} of {year}" : "{number} недела од {year}",
    "Daily" : "Дневно",
    "Weekly" : "Неделно",
    "Monthly" : "Месечно",
    "Yearly" : "Годишно",
    "_Every %n day_::_Every %n days_" : ["Секој ден","Секој %n дена"],
    "_Every %n week_::_Every %n weeks_" : ["Секоја недела","Секој %n недели"],
    "_Every %n month_::_Every %n months_" : ["Секој %n месец","Секој %n месеци"],
    "_Every %n year_::_Every %n years_" : ["Секоја година","Секој %n години"],
    "_on {weekday}_::_on {weekdays}_" : ["во {weekday}","во {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["на ден {dayOfMonthList}","на денови {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "на {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {dayOfMonthList}" : "во {monthNames} на {dayOfMonthList}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "во {monthNames} на {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "до {untilDate}",
    "_%n time_::_%n times_" : ["%n пат","%n пати"],
    "second" : "втор",
    "third" : "трети",
    "fourth" : "четврти",
    "fifth" : "петти",
    "second to last" : "претпоследен",
    "last" : "последен",
    "Untitled task" : "Неименувана задача",
    "Please ask your administrator to enable the Tasks App." : "Замолете го сервер администраторот да ја овозможи апликацијата задачи.",
    "You are not allowed to edit this event as an attendee." : "Немате дозвола да го уредувате овој настан како учесник.",
    "W" : "Н",
    "%n more" : "%n други",
    "No events to display" : "Нема настани за приказ",
    "All participants declined" : "Сите учесници одбија",
    "Please confirm your participation" : "Ве молиме потврдете го вашато присуство",
    "You declined this event" : "Вие го одбивте овој настан",
    "Your participation is tentative" : "Вашето учество е привремено",
    "_+%n more_::_+%n more_" : ["+%n друг","+%n други"],
    "No events" : "Нема настани",
    "Create a new event or change the visible time-range" : "Креирајте нов настан или променете го видливиот временски опсег",
    "Failed to save event" : "Неуспешно зачувување на настанот",
    "It might have been deleted, or there was a typo in a link" : "Можеби е избришан или има грешка во врската",
    "It might have been deleted, or there was a typo in the link" : "Можеби е избришан или има грешка во врската",
    "Meeting room" : "Соба за состаноци",
    "Lecture hall" : "Сала за предавање",
    "Seminar room" : "Семинарска сала",
    "Other" : "Останато",
    "When shared show" : "Приказ кога е споделен",
    "When shared show full event" : "Кога е споделен, прикажи го целосно настанот",
    "When shared show only busy" : "Кога е споделен, прикажи зафатено",
    "When shared hide this event" : "Кога е споделен, сокриј го настанот",
    "The visibility of this event in read-only shared calendars." : "Видливоста на овој настан во споделени календари со само-преглед.",
    "Add a location" : "Додади локација",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Додај опис\n\n- За што е овој состанок\n- Точки на дневен ред\n- Сè што учесниците треба да подготват",
    "Status" : "Статус",
    "Confirmed" : "Потврдено",
    "Canceled" : "Откажано",
    "Confirmation about the overall status of the event." : "Потврда за целокупниот статус на настанот.",
    "Show as" : "Прикажи како",
    "Take this event into account when calculating free-busy information." : "Го има во предвид овој настан при пресметување на информации за слободен-зафатен.",
    "Categories" : "Категории",
    "Categories help you to structure and organize your events." : "Категориите ви помагаат да ги структурирате и организирате вашите настани.",
    "Search or add categories" : "Барај или додади категории",
    "Add this as a new category" : "Додади како нова категорија",
    "Custom color" : "Прилагодена боја",
    "Special color of this event. Overrides the calendar-color." : "Специјална боја на овој настан. Ја отфрла бојата на календарот.",
    "Error while sharing file" : "Грешка при споделување на датотека",
    "Error while sharing file with user" : "Грешка при споделување на датотека со корисник",
    "Error creating a folder {folder}" : "Грешка при создавање на папката {folder}",
    "Attachment {fileName} already exists!" : "Прилогот {fileName} веќе постои!",
    "Attachment {fileName} added!" : "Прилогот {fileName} е додаден!",
    "An error occurred during uploading file {fileName}" : "Настана грешка при прикачување на датотека {fileName}",
    "An error occurred during getting file information" : "Настана грешка при преземање на информации од датотека",
    "Talk conversation for proposal" : "Talk разговор за предлогот",
    "An error occurred, unable to delete the calendar." : "Настана грешка, неможе да се избрише календарот.",
    "Imported {filename}" : "Импортирано {filename}",
    "This is an event reminder." : "Ова е потсетник за настан.",
    "Error while parsing a PROPFIND error" : "Грешка при обработка на PROPFIND грешката",
    "Appointment not found" : "Терминот не е пронајден",
    "User not found" : "Корисникот не е пронајден",
    "Hidden" : "Сокриен",
    "can edit" : "може да се измени",
    "Calendar name …" : "Име на календар ...",
    "Default attachments location" : "Стандардна локација за прилози",
    "Automatic ({detected})" : "Автоматски ({detected})",
    "Shortcut overview" : "Преглед на кратенки преку тастатура",
    "CalDAV link copied to clipboard." : "CalDAV линкот е копиран.",
    "CalDAV link could not be copied to clipboard." : "CalDAV линкот неможе да биде копиран.",
    "Enable birthday calendar" : "Овозможи календар со родендени",
    "Show tasks in calendar" : "Прикажи ги задачите во календарнот",
    "Enable simplified editor" : "Овозможи поедноставен уредувач",
    "Limit the number of events displayed in the monthly view" : "Ограничи број на настани прикажани во месечниот преглед",
    "Show weekends" : "Прикажи викенди",
    "Show week numbers" : "Прикажи броеви на неделите",
    "Time increments" : "Временско зголемување",
    "Default calendar for incoming invitations" : "Стандарден календар за дојдовни покани",
    "Copy primary CalDAV address" : "Копирај примарна CalDAV адреса",
    "Copy iOS/macOS CalDAV address" : "Копирај iOS/macOS CalDAV адреса",
    "Personal availability settings" : "Параметри за лична достапност",
    "Show keyboard shortcuts" : "Прикажи кратенки преку тастатура",
    "Create a new public conversation" : "Создај нов јавен разговор",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} поканети, {confirmedCount} потврдени",
    "Successfully appended link to talk room to location." : "Успешно е додадена врска од собата за разговор во локација.",
    "Successfully appended link to talk room to description." : "Успешно додаден линк од собата за разговор во описот.",
    "Error creating Talk room" : "Грешка при креирање на соба за разговор",
    "_%n more guest_::_%n more guests_" : ["%n гостин","%n други гости"],
    "The visibility of this event in shared calendars." : "Видливост на овој настан во споделен календар."
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
