OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Den angivne e-mail-adresse er for lang",
    "User-Session unexpectedly expired" : "Bruger-Sessionen udløb uventet",
    "Provided email-address is not valid" : "Leveret e-mailadresse er ikke gyldig ",
    "%s has published the calendar »%s«" : "%s har oprettet en begivenhed i kalenderen »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Uventet fejl ved afsendelse, venligst kontakt din administrator",
    "Successfully sent email to %1$s" : "Sendt e-mail til %1$s",
    "Hello," : "Hej,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Vi ønkser at informerer dig om at %s har oprettet en begivenhed i kalenderen »%s«.",
    "Open »%s«" : "Åbn »%s«",
    "Cheers!" : "Hav en fortsat god dag.",
    "Upcoming events" : "Kommende begivenheder",
    "No more events today" : "Ikke flere begivenheder i dag",
    "No upcoming events" : "Ingen kommende begivenheder",
    "More events" : "Flere begivenheder",
    "%1$s with %2$s" : "%1$s med %2$s",
    "Calendar" : "Kalender",
    "New booking {booking}" : "Ny booking {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) bookede aftalen \"{config_display_name}\" den {date_time}.",
    "Appointments" : "Aftaler",
    "Schedule appointment \"%s\"" : "Planlæg en aftale \"%s\"",
    "Schedule an appointment" : "Planlæg en aftale",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : "Gør klar til %s",
    "Follow up for %s" : "Følg op til %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Din aftale \"%s\" med %s skal bekræftes",
    "Dear %s, please confirm your booking" : "Kære %s, bekræft venligst din reservation",
    "Confirm" : "Bekræft",
    "Appointment with:" : "Aftale med:",
    "Description:" : "Beskrivelse:",
    "This confirmation link expires in %s hours." : "Dette bekræftelseslink udløber om %s timer.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Hvis du alligevel ønsker at aflyse aftalen, så kontakt venligst arrangøren ved at svare på denne mail, eller gennem dennes profil side. ",
    "Your appointment \"%s\" with %s has been accepted" : "Din aftale \"%s\" med %s er blevet accepteret",
    "Dear %s, your booking has been accepted." : "%s, din aftale er blevet accepteret.",
    "Appointment for:" : "Aftale for:",
    "Date:" : "Dato:",
    "You will receive a link with the confirmation email" : "Du modtager et link med bekræftelsesmailen",
    "Where:" : "Hvor:",
    "Comment:" : "Kommentar:",
    "You have a new appointment booking \"%s\" from %s" : "Du har en ny aftale booking \"%s\" fra %s",
    "Dear %s, %s (%s) booked an appointment with you." : "Kære %s, %s (%s) bookede en aftale med dig.",
    "%s has proposed a meeting" : "%s har foreslået et møde",
    "%s has updated a proposed meeting" : "%s har opdateret et foreslået møde",
    "%s has canceled a proposed meeting" : "%s har annulleret et foreslået møde",
    "Dear %s, a new meeting has been proposed" : "Kære %s, et nyt møde er blevet foreslået",
    "Dear %s, a proposed meeting has been updated" : "Kære %s, et foreslået møde er blevet opdateret",
    "Dear %s, a proposed meeting has been cancelled" : "Kære %s, et forslået møde er blevet annulleret",
    "Location:" : "Sted:",
    "Duration:" : "Varighed:",
    "%1$s from %2$s to %3$s" : "%1$s fra %2$s til %3$s",
    "Dates:" : "Datoer:",
    "Respond" : "Svar",
    "A Calendar app for Nextcloud" : "En kalender-app til Nextcloud",
    "A Calendar app for Nextcloud. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Like Contacts, Talk, Tasks, Deck and Circles\n* 🌐 **WebCal Support!** Want to see your favorite team's matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 **Search!** Find your events at ease\n* ☑️ **Tasks!** See tasks or Deck cards with a due date directly in the calendar\n* 🔈 **Talk rooms!** Create an associated Talk room when booking a meeting with just one click\n* 📆 **Appointment booking** Send people a link so they can book an appointment with you [using this app](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Attachments!** Add, upload and view event attachments\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "En kalender app til Nextcloud. Synkroniser let begivenheder fra forskellige apparater med din Nextcloud og rediger dem online.\n\n* 🚀 **Integration med andre Nextcloud apps!** Såsom Kontakter, Snak, Opgaver, Deck og Cirkler\n* 🌐 **WebCal understøttelse!** Ønsker du at se dine favorit teams' matchdage i din kalender? Intet problem!\n* 🙋 **Deltagere!** Inviter personer til dine begivenheder\n* ⌚ **Ledig/Optaget!** Se hvornår dine deltagere er ledige til et møde\n* ⏰ **Påmindelser!** Få alarmer for begivenheder i din browse og via e-mail\n* 🔍 **Søg!** Find let dine begivenheder\n* ☑️ **Opgaver!** Se opgaver eller Deck kort med en forfaldsdato direkte i kalenderen\n* 🔈 **Snak rum!** Opret et associeret Snak rum når du booker et møde, med kun ét klik\n* 📆 **Aftale booking** Send et link til personer, så de kan booke en aftale med dig [ved anvendelse af denne app](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Vedhæftninger!** Tilføj, upload og vis begivenhedsvedhæftninger\n* 🙈 **Vi genopfinder ikke hjulet!** Baseret på de glimrende [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) og [fullcalendar](https://github.com/fullcalendar/fullcalendar) biblioteker.",
    "Previous day" : "Forrige dag",
    "Previous week" : "Forrige uge",
    "Previous year" : "Forrige år",
    "Previous month" : "Forrige måned",
    "Next day" : "Næste dag",
    "Next week" : "Næste uge",
    "Next year" : "Næste år",
    "Next month" : "Næste måned",
    "Create new event" : "Opret ny begivenhed",
    "Event" : "Begivenhed",
    "Today" : "I dag",
    "Day" : "Dag",
    "Week" : "Uge",
    "Month" : "Måned",
    "Year" : "År",
    "List" : "Liste",
    "Appointment link was copied to clipboard" : "Aftalelink blev kopieret til udklipsholder",
    "Appointment link could not be copied to clipboard" : "Aftalelinket kunne ikke kopieres til udklipsholderen",
    "Preview" : "Forhåndsvisning",
    "Copy link" : "Kopiér link",
    "Edit" : "Redigér",
    "Delete" : "Slet",
    "Appointment schedules" : "Aftaleplanlægninger",
    "Create new" : "Opret ny",
    "Disable calendar \"{calendar}\"" : "Slå kalender fra {calendar}",
    "Disable untitled calendar" : "Deaktiver unavngiven kalender",
    "Enable calendar \"{calendar}\"" : "Slå kalender til {calendar}",
    "Enable untitled calendar" : "Aktiver unavngiven kalender",
    "An error occurred, unable to change visibility of the calendar." : "Kalenderens synlighed kunne ikke ændres.",
    "Untitled calendar" : "Unanvngiven kalender",
    "Shared with you by" : "Delt med dig af",
    "Edit and share calendar" : "Redigér og del kalender",
    "Edit calendar" : "Redigér kalender",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Fjerner deling af kalenderen om {countdown} sekund","Fjerner deling af kalenderen om {countdown} sekunder"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Kalenderen bliver slettet om {countdown} sekunder","Kalenderen bliver slettet om {countdown} sekunder"],
    "An error occurred, unable to create the calendar." : "Der opstod en fejl, og kalenderen kunne ikke oprettes.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Indtast venligst et gyldigt link (startende med http://, https://, webcal:// eller webcals://)",
    "Calendars" : "Kalendere",
    "Add new" : "Tilføj ny",
    "New calendar" : "Ny kalender",
    "Name for new calendar" : "Navn på ny kalender",
    "Creating calendar …" : "Opretter kalender…",
    "New calendar with task list" : "Ny kalender med opgaveliste",
    "New subscription from link (read-only)" : "Nyt abonnement fra link (skrivebeskyttet)",
    "Creating subscription …" : "Opretter abonnement…",
    "Add public holiday calendar" : "Tilføj helligdagskalender",
    "Add custom public calendar" : "Tilføj brugerdefineret offentlig kalender",
    "Calendar link copied to clipboard." : "Kalender link kopieret.",
    "Calendar link could not be copied to clipboard." : "Kalender link kunne ikke kopieres.",
    "Copy subscription link" : "Kopier abonnementslink",
    "Copying link …" : "Kopierer link…",
    "Copied link" : "Link kopieret",
    "Could not copy link" : "Link kunne ikke kopieres",
    "Export" : "Eksportér",
    "Untitled item" : "Unavngiven element",
    "Unknown calendar" : "Ukendt kalender",
    "Could not load deleted calendars and objects" : "Kunne ikke indlæse slettede kalendere og objekter",
    "Could not delete calendar or event" : "Kunne ikke slette kalender eller begivenhed",
    "Could not restore calendar or event" : "Kunne ikke gendanne kalender eller begivenhed",
    "Do you really want to empty the trash bin?" : "Vil du virkelig tømme papirkurven?",
    "Empty trash bin" : "Tom papirkurv",
    "Trash bin" : "Papirkurv",
    "Loading deleted items." : "Indlæser slettede elementer.",
    "You do not have any deleted items." : "Du har ingen slettede elementer.",
    "Name" : "Navn",
    "Deleted" : "Slettet",
    "Restore" : "Gendan",
    "Delete permanently" : "Slet permanent",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Emner i papirkurven slettes efter {numDays} dag","Emner i papirkurven slettes efter {numDays} dage"],
    "Could not update calendar order." : "Kunne ikke opdatere kalenderrækkefølgen.",
    "Shared calendars" : "Delte kalendere",
    "Deck" : "Opslag",
    "Internal link" : "Internt link",
    "A private link that can be used with external clients" : "Et privat link der kan blive brugt mad eksterne klienter",
    "Copy internal link" : "Kopier internt link",
    "An error occurred, unable to publish calendar." : "Kalenderen kunne ikke udgives",
    "An error occurred, unable to send email." : "Der opstod en fejl, kunne ikke sende e-mail.",
    "Embed code copied to clipboard." : "Indlejringskode kopieret til udklipsholder.",
    "Embed code could not be copied to clipboard." : "Indlejringskoden kunne ikke kopieres til udklipsholderen.",
    "Unpublishing calendar failed" : "Udgivelse af kalender mislykkedes",
    "Share link" : "Del link",
    "Copy public link" : "Kopier offentligt link",
    "Send link to calendar via email" : "Send link til kalender via e-mail",
    "Enter one address" : "Indtast en adresse",
    "Sending email …" : "Sender email…",
    "Copy embedding code" : "Kopier indlejringskode",
    "Copying code …" : "Kopierer kode…",
    "Copied code" : "Kode kopieret",
    "Could not copy code" : "Kode kunne ikke kopieres",
    "Delete share link" : "Slet delingslink",
    "Deleting share link …" : "Sletter delingslink…",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Team)",
    "An error occurred while unsharing the calendar." : "Der opstod en fejl under fjernelse af deling af kalenderen.",
    "An error occurred, unable to change the permission of the share." : "Der opstod en fejl, som ikke kunne ændre tilladelsen til delingen.",
    "can edit and see confidential events" : "Kan se og redigere fortrolige aftaler",
    "Unshare with {displayName}" : "Fjern deling med {displayName}",
    "Share with users or groups" : "Del med brugere eller grupper",
    "No users or groups" : "Ingen brugere eller grupper",
    "Failed to save calendar name and color" : "Kunne ikke gemme kalendernavn og farve",
    "Calendar name …" : "Kalendernavn …",
    "Never show me as busy (set this calendar to transparent)" : "Vis mig aldrig som optaget (sæt denne kalender til gennemsigtig)",
    "Share calendar" : "Del kalender",
    "Unshare from me" : "Fjern deling fra mig",
    "Save" : "Gem",
    "No title" : "Ingen titel",
    "Are you sure you want to delete \"{title}\"?" : "Er du sikker på at du ønsker at slette \"{title}\"?",
    "Deleting proposal \"{title}\"" : "Sletter forslag \"{title}\"",
    "Successfully deleted proposal" : "Slettede forslaget",
    "Failed to delete proposal" : "Kunne ikke slette forslag",
    "Failed to retrieve proposals" : "Kunne ikke hente forslag",
    "Meeting proposals" : "Mødeforslag",
    "A configured email address is required to use meeting proposals" : "En konfigureret e-mailadresse er påkrævet for at bruge møde forslag",
    "No active meeting proposals" : "Ingen aktive møde forslag",
    "View" : "Vis",
    "Import calendars" : "Importér kalendere",
    "Please select a calendar to import into …" : "Vælg venligst en kalender, der skal importeres til...",
    "Filename" : "Filnavn",
    "Calendar to import into" : "Kalender at importere til",
    "Cancel" : "Annuller",
    "_Import calendar_::_Import calendars_" : ["Importér kalender","Importér kalendere"],
    "Select the default location for attachments" : "Vælg standardplaceringen for vedhæftede filer",
    "Pick" : "Vælg",
    "Invalid location selected" : "Ugyldig placering er valgt",
    "Attachments folder successfully saved." : "Mappen vedhæftede filer blev gemt.",
    "Error on saving attachments folder." : "Fejl ved lagring af vedhæftede filer mappen.",
    "Attachments folder" : "Mappe til vedhæftede filer",
    "{filename} could not be parsed" : "{filename} kunne ikke fortolkes",
    "No valid files found, aborting import" : "Ingen gyldige filer fundet, importen afbrydes",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["%n begivenhed blev importeret","%n begivenheder blev importeret"],
    "Import partially failed. Imported {accepted} out of {total}." : "Importen mislykkedes delvist. Importeret {accepted} ud af {total}.",
    "Automatic" : "Automatisk",
    "Automatic ({timezone})" : "Automatisk ({timezone})",
    "New setting was not saved successfully." : "Den nye indstilling blev ikke gemt.",
    "Timezone" : "Tidszone",
    "Navigation" : "Navigation",
    "Previous period" : "Tidligere periode",
    "Next period" : "Næste periode",
    "Views" : "Visninger",
    "Day view" : "Dagsvisning",
    "Week view" : "Ugevisning",
    "Month view" : "Månedsvisning",
    "Year view" : "Årsvisning",
    "List view" : "Vis som liste",
    "Actions" : "Handlinger",
    "Create event" : "Opret begivenhed",
    "Show shortcuts" : "Vis genveje",
    "Editor" : "Editor",
    "Close editor" : "Luk editor",
    "Save edited event" : "Gem redigeret begivenhed",
    "Delete edited event" : "Slet redigeret begivenhed",
    "Duplicate event" : "Dubleret begivenhed",
    "or" : "eller",
    "Calendar settings" : "Kalender indstillinger",
    "At event start" : "Ved arrangementets start",
    "No reminder" : "Ingen påmindelse",
    "Failed to save default calendar" : "Kunne ikke gemme standard kalenderen",
    "General" : "Generelt",
    "Availability settings" : "Tilgængelige oversættelser",
    "CalDAV" : "CalDAV",
    "Access Nextcloud calendars from other apps and devices" : "Tilgå Nextclouds kalendere fra andre apps og enheder",
    "CalDAV URL" : "CalDAV adresse",
    "Appearance" : "Udseende",
    "Birthday calendar" : "Fødselsdagkalender",
    "Tasks in calendar" : "Opgaver i kalenderen",
    "Weekends" : "Weekender",
    "Week numbers" : "Ugenumre",
    "Limit number of events shown in Month view" : "Begræns antal af aftaler i månedsoversigten",
    "Density in Day and Week View" : "Luft i dag og uge oversigten",
    "Editing" : "Redigering",
    "Default reminder" : "Standard påmindelse",
    "Simple event editor" : "Simpel aftale editor",
    "\"More details\" opens the detailed editor" : "\"Flere detaljer\" åbner detalje editoren",
    "Files" : "Filer",
    "Appointment schedule successfully created" : "Aftaleplanlægning blev oprettet",
    "Appointment schedule successfully updated" : "Aftaleplanlægningen er opdateret",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minut","{duration} minutter"],
    "0 minutes" : "0 minutter",
    "_{duration} hour_::_{duration} hours_" : ["{duration} time","{duration} timer"],
    "_{duration} day_::_{duration} days_" : ["{duration} dag","{duration} dage"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} uge","{duration} uger"],
    "_{duration} month_::_{duration} months_" : ["{duration} måned","{duration} måneder"],
    "_{duration} year_::_{duration} years_" : ["{duration} år","{duration} år"],
    "To configure appointments, add your email address in personal settings." : "For at konfigurere aftaler - tilføj venligst din e-mailadresse under personlige indstillinger.",
    "Public – shown on the profile page" : "Offentlig – vist på profilsiden",
    "Private – only accessible via secret link" : "Privat – kun tilgængelig via hemmeligt link",
    "Appointment schedule saved" : "Aftaleplanlægningen gemt",
    "Create appointment schedule" : "Opret aftaleplanlægning",
    "Edit appointment schedule" : "Redigér aftaleplanlægning",
    "Update" : "Opdatér",
    "Appointment name" : "Aftale navn",
    "Location" : "Sted",
    "Create a Talk room" : "Opret et Snak rum",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Et unikt link vil blive genereret for hver booket aftale og sendt via bekræftelsesmailen",
    "Description" : "Beskrivelse",
    "Visibility" : "Synlighed",
    "Duration" : "Varighed",
    "Increments" : "Inkrementer",
    "Additional calendars to check for conflicts" : "Yderligere kalendere til at tjekke for konflikter",
    "Pick time ranges where appointments are allowed" : "Vælg tidsintervaller, hvor aftaler er tilladt",
    "to" : "til",
    "Delete slot" : "Slet slot",
    "No times set" : "Ingen tider fastsat",
    "Add" : "Tilføj",
    "Monday" : "Mandag",
    "Tuesday" : "Tirsdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Lørdag",
    "Sunday" : "Søndag",
    "Weekdays" : "Hverdage",
    "Add time before and after the event" : "Tilføj tid før og efter begivenheden",
    "Before the event" : "Før arrangementet",
    "After the event" : "Efter arrangementet",
    "Planning restrictions" : "Planlægningsrestriktioner",
    "Minimum time before next available slot" : "Minimum tid før næste ledige plads",
    "Max slots per day" : "Max slots om dagen",
    "Limit how far in the future appointments can be booked" : "Begræns hvor langt ude i fremtiden, der kan bookes tider",
    "It seems a rate limit has been reached. Please try again later." : "Det ser ud til, at en begrænsning er nået. Prøv venligst igen senere.",
    "Please confirm your reservation" : "Bekræft venligst din reservation",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Vi har sendt dig en e-mail med detaljer. Bekræft venligst din aftale ved at bruge linket i e-mailen. Du kan lukke denne side nu.",
    "Your name" : "Dit navn",
    "Your email address" : "Din email adresse",
    "Please share anything that will help prepare for our meeting" : "Del venligst alt, der kan hjælpe med at forberede vores møde",
    "Could not book the appointment. Please try again later or contact the organizer." : "Det var ikke muligt at bestille tid. Prøv venligst igen senere eller kontakt arrangøren.",
    "Back" : "Tilbage",
    "Book appointment" : "Book aftale",
    "Error fetching Talk conversations." : "Fejl under hentning af Snak samtaler.",
    "Conversation does not have a valid URL." : "Samtaler har ikke en gyldig URL.",
    "Successfully added Talk conversation link to location." : "Tilføjede Snak samtale link til placering.",
    "Successfully added Talk conversation link to description." : "Tilføjede Snak samtale link til beskrivelse.",
    "Failed to apply Talk room." : "Kunne ikke anvende Snak rum",
    "Talk conversation for event" : "Snak samtale for begivenhed",
    "Error creating Talk conversation" : "Fejl under oprettelse af Snak samtale",
    "Select a Talk Room" : "Vælg et Snak rum",
    "Add Talk conversation" : "Tilføj Snak samtale",
    "Fetching Talk rooms…" : "Henter Snak rum...",
    "No Talk room available" : "Ingen Snak rum tilgængelige",
    "Create public conversation" : "Opret offentlig samtale",
    "Select conversation" : "Vælg samtale",
    "on" : "på",
    "at" : "ved",
    "before at" : "før kl",
    "Notification" : "Notifikation",
    "Email" : "E-mail",
    "Audio notification" : "Lydmeddelelse",
    "Other notification" : "Anden meddelelse",
    "Relative to event" : "I forhold til begivenhed",
    "On date" : "På dato",
    "Edit time" : "Redigér tid",
    "Save time" : "Gem tid",
    "Remove reminder" : "Fjern påmindelse",
    "Add reminder" : "Tilføj påmindelse",
    "seconds" : "sekunder ",
    "minutes" : "minutter",
    "hours" : "timer",
    "days" : "dage",
    "weeks" : "uger",
    "Choose a file to add as attachment" : "Vælg en fil, der skal tilføjes som vedhæftning",
    "Choose a file to share as a link" : "Vælg en fil der skal deles som link",
    "Attachment {name} already exist!" : "Vedhæftet fil {name} findes allerede!",
    "Could not upload attachment(s)" : "Kunne ikke uploade vedhæftning(er)",
    "You are about to navigate to {link}. Are you sure to proceed?" : "Du er ved at åbne linket:{link}. Er du sikker på, at du vil fortsætte?",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Du er ved at navigere til {host}. Er du sikker på at du vil fortsætte? Link: {link}",
    "Proceed" : "Fortsæt",
    "No attachments" : "Ingen vedhæftede filer",
    "Add from Files" : "Tilføj fra Filer",
    "Upload from device" : "Upload fra enhed",
    "Delete file" : "Slet fil",
    "Confirmation" : "Bekræftelse",
    "_{count} attachment_::_{count} attachments_" : ["{count} vedhæftet fil","{count} vedhæftede filer"],
    "Suggested" : "Foreslået",
    "Available" : "Tilgængelig",
    "Invitation accepted" : "Invitation accepteret",
    "Accepted {organizerName}'s invitation" : "Accepterede invitationen fra {organizerName}",
    "Participation marked as tentative" : "Deltagelse markeret som foreløbig",
    "Invitation is delegated" : "Invitation er uddelegeret",
    "Not available" : "Ikke tilgængelig",
    "Invitation declined" : "Invitation afvist",
    "Declined {organizerName}'s invitation" : "Afviste {organizerName}s invitation",
    "Availability will be checked" : "Tilgængelighed bliver kontrolleret",
    "Invitation will be sent" : "Invitation sendes",
    "Failed to check availability" : "Kunne ikke kontrollere tilgængelighed",
    "Failed to deliver invitation" : "Kunne ikke aflevere invitation",
    "Awaiting response" : "Afventer svar",
    "Checking availability" : "Kontrol af tilgængelighed",
    "Has not responded to {organizerName}'s invitation yet" : "Har endnu ikke svaret på {organizerName}s invitation",
    "Suggested times" : "Foreslåede tidspunkter",
    "chairperson" : "formand",
    "required participant" : "nødvendig deltager",
    "non-participant" : "ikke-deltager",
    "optional participant" : "valgfri deltager",
    "{organizer} (organizer)" : "{organizer} (arrangør)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Selected slot" : "Den valgte plads",
    "Availability of attendees, resources and rooms" : "Tilgængelighed af deltagere, ressourcer og lokaler",
    "Suggestion accepted" : "Forslag accepteret",
    "Previous date" : "Forrige dato",
    "Next date" : "Næste dato",
    "Legend" : "Forklaring",
    "Out of office" : "Ikke på kontoret",
    "Attendees:" : "Deltagere:",
    "local time" : "lokal tid",
    "Done" : "Færdig",
    "Search room" : "Søg rum",
    "Room name" : "Rumnavn",
    "Check room availability" : "kontroller rumtilgængelighed",
    "Free" : "Ledig",
    "Busy (tentative)" : "Optaget (foreløbig)",
    "Busy" : "Optaget",
    "Unknown" : "Ukendt",
    "Find a time" : "Find et tidspunkt",
    "The invitation has been accepted successfully." : "Invitationen er blevet accepteret.",
    "Failed to accept the invitation." : "Kunne ikke acceptere invitationen.",
    "The invitation has been declined successfully." : "Invitationen er blevet afvist.",
    "Failed to decline the invitation." : "Invitationen kunne ikke afvises.",
    "Your participation has been marked as tentative." : "Din deltagelse er blevet markeret som foreløbig.",
    "Failed to set the participation status to tentative." : "Kunne ikke indstille deltagelsesstatus til foreløbig.",
    "Accept" : "Accepter",
    "Decline" : "Afvis",
    "Tentative" : "Foreløbig",
    "No attendees yet" : "Ingen deltagere endnu",
    "Please add at least one attendee to use the \"Find a time\" feature." : "Tilføj venligst mindst én deltager for at anvende funktionen \"Find et tidspunkt\".",
    "Attendees" : "Deltagere",
    "Remove group" : "Fjern gruppe",
    "Remove attendee" : "Fjern deltager",
    "Request reply" : "Anmod om svar",
    "Chairperson" : "Formand",
    "Required participant" : "Nødvendig deltager",
    "Optional participant" : "Valgfri deltager",
    "Non-participant" : "Deltager ikke",
    "_%n member_::_%n members_" : ["%n medlemer","%n medlemer"],
    "Search for emails, users, contacts, contact groups or teams" : "Søg efter e-mails, brugere, kontaktgrupper eller teams",
    "No match found" : "Ingen match fundet",
    "Note that members of circles get invited but are not synced yet." : "Bemærk, at medlemmer af cirkler bliver inviteret, men er endnu ikke synkroniseret.",
    "Note that members of contact groups get invited but are not synced yet." : "Bemærk at medlemmer af kontaktgrupper inviteres, men endnu ikke er synkroniserede.",
    "(organizer)" : "(arrangør)",
    "Make {label} the organizer" : "Gør {label} til arrangør",
    "Make {label} the organizer and attend" : "Gør {label} til arrangør og deltag",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "For at udsende invitationer og håndtere svar, [linkopen]tilføj din e-mailadresse i personlige indstillinger[linkclose].",
    "Remove color" : "Fjern farve",
    "Event title" : "Titel",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Kan ikke ændre heldagsindstillingen for begivenheder, der er en del af et gentagelsessæt.",
    "From" : "Fra",
    "To" : "Til",
    "Your Time" : "Din tid",
    "Repeat" : "Gentag",
    "Repeat event" : "Gentag begivenhed",
    "_time_::_times_" : ["gang","gange"],
    "never" : "aldrig",
    "on date" : "på dato",
    "after" : "efter",
    "End repeat" : "Afslut gentagelse",
    "Select to end repeat" : "Vælg for at afslutte gentagelsen",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Denne begivenhed er gentagelses-undtagelsen af et gentagelsessæt. Du kan ikke tilføje en gentagelsesregel til den.",
    "first" : "første",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Ændringer i gentagelsesreglen vil kun gælde for denne og alle fremtidige hændelser.",
    "Repeat every" : "Gentag hver",
    "By day of the month" : "Efter dag i måneden",
    "On the" : "Den",
    "_day_::_days_" : ["dag","dage"],
    "_week_::_weeks_" : ["uge","uger"],
    "_month_::_months_" : ["måned","måneder"],
    "_year_::_years_" : ["år","år"],
    "On specific day" : "På specifik dag",
    "weekday" : "hverdag",
    "weekend day" : "weekenddag",
    "Does not repeat" : "Gentager sig ikke",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Gentagelsesdefinitionen af denne begivenhed understøttes ikke fuldt ud af Nextcloud. Hvis du redigerer gentagelsesmulighederne, kan visse gentagelser gå tabt.",
    "No rooms or resources yet" : "Ingen lokaler eller ressourcer endnu",
    "Resources" : "Resourcer",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} sæde","{seatingCapacity} sæder"],
    "Add resource" : "Tilføj ressource",
    "Has a projector" : "Har en projektor",
    "Has a whiteboard" : "Har en whiteboardtavle",
    "Wheelchair accessible" : "Kørestolsvenligt",
    "Remove resource" : "Fjern ressource",
    "Search for resources or rooms" : "Søg efter ressourcer eller lokaler",
    "available" : "tilgængelig",
    "unavailable" : "ikke tilgængelig",
    "Show all rooms" : "Vis alle rum",
    "Projector" : "Projektor",
    "Whiteboard" : "Whiteboard",
    "Room type" : "Værelsestype",
    "Any" : "Enhver",
    "Minimum seating capacity" : "Minimum siddekapacitet",
    "More details" : "Flere detaljer",
    "Update this and all future" : "Opdatér denne og alle fremtidige",
    "Update this occurrence" : "Opdatér denne forekomst",
    "Public calendar does not exist" : "Offentlig kalender findes ikke",
    "Maybe the share was deleted or has expired?" : "Måske er delingen blevet slettet eller er udløbet?",
    "Remove date" : "Fjern dato",
    "Attendance required" : "Deltagelse krævet",
    "Attendance optional" : "Deltagelse valgfri",
    "Remove participant" : "Fjern deltager",
    "Yes" : "Ja",
    "No" : "Nej",
    "Maybe" : "Måske",
    "None" : "Ingen",
    "Select your meeting availability" : "Vælg din møde tilgængelighed",
    "Create a meeting for this date and time" : "Opret et møde for denne dato og tidspunkt",
    "Create" : "Opret",
    "No participants or dates available" : "Ingen deltagere eller datoer er tilgængelige",
    "from {formattedDate}" : "fra {formattedDate}",
    "to {formattedDate}" : "til {formattedDate}",
    "on {formattedDate}" : "på {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "fra {formattedDate} kl. {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "til {formattedDate} at {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "{formattedDate} kl. {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} kl. {formattedTime}",
    "Please enter a valid date" : "Indtast venligst en gyldig dato",
    "Please enter a valid date and time" : "Indtast venligst en gyldig dato og tid",
    "Select a time zone" : "Vælg en tidszone",
    "Please select a time zone:" : "Vælg venligst en tidszone:",
    "Pick a time" : "Vælg et tidspunkt",
    "Pick a date" : "Vælg en dato",
    "Type to search time zone" : "Indtast for at søge i tidszone",
    "Global" : "Global",
    "Holidays in {region}" : "Ferie i {region}",
    "An error occurred, unable to read public calendars." : "Der opstod en fejl, og det var ikke muligt at læse offentlige kalendere.",
    "An error occurred, unable to subscribe to calendar." : "Der opstod en fejl, og der kunne ikke abonneres på kalenderen.",
    "Public holiday calendars" : "Helligdagskallendere",
    "Public calendars" : "Offentlige kalendere",
    "No valid public calendars configured" : "Ingen gyldige offentlige kalendere konfigureret",
    "Speak to the server administrator to resolve this issue." : "Kontakt venligst serveradministratoren for at løse dette problem.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Helligdagskalendere leveres af Thunderbird. Kalenderdata vil blive downloadet fra {website}",
    "These public calendars are suggested by the server administrator. Calendar data will be downloaded from the respective website." : "Disse offentlige kalendere er foreslået af server administrator. Kalender-data vil blive downloadet fra de pågældende hjemmesider",
    "By {authors}" : "Af {authors}",
    "Subscribed" : "Abonneret",
    "Subscribe" : "Tilmeld",
    "Could not fetch slots" : "Kunne ikke hente pladser",
    "Select a date" : "Vælg en dato",
    "Select slot" : "Vælg tidspunkt",
    "No slots available" : "Ingen ledige tidspunkter",
    "The slot for your appointment has been confirmed" : "Tidspunktet for din aftale er blevet bekræftet",
    "Appointment Details:" : "Detaljer om aftale:",
    "Time:" : "Tid:",
    "Booked for:" : "Booket til:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Tak skal du have. Din reservation fra {startDate} til {endDate} er blevet bekræftet.",
    "Book another appointment:" : "Bestil endnu en tid:",
    "See all available slots" : "Se alle tilgængelige tidspunkter",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Tidsrummet for din aftale fra {startDate} til {endDate} er ikke længere tilgængeligt.",
    "Please book a different slot:" : "Book venligst et andet tidspunkt:",
    "Book an appointment with {name}" : "Book en tid med {name}",
    "No public appointments found for {name}" : "Ingen offentlige aftaler fundet for {name}",
    "Personal" : "Personlig",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Den automatiske tidszoneregistrering bestemte, at din tidszone var UTC.\nDette er højst sandsynligt resultatet af sikkerhedsforanstaltninger i din webbrowser.\nIndstil venligst din tidszone manuelt i kalenderindstillingerne.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Din konfigurerede tidszone ({timezoneId}) blev ikke fundet. Falder tilbage til UTC.\nSkift venligst din tidszone i indstillingerne og rapporter dette problem.",
    "Show unscheduled tasks" : "Vis ikke planlagte opgaver",
    "Unscheduled tasks" : "Ikke planlagte opgaver",
    "Availability of {displayName}" : "Tilgængelighed af {displayName}",
    "Discard event" : "Forkast begivenhed",
    "Edit event" : "Redigér begivenhed",
    "Event does not exist" : "Begivenheden eksisterer ikke",
    "Duplicate" : "dubletter",
    "Delete this occurrence" : "Slet denne forekomst",
    "Delete this and all future" : "Slet denne og alle fremtidige",
    "All day" : "Hele dagen",
    "Modifications wont get propagated to the organizer and other attendees" : "Ændringer vil ikke blive bredt ud til organisatoren og andre deltagere",
    "Managing shared access" : "Håndtering af delt adgang",
    "Deny access" : "Nægt adgang",
    "Invite" : "Invitere",
    "Discard changes?" : "Forkast ændringer?",
    "Are you sure you want to discard the changes made to this event?" : "Er du sikker på at du vil forkaste ændringer der er foretaget på denne begivenhed",
    "_User requires access to your file_::_Users require access to your file_" : ["Brugeren kræver adgang til din fil","Brugere kræver adgang til din fil"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Vedhæftet fil kræver delt adgang","Vedhæftede filer, der kræver delt adgang"],
    "Untitled event" : "Unavngiven begivenhed",
    "Close" : "Luk",
    "Modifications will not get propagated to the organizer and other attendees" : "Ændringer vil ikke blive udbredt til organisatoren eller andre deltagere",
    "Meeting proposals overview" : "Mødeforslagsoversigt",
    "Edit meeting proposal" : "Redigér oversigt over mødeforslag",
    "Create meeting proposal" : "Opret mødeforslag",
    "Update meeting proposal" : "Opdatér mødeforslag",
    "Saving proposal \"{title}\"" : "Gemmer mødeforslag for \"{title}\"",
    "Successfully saved proposal" : "Forslag gemt med succes",
    "Failed to save proposal" : "Forslag kunne ikke gemmes",
    "Create a meeting for \"{date}\"? This will create a calendar event with all participants." : "Opret et møde for \"{date}\"? Dette vil oprette en kalenderbegivenhed for alle deltagere.",
    "Creating meeting for {date}" : "Opretter møde for {date}",
    "Successfully created meeting for {date}" : "Mødet for {date} blev oprettet med succes",
    "Failed to create a meeting for {date}" : "Oprettelse af møde for {date} fejlede",
    "Please enter a valid duration in minutes." : "Indtast venligst en gyldig varighed i minutter",
    "Failed to fetch proposals" : "Hentning af forslag fejlede",
    "Failed to fetch free/busy data" : "Fejl under hentning af ledig/optaget data",
    "Selected" : "Markeret",
    "No Description" : "Ingen beskrivelse",
    "No Location" : "Ingen lokation",
    "Edit this meeting proposal" : "Redigér dette mødeforslag",
    "Delete this meeting proposal" : "Slet dette mødeforslag",
    "Title" : "Titel",
    "15 min" : "15 min",
    "30 min" : "30 min",
    "60 min" : "60 min",
    "90 min" : "90 minutter",
    "Participants" : "Deltagere",
    "Selected times" : "Valgte tidspunkter",
    "Previous span" : "Forrige element",
    "Next span" : "Næste element",
    "Less days" : "Færre dage",
    "More days" : "Flere dage",
    "Loading meeting proposal" : "Indlæser mødeforslag",
    "No meeting proposal found" : "Ingen mødeforslag fundet",
    "Please wait while we load the meeting proposal." : "Vent venligst, mens vi indlæser mødeforslaget",
    "The link you followed may be broken, or the meeting proposal may no longer exist." : "Linket du forsøger at besøge er ødelagt eller mødeforslaget eksisterer ikke mere",
    "Thank you for your response!" : "Tak for dit svar",
    "Your vote has been recorded. Thank you for participating!" : "Din stemme er blevet gemt. Tak for din deltagelse",
    "Unknown User" : "Ukendt bruger",
    "No Title" : "Ingen titel",
    "No Duration" : "Ingen varighed",
    "Select a different time zone" : "Vælg en anden tidszone",
    "Submit" : "Send",
    "Subscribe to {name}" : "Abonner på {name}",
    "Export {name}" : "Eksportér {name}",
    "Show availability" : "Vis tilgængelighed",
    "Anniversary" : "Årsdag",
    "Appointment" : "Aftale",
    "Business" : "Forretning",
    "Education" : "Uddannelse",
    "Holiday" : "Ferie",
    "Meeting" : "Møde",
    "Miscellaneous" : "Diverse",
    "Non-working hours" : "Ikke-arbejdstid",
    "Not in office" : "Ikke på kontoret",
    "Phone call" : "Telefon opkald",
    "Sick day" : "Sygedag",
    "Special occasion" : "Speciel lejlighed",
    "Travel" : "Rejse",
    "Vacation" : "Ferie",
    "Midnight on the day the event starts" : "Midnat på dagen, hvor arrangementet starter",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n dag før begivenheden kl. {formattedHourMinute}","%n dage før begivenheden kl. {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n uge før begivenheden på {formattedHourMinute}","%n uger før begivenheden på {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "på dagen for begivenheden kl. {formattedHourMinute}",
    "at the event's start" : "ved arrangementets start",
    "at the event's end" : "ved arrangementets afslutning",
    "{time} before the event starts" : "{time} før begivenheden starter",
    "{time} before the event ends" : "{time} før begivenheden slutter",
    "{time} after the event starts" : "{time} efter begivenhedens start",
    "{time} after the event ends" : "{time} efter begivenheden slutter",
    "on {time}" : "{time}",
    "on {time} ({timezoneId})" : "den {time} ({timezoneId})",
    "Week {number} of {year}" : "Uge {number} i {year}",
    "Daily" : "Dagligt",
    "Weekly" : "Ugentligt",
    "Monthly" : "Månedligt",
    "Yearly" : "Årligt",
    "_Every %n day_::_Every %n days_" : ["Hver %n dag","Hver %n dage"],
    "_Every %n week_::_Every %n weeks_" : ["Hver %n uge","Hver %n uger"],
    "_Every %n month_::_Every %n months_" : ["Hver %n måned","Hver %n måneder"],
    "_Every %n year_::_Every %n years_" : ["Hver %n år","Hver %n år"],
    "_on {weekday}_::_on {weekdays}_" : ["på {weekday}","på {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["på dagen {dayOfMonthList}","på dagene {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "på {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {dayOfMonthList}" : "i {monthNames} på dagen(e) {dayOfMonthList}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "i {monthNames} på {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "indtil {untilDate}",
    "_%n time_::_%n times_" : ["%n gang","%n gange"],
    "second" : "sekund",
    "third" : "tredje",
    "fourth" : "fjerde",
    "fifth" : "femte",
    "second to last" : "næstsidste",
    "last" : "sidste",
    "Untitled task" : "Unavngivet opgave",
    "Please ask your administrator to enable the Tasks App." : "Bed din administrator om at aktivere Opgaver-appen.",
    "You are not allowed to edit this event as an attendee." : "Du har ikke tilladelse til at redigere denne begivenhed som deltager.",
    "W" : "U",
    "%n more" : "%n yderligere",
    "No events to display" : "Ingen begivenheder",
    "All participants declined" : "Alle deltagere afviste",
    "Please confirm your participation" : "Bekræft venligst din deltagelse",
    "You declined this event" : "Di afviste denne begivenhed",
    "Your participation is tentative" : "Din deltagelse er foreløbig",
    "_+%n more_::_+%n more_" : ["+%n yderligere","+%n yderligere"],
    "No events" : "Ingen begivenheder",
    "Create a new event or change the visible time-range" : "Opret en ny begivenhed, eller skift det synlige tidsinterval",
    "Failed to save event" : "Kunne ikke gemme event",
    "It might have been deleted, or there was a typo in a link" : "Det kan være blevet slettet, eller der var en tastefejl i et link",
    "It might have been deleted, or there was a typo in the link" : "Det kan være blevet slettet, eller der var en tastefejl i linket",
    "Meeting room" : "Mødelokale",
    "Lecture hall" : "Foredragssal",
    "Seminar room" : "Seminarrum",
    "Other" : "Andet",
    "When shared show" : "Ved delt vis",
    "When shared show full event" : "Når delt, vis den fulde begivenhed",
    "When shared show only busy" : "Når delt, vis kun optaget",
    "When shared hide this event" : "Når delt, skjul denne begivenhed",
    "The visibility of this event in read-only shared calendars." : "Synligheden af denne aftale i delte skrivebeskyttede kalendere.",
    "Add a location" : "Tilføj en placering",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Tilføj en beskrivelse\n\n- Hvad omhandler mødet\n- Dagsordenselementer\n- Noget som deltagerne skal forberede",
    "Status" : "Status",
    "Confirmed" : "Bekræftet",
    "Canceled" : "Annulleret",
    "Confirmation about the overall status of the event." : "Bekræftelse af arrangementets overordnede status.",
    "Show as" : "Vis som",
    "Take this event into account when calculating free-busy information." : "Tag denne begivenhed i betragtning, når du beregner ledig-optaget-information.",
    "Categories" : "Kategorier",
    "Categories help you to structure and organize your events." : "Kategorier hjælper dig med at strukturere og organisere dine begivenheder.",
    "Search or add categories" : "Søg eller tilføj kategorier",
    "Add this as a new category" : "Tilføj dette som en ny kategori",
    "Custom color" : "Brug brugerdefineret farve",
    "Special color of this event. Overrides the calendar-color." : "Særlig farve på denne begivenhed. Tilsidesætter kalenderfarven.",
    "Error while sharing file" : "Fejl ved deling af fil",
    "Error while sharing file with user" : "Fejl under deling af fil med bruger",
    "Error creating a folder {folder}" : "Fejl under oprettelse af en mappe {folder}",
    "Attachment {fileName} already exists!" : "Vedhæftet fil {fileName} findes allerede!",
    "Attachment {fileName} added!" : "Vedhæftning {fileName} tilføjet!",
    "An error occurred during uploading file {fileName}" : "En fejl opstod under upload af fil {fileName}",
    "An error occurred during getting file information" : "Der opstod en fejl under hentning af filoplysninger",
    "Talk conversation for proposal" : "Snak samtale for forslag",
    "An error occurred, unable to delete the calendar." : "Kalenderen kunne ikke slettes.",
    "Imported {filename}" : "Importerede {filename}",
    "This is an event reminder." : "Dette er en begivenhedspåmindelse.",
    "Error while parsing a PROPFIND error" : "Fejl under parsing af en PROPFIND-fejl",
    "Appointment not found" : "Aftale ikke fundet",
    "User not found" : "Bruger ikke fundet",
    "Hidden" : "Skjult",
    "can edit" : "kan redigere",
    "Calendar name …" : "Kalender navn …",
    "Default attachments location" : "Standardplacering for vedhæftede filer",
    "Automatic ({detected})" : "Automatisk ({detected})",
    "Shortcut overview" : "Genvejsoversigt",
    "CalDAV link copied to clipboard." : "CalDAV-linket er kopieret til udklipsholderen.",
    "CalDAV link could not be copied to clipboard." : "CalDAV-linket kunne ikke kopieres til udklipsholderen.",
    "Enable birthday calendar" : "Slå fødselsdagskalender til",
    "Show tasks in calendar" : "Vis opgaver i kalenderen",
    "Enable simplified editor" : "Slå simpel editor til",
    "Limit the number of events displayed in the monthly view" : "Begræns antallet af hændelser, der vises i månedsvisningen",
    "Show weekends" : "Vis weekender",
    "Show week numbers" : "Vis ugenummer ",
    "Time increments" : "Tidsintervaller",
    "Default calendar for incoming invitations" : "Standard kalender for indkomne invitationer",
    "Copy primary CalDAV address" : "Kopier primær CalDAV-adresse",
    "Copy iOS/macOS CalDAV address" : "Kopiér iOS/macOS CalDAV adresse",
    "Personal availability settings" : "Personlige tilgængelighedsindstillinger",
    "Show keyboard shortcuts" : "Vis tastaturgenveje",
    "Create a new public conversation" : "Opret en ny offentlig samtale",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} inviteret, {confirmedCount} bekræftet",
    "Successfully appended link to talk room to location." : "Linket til Snak rum er tilføjet til lokationen.",
    "Successfully appended link to talk room to description." : "Link til Snak rum blev tilføjet til beskrivelse.",
    "Error creating Talk room" : "Fejl ved oprettelse af Snak rum",
    "_%n more guest_::_%n more guests_" : ["%n flere gæster","%n flere gæster"],
    "The visibility of this event in shared calendars." : "Synligheden af denne begivenhed i delte kalendere."
},
"nplurals=2; plural=(n != 1);");
