OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Norādītā e-pasta adrese ir pārāk gara",
    "User-Session unexpectedly expired" : "Lietotāja sesija negaidīti beidzās",
    "Provided email-address is not valid" : "Norādītā e-pasta adrese nav derīga",
    "%s has published the calendar »%s«" : "%s dalījās ar kalendāru »%s«",
    "Unexpected error sending email. Please contact your administrator." : "E-pasta ziņojuma nosūtīšanas laikā bija neparedzēta kļūda. Lūgums sazināties ar savu pārvaldītāju.",
    "Successfully sent email to %1$s" : "E-pasta ziņojums sekmīgi nosūtīts uz %1$s",
    "Hello," : "Sveiciens,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Mēs vēlējāmies ziņot, ka %s padarīja pieejamu kalendāru »%s«.",
    "Open »%s«" : "Atvērt »%s«",
    "Cheers!" : "Priekā!",
    "Upcoming events" : "Gaidāmie notikumi",
    "No more events today" : "Šodien vairs nav notikumu",
    "No upcoming events" : "Nav gaidāmu notikumu",
    "More events" : "Vairāk notikumu",
    "%1$s with %2$s" : "%1$s ar %2$s",
    "Calendar" : "Kalendārs",
    "New booking {booking}" : "Jauna rezervācija {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) rezervēja tikšanos \"{config_display_name}\" {date_time}.",
    "Appointments" : "Plānotās tikšanās",
    "Schedule appointment \"%s\"" : " Ieplānot tikšanos \"%s\"",
    "Schedule an appointment" : "Ieplānot tikšanos",
    "Prepare for %s" : "Sagatavojies %s",
    "Follow up for %s" : "Seko līdzi %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Tavai tikšanās \"%s\" ar %s nepieciešama apstiprināšana.",
    "Dear %s, please confirm your booking" : " %s, lūgums apstiprināt savu rezervāciju",
    "Confirm" : "Apstiprināt",
    "This confirmation link expires in %s hours." : "Šī apstiprinājuma saites derīgums beigsies pēc %s stundām.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Ja tomēr ir vēlme atcelt tikšanos, lūgums sazināties ar rīkotāju, atbildot uz šo e-pasta ziņojumu vai apmeklējot tā profilu.",
    "Your appointment \"%s\" with %s has been accepted" : "Tava paredzētā  tikšanās \"%s\" ar %s tika apstiprināta.",
    "Dear %s, your booking has been accepted." : " %s, Tava rezervācija tika apstiprināta.",
    "Appointment for:" : "Plānota tikšanās:",
    "Date:" : "Datums:",
    "You will receive a link with the confirmation email" : "Tu saņemsi saiti apstiprinājuma e-pasta ziņojumā",
    "Where:" : "Kur:",
    "Comment:" : "Piebilde:",
    "You have a new appointment booking \"%s\" from %s" : "Jums ir jauna tikšanās rezervācija \"%s\" no %s",
    "Dear %s, %s (%s) booked an appointment with you." : " %s, %s (%s) rezervēja tikšanos ar Jums.",
    "Location:" : "Atrašanās vieta:",
    "A Calendar app for Nextcloud" : "Nextcloud kalendāra lietotne",
    "Previous day" : "Iepriekšējā diena",
    "Previous week" : "Iepriekšējā nedēļa",
    "Previous year" : "Iepriekšējais gads",
    "Previous month" : "Iepriekšējais mēnesis",
    "Next day" : "Nākamā diena",
    "Next week" : "Nākamā nedēļa",
    "Next year" : "Nākamais gads",
    "Next month" : "Nākamais mēnesis",
    "Create new event" : "Izveidot jaunu notikumu",
    "Event" : "Notikums",
    "Today" : "Šodien",
    "Day" : "Diena",
    "Week" : "Nedēļa",
    "Month" : "Mēnesis",
    "Year" : "Gads",
    "List" : "Saraksts",
    "Appointment link was copied to clipboard" : "Plānotās tikšanās saite tika ievietota starpliktuvē.",
    "Appointment link could not be copied to clipboard" : "Plānotās tikšanās saiti nevarēja ievietot starpliktuvē.",
    "Preview" : "Priekšskatīt",
    "Copy link" : "Ievietot saiti starpliktuvē",
    "Edit" : "Labot",
    "Delete" : "Izdzēst",
    "Create new" : "Izveidot jaunu",
    "Disable calendar \"{calendar}\"" : "Atspējot kalendāru \"{calendar}\"",
    "Disable untitled calendar" : "Atspējot kalendāru bez nosaukuma",
    "Enable calendar \"{calendar}\"" : "Iespējot kalendāru \"{calendar}\"",
    "Enable untitled calendar" : "Iespējot kalendāru bez nosaukuma ",
    "An error occurred, unable to change visibility of the calendar." : "Atgadījās kļūda, nevar mainīt kalendāra redzamību.",
    "Untitled calendar" : "Kalendārs bez nosaukuma",
    "Shared with you by" : "Koplietots ar Jums",
    "Edit and share calendar" : "Labot un koplietot kalendāru",
    "Edit calendar" : "Labot kalendāru",
    "An error occurred, unable to create the calendar." : "Atgadījās kļūda, nevar izveidot kalendāru.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Lūgums ievadīt derīgu saiti (sākas ar http://, https://, webcal:// vai webcals://)",
    "Calendars" : "Kalendāri",
    "Add new" : "Pievienot jaunu",
    "New calendar" : "Jauns kalendārs",
    "Name for new calendar" : "Jaunā kalendāra nosaukums",
    "Creating calendar …" : "Izveido kalendāru ...",
    "New calendar with task list" : "Jauns kalendārs ar uzdevumu sarakstu",
    "New subscription from link (read-only)" : "Jauna abonēšana no saites (tikai lasāms)",
    "Creating subscription …" : "Izveido abonementu ...",
    "Add public holiday calendar" : "Pievienot publisku brīvdienu kalendāru",
    "Add custom public calendar" : "Pievienot pielāgotu publisko kalendāru",
    "Calendar link copied to clipboard." : "Kalendāra saite ievietota starpliktuvē.",
    "Calendar link could not be copied to clipboard." : "Kalendāra saiti nevarēja ievietot starpliktuvē.",
    "Copy subscription link" : "Ievietot abonēšanas saiti starpliktuvē",
    "Copying link …" : "Saite tiek ievietota starpliktuvē ...",
    "Copied link" : "Kopēta saite",
    "Could not copy link" : "Neizdevās ievietot saiti starpliktuvē",
    "Export" : "Izgūt",
    "Untitled item" : "Nenosaukts vienums",
    "Unknown calendar" : "Nezināms kalendārs",
    "Could not load deleted calendars and objects" : "Nevarēja ielādēt izdzēstos kalendārus un objektus",
    "Could not restore calendar or event" : "Nevarēja atjaunot kalendāru vai notikumu",
    "Do you really want to empty the trash bin?" : "Vai tiešām iztukšot atkritni?",
    "Empty trash bin" : "Izdzēst atkritnes saturu",
    "Trash bin" : "Miskaste",
    "Loading deleted items." : "Ielādē izdzēstos vienumus.",
    "You do not have any deleted items." : "Nav neviena izdzēsta vienuma.",
    "Name" : "Nosaukums",
    "Deleted" : "Izdzēsts",
    "Restore" : "Atjaunot",
    "Delete permanently" : "Neatgriezeniski izdzēst",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Atkritnes vienumi tiek izdzēsti pēc {numDays} dienām","Atkritnes vienumi tiek izdzēsti pēc {numDays} dienas","Atkritnes vienumi tiek izdzēsti pēc {numDays} dienām"],
    "Could not update calendar order." : "Nevarēja atjaunināt kalendāru secību.",
    "Internal link" : "Iekšējā saite",
    "A private link that can be used with external clients" : "Privāta saite, kas var tikt izmantota ar ārējiem klientiem.",
    "Copy internal link" : "Ievietot iekšējo saiti starpliktuvē",
    "An error occurred, unable to publish calendar." : "Atgadījās kļūda, neizdevās publiskot kalendāru.",
    "An error occurred, unable to send email." : "Atgadījās kļūda, nevarēja nosūtīt e-pasta ziņojumu.",
    "Embed code copied to clipboard." : "Iegulšanas kods ievietots starpliktuvē.",
    "Embed code could not be copied to clipboard." : "Iegulšanas kodu nevarēja ievietot starpliktuvē.",
    "Unpublishing calendar failed" : "Neizdevās atcelt kalendāra publicēšanu",
    "Share link" : "Koplietot saiti",
    "Copy public link" : "Ievietot publisko saiti starpliktuvē",
    "Send link to calendar via email" : "Nosūtīt saiti kalendāra saiti e-pastā",
    "Enter one address" : "Ievadiet vienu adresi",
    "Sending email …" : "Sūta e-pastu ...",
    "Copying code …" : "Kopē kodu ...",
    "Copied code" : "Kopētais kods",
    "Could not copy code" : "Neizdevās nokopēt kodu",
    "Delete share link" : "Izdzēst kopīgojuma saiti",
    "Deleting share link …" : "Dzēš koplietoto saiti ...",
    "An error occurred while unsharing the calendar." : "Atgadījās kļūda kalendāra koplietošanas atcelšanas laikā.",
    "An error occurred, unable to change the permission of the share." : "Atgadījās kļūda, nevar mainīt kopīgojuma atļauju.",
    "Unshare with {displayName}" : "Atcelt kopīgošanu ar {displayName}",
    "Share with users or groups" : "Koplietot ar lietotājiem vai grupām",
    "No users or groups" : "Nav lietotāji vai grupas",
    "Failed to save calendar name and color" : "Neizdevās saglabāt kalendāra nosaukumu un krāsu.",
    "Never show me as busy (set this calendar to transparent)" : "Nekad nerādīt mani kā aizņemtu (iestatīt šo kalendāru caurspīdīgu)",
    "Share calendar" : "Koplietot kalendāru",
    "Unshare from me" : "Atcelt koplietošanu no manis",
    "Save" : "Saglabāt",
    "View" : "Skats",
    "Import calendars" : "Ievietot kalendārus",
    "Please select a calendar to import into …" : "Lūgums atlasīt kalendāru, kurā ievietot ...",
    "Filename" : "Datnes nosaukums",
    "Calendar to import into" : "Kalendārs, kurā ievietot",
    "Cancel" : "Atcelt",
    "Select the default location for attachments" : "Atlasīt pielikumu noklusējuma atrašanās vietu",
    "Invalid location selected" : "Ir izvēlēta nederīga atrašanās vieta ",
    "Attachments folder successfully saved." : "Pielikumu mape saglabāta sekmīgi.",
    "Error on saving attachments folder." : "Kļūda saglabājot pielikumu mapi.",
    "No valid files found, aborting import" : "Nav atrastas derīgas datnes, ievietošana tiek pārtraukta.",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Sekmīgi ievietoti %n notikumi","Sekmīgi ievietots %n notikums","Sekmīgi ievietoti %n notikumi"],
    "Import partially failed. Imported {accepted} out of {total}." : "Ievietošana daļēji neizdevās. Ievietoti {accepted} no {total}.",
    "Automatic" : "Automātisks",
    "Automatic ({timezone})" : "Automātiski ({timezone})",
    "New setting was not saved successfully." : "Jauna iestatījuma saglabāšana neizdevās.",
    "Timezone" : "Laika josla",
    "Navigation" : "Navigācija",
    "Previous period" : "Iepriekšējais laika posms",
    "Next period" : "Nākamais periods",
    "Views" : "Skatījumi",
    "Day view" : "Dienas skats",
    "Week view" : "Nedēļas skats",
    "Month view" : "Mēneša skats",
    "Year view" : "Gada skats",
    "List view" : "Saraksta izkārtojums",
    "Actions" : "Darbības",
    "Create event" : "Izveidot notikumu",
    "Show shortcuts" : "Rādīt saīsnes",
    "Editor" : "Redaktors",
    "Close editor" : "Aizvērt redaktoru",
    "Save edited event" : "Saglabāt laboto notikumu",
    "Delete edited event" : "Izdzēst laboto notikumu",
    "Duplicate event" : "Pavairot notikumu",
    "or" : "vai",
    "Calendar settings" : "Kalendāra iestatījumi",
    "No reminder" : "Nav atgādinājuma",
    "Failed to save default calendar" : "Neizdevās saglabāt noklusējuma kalendāru",
    "General" : "Vispārīgi",
    "Appearance" : "Izskats",
    "Editing" : "Labošana",
    "Default reminder" : "Noklusējuma atgādinājums",
    "Files" : "Datnes",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minūšu","{duration} minūte","{duration} minūtes"],
    "0 minutes" : "0 minūtes",
    "_{duration} hour_::_{duration} hours_" : ["{duration} stundu","{duration} stunda","{duration} stundas"],
    "_{duration} day_::_{duration} days_" : ["{duration} dienas","{duration} diena","{duration} dienas"],
    "To configure appointments, add your email address in personal settings." : "Lai konfigurētu pievienotos notikumus, personiskajos iestatījumos jāpievieno sava e-pasta adrese.",
    "Public – shown on the profile page" : "Publiski - parādīts profilā",
    "Private – only accessible via secret link" : "Privāts – pieejams tikai ar slepeno saiti",
    "Update" : "Atjaunināt",
    "Appointment name" : "Tikšanās nosaukums",
    "Location" : "Atrašanās vieta",
    "Create a Talk room" : "Izveidojiet Tērzēšanas istabu",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Neatkārtojama saite tiks izveidota katram aizņemtajam tikšanās laikam un tiks nosūtīta ar apstiprinājuma e-pasta ziņojumu.",
    "Description" : "Apraksts",
    "Visibility" : "Redzamība",
    "Duration" : "Ilgums",
    "Additional calendars to check for conflicts" : "Papildu kalendāri nesaderību pārbaudīšanai",
    "Pick time ranges where appointments are allowed" : "Jāizvēlas laika apgabali, kuros ir atļautas tikšanās",
    "to" : "kam",
    "No times set" : "Laiks nav noteikts",
    "Add" : "Pievienot",
    "Monday" : "Pirmdiena",
    "Tuesday" : "Otrdiena",
    "Wednesday" : "Trešdiena",
    "Thursday" : "Ceturtdiena",
    "Friday" : "Piektdiena",
    "Saturday" : "Sestdiena",
    "Sunday" : "Svētdiena",
    "Add time before and after the event" : "Pievienot laiku pirms un pēc notikuma",
    "Before the event" : "Pirms notikuma",
    "After the event" : "Pēc notikuma",
    "Planning restrictions" : "Plānošanas ierobežojumi",
    "Limit how far in the future appointments can be booked" : "Ierobežot, cik tālu nākotnē var rezervēt plānotu tikšanos.",
    "Please confirm your reservation" : "Lūgums apstiprināt savu rezervāciju",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Mēs nosūtījām e-pasta ziņojumu ar informāciju. Lūgums apstiprināt savu tikšanos ar e-pasta ziņojumā esošo saiti. Šo lapu tagad var aizvērt.",
    "Your name" : "Tavs vārds",
    "Your email address" : "Tava e-pasta adrese",
    "Please share anything that will help prepare for our meeting" : "Lūgums koplietot visu, kas palīdzēs sagatavoties mūsu sanāksmei",
    "Could not book the appointment. Please try again later or contact the organizer." : "Neizdevās pieteikt tikšanos. Lūgums vēlāk mēģināt vēlreiz vai sazināties ar rīkotāju.",
    "Successfully added Talk conversation link to location." : "Talk sarunas saite sekmīgi pievienota atrašanās vietai.",
    "Successfully added Talk conversation link to description." : "Talk sarunas saite sekmīgi pievienota aprakstam.",
    "Failed to apply Talk room." : "Neizdevās pielietot Talk istabu.",
    "Add Talk conversation" : "Pievienot Talk sarunu",
    "Select conversation" : "Atlasīt sarunu",
    "at" : "plkst.",
    "before at" : "pirms ",
    "Notification" : "Paziņojums",
    "Email" : "E-pasts",
    "Audio notification" : "Skaņas paziņojums",
    "Other notification" : "Cits paziņojums",
    "Relative to event" : "Attiecībā pret notikumu",
    "On date" : "Datumā",
    "Edit time" : "Labot laiku",
    "Save time" : "Saglabāt laiku",
    "Remove reminder" : "Noņemt atgādinājumu",
    "Add reminder" : "Pievienot atgādinājumu",
    "seconds" : "sekundes",
    "minutes" : "minūtes",
    "hours" : "stundas",
    "days" : "dienas",
    "weeks" : "nedēļas",
    "Choose a file to add as attachment" : "Izvēlēties datni, ko pievienot kā pielikumu",
    "Choose a file to share as a link" : "Jāizvēlas datne, ko kopīgot kā saiti",
    "Attachment {name} already exist!" : "Pielikums {name} jau pastāv.",
    "Could not upload attachment(s)" : "Neizdevās augšupielādēt pielikumu(s)",
    "No attachments" : "Nav pielikumu",
    "Add from Files" : "Pievienot no Datnēm",
    "Upload from device" : "Augšupielādēt no ierīces",
    "Delete file" : "Izdzēst datni",
    "Suggested" : "Ieteikts",
    "Available" : "Pieejams",
    "Invitation accepted" : "Ielūgums apstiprināts",
    "Accepted {organizerName}'s invitation" : "Apstiprināts {organizerName} uzaicinājums",
    "Participation marked as tentative" : "Dalība atzīmēta kā nenoteikta",
    "Invitation is delegated" : "Uzaicinājums ir deleģēts",
    "Not available" : "Nav pieejams",
    "Invitation declined" : "Ielūgums noraidīts",
    "Declined {organizerName}'s invitation" : "Noraidīts {organizerName} uzaicinājums",
    "Failed to check availability" : "Neizdevās pārbaudīt pieejamību",
    "Failed to deliver invitation" : "Uzaicinājumu neizdevās piegādāt",
    "Awaiting response" : "Gaida atbildi",
    "Checking availability" : "Pārbauda pieejamību",
    "Has not responded to {organizerName}'s invitation yet" : "Vēl nav atbildējis uz {organizerName} uzaicinājumu",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Availability of attendees, resources and rooms" : "Dalībnieku, resursu un telpu pieejamība",
    "Out of office" : "Ārpus biroja",
    "Done" : "Pabeigts",
    "Room name" : "Sapulču telpas nosaukums",
    "Free" : "Brīvs",
    "Busy (tentative)" : "Aizņemts (nenoteikts)",
    "Busy" : "Aizņemts",
    "Unknown" : "Nezināms",
    "Find a time" : "Atrast laiku",
    "The invitation has been accepted successfully." : "Uzaicinājums tika sekmīgi apstiprināts.",
    "Failed to accept the invitation." : "Neizdevās apstiprināt uzaicinājumu.",
    "The invitation has been declined successfully." : "Uzaicinājums tika sekmīgi noraidīts.",
    "Failed to decline the invitation." : "Neizdevās atteikt uzaicinājumu.",
    "Your participation has been marked as tentative." : "Tava piedalīšanās tika atzīmēta kā nenoteikta.",
    "Failed to set the participation status to tentative." : "Neizdevās iestatīt dalības stāvokli kā nenoteiktu.",
    "Accept" : "Pieņemt",
    "Decline" : "Noraidīt",
    "Tentative" : "Mēģinājums",
    "No attendees yet" : "Vēl nav dalībnieku",
    "Attendees" : "Dalībnieki",
    "Remove group" : "Noņemt grupu",
    "Remove attendee" : "Noņemt dalībnieku",
    "Request reply" : "Pieprasīt atbildi",
    "Chairperson" : "Priekšsēdētājs",
    "Required participant" : "Nepieciešams dalībnieks",
    "Optional participant" : "Papildu dalībnieks",
    "Search for emails, users, contacts, contact groups or teams" : "Meklēt e-pasta adreses, lietotājus, kontaktpersonas, saziņas kopas vai komandas",
    "Remove color" : "Noņemt krāsu",
    "Event title" : "Notikuma nosaukums",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Nevar izmainīt visas dienas iestatījumu notikumiem, kas ir daļa no atkārtojumu kopas.",
    "From" : "No",
    "To" : "Līdz",
    "Repeat" : "Atkārtot",
    "never" : "nekad",
    "on date" : "datumā",
    "after" : "pēc",
    "End repeat" : "Beigt atkārtošanu",
    "Select to end repeat" : "Atlasīt, lai beigtu atkārtošanu",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Šis notikums ir atkārtojuma izņēmums no atkārtojumu kopas. Tam nevar pievienot atkārtojuma kārtulu.",
    "first" : "pirmais",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Izmaiņas atkārtošanās kārtulai tiks piemērotas tikai šim un visiem turpmākajiem notikumiem.",
    "Repeat every" : "Atkārtot katru",
    "By day of the month" : "Mēneša dienā",
    "weekday" : "darba diena",
    "weekend day" : "brīvdiena",
    "Does not repeat" : "Neatkārtojas",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Atkārtošanās definīcija šim notikumam Nextcloud nav pilnībā atbalstīta. Ja tiek labotas atkārtošanās iespējas, noteikti atkārtojošies notikumi var tikt zaudēti.",
    "No rooms or resources yet" : "Vēl nav telpu vai resursu.",
    "Resources" : "Resursi",
    "Add resource" : "Pievienot resursu",
    "Has a projector" : "Ir projektors",
    "Has a whiteboard" : "Ir tāfele",
    "Wheelchair accessible" : "Iespējams piekļūt ar ratiņkrēslu",
    "Remove resource" : "Noņemt resursu",
    "Search for resources or rooms" : "Meklēt resursus vai telpas",
    "available" : "pieejams",
    "unavailable" : "nav pieejams",
    "Projector" : "Projektors",
    "Whiteboard" : "Tāfele",
    "Room type" : "Telpas veids",
    "Any" : "jebkurš",
    "Minimum seating capacity" : "Mazākā sēdvietu ietilpība",
    "More details" : "Izvērstāk",
    "Update this and all future" : "Atjaunināt šo un visus turpmākos",
    "Update this occurrence" : "Atjaunināt šo notikumu",
    "Public calendar does not exist" : "Publiskais kalendārs nepastāv",
    "Maybe the share was deleted or has expired?" : "Varbūt kopīgojums tika izdzēsts, vai arī ir beidzies tā derīgums?",
    "Yes" : "Jā",
    "No" : "Nē",
    "None" : "Nekas",
    "from {formattedDate}" : "no {formattedDate}",
    "to {formattedDate}" : "līdz {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "no {formattedDate} plkst. {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "līdz {formattedDate} plkst. {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "{formattedDate} plkst. {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} plkst. {formattedTime}",
    "Please enter a valid date" : "Lūgums ievadīt derīgu datumu",
    "Please enter a valid date and time" : "Lūgums ievadīt derīgu datumu un laiku",
    "Please select a time zone:" : "Lūgums atlasīt laika joslu:",
    "Pick a time" : "Izvēlēties laiku",
    "Pick a date" : "Izvēlēties datumu",
    "Type to search time zone" : "Rakstīt, lai meklētu laika zonu",
    "Global" : "Globāls",
    "Holidays in {region}" : "Brīvdienas {region}",
    "An error occurred, unable to read public calendars." : "Atgadījās kļūda, nevarēja nolasīt publiskos kalendārus.",
    "An error occurred, unable to subscribe to calendar." : "Atgadījās kļūda, neizdevās abonēt kalendāru.",
    "Speak to the server administrator to resolve this issue." : "Jāsazinās ar servera pārvaldītāju, lai atrisinātu šo sarežģījumu.",
    "Subscribed" : "Abonēts",
    "Subscribe" : "Abonēt",
    "Select slot" : "Atlasīt laikspraugu",
    "The slot for your appointment has been confirmed" : "Vieta paredzētajam notikumam tika apstiprināta",
    "Appointment Details:" : "Informācija par paredzēto tikšanos:",
    "Time:" : "Laiks:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Paldies! Rezervācija no {startDate} līdz {endDate} tika apstiprināta.",
    "Book another appointment:" : "Rezervēt vēl vienu plānotu tikšanos",
    "Book an appointment with {name}" : "Pieteikt tikšanos ar {name}",
    "Personal" : "Personīgs",
    "Edit event" : "Labot notikumu",
    "Event does not exist" : "Notikums nepastāv",
    "Duplicate" : "Pavairot",
    "Delete this occurrence" : "Izdzēst šo notikumu",
    "All day" : "Visas dienas",
    "Managing shared access" : "Koplietotās piekļuves pārvaldība",
    "Deny access" : "Liegt piekļuvi",
    "Invite" : "Uzaicināt",
    "_User requires access to your file_::_Users require access to your file_" : ["Lietotāji pieprasa piekļuvi Tavai datnei","Lietotājs pieprasa piekļuvi Tavai datnei","Lietotāji pieprasa piekļuvi Tavai datnei"],
    "Untitled event" : "Nenosaukts notikums",
    "Close" : "Aizvērt",
    "Selected" : "Atlasītās",
    "Title" : "Virsraksts",
    "Participants" : "Dalībnieki",
    "Submit" : "Iesniegt",
    "Subscribe to {name}" : "Abonēt {name}",
    "Export {name}" : "Izgūt {name}",
    "Anniversary" : "Gadadiena",
    "Appointment" : "Plānota tikšanās",
    "Business" : "Komandējums",
    "Education" : "Izglītība",
    "Holiday" : "Brīvdiena",
    "Meeting" : "Tikšanās",
    "Miscellaneous" : "Dažādi",
    "Non-working hours" : "Ārpus darba laika",
    "Not in office" : "Ārpus biroja",
    "Phone call" : "Telefona zvans",
    "Sick day" : "Slimības diena",
    "Special occasion" : "Īpašs notikums",
    "Travel" : "Ceļojums",
    "Vacation" : "Atvaļinājums",
    "Midnight on the day the event starts" : "Pusnakts dienā, kad notiek notikums",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n dienas pirms notikuma plkst. {formattedHourMinute}","%n dienu pirms notikuma plkst. {formattedHourMinute}","%n dienas pirms notikuma plkst. {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n nedēļas pirms notikuma plkst. {formattedHourMinute}","%n nedēļu pirms notikuma plkst. {formattedHourMinute}","%n nedēļas pirms notikuma plkst. {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "notikuma dienā plkst. {formattedHourMinute}",
    "at the event's start" : "notikuma sākumā",
    "at the event's end" : "notikuma beigās",
    "{time} before the event starts" : "{time} pirms notikuma sākuma",
    "{time} before the event ends" : "{time} pirms notikuma beigām",
    "{time} after the event starts" : "{time} pēc notikuma sākuma",
    "{time} after the event ends" : "{time} pēc notikuma beigām",
    "Week {number} of {year}" : "{number} nedēļa no {year}",
    "Daily" : "Katru dienu",
    "Weekly" : "Katru nedēļu",
    "Monthly" : "Ikmēneša",
    "Yearly" : "Ik gadu",
    "_on {weekday}_::_on {weekdays}_" : ["{weekdays}","{weekdays}","{weekdays}"],
    "until {untilDate}" : "līdz {untilDate}",
    "second" : "otrais",
    "third" : "trešais",
    "fourth" : "ceturtais",
    "fifth" : "piektais",
    "second to last" : "pirmspēdējais",
    "last" : "pēdējais",
    "Untitled task" : "Uzdevums bez nosaukuma",
    "Please ask your administrator to enable the Tasks App." : "Lūgums vaicāt pārvaldītājam iespējot uzdevumu lietotni.",
    "You are not allowed to edit this event as an attendee." : "Nav ļauts labot šo notikumu kā dalībniekam.",
    "%n more" : "vēl %n ",
    "No events to display" : "Nav notikumu, ko attēlot",
    "_+%n more_::_+%n more_" : ["+ vēl %n","+ vēl %n","+ vēl %n"],
    "No events" : "Nav notikumu",
    "Create a new event or change the visible time-range" : "Izveidot jaunu notikumu vai mainīt redzamo laika diapazonu",
    "Failed to save event" : "Neizdevās saglabāt notikumu",
    "Meeting room" : "Sanāksmju telpa",
    "Lecture hall" : "Lekciju zāle",
    "Seminar room" : "Semināra telpa",
    "Other" : "Cits",
    "When shared show" : "Kad koplietots rāda",
    "When shared show full event" : "Ja kopīgots, tad rādīt pilnu notikumu",
    "When shared show only busy" : "Ja kopīgots, tad rādīt tikai aizņemtos",
    "When shared hide this event" : "Ja kopīgots, tad paslēpt šo notikumu",
    "Add a location" : "Pievienot atrašanās vietu",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Pievienot aprakstu\n\n- Par ko ir šī tikšanās\n- Darba kārtības vienumi\n- Jebkas, kam dalībniekiem ir jāsagatavojas",
    "Status" : "Status",
    "Confirmed" : "Apstiprināts",
    "Canceled" : "Atcelts",
    "Confirmation about the overall status of the event." : "Apstiprinājums par kopējo notikuma stāvokli.",
    "Show as" : "Rādīt kā",
    "Take this event into account when calculating free-busy information." : "Ņemiet vērā šo notikumu, aprēķinot pieejamību vai aizņemtību.",
    "Categories" : "Kategorijas",
    "Categories help you to structure and organize your events." : "Kategorijas palīdz jums strukturēt un organizēt savus notikumus.",
    "Search or add categories" : "Meklēt vai pievienot kategorijas",
    "Add this as a new category" : "Pievienot kā jaunu kategoriju",
    "Custom color" : "Pielāgota krāsa",
    "Special color of this event. Overrides the calendar-color." : "Īpaša notikuma krāsa. Aizstāj kalendāra krāsu.",
    "Error while sharing file" : "Kļūda datnes kopīgošanā",
    "Error while sharing file with user" : "Kļūda datnes kopīgošanā ar lietotāju",
    "Attachment {fileName} already exists!" : "Pielikums {fileName} jau pastāv.",
    "An error occurred during getting file information" : "Kļūda datnes informācijas iegūšanas laikā",
    "An error occurred, unable to delete the calendar." : "Atgadījās kļūda, neizdevās izdzēst kalendāru.",
    "Imported {filename}" : "Ievietota {filename}",
    "This is an event reminder." : "Šis ir notikuma atgādinājums.",
    "Appointment not found" : "Tikšanās nav atrasta",
    "User not found" : "Lietotājs nav atrasts",
    "Hidden" : "Paslēpts",
    "can edit" : "var labot",
    "Calendar name …" : "Kalendāra nosaukums ...",
    "Default attachments location" : "Pielikumu noklusējuma atrašanās vietas",
    "Automatic ({detected})" : "Automātiska ({detected})",
    "Shortcut overview" : "Īsceļu pārskats",
    "CalDAV link copied to clipboard." : "Kalendāra saite ievietota starpliktuvē.",
    "CalDAV link could not be copied to clipboard." : "Kalendāra saiti neizdevās ievietot starpliktuvē.",
    "Enable birthday calendar" : "Iespējot dzimšanas dienas kalendāru",
    "Show tasks in calendar" : "Rādīt uzdevumus kalendārā",
    "Enable simplified editor" : "Iespējot vienkāršoto redaktoru",
    "Limit the number of events displayed in the monthly view" : "Ierobežot notikumu skaitu, kas tiek parādīti mēneša skatā",
    "Show weekends" : "Rādīt nedēļas nogales",
    "Show week numbers" : "Rādīt nedēļu numurus",
    "Copy primary CalDAV address" : "Ievietot starpliktuvē galveno CalDAV adresi",
    "Copy iOS/macOS CalDAV address" : "Kopēt IOS/macOS CalDAV adresi",
    "Personal availability settings" : "Personiskās pieejamības iestatījumi",
    "Show keyboard shortcuts" : "Rādīt tastatūras saīsnes taustiņus",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} uzaicināti, {confirmedCount} apstiprinājuši",
    "Error creating Talk room" : "Notika kļūda, veidojot tērzēšanas istabu",
    "The visibility of this event in shared calendars." : "Šī notikuma redzamība koplietotos kalendāros."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
