OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Ar choinníoll go bhfuil an seoladh ríomhphoist ró-fhada",
    "User-Session unexpectedly expired" : "Chuaigh an Seisiún Úsáideora in éag gan choinne",
    "Provided email-address is not valid" : "Ar choinníoll nach bhfuil an seoladh ríomhphoist bailí",
    "%s has published the calendar »%s«" : "D'fhoilsigh %s an féilire »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Earráid gan choinne agus ríomhphost á sheoladh. Déan teagmháil le do riarthóir le do thoil.",
    "Successfully sent email to %1$s" : "D'éirigh le seoladh ríomhphoist chuig %1$s",
    "Hello," : "Dia dhuit,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Theastaigh uainn a chur in iúl duit go bhfuil an féilire »%s« foilsithe ag %s.",
    "Open »%s«" : "Oscail »%s«",
    "Cheers!" : "Sláinte mhaith!",
    "Upcoming events" : "Imeachtaí atá ag Teacht",
    "No more events today" : "Níl a thuilleadh imeachtaí ann inniu",
    "No upcoming events" : "Níl aon imeachtaí le teacht",
    "More events" : "Tuilleadh imeachtaí",
    "%1$s with %2$s" : "%1$s le %2$s",
    "Calendar" : "Féilire",
    "New booking {booking}" : "Áirithint nua {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "chuir {display_name} ({email}) an coinne \"{config_display_name}\" in áirithe ar {date_time}.",
    "Appointments" : "Coinní",
    "Schedule appointment \"%s\"" : "Sceideal coinne \"%s\"",
    "Schedule an appointment" : "Sceideal coinne",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : "Ullmhaigh do %s",
    "Follow up for %s" : "Leantach le haghaidh %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Ní mór do choinne \"%s\" le %s a dhearbhú",
    "Dear %s, please confirm your booking" : "A %s, a chara, deimhnigh d'áirithint le do thoil",
    "Confirm" : "Deimhnigh",
    "Appointment with:" : "Ceapachán le:",
    "Description:" : "Cur síos:",
    "This confirmation link expires in %s hours." : "Rachaidh an nasc dearbhaithe seo in éag i gceann %s uair.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Más mian leat an coinne a chur ar ceal tar éis an tsaoil, déan teagmháil le d’eagraí trí fhreagra a thabhairt don ríomhphost seo nó trí chuairt a thabhairt ar a leathanach próifíle le do thoil.",
    "Your appointment \"%s\" with %s has been accepted" : "Glacadh le do choinne \"%s\" le %s",
    "Dear %s, your booking has been accepted." : "A %s, a chara, glacadh le d'áirithint.",
    "Appointment for:" : "Ceapachán le haghaidh:",
    "Date:" : "Dáta:",
    "You will receive a link with the confirmation email" : "Gheobhaidh tú nasc leis an ríomhphost deimhnithe",
    "Where:" : "Cá háit:",
    "Comment:" : "Nóta tráchta:",
    "You have a new appointment booking \"%s\" from %s" : "Tá coinne nua agat le \"%s\" a chur in áirithe ó %s",
    "Dear %s, %s (%s) booked an appointment with you." : "A %s, a chara, chuir %s (%s) coinne in áirithe leat.",
    "%s has proposed a meeting" : "Tá cruinniú molta ag %s",
    "%s has updated a proposed meeting" : "Tá cruinniú beartaithe nuashonraithe ag %s",
    "%s has canceled a proposed meeting" : "Tá cruinniú beartaithe curtha ar ceal ag %s",
    "Dear %s, a new meeting has been proposed" : "A %s, tá cruinniú nua molta",
    "Dear %s, a proposed meeting has been updated" : "A %s, tá cruinniú beartaithe nuashonraithe",
    "Dear %s, a proposed meeting has been cancelled" : "A %s, tá cruinniú beartaithe curtha ar ceal",
    "Location:" : "Suíomh:",
    "Duration:" : "Fad:",
    "%1$s from %2$s to %3$s" : "%1$s ó %2$s go %3$s",
    "Dates:" : "Dátaí:",
    "Respond" : "Freagair",
    "A Calendar app for Nextcloud" : "Aip Féilire do Nextcloud",
    "A Calendar app for Nextcloud. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Like Contacts, Talk, Tasks, Deck and Circles\n* 🌐 **WebCal Support!** Want to see your favorite team's matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 **Search!** Find your events at ease\n* ☑️ **Tasks!** See tasks or Deck cards with a due date directly in the calendar\n* 🔈 **Talk rooms!** Create an associated Talk room when booking a meeting with just one click\n* 📆 **Appointment booking** Send people a link so they can book an appointment with you [using this app](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Attachments!** Add, upload and view event attachments\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Aip Féilire do Nextcloud. Sioncronaigh go héasca imeachtaí ó ghléasanna éagsúla le do Nextcloud agus cuir in eagar iad ar líne.\n\n* 🚀 **Comhtháthú le haipeanna eile Nextcloud!** Cosúil le Teagmhálacha, Caint, Tascanna, Deic agus Ciorcail\n* 🌐 **Tacaíocht WebCal!** Ar mhaith leat laethanta cluichí na foirne is fearr leat a fheiceáil i d’fhéilire? Fadhb ar bith!\n* 🙋 **Freastalaithe!** Tabhair cuireadh do dhaoine teacht chuig d’imeachtaí\n* ⌚ **Saor in Aisce/Gnóthach!** Féach cathain a bheidh do lucht freastail ar fáil le bualadh\n* ⏰ **Meabhrúcháin!** Faigh aláram le haghaidh imeachtaí laistigh de do bhrabhsálaí agus trí ríomhphost\n* 🔍 **Cuardaigh!** Faigh do chuid imeachtaí ar a suaimhneas\n* ☑️ **Tascanna!** Féach tascanna nó cártaí Deic le dáta dlite díreach san fhéilire\n* 🔈 **Seomraí cainte!** Cruthaigh seomra Caint gaolmhar agus cruinniú á chur in áirithe agat gan ach cliceáil amháin\n* 📆 **Coinne a chur in áirithe** Seol nasc chuig daoine ionas gur féidir leo coinne a chur in áirithe leat [leis an aip seo] ( https://apps.nextcloud.com/apps/appointments)\n* 📎 **Ceangaltáin!** Cuir leis, uaslódáil agus féach ar cheangaltáin imeachta\n* 🙈 **Nílimid ag athchruthú an rotha!** Bunaithe ar an leabharlann iontach [c-dav](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) agus [fullcalendar](https://lgithubar.com/library",
    "Previous day" : "Lá roimhe sin",
    "Previous week" : "An tseachtain roimhe sin",
    "Previous year" : "bhliain roimhe sin",
    "Previous month" : "an mhí roimhe sin",
    "Next day" : "An chéad lá eile",
    "Next week" : "An tseachtain seo chugainn",
    "Next year" : "An bhliain seo chugainn",
    "Next month" : "An mhí seo chugainn",
    "Create new event" : "Cruthaigh imeacht nua",
    "Event" : "Imeacht",
    "Today" : "Inniu",
    "Day" : "Lá",
    "Week" : "Seachtain",
    "Month" : "Mí",
    "Year" : "Bliain",
    "List" : "Liosta",
    "Appointment link was copied to clipboard" : "Rinneadh an nasc coinní a chóipeáil chuig an ngearrthaisce",
    "Appointment link could not be copied to clipboard" : "Níorbh fhéidir an nasc coinní a chóipeáil chuig an ngearrthaisce",
    "Preview" : "Réamhamharc",
    "Copy link" : "Cóipeáil an nasc",
    "Edit" : "Cuir in eagar",
    "Delete" : "Scrios",
    "Appointment schedules" : "Sceidil ceapacháin",
    "Create new" : "Cruthaigh nua",
    "Disable calendar \"{calendar}\"" : "Díchumasaigh féilire \"{calendar}\"",
    "Disable untitled calendar" : "Díchumasaigh féilire gan teideal",
    "Enable calendar \"{calendar}\"" : "Cumasaigh féilire \"{calendar}\"",
    "Enable untitled calendar" : "Cumasaigh féilire gan teideal",
    "An error occurred, unable to change visibility of the calendar." : "Tharla earráid, níorbh fhéidir infheictheacht an fhéilire a athrú.",
    "Untitled calendar" : "Féilire gan teideal",
    "Shared with you by" : "Roinnte le leat ag",
    "Edit and share calendar" : "Cuir féilire in eagar agus a roinnt",
    "Edit calendar" : "Cuir féilire in eagar",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Ag dí-roinnt an fhéilire i {countdown} soicind","Ag dí-roinnt an fhéilire i {countdown} soicind","Ag dí-roinnt an fhéilire i {countdown} soicind","Ag dí-roinnt an fhéilire i {countdown} soicind","Ag dí-roinnt an fhéilire i {countdown} soicind"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["An féilire á scriosadh i {countdown} soicind","An féilire á scriosadh i {countdown} soicind","An féilire á scriosadh i {countdown} soicind","An féilire á scriosadh i {countdown} soicind","An féilire á scriosadh i {countdown} soicind"],
    "An error occurred, unable to create the calendar." : "Tharla earráid, níorbh fhéidir an féilire a chruthú.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Cuir isteach nasc bailí (ag tosú le http://, https://, webcal://, nó webcals://) le do thoil",
    "Calendars" : "Féilirí",
    "Add new" : "Cuir nua leis",
    "New calendar" : "Féilire nua",
    "Name for new calendar" : "Ainm don fhéilire nua",
    "Creating calendar …" : "Féilire á chruthú …",
    "New calendar with task list" : "Féilire nua le liosta tascanna",
    "New subscription from link (read-only)" : "Síntiús nua ón nasc (read-only)",
    "Creating subscription …" : "Síntiús a chruthú …",
    "Add public holiday calendar" : "Cuir féilire saoire poiblí leis",
    "Add custom public calendar" : "Cuir féilire poiblí saincheaptha leis",
    "Calendar link copied to clipboard." : "Cóipeáladh an nasc féilire chuig an ngearrthaisce.",
    "Calendar link could not be copied to clipboard." : "Níorbh fhéidir nasc féilire a chóipeáil chuig an ngearrthaisce.",
    "Copy subscription link" : "Cóipeáil nasc síntiús",
    "Copying link …" : "Nasc á chóipeáil …",
    "Copied link" : "Nasc cóipeáilte",
    "Could not copy link" : "Níorbh fhéidir an nasc a chóipeáil",
    "Export" : "Easpórtáil",
    "Untitled item" : "Mír gan teideal",
    "Unknown calendar" : "Féilire anaithnid",
    "Could not load deleted calendars and objects" : "Níorbh fhéidir féilirí agus oibiachtaí scriosta a lódáil",
    "Could not delete calendar or event" : "Níorbh fhéidir féilire nó imeacht a scriosadh",
    "Could not restore calendar or event" : "Níorbh fhéidir féilire nó imeacht a chur ar ais",
    "Do you really want to empty the trash bin?" : "Ar mhaith leat an bosca bruscair a fholmhú?",
    "Empty trash bin" : "Bruscar folamh",
    "Trash bin" : "Bruscar",
    "Loading deleted items." : "Míreanna scriosta á lódáil.",
    "You do not have any deleted items." : "Níl aon mhír scriosta agat.",
    "Name" : "Ainm",
    "Deleted" : "Scriosta",
    "Restore" : "Athchóirigh",
    "Delete permanently" : "Scrios go buan",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Scriostar míreanna sa bhosca bruscair tar éis {numDays} lá","Scriostar míreanna sa bhosca bruscair tar éis {numDays} laethanta","Scriostar míreanna sa bhosca bruscair tar éis {numDays} laethanta","Scriostar míreanna sa bhosca bruscair tar éis {numDays} laethanta","Scriostar míreanna sa bhosca bruscair tar éis {numDays} laethanta"],
    "Could not update calendar order." : "Níorbh fhéidir an t-ordú féilire a nuashonrú.",
    "Shared calendars" : "Féilirí roinnte",
    "Deck" : "Deic",
    "Internal link" : "Nasc inmheánach",
    "A private link that can be used with external clients" : "Nasc príobháideach is féidir a úsáid le cliaint sheachtracha",
    "Copy internal link" : "Cóipeáil an nasc inmheánach",
    "An error occurred, unable to publish calendar." : "Tharla earráid, ní féidir an féilire a fhoilsiú.",
    "An error occurred, unable to send email." : "Tharla earráid, ní féidir ríomhphost a sheoladh.",
    "Embed code copied to clipboard." : "Cóipeáladh an cód chuig an ngearrthaisce.",
    "Embed code could not be copied to clipboard." : "Níorbh fhéidir an cód leabaithe a chóipeáil chuig an ngearrthaisce.",
    "Unpublishing calendar failed" : "Theip ar dhífhoilsiú an fhéilire",
    "Share link" : "Comhroinn nasc",
    "Copy public link" : "Cóipeáil nasc poiblí",
    "Send link to calendar via email" : "Seol nasc chuig an bhféilire trí ríomhphost",
    "Enter one address" : "Cuir isteach seoladh amháin",
    "Sending email …" : "Ríomhphost á sheoladh …",
    "Copy embedding code" : "Cóipeáil cód leabú",
    "Copying code …" : "Cód á chóipeáil …",
    "Copied code" : "Cód cóipeáilte",
    "Could not copy code" : "Níorbh fhéidir an cód a chóipeáil",
    "Delete share link" : "Scrios an nasc comhroinnte",
    "Deleting share link …" : "Nasc comhroinnte á scriosadh …",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Foireann)",
    "An error occurred while unsharing the calendar." : "Tharla earráid agus an féilire á dhí-roinnt.",
    "An error occurred, unable to change the permission of the share." : "Tharla earráid, níorbh fhéidir cead na comhroinnte a athrú.",
    "can edit and see confidential events" : "is féidir imeachtaí rúnda a chur in eagar agus a fheiceáil",
    "Unshare with {displayName}" : "Díroinn le {displayName}",
    "Share with users or groups" : "Roinn le húsáideoirí nó le grúpaí",
    "No users or groups" : "Gan úsáideoirí nó grúpaí",
    "Failed to save calendar name and color" : "Theip ar shábháil ainm agus dath an fhéilire",
    "Calendar name …" : "Ainm an fhéilire …",
    "Never show me as busy (set this calendar to transparent)" : "Ná taispeáin dom chomh gnóthach riamh (socraigh an féilire seo go trédhearcach)",
    "Share calendar" : "Comhroinn féilire",
    "Unshare from me" : "Dí-roinn uaim",
    "Save" : "Sábháil",
    "No title" : "Gan teideal",
    "Are you sure you want to delete \"{title}\"?" : "An bhfuil tú cinnte gur mian leat \"{title}\" a scriosadh?",
    "Deleting proposal \"{title}\"" : "Ag scriosadh togra \"{title}\"",
    "Successfully deleted proposal" : "Scriosadh an togra go rathúil",
    "Failed to delete proposal" : "Theip ar an togra a scriosadh",
    "Failed to retrieve proposals" : "Theip ar na moltaí a aisghabháil",
    "Meeting proposals" : "Tograí cruinnithe",
    "A configured email address is required to use meeting proposals" : "Tá seoladh ríomhphoist cumraithe ag teastáil chun moltaí cruinnithe a úsáid",
    "No active meeting proposals" : "Gan aon mholtaí cruinnithe gníomhacha",
    "View" : "Amharc",
    "Import calendars" : "Iompórtáil féilirí",
    "Please select a calendar to import into …" : "Le do thoil roghnaigh féilire le hiompórtáil isteach in …",
    "Filename" : "Ainm comhaid",
    "Calendar to import into" : "Féilire le hiompórtáil isteach",
    "Cancel" : "Cealaigh",
    "_Import calendar_::_Import calendars_" : ["Iompórtáil féilire","Iompórtáil féilirí","Iompórtáil féilirí","Iompórtáil féilirí","Iompórtáil féilirí"],
    "Select the default location for attachments" : "Roghnaigh an suíomh réamhshocraithe le haghaidh ceangaltán",
    "Pick" : "Pioc",
    "Invalid location selected" : "Suíomh neamhbhailí roghnaithe",
    "Attachments folder successfully saved." : "D'éirigh le fillteán na gceangaltán a shábháil.",
    "Error on saving attachments folder." : "Earráid agus fillteán na gceangaltán á shábháil.",
    "Attachments folder" : "Fillteán ceangaltáin",
    "{filename} could not be parsed" : "Níorbh fhéidir {filename} a pharsáil",
    "No valid files found, aborting import" : "Níor aimsíodh aon chomhaid bhailí, ag cur deireadh leis an iompórtáil",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["D'éirigh le hiompórtáil %n imeacht","D'éirigh le hiompórtáil %n n-imeacht","D'éirigh le hiompórtáil %n n-imeacht","D'éirigh le hiompórtáil %n n-imeacht","D'éirigh le hiompórtáil %n n-imeacht"],
    "Import partially failed. Imported {accepted} out of {total}." : "Theip ar an iompórtáil i bpáirt. Iompórtáladh {accepted} as {total}.",
    "Automatic" : "Uathoibríoch",
    "Automatic ({timezone})" : "Uathoibríoch ({timezone})",
    "New setting was not saved successfully." : "Níor sábháladh an socrú nua.",
    "Timezone" : "Crios ama",
    "Navigation" : "Loingseoireacht",
    "Previous period" : "Tréimhse roimhe seo",
    "Next period" : "An chéad tréimhse eile",
    "Views" : "Radhairc",
    "Day view" : "Radharc an lae",
    "Week view" : "Radharc na seachtaine",
    "Month view" : "Radharc na míosa",
    "Year view" : "Radharc na bliana",
    "List view" : "Amharc liosta",
    "Actions" : "Gníomhartha",
    "Create event" : "Cruthaigh imeacht",
    "Show shortcuts" : "Taispeáin aicearraí",
    "Editor" : "eagarthóir",
    "Close editor" : "Dún eagarthóir",
    "Save edited event" : "Sábháil imeacht curtha in eagar",
    "Delete edited event" : "Scrios imeacht curtha in eagar",
    "Duplicate event" : "Imeacht dhúblach",
    "or" : "nó",
    "Calendar settings" : "Socruithe féilire",
    "At event start" : "Ag tús na hócáide",
    "No reminder" : "Gan meabhrúchán",
    "Failed to save default calendar" : "Theip ar shábháil an fhéilire réamhshocraithe",
    "General" : "Ginearálta",
    "Availability settings" : "Socruithe infhaighteachta",
    "CalDAV" : "CalDAV",
    "Access Nextcloud calendars from other apps and devices" : "Rochtain ar fhéilirí Nextcloud ó aipeanna agus gléasanna eile",
    "CalDAV URL" : "URL CalDAV",
    "Server Address for iOS and macOS" : "Seoladh Freastalaí le haghaidh iOS agus macOS",
    "Appearance" : "Dealramh",
    "Birthday calendar" : "Féilire breithlá",
    "Tasks in calendar" : "Tascanna sa fhéilire",
    "Weekends" : "Deireadh seachtaine",
    "Week numbers" : "Uimhreacha na seachtaine",
    "Limit number of events shown in Month view" : "Teorainn a chur le líon na n-imeachtaí a thaispeántar san amharc Míosa",
    "Density in Day and Week View" : "Dlús i Radharc an Lae agus na Seachtaine",
    "Editing" : "Eagarthóireacht",
    "Default reminder" : "Meabhrúchán réamhshocraithe",
    "Simple event editor" : "Eagarthóir imeachtaí simplí",
    "\"More details\" opens the detailed editor" : "Osclaíonn \"Tuilleadh sonraí\" an t-eagarthóir mionsonraithe",
    "Files" : "Comhaid",
    "Appointment schedule successfully created" : "D'éirigh le sceideal na gcoinní a chruthú",
    "Appointment schedule successfully updated" : "D'éirigh le sceideal na gcoinní a nuashonrú",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} nóiméad","{duration} nóiméad","{duration} nóiméad","{duration} nóiméad","{duration} nóiméad"],
    "0 minutes" : "0 nóiméad",
    "_{duration} hour_::_{duration} hours_" : ["{fad} uair","{fad} uair an chloig","{fad} uair an chloig","{fad} uair an chloig","{fad} uair an chloig"],
    "_{duration} day_::_{duration} days_" : ["{fad} lá","{fad} lá","{fad} lá","{fad} lá","{fad} lá"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} seachtain","{duration} seachtain","{duration} seachtain","{duration} seachtain","{duration} seachtain"],
    "_{duration} month_::_{duration} months_" : ["{duration} mhí","{duration} mhí","{duration} mhí","{duration} mhí","{duration} mhí"],
    "_{duration} year_::_{duration} years_" : ["{duration} bliana","{duration} bliana","{duration} bliana","{duration} bliana","{duration} bliana"],
    "To configure appointments, add your email address in personal settings." : "Chun coinní a chumrú, cuir do sheoladh ríomhphoist i socruithe pearsanta.",
    "Public – shown on the profile page" : "Poiblí – léirithe ar an leathanach próifíle",
    "Private – only accessible via secret link" : "Príobháideach – ní féidir teacht air ach trí nasc rúnda",
    "Appointment schedule saved" : "Sceideal coinní sábháilte",
    "Create appointment schedule" : "Cruthaigh sceideal coinne",
    "Edit appointment schedule" : "Cuir sceideal na gcoinní in eagar",
    "Update" : "Nuashonrú",
    "Appointment name" : "Ainm an cheapacháin",
    "Location" : "Suíomh",
    "Create a Talk room" : "Cruthaigh seomra Caint",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Cruthófar nasc uathúil le haghaidh gach coinne a chuirtear in áirithe agus seolfar é tríd an ríomhphost deimhnithe",
    "Description" : "Cur síos",
    "Visibility" : "Infheictheacht",
    "Duration" : "Fad",
    "Increments" : "Incrimintí",
    "Additional calendars to check for conflicts" : "Féilirí breise chun coinbhleachtaí a sheiceáil",
    "Pick time ranges where appointments are allowed" : "Roghnaigh raonta ama ina gceadaítear coinní",
    "to" : "chun",
    "Delete slot" : "Scrios sliotán",
    "No times set" : "Uimh amanna socraithe",
    "Add" : "Cuir",
    "Monday" : "Dé Luain",
    "Tuesday" : "Dé Máirt",
    "Wednesday" : "Dé Céadaoin",
    "Thursday" : "Déardaoin",
    "Friday" : "Aoine",
    "Saturday" : "Sathairn",
    "Sunday" : "Domhnach",
    "Weekdays" : "Laethanta na seachtaine",
    "Add time before and after the event" : "Cuir am leis roimh an imeacht agus ina dhiaidh",
    "Before the event" : "Roimh an ócáid",
    "After the event" : "Tar éis na hócáide",
    "Planning restrictions" : "Srianta pleanála",
    "Minimum time before next available slot" : "Íosmhéid ama roimh an gcéad sliotán eile atá ar fáil",
    "Max slots per day" : "Sliotán uasta in aghaidh an lae",
    "Limit how far in the future appointments can be booked" : "Teorainn a chur le cé chomh fada sa todhchaí is féidir coinní a chur in áirithe",
    "It seems a rate limit has been reached. Please try again later." : "Is cosúil go bhfuil teorainn ráta bainte amach. Bain triail eile as ar ball le do thoil.",
    "Please confirm your reservation" : "Deimhnigh d’áirithint le do thoil",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Sheolamar ríomhphost chugat le sonraí. Deimhnigh do choinne ag baint úsáide as an nasc sa ríomhphost le do thoil. Is féidir leat an leathanach seo a dhúnadh anois le do thoil.",
    "Your name" : "Do ainm",
    "Your email address" : "Do sheoladh ríomhphoist",
    "Please share anything that will help prepare for our meeting" : "Roinnigí le bhur dtoil aon rud a chuideoidh linn ullmhú dár gcruinniú  le do thoil",
    "Could not book the appointment. Please try again later or contact the organizer." : "Níorbh fhéidir an coinne a chur in áirithe. Bain triail eile as ar ball le do thoil nó déan teagmháil leis an eagraí  le do thoil.",
    "Back" : "Ar ais",
    "Book appointment" : "Coinne leabhar",
    "Error fetching Talk conversations." : "Earráid agus comhráite Talk á fháil.",
    "Conversation does not have a valid URL." : "Níl URL bailí ag an gcomhrá.",
    "Successfully added Talk conversation link to location." : "D'éirigh leis an nasc Talk Chat a chur leis an suíomh.",
    "Successfully added Talk conversation link to description." : "D'éirigh leis an nasc Talk conversation a chur leis an gcur síos.",
    "Failed to apply Talk room." : "Theip ar an seomra cainte a chur i bhfeidhm.",
    "Talk conversation for event" : "Labhair comhrá don imeacht",
    "Error creating Talk conversation" : "Earráid agus comhrá á chruthú",
    "Select a Talk Room" : "Roghnaigh Seomra Caint",
    "Add Talk conversation" : "Cuir comhrá leis",
    "Fetching Talk rooms…" : "Seomraí Caint á bhfáil…",
    "No Talk room available" : "Níl seomra cainte ar fáil",
    "Create public conversation" : "Cruthaigh comhrá poiblí",
    "Select conversation" : "Roghnaigh comhrá",
    "on" : "ar",
    "at" : "ag",
    "before at" : "roimh ag",
    "Notification" : "Fógra",
    "Email" : "Ríomhphost",
    "Audio notification" : "Fógra fuaime",
    "Other notification" : "Fógra eile",
    "Relative to event" : "I gcoibhneas leis an imeacht",
    "On date" : "Ar dháta",
    "Edit time" : "Cuir am in eagar",
    "Save time" : "Sábháil am",
    "Remove reminder" : "Bain meabhrúchán",
    "Add reminder" : "Cuir meabhrúchán leis",
    "seconds" : "soicind",
    "minutes" : "nóiméad",
    "hours" : "uair an chloig",
    "days" : "laethanta",
    "weeks" : "seachtaine",
    "Choose a file to add as attachment" : "Roghnaigh comhad le cur leis mar cheangaltán",
    "Choose a file to share as a link" : "Roghnaigh comhad le roinnt mar nasc",
    "Attachment {name} already exist!" : "Tá ceangaltán {name} ann cheana féin!",
    "Could not upload attachment(s)" : "Níorbh fhéidir ceangaltán(cheangail) a uaslódáil",
    "You are about to navigate to {link}. Are you sure to proceed?" : "Tá tú ar tí nascleanúint a dhéanamh chuig {link}. An bhfuil tú cinnte go leanfaidh tú ar aghaidh?",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Tá tú ar tí nascleanúint a dhéanamh chuig {host}. An bhfuil tú cinnte leanúint ar aghaidh? Nasc: {link}",
    "Proceed" : "Lean ar aghaidh",
    "No attachments" : "Gan ceangaltáin",
    "Add from Files" : "Cuir ó Chomhaid",
    "Upload from device" : "Íosluchtaigh ó gléas",
    "Delete file" : "Scrios an comhad",
    "Confirmation" : "Daingniú",
    "_{count} attachment_::_{count} attachments_" : ["{comhaireamh} ceangaltán","{comhaireamh} ceangaltán","{comhaireamh} ceangaltán","{comhaireamh} ceangaltán","{comhaireamh} ceangaltán"],
    "Suggested" : "Molta",
    "Available" : "Ar fáil",
    "Invitation accepted" : "Glacadh le cuireadh",
    "Accepted {organizerName}'s invitation" : "Glacadh le cuireadh {organizerName}",
    "Participation marked as tentative" : "Rannpháirtíocht marcáilte mar thrialach",
    "Invitation is delegated" : "Tarmligtear cuireadh",
    "Not available" : "Níl sé ar fáil",
    "Invitation declined" : "Diúltaíodh don chuireadh",
    "Declined {organizerName}'s invitation" : "Dhiúltaigh {organizerName} cuireadh",
    "Availability will be checked" : "Seiceálfar infhaighteacht",
    "Invitation will be sent" : "Seolfar cuireadh",
    "Failed to check availability" : "Theip ar infhaighteacht a sheiceáil",
    "Failed to deliver invitation" : "Theip ar an gcuireadh a sheachadadh",
    "Awaiting response" : "Ag feitheamh le freagra",
    "Checking availability" : "Infhaighteacht a sheiceáil",
    "Has not responded to {organizerName}'s invitation yet" : "Níor fhreagair cuireadh {organizerName} fós",
    "Suggested times" : "Amanna molta",
    "chairperson" : "cathaoirleach",
    "required participant" : "rannpháirtí riachtanach",
    "non-participant" : "neamh-rannpháirtí",
    "optional participant" : "rannpháirtí roghnach",
    "{organizer} (organizer)" : "{organizer} (eagraí)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Selected slot" : "Sliotán roghnaithe",
    "Availability of attendees, resources and rooms" : "Infhaighteacht lucht freastail, acmhainní agus seomraí",
    "Suggestion accepted" : "Glacadh le moladh",
    "Previous date" : "Dáta roimhe seo",
    "Next date" : "An chéad dáta eile",
    "Legend" : "Finscéal",
    "Out of office" : "As oifig",
    "Attendees:" : "Lucht freastail:",
    "local time" : "am áitiúil",
    "Done" : "Déanta",
    "Search room" : "Seomra cuardaigh",
    "Room name" : "Ainm an tseomra",
    "Check room availability" : "Seiceáil infhaighteacht an tseomra",
    "Free" : "Saor",
    "Busy (tentative)" : "gnóthach (éiginnte)",
    "Busy" : "Gnóthach",
    "Unknown" : "Anaithnid",
    "Find a time" : "Faigh am",
    "The invitation has been accepted successfully." : "Glacadh leis an gcuireadh go rathúil.",
    "Failed to accept the invitation." : "Theip ar glacadh leis an gcuireadh.",
    "The invitation has been declined successfully." : "Diúltaíodh don chuireadh.",
    "Failed to decline the invitation." : "Theip ar dhiúltú an cuireadh.",
    "Your participation has been marked as tentative." : "Marcáladh do rannpháirtíocht mar shealadach.",
    "Failed to set the participation status to tentative." : "Theip ar stádas na rannpháirtíochta a shocrú go sealadach.",
    "Accept" : "Glac",
    "Decline" : "Meath",
    "Tentative" : "Sealadach",
    "No attendees yet" : "Níl aon lucht freastail fós",
    "{confirmedCount} confirmed, {waitingCount} awaiting response" : "Deimhníodh {confirmedCount}, tá {waitingCount} ag fanacht le freagra",
    "Please add at least one attendee to use the \"Find a time\" feature." : "Cuir freastalaí amháin ar a laghad leis le go n-úsáidfidh tú an ghné \"Aimsigh am\".",
    "Attendees" : "Lucht freastail",
    "_%n more attendee_::_%n more attendees_" : ["%n freastalaí eile","%n níos mó freastalaithe","%n níos mó freastalaithe","%n níos mó freastalaithe","%n níos mó freastalaithe"],
    "Remove group" : "Bain an grúpa",
    "Remove attendee" : "Bain an freastail",
    "Request reply" : "Iarr freagra",
    "Chairperson" : "Cathaoirleach",
    "Required participant" : "Rannpháirtí riachtanach",
    "Optional participant" : "Rannpháirtí roghnach",
    "Non-participant" : "Neamh-rannpháirtí",
    "_%n member_::_%n members_" : ["%n bhall","%n members","%n members","%n members","%n members"],
    "Search for emails, users, contacts, contact groups or teams" : "Déan cuardach do ríomhphoist, úsáideoirí, teagmhálaithe, grúpaí teagmhála nó foirne",
    "No match found" : "Níor aimsíodh aon mheaitseáil",
    "Note that members of circles get invited but are not synced yet." : "Tabhair faoi deara go bhfaigheann baill de chiorcail cuireadh ach nach bhfuil siad sioncronaithe fós.",
    "Note that members of contact groups get invited but are not synced yet." : "Tabhair faoi deara go bhfaigheann baill de ghrúpaí teagmhála cuireadh ach nach bhfuil siad sioncronaithe fós.",
    "(organizer)" : "(eagraí)",
    "Make {label} the organizer" : "Déan {label} an t-eagraí",
    "Make {label} the organizer and attend" : "Déan {label} an t-eagraí agus freastal air",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Chun cuirí a sheoladh amach agus freagraí a láimhseáil, [linkopen]cuir do sheoladh ríomhphoist i socruithe pearsanta[linkclose].",
    "Remove color" : "Bain dath",
    "Event title" : "Teideal an imeachta",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Ní féidir an socrú lae a mhodhnú le haghaidh imeachtaí atá mar chuid de thacar atarlaithe.",
    "From" : "Ó",
    "To" : "Chun",
    "Your Time" : "Do Am",
    "Repeat" : "Déan arís",
    "Repeat event" : "Imeacht arís",
    "_time_::_times_" : ["am","amanna","amanna","amanna","amanna"],
    "never" : "riamh",
    "on date" : "ar dháta",
    "after" : "tar éis",
    "End repeat" : "Cuir deireadh leis an athuair",
    "Select to end repeat" : "Roghnaigh chun deireadh a chur leis an athuair",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Is eisceacht é an teagmhas seo maidir le tacar atarlaithe. Ní féidir leat riail atarlaithe a chur leis.",
    "first" : " an chéad",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Ní bhainfidh athruithe ar an riail atarlaithe ach leis seo agus le gach tarlú sa todhchaí.",
    "Repeat every" : "Déan gach",
    "By day of the month" : "De réir lá na míosa",
    "On the" : "Ar an",
    "_day_::_days_" : ["lá","laethanta","laethanta","laethanta","laethanta"],
    "_week_::_weeks_" : ["seachtain","seachtaine","seachtaine","seachtaine","seachtaine"],
    "_month_::_months_" : ["mí","míonna","míonna","míonna","míonna"],
    "_year_::_years_" : ["bliain","blianta","blianta","blianta","blianta"],
    "On specific day" : "Ar lá ar leith",
    "weekday" : "i rith na seachtaine",
    "weekend day" : "lá deireadh seachtaine",
    "Does not repeat" : "Ní athuair",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Ní thacaíonn Nextcloud go hiomlán le sainmhíniú atarlaithe an imeachta seo. Má chuireann tú na roghanna atarlaithe in eagar, seans go gcaillfear atarlú áirithe.",
    "No rooms or resources yet" : "Níl seomraí ná acmhainní ann fós",
    "Resources" : "Acmhainní",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : [" {suíocháin Cumas} suíochán","{Toilleadh suíocháin} suíocháin","{Toilleadh suíocháin} suíocháin","{Toilleadh suíocháin} suíocháin","{Toilleadh suíocháin} suíocháin"],
    "Add resource" : "Cuir acmhainn leis",
    "Has a projector" : "Tá teilgeoir",
    "Has a whiteboard" : "Tá clár bán",
    "Wheelchair accessible" : "Inrochtana do chathaoireacha rothaí",
    "Remove resource" : "Bain acmhainn",
    "Search for resources or rooms" : "Cuardaigh acmhainní nó seomraí",
    "available" : "ar fáil",
    "unavailable" : "ar fáil",
    "Show all rooms" : "Taispeáin gach seomra",
    "Projector" : "Teilgeoir",
    "Whiteboard" : "Clár bán",
    "Room type" : "Cineál seomra",
    "Any" : "Aon",
    "Minimum seating capacity" : "Toilleadh suíocháin íosta",
    "More details" : "Tuilleadh sonraí",
    "Update this and all future" : "Nuashonraigh seo agus gach todhchaí",
    "Update this occurrence" : "Nuashonraigh an teagmhas seo",
    "Public calendar does not exist" : "Níl féilire poiblí ann",
    "Maybe the share was deleted or has expired?" : "B'fhéidir gur scriosadh an sciar nó go bhfuil sé imithe in éag?",
    "Remove date" : "Bain an dáta",
    "Attendance required" : "Freastal riachtanach",
    "Attendance optional" : "Roghnach láithreacht",
    "Remove participant" : "Bain rannpháirtí",
    "Yes" : "Tá",
    "No" : "Níl",
    "Maybe" : "B'fhéidir",
    "None" : "aon cheann",
    "Select your meeting availability" : "Roghnaigh infhaighteacht do chruinnithe",
    "Create a meeting for this date and time" : "Cruigh cruinniú don dáta agus am seo",
    "Create" : "Cruthaigh",
    "No participants or dates available" : "Níl aon rannpháirtithe ná dátaí ar fáil",
    "from {formattedDate}" : "ó {formattedDate}",
    "to {formattedDate}" : "chuig {formattedDate}",
    "on {formattedDate}" : "ar {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "ó {formattedDate} ag {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "chuig {formattedDate} ag {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "ar {formattedDate} ag {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} ag {formattedTime}",
    "Please enter a valid date" : "Cuir isteach dáta bailí le do thoil",
    "Please enter a valid date and time" : "Cuir isteach dáta agus am bailí le do thoil",
    "Select a time zone" : "Roghnaigh crios ama",
    "Please select a time zone:" : "Roghnaigh crios ama le do thoil:",
    "Pick a time" : "Roghnaigh am",
    "Pick a date" : "Roghnaigh dáta",
    "Type to search time zone" : "Clóscríobh chun crios ama a chuardach",
    "Global" : "Domhanda",
    "Holidays in {region}" : "Laethanta Saoire i {region}",
    "An error occurred, unable to read public calendars." : "Tharla earráid, níorbh fhéidir féilirí poiblí a léamh.",
    "An error occurred, unable to subscribe to calendar." : "Tharla earráid, ní féidir liostáil le féilire.",
    "Public holiday calendars" : "Féilirí saoire poiblí",
    "Public calendars" : "Féilirí poiblí",
    "No valid public calendars configured" : "Níl aon fhéilire poiblí bailí cumraithe",
    "Speak to the server administrator to resolve this issue." : "Labhair le riarthóir an fhreastalaí chun an fhadhb seo a réiteach.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Soláthraíonn Thunderbird féilirí saoire poiblí. Déanfar sonraí féilire a íoslódáil ó {website}",
    "These public calendars are suggested by the server administrator. Calendar data will be downloaded from the respective website." : "Molann riarthóir an fhreastalaí na féilirí poiblí seo. Íoslódálfar sonraí an fhéilire ón suíomh Gréasáin faoi seach.",
    "By {authors}" : "Le {authors}",
    "Subscribed" : "Suibscríofa",
    "Subscribe" : "Liostáil",
    "Could not fetch slots" : "Níorbh fhéidir sliotáin a fháil",
    "Select a date" : "Roghnaigh dáta",
    "Select slot" : "Roghnaigh sliotán",
    "No slots available" : "Níl sliotáin ar fáil",
    "The slot for your appointment has been confirmed" : "Tá an sliotán le haghaidh do choinne deimhnithe",
    "Appointment Details:" : "Sonraí Coinne:",
    "Time:" : "Am:",
    "Booked for:" : "Áirithe le haghaidh:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Go raibh maith agat. Deimhníodh d'áirithint ó {startDate} go {endDate}.",
    "Book another appointment:" : "Cuir coinne eile in áirithe:",
    "See all available slots" : "Féach ar gach sliotán atá ar fáil",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Níl an sliotán do do choinne ó {startDate} go {endDate} ar fáil a thuilleadh.",
    "Please book a different slot:" : "Cuir sliotán eile in áirithe le do thoil:",
    "Book an appointment with {name}" : "Cuir coinne le {name} in áirithe",
    "No public appointments found for {name}" : "Níor aimsíodh aon cheapachán poiblí le haghaidh {name}",
    "Personal" : "Pearsanta",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Chinn an bhrath uathoibríoch crios ama gurb é UTC do chrios ama.\nIs dócha gurb é seo an toradh ar bhearta slándála do bhrabhsálaí gréasáin.\nSocraigh do chrios ama de láimh sna socruithe féilire le do thoil.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Níor aimsíodh do chrios ama cumraithe ({timezoneId}). Ag titim ar ais go UTC.\nAthraigh do chrios ama sna socruithe agus cuir in iúl don fhadhb seo le do thoil.",
    "Show unscheduled tasks" : "Taispeáin tascanna neamhsceidealaithe",
    "Unscheduled tasks" : "Tascanna neamhsceidealaithe",
    "Availability of {displayName}" : "Infhaighteacht na{displayName}",
    "Discard event" : "Scrios an t-imeacht",
    "Edit event" : "Cuir an t-imeacht in eagar",
    "Event does not exist" : "Níl imeacht ann",
    "Duplicate" : "Dúblach",
    "Delete this occurrence" : "Scrios an teagmhas seo",
    "Delete this and all future" : "Scrios seo agus gach todhchaí",
    "All day" : "An lá ar fad",
    "Modifications wont get propagated to the organizer and other attendees" : "Ní dhéanfar modhnuithe a iomadú chuig an eagraí agus chuig lucht freastail eile",
    "Managing shared access" : "Rochtain roinnte a bhainistiú",
    "Deny access" : "Diúltaigh rochtain",
    "Invite" : "Cuireadh",
    "Discard changes?" : "Na hathruithe a sheachaint?",
    "Are you sure you want to discard the changes made to this event?" : "An bhfuil tú cinnte gur mian leat na hathruithe a rinneadh ar an imeacht seo a chaitheamh amach?",
    "_User requires access to your file_::_Users require access to your file_" : ["Éilíonn an t-úsáideoir rochtain ar do chomhad","Teastaíonn rochtain ar do chomhad ó úsáideoirí","Teastaíonn rochtain ar do chomhad ó úsáideoirí","Teastaíonn rochtain ar do chomhad ó úsáideoirí","Teastaíonn rochtain ar do chomhad ó úsáideoirí"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Teastaíonn rochtain roinnte ón gceangaltán","Ceangaltáin óna dteastaíonn rochtain roinnte","Ceangaltáin óna dteastaíonn rochtain roinnte","Ceangaltáin óna dteastaíonn rochtain roinnte","Ceangaltáin óna dteastaíonn rochtain roinnte"],
    "Untitled event" : "Imeacht gan teideal",
    "Close" : "Dún",
    "Modifications will not get propagated to the organizer and other attendees" : "Ní dhéanfar na modhnuithe a fhorleathadh chuig an eagraí agus chuig lucht freastail eile",
    "Meeting proposals overview" : "Forbhreathnú ar thograí cruinnithe",
    "Edit meeting proposal" : "Cuir togra cruinnithe in eagar",
    "Create meeting proposal" : "Cruthaigh togra cruinnithe",
    "Update meeting proposal" : "Nuashonraigh togra cruinnithe",
    "Saving proposal \"{title}\"" : "Ag sábháil an togra \"{title}\"",
    "Successfully saved proposal" : "Sábháileadh an togra go rathúil",
    "Failed to save proposal" : "Theip ar an togra a shábháil",
    "Create a meeting for \"{date}\"? This will create a calendar event with all participants." : "Cruinniú a chruthú do \"{date}\"? Cruthóidh sé seo imeacht féilire leis na rannpháirtithe go léir.",
    "Creating meeting for {date}" : "Cruinniú á chruthú do {date}",
    "Successfully created meeting for {date}" : "Cruinniú cruthaithe go rathúil do {date}",
    "Failed to create a meeting for {date}" : "Theip ar chruinniú a chruthú do {date}",
    "Please enter a valid duration in minutes." : "Cuir isteach fad bailí i nóiméid le do thoil.",
    "Failed to fetch proposals" : "Theip ar thograí a fháil",
    "Failed to fetch free/busy data" : "Theip ar shonraí saor/gnóthach a fháil",
    "Selected" : "Roghnaithe",
    "No Description" : "Gan Cur Síos",
    "No Location" : "Gan Suíomh",
    "Edit this meeting proposal" : "Cuir an togra cruinnithe seo in eagar",
    "Delete this meeting proposal" : "Scrios an togra cruinnithe seo",
    "Title" : "Teideal",
    "15 min" : "15 nóiméad",
    "30 min" : "30 nóim",
    "60 min" : "60 nóiméad",
    "90 min" : "90 nóiméad",
    "Participants" : "Rannpháirtithe",
    "Selected times" : "Amanna roghnaithe",
    "Previous span" : "Réise roimhe",
    "Next span" : "Réise seo chugainn",
    "Less days" : "Níos lú laethanta",
    "More days" : "Tuilleadh laethanta",
    "Loading meeting proposal" : "Ag lódáil togra cruinnithe",
    "No meeting proposal found" : "Níor aimsíodh aon togra cruinnithe",
    "Please wait while we load the meeting proposal." : "Fan go fóill agus muid ag lódáil an togra cruinnithe.",
    "The link you followed may be broken, or the meeting proposal may no longer exist." : "B’fhéidir go bhfuil an nasc a lean tú briste, nó b’fhéidir nach bhfuil an togra cruinnithe ann a thuilleadh.",
    "Thank you for your response!" : "Go raibh maith agat as do fhreagra!",
    "Your vote has been recorded. Thank you for participating!" : "Tá do vóta taifeadta. Go raibh maith agat as páirt a ghlacadh!",
    "Unknown User" : "Úsáideoir Anaithnid",
    "No Title" : "Gan Teideal",
    "No Duration" : "Gan Fad",
    "Select a different time zone" : "Roghnaigh crios ama difriúil",
    "Submit" : "Cuir isteach",
    "Subscribe to {name}" : "Liostáil le {name}",
    "Export {name}" : "Easpórtáil {name}",
    "Show availability" : "Taispeáin infhaighteacht",
    "Anniversary" : "Comóradh",
    "Appointment" : "Ceapachán",
    "Business" : "Gnó",
    "Education" : "Oideachas",
    "Holiday" : "Saoire",
    "Meeting" : "Cruinniú",
    "Miscellaneous" : "Ilghnéitheach",
    "Non-working hours" : "Uaireanta neamh-oibre",
    "Not in office" : "Ní in oifig",
    "Phone call" : "Glaoch fóin",
    "Sick day" : "Lá breoite",
    "Special occasion" : "Ócáid speisialta",
    "Travel" : "Taisteal",
    "Vacation" : "Laethanta saoire",
    "Midnight on the day the event starts" : "Meán oíche ar an lá a thosaíonn an ócáid",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n lá roimh an imeacht ag {formattedHourMinute}","%n lá roimh an imeacht ag {formattedHourMinute}","%n lá roimh an imeacht ag {formattedHourMinute}","%n lá roimh an imeacht ag {formattedHourMinute}","%n lá roimh an imeacht ag {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n seachtain roimh an imeacht ag {formattedHourMinute}","%n seachtain roimh an imeacht ag {formattedHourMinute}","%n seachtain roimh an imeacht ag {formattedHourMinute}","%n seachtain roimh an imeacht ag {formattedHourMinute}","%n seachtain roimh an imeacht ag {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "ar lá an imeachta ag {formattedHourMinute}",
    "at the event's start" : "ag tús na hócáide",
    "at the event's end" : "ag deireadh na hócáide",
    "{time} before the event starts" : "{time} sula dtosaíonn an t-imeacht",
    "{time} before the event ends" : "{time} sula dtiocfaidh deireadh leis an imeacht",
    "{time} after the event starts" : "{time} tar éis don imeacht tosú",
    "{time} after the event ends" : "{time} tar éis don imeacht críochnú",
    "on {time}" : "ar {am}",
    "on {time} ({timezoneId})" : "ar {time} ({timezoneId})",
    "Week {number} of {year}" : "Seachtain {uimhir} de {bliain}",
    "Daily" : "Laethúil",
    "Weekly" : "Seachtainiúil",
    "Monthly" : "Go míosúil",
    "Yearly" : "Bliantúil",
    "_Every %n day_::_Every %n days_" : ["Gach %n lá","Gach %n lá","Gach %n lá","Gach %n lá","Gach %n lá"],
    "_Every %n week_::_Every %n weeks_" : ["Gach %n seachtain","Gach %n seachtain","Gach %n seachtain","Gach %n seachtain","Gach %n seachtain"],
    "_Every %n month_::_Every %n months_" : ["Gach %n mí","Gach %n mí","Gach %n mí","Gach %n mí","Gach %n mí"],
    "_Every %n year_::_Every %n years_" : ["Gach %n bliain","Gach %n bliain","Gach %n bliain","Gach %n bliain","Gach %n bliain"],
    "_on {weekday}_::_on {weekdays}_" : ["ar {weekday}","ar {weekdays}","ar {weekdays}","ar {weekdays}","ar {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["ar lá {dayOfMonthList}","ar laethanta {dayOfMonthList}","ar laethanta {dayOfMonthList}","ar laethanta {dayOfMonthList}","ar laethanta {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "ar an {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {dayOfMonthList}" : "in {monthNames} ar an {dayOfMonthList}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "in {monthNames} ar an {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "go dtí {untilDate}",
    "_%n time_::_%n times_" : ["%n am","%n uair","%n uair","%n uair","%n uair"],
    "second" : "soicind",
    "third" : "an tríú",
    "fourth" : "an ceathrú",
    "fifth" : "an cúigiú",
    "second to last" : "dara go deireanach",
    "last" : "go deireanach",
    "Untitled task" : "Tasc gan teideal",
    "Please ask your administrator to enable the Tasks App." : "Iarr ar do riarthóir an Aip Tascanna a chumasú le do thoil.",
    "You are not allowed to edit this event as an attendee." : "Níl cead agat an imeacht seo a chur in eagar mar fhreastalaí.",
    "W" : "W",
    "%n more" : "%n níos mó",
    "No events to display" : "Níl aon imeachtaí le taispeáint",
    "All participants declined" : "Dhiúltaigh na rannpháirtithe go léir",
    "Please confirm your participation" : "Deimhnigh do rannpháirtíocht",
    "You declined this event" : "Dhiúltaigh tú don imeacht seo",
    "Your participation is tentative" : "Tá do rannpháirtíocht trialach",
    "_+%n more_::_+%n more_" : ["+%n eile","+%n eile","+%n eile","+%n eile","+%n eile"],
    "No events" : "Gan imeachtaí",
    "Create a new event or change the visible time-range" : "Cruthaigh imeacht nua nó athraigh an raon ama infheicthe",
    "Failed to save event" : "Theip ar shábháil an imeachta",
    "It might have been deleted, or there was a typo in a link" : "Seans gur scriosadh é, nó go raibh clóscríobh i nasc",
    "It might have been deleted, or there was a typo in the link" : "Seans gur scriosadh é, nó go raibh clóscríobh sa nasc",
    "Meeting room" : "Seomra cruinnithe",
    "Lecture hall" : "halla léachta",
    "Seminar room" : "Seomra seimineáir",
    "Other" : "Eile",
    "When shared show" : "Nuair a bheidh an seó roinnte",
    "When shared show full event" : "Nuair a chomhroinntear taispeáin imeacht iomlán",
    "When shared show only busy" : "Nuair a bheidh an seó roinnte ach gnóthach",
    "When shared hide this event" : "Nuair a bheidh tú roinnte cuir an t-imeacht seo i bhfolach",
    "The visibility of this event in read-only shared calendars." : "Infheictheacht an imeachta seo i bhféilirí comhroinnte inléite amháin.",
    "Add a location" : "Cuir suíomh leis",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Cuir cur síos leis\n\n- Cad faoi atá an cruinniú seo?\n- Míreanna ar an gclár\n- Rud ar bith is gá do rannpháirtithe a ullmhú",
    "Status" : "Stádas",
    "Confirmed" : "Deimhnithe",
    "Canceled" : "Ar ceal",
    "Confirmation about the overall status of the event." : "Deimhniú faoi stádas foriomlán an imeachta.",
    "Show as" : "Taispeáin mar",
    "Take this event into account when calculating free-busy information." : "Cuir an t-imeacht seo san áireamh agus faisnéis saor-ghnóthach á ríomh.",
    "Categories" : "Catagóirí",
    "Categories help you to structure and organize your events." : "Cuidíonn catagóirí leat do chuid imeachtaí a struchtúrú agus a eagrú.",
    "Search or add categories" : "Cuardaigh nó cuir catagóirí leis",
    "Add this as a new category" : "Cuir é seo leis mar chatagóir nua",
    "Custom color" : "Dath saincheaptha",
    "Special color of this event. Overrides the calendar-color." : "Dath speisialta na hócáide seo. sháraíonn an dath féilire.",
    "Error while sharing file" : "Earráid agus an comhad á roinnt",
    "Error while sharing file with user" : "Earráid agus an comhad á roinnt leis an úsáideoir",
    "Error creating a folder {folder}" : "Earráid ag cruthú fillteáin {folder}",
    "Attachment {fileName} already exists!" : "Tá ceangaltán {fileName} ann cheana féin!",
    "Attachment {fileName} added!" : "Cuireadh an ceangaltán {fileName} leis!",
    "An error occurred during uploading file {fileName}" : "Tharla earráid agus an comhad {fileName} á uaslódáil",
    "An error occurred during getting file information" : "Tharla earráid agus faisnéis comhaid á fáil",
    "Talk conversation for proposal" : "Comhrá cainte le haghaidh togra",
    "An error occurred, unable to delete the calendar." : "Tharla earráid, níorbh fhéidir an féilire a scriosadh.",
    "Imported {filename}" : "Iompórtáladh {filename}",
    "This is an event reminder." : "Is meabhrúchán imeachta é seo.",
    "Error while parsing a PROPFIND error" : "Earráid agus earráid PROPFIND á parsáil",
    "Appointment not found" : "Níor aimsíodh an coinne",
    "User not found" : "Úsáideoir gan aimsiú",
    "Hidden" : "I bhfolach",
    "can edit" : "is féidir in eagar",
    "Calendar name …" : "Ainm an fhéilire…",
    "Default attachments location" : "Default attachments location",
    "Automatic ({detected})" : "Uathoibríoch ({detected})",
    "Shortcut overview" : "Forbhreathnú aicearra",
    "CalDAV link copied to clipboard." : "Nasc CalDAV cóipeáilte chuig an ngearrthaisce.",
    "CalDAV link could not be copied to clipboard." : "Níorbh fhéidir nasc CalDAV a chóipeáil chuig an ngearrthaisce.",
    "Enable birthday calendar" : "Cumasaigh féilire lá breithe",
    "Show tasks in calendar" : "Taispeáin tascanna i bhféilire",
    "Enable simplified editor" : "Cumasaigh eagarthóir simplithe",
    "Limit the number of events displayed in the monthly view" : "Teorainn a chur le líon na n-imeachtaí a thaispeántar san amharc míosúil",
    "Show weekends" : "Taispeáin deireadh seachtaine",
    "Show week numbers" : "Taispeáin uimhreacha na seachtaine",
    "Time increments" : "Arduithe ama",
    "Default calendar for incoming invitations" : "Féilire réamhshocraithe le haghaidh cuirí isteach",
    "Copy primary CalDAV address" : "Cóipeáil príomhsheoladh CalDAV",
    "Copy iOS/macOS CalDAV address" : "Cóipeáil seoladh iOS/macOS CalDAV",
    "Personal availability settings" : "Socruithe infhaighteachta pearsanta",
    "Show keyboard shortcuts" : "Taispeáin aicearraí méarchláir",
    "Create a new public conversation" : "Cruthaigh comhrá poiblí nua",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} cuireadh, {confirmedCount} dearbhaithe",
    "Successfully appended link to talk room to location." : "D'éirigh le ceangal leis an seomra cainte a chur i gceangal le suíomh.",
    "Successfully appended link to talk room to description." : "D'éirigh le ceangal leis an seomra cainte a chur i gceangal leis an gcur síos.",
    "Error creating Talk room" : "Earráid agus an seomra cainte á chruthú",
    "_%n more guest_::_%n more guests_" : ["%n aoi eile","%n aíonna eile","%n aíonna eile","%n aíonna eile","%n aíonna eile"],
    "The visibility of this event in shared calendars." : "Infheictheacht an imeachta seo i bhféilirí roinnte."
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
