<?php

declare(strict_types=1);
/**
 * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */
script(\OCA\Calendar\AppInfo\Application::APP_ID, 'calendar-appointments-conflict');

?>

<div id="appointment-conflict"></div>
