OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "La dirección de correo electrónico proporcionada es demasiado larga",
    "User-Session unexpectedly expired" : "La sesión de usuario expiró inesperadamente",
    "Provided email-address is not valid" : "La dirección de correo electrónico proporcionada es inválida",
    "%s has published the calendar »%s«" : "%s ha publicado el calendario »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Error inesperado al enviar el correo electrónico. Por favor, contacte a su administrador.",
    "Successfully sent email to %1$s" : "Correo electrónico enviado exitosamente a %1$s",
    "Hello," : "Hola,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Queremos informarte que %s ha publicado el calendario »%s«.",
    "Open »%s«" : "Abrir »%s«",
    "Cheers!" : "¡Saludos!",
    "Upcoming events" : "Próximos eventos",
    "No more events today" : "No hay más eventos hoy",
    "No upcoming events" : "No hay eventos próximos",
    "More events" : "Más eventos",
    "%1$s with %2$s" : "%1$s con %2$s",
    "Calendar" : "Calendario",
    "New booking {booking}" : "Nueva reservación {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) reservó la cita \"{config_display_name}\" el {date_time}.",
    "Appointments" : "Citas",
    "Schedule appointment \"%s\"" : "Programar cita \"%s\"",
    "Schedule an appointment" : "Programar una cita",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : "Preparación para %s",
    "Follow up for %s" : "Seguimiento para %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Su cita \"%s\" con %s necesita confirmación",
    "Dear %s, please confirm your booking" : "Estimado(a) %s, por favor, confirme su reservación",
    "Confirm" : "Confirmar",
    "Appointment with:" : "Cita con:",
    "Description:" : "Descripción:",
    "This confirmation link expires in %s hours." : "Este enlace de confirmación caduca en %s horas.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Si desea cancelar la cita después de todo, por favor, contacte al organizador respondiendo a este correo o visite su página del perfil.",
    "Your appointment \"%s\" with %s has been accepted" : "Su cita \"%s\" con %s ha sido aceptada",
    "Dear %s, your booking has been accepted." : "Estimado(a) %s, su reservación ha sido aceptada.",
    "Appointment for:" : "Cita para:",
    "Date:" : "Fecha:",
    "You will receive a link with the confirmation email" : "Recibirá un enlace con el correo electrónico con de confirmación",
    "Where:" : "Dónde:",
    "Comment:" : "Comentario:",
    "You have a new appointment booking \"%s\" from %s" : "Tiene una nueva reservación \"%s\" de %s",
    "Dear %s, %s (%s) booked an appointment with you." : "Estimado(a) %s, %s (%s) ha reservado una cita con Ud.",
    "Location:" : "Ubicación:",
    "A Calendar app for Nextcloud" : "Una aplicación de Calendario para Nextcloud",
    "Previous day" : "Día anterior",
    "Previous week" : "Semana anterior",
    "Previous year" : "Año anterior",
    "Previous month" : "Mes anterior",
    "Next day" : "Próximo día",
    "Next week" : "Próxima semana",
    "Next year" : "Próximo año",
    "Next month" : "Próximo mes",
    "Create new event" : "Crear nuevo evento",
    "Event" : "Evento",
    "Today" : "Hoy",
    "Day" : "Día",
    "Week" : "Semana",
    "Month" : "Mes",
    "Year" : "Año",
    "List" : "Lista",
    "Appointment link was copied to clipboard" : "El enlace de la cita se copió al portapapeles",
    "Appointment link could not be copied to clipboard" : "No se pudo copiar el enlace de la cita al portapapeles",
    "Preview" : "Previsualizar",
    "Copy link" : "Copiar liga",
    "Edit" : "Editar",
    "Delete" : "Borrar",
    "Appointment schedules" : "Cronograma de citas",
    "Create new" : "Crear nuevo",
    "Disable calendar \"{calendar}\"" : "Deshabilitar calendario \"{calendar}\"",
    "Disable untitled calendar" : "Deshabilitar calendario sin título",
    "Enable calendar \"{calendar}\"" : "Habilitar calendario \"{calendar}\"",
    "Enable untitled calendar" : "Habilitar calendario sin título",
    "An error occurred, unable to change visibility of the calendar." : "Ocurrió un error, no se pudo cambiar la visibilidad del calendario.",
    "Untitled calendar" : "Calendario sin título",
    "Shared with you by" : "Compartido con Ud. por",
    "Edit and share calendar" : "Editar y compartir calendario",
    "Edit calendar" : "Editar calendario",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Dejando de compartir el calendario en {countdown} segundo","Dejando de compartir el calendario en {countdown} segundos","Dejando de compartir el calendario en {countdown} segundos"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Eliminando el calendario en {countdown} segundo","Eliminando el calendario en {countdown} segundos","Eliminando el calendario en {countdown} segundos"],
    "An error occurred, unable to create the calendar." : "Ocurrió un error, no se pudo crear el calendario.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Por favor, ingrese un enlace válido (comenzando con http://, https://, webcal:// o webcals://)",
    "Calendars" : "Calendarios",
    "Add new" : "Añadir nuevo",
    "New calendar" : "Nuevo calendario",
    "Name for new calendar" : "Nombre del nuevo calendario",
    "Creating calendar …" : "Creando calendario …",
    "New calendar with task list" : "Nuevo calendario con lista de tareas",
    "New subscription from link (read-only)" : "Nueva suscripción desde enlace (sólo lectura)",
    "Creating subscription …" : "Creando suscripción …",
    "Add public holiday calendar" : "Añadir calendario público de días feriados",
    "Add custom public calendar" : "Añadir calendario público personalizado",
    "Calendar link copied to clipboard." : "Enlace del calendario copiado al portapapeles.",
    "Calendar link could not be copied to clipboard." : "No se pudo copiar el enlace del calendario al portapapeles.",
    "Copy subscription link" : "Copiar enlace de suscripción",
    "Copying link …" : "Copiando enlace …",
    "Copied link" : "Enlace copiado",
    "Could not copy link" : "No se pudo copiar el enlace",
    "Export" : "Exportar",
    "Untitled item" : "Elemento sin título",
    "Unknown calendar" : "Calendario desconocido",
    "Could not load deleted calendars and objects" : "No se pudieron cargar los calendarios y objetos eliminados",
    "Could not delete calendar or event" : "No se pudo eliminar el calendario o el evento",
    "Could not restore calendar or event" : "No se pudo restaurar el calendario o evento",
    "Do you really want to empty the trash bin?" : "¿Realmente desea vaciar la papelera?",
    "Empty trash bin" : "Vaciar la papelera de reciclaje",
    "Trash bin" : "Papelera",
    "Loading deleted items." : "Cargando elementos eliminados.",
    "You do not have any deleted items." : "No tiene elementos eliminados.",
    "Name" : "Nombre",
    "Deleted" : "Eliminado",
    "Restore" : "Restaurar",
    "Delete permanently" : "Borrar permanentemente",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Los elementos en la papelera se eliminan después de {numDays} día","Los elementos en la papelera se eliminan después de {numDays} días","Los elementos en la papelera se eliminan después de {numDays} días"],
    "Could not update calendar order." : "No se pudo actualizar el orden del calendario.",
    "Shared calendars" : "Compartir calendarios",
    "Deck" : "Deck",
    "Internal link" : "Enlace interno",
    "A private link that can be used with external clients" : "Un enlace privado que se puede usar con clientes externos",
    "Copy internal link" : "Copiar enlace interno",
    "An error occurred, unable to publish calendar." : "Ocurrió un error, no se pudo publicar el calendario.",
    "An error occurred, unable to send email." : "Ocurrió un error, no se pudo enviar el correo electrónico.",
    "Embed code copied to clipboard." : "Código embebido copiado al portapapeles.",
    "Embed code could not be copied to clipboard." : "No se pudo copiar el código embebido al portapapeles.",
    "Unpublishing calendar failed" : "No se pudo despublicar el calendario",
    "Share link" : "Compartir liga",
    "Copy public link" : "Copiar enlace público",
    "Send link to calendar via email" : "Enviar enlace del calendario por correo electrónico",
    "Enter one address" : "Escriba una dirección",
    "Sending email …" : "Enviando correo electrónico …",
    "Copy embedding code" : "Copiar código embebido",
    "Copying code …" : "Copiando código …",
    "Copied code" : "Código copiado",
    "Could not copy code" : "No se pudo copiar el código",
    "Delete share link" : "Eliminar enlace compartido",
    "Deleting share link …" : "Eliminando enlace compartido …",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Equipo)",
    "An error occurred while unsharing the calendar." : "Ocurrió un error al dejar de compartir el calendario.",
    "An error occurred, unable to change the permission of the share." : "Ocurrió un error, no se pudieron cambiar los permisos del recurso compartido.",
    "Unshare with {displayName}" : "Dejar de compartir con {displayName}",
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "No users or groups" : "Sin usuarios ni grupos",
    "Failed to save calendar name and color" : "No se pudo guardar el nombre ni el color del calendario",
    "Never show me as busy (set this calendar to transparent)" : "Nunca mostrarme como ocupado (establecer este calendario como transparente)",
    "Share calendar" : "Compartir calendario",
    "Unshare from me" : "Dejar de compartir conmigo",
    "Save" : "Guardar",
    "View" : "Ver",
    "Import calendars" : "Importar calendarios",
    "Please select a calendar to import into …" : "Por favor, seleccione un calendario al que importar …",
    "Filename" : "Nombre del archivo",
    "Calendar to import into" : "Calendario en el cual importar",
    "Cancel" : "Cancelar",
    "_Import calendar_::_Import calendars_" : ["Importar calendario","Importar calendarios","Importar calendarios"],
    "Select the default location for attachments" : "Seleccionar la ubicación predeterminada para los adjuntos",
    "Pick" : "Elegir",
    "Invalid location selected" : "Ubicación seleccionada inválida",
    "Attachments folder successfully saved." : "La carpeta de adjuntos se guardó exitosamente.",
    "Error on saving attachments folder." : "Ocurrió un error al guardar la carpeta de adjuntos.",
    "{filename} could not be parsed" : "No se pudo analizar {filename}",
    "No valid files found, aborting import" : "No se encontraron archivos válidos, cancelando la importación",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Se importó exitosamente %n evento","Se importaron exitosamente %n eventos","Se importaron exitosamente %n eventos"],
    "Import partially failed. Imported {accepted} out of {total}." : "La importación falló parcialmente. Se importaron {accepted} de {total}.",
    "Automatic" : "Automático",
    "Automatic ({timezone})" : "({timezone}) automática",
    "New setting was not saved successfully." : "No se guardó correctamente la nueva configuración.",
    "Timezone" : "Zona horaria",
    "Navigation" : "Navegación",
    "Previous period" : "Periodo anterior",
    "Next period" : "Periodo siguiente",
    "Views" : "Vistas",
    "Day view" : "Vista diaria",
    "Week view" : "Vista semanal",
    "Month view" : "Vista mensual",
    "Year view" : "Vista anual",
    "List view" : "Vista de lista",
    "Actions" : "Acciones",
    "Create event" : "Crear evento",
    "Show shortcuts" : "Mostrar atajos",
    "Editor" : "Editor",
    "Close editor" : "Cerrar editor",
    "Save edited event" : "Guardar evento editado",
    "Delete edited event" : "Eliminar evento editado",
    "Duplicate event" : "Duplicar evento",
    "or" : "o",
    "Calendar settings" : "Configuración del calendario",
    "At event start" : "Al comienzo del evento",
    "No reminder" : "Sin recordatorio",
    "Failed to save default calendar" : "No se pudo guardar el calendario predeterminado",
    "General" : "General",
    "Appearance" : "Apariencia",
    "Editing" : "Editando",
    "Default reminder" : "Recordatorio predeterminado",
    "Files" : "Archivo",
    "Appointment schedule successfully created" : "El cronograma de citas fue creado exitosamente",
    "Appointment schedule successfully updated" : "El cronograma de citas fue actualizado exitosamente",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minuto","{duration} minutos","{duration} minutos"],
    "0 minutes" : "0 minutos",
    "_{duration} hour_::_{duration} hours_" : ["{duration} hora","{duration} horas","{duration} horas"],
    "_{duration} day_::_{duration} days_" : ["{duration} día","{duration} días","{duration} días"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} semana","{duration} semanas","{duration} semanas"],
    "_{duration} month_::_{duration} months_" : ["{duration} mes","{duration} meses","{duration} meses"],
    "_{duration} year_::_{duration} years_" : ["{duration} año","{duration} años","{duration} años"],
    "To configure appointments, add your email address in personal settings." : "Para configurar las citas, agregue su dirección de correo electrónico en la configuración personal.",
    "Public – shown on the profile page" : "Público - se muestra en la página de perfil",
    "Private – only accessible via secret link" : "Privado - accesible únicamente mediante enlace secreto",
    "Appointment schedule saved" : "Cronograma de citas guardado",
    "Create appointment schedule" : "Crear cronograma de citas",
    "Edit appointment schedule" : "Editar cronograma de citas",
    "Update" : "Actualizar",
    "Appointment name" : "Nombre de la cita",
    "Location" : "Ubicación",
    "Create a Talk room" : "Crear una sala de Talk",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Se generará un enlace único por cada cita agendada y se enviará a través del correo electrónico de confirmación",
    "Description" : "Descripción",
    "Visibility" : "Visibilidad",
    "Duration" : "Duración",
    "Increments" : "Incrementos",
    "Additional calendars to check for conflicts" : "Calendarios adicionales para comprobar por conflictos",
    "Pick time ranges where appointments are allowed" : "Elegir rangos de tiempo para permitir citas",
    "to" : "para",
    "Delete slot" : "Eliminar ranura",
    "No times set" : "No se han establecido horarios",
    "Add" : "Agregar",
    "Monday" : "Lunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Jueves",
    "Friday" : "Viernes",
    "Saturday" : "Sábado",
    "Sunday" : "Domingo",
    "Weekdays" : "Días laborales",
    "Add time before and after the event" : "Añadir tiempo antes y después del evento",
    "Before the event" : "Antes del evento",
    "After the event" : "Después del evento",
    "Planning restrictions" : "Restricciones de planificación",
    "Minimum time before next available slot" : "Tiempo mínimo antes del próximo espacio disponible",
    "Max slots per day" : "Cantidad de espacios máximos al día",
    "Limit how far in the future appointments can be booked" : "Limitar qué tan lejos en el futuro se pueden reservar citas",
    "It seems a rate limit has been reached. Please try again later." : "Límite de solicitudes alcanzado. Por favor, intente de nuevo más tarde.",
    "Please confirm your reservation" : "Por favor, confirme su reservación",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Le hemos enviado un correo electrónico con los detalles. Por favor, confirme su cita usando el enlace del correo. Puede cerrar esta página ahora.",
    "Your name" : "Su nombre",
    "Your email address" : "Tu dirección de correo electrónico",
    "Please share anything that will help prepare for our meeting" : "Por favor, comparta cualquier cosa que ayude a prepararnos para nuestra reunión.",
    "Could not book the appointment. Please try again later or contact the organizer." : "No se pudo reservar la cita. Por favor, intente de nuevo más tarde o contacte al organizador.",
    "Back" : "Atrás",
    "Book appointment" : "Reservar cita",
    "on" : "el",
    "at" : "a las",
    "before at" : "antes de las",
    "Notification" : "Notificación",
    "Email" : "Correo electrónico",
    "Audio notification" : "Notificación de audio",
    "Other notification" : "Otra notificación",
    "Relative to event" : "Relativo al evento",
    "On date" : "En la fecha",
    "Edit time" : "Editar hora",
    "Save time" : "Guardar hora",
    "Remove reminder" : "Eliminar recordatorio",
    "Add reminder" : "Añadir recordatorio",
    "seconds" : "segundos",
    "minutes" : "minutos",
    "hours" : "horas",
    "days" : "días",
    "weeks" : "semanas",
    "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
    "Choose a file to share as a link" : "Elegir un archivo para compartir como enlace",
    "Attachment {name} already exist!" : "¡El adjunto {name} ya existe!",
    "Could not upload attachment(s)" : "No se pudo cargar el(los) adjunto(s)",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Estás a punto de navegar a {host}. ¿Estás seguro? Enlace: {link}",
    "Proceed" : "Proceder",
    "No attachments" : "Sin adjuntos",
    "Add from Files" : "Agregar desde Archivos",
    "Upload from device" : "Cargar desde el dispositivo",
    "Delete file" : "Borrar archivo",
    "Confirmation" : "Confirmación",
    "_{count} attachment_::_{count} attachments_" : ["{count} adjunto","{count} adjuntos","{count} adjuntos"],
    "Suggested" : "Sugerido",
    "Available" : "Disponible",
    "Invitation accepted" : "Invitación aceptada",
    "Accepted {organizerName}'s invitation" : "Se aceptó la invitación de {organizerName}",
    "Participation marked as tentative" : "Participación marcada como tentativa",
    "Invitation is delegated" : "Se delegó la invitación",
    "Not available" : "No disponible",
    "Invitation declined" : "Invitación rechazada",
    "Declined {organizerName}'s invitation" : "Se rechazó la invitación de {organizerName}",
    "Awaiting response" : "Esperando respuesta",
    "Checking availability" : "Comprobando disponibilidad",
    "Has not responded to {organizerName}'s invitation yet" : "No ha respondido a la invitación de {organizerName} aún",
    "chairperson" : "presidente",
    "required participant" : "participante requerido",
    "non-participant" : "no participante",
    "optional participant" : "participante opcional",
    "{organizer} (organizer)" : "{organizer} (organizador)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Availability of attendees, resources and rooms" : "Disponibilidad de asistentes, recursos y salas",
    "Suggestion accepted" : "Sugerencia aceptada",
    "Legend" : "Leyenda",
    "Out of office" : "Fuera de la oficina",
    "Attendees:" : "Asistentes:",
    "Done" : "Terminado",
    "Search room" : "Buscar sala",
    "Room name" : "Nombre del cuarto",
    "Check room availability" : "Comprobar la disponibilidad de salas",
    "Free" : "Disponible",
    "Busy (tentative)" : "Ocupado (tentativo)",
    "Busy" : "Ocupado",
    "Unknown" : "Desconocido",
    "Find a time" : "Buscar una hora",
    "The invitation has been accepted successfully." : "Invitación aceptada exitosamente.",
    "Failed to accept the invitation." : "No se pudo aceptar la invitación.",
    "The invitation has been declined successfully." : "Invitación rechazada exitosamente.",
    "Failed to decline the invitation." : "No se pudo rechazar la invitación.",
    "Your participation has been marked as tentative." : "Su participación ha sido marcada como tentativa.",
    "Failed to set the participation status to tentative." : "No se pudo establecer el estado de participación como tentativa.",
    "Accept" : "Aceptar",
    "Decline" : "Rechazar",
    "Tentative" : "Tentativo",
    "No attendees yet" : "Aún no hay asistentes",
    "Attendees" : "Asistentes",
    "Remove group" : "Eliminar grupo",
    "Remove attendee" : "Eliminar asistente",
    "Request reply" : "Solicitar respuesta",
    "Chairperson" : "Presidente",
    "Required participant" : "Participante requerido",
    "Optional participant" : "Participante opcional",
    "Non-participant" : "No participante",
    "_%n member_::_%n members_" : ["%n miembro","%n miembros","%n miembros"],
    "No match found" : "No se encontraron coincidencias",
    "Note that members of circles get invited but are not synced yet." : "Tenga en cuenta que los miembros de los círculos serán invitados pero aún no están sincronizados.",
    "(organizer)" : "(organizador)",
    "Make {label} the organizer" : "Hacer que {label} sea el organizador",
    "Make {label} the organizer and attend" : "Hacer que {label} sea el organizador y asistente",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Para enviar invitaciones y manejar respuestas, [linkopen]agregue su dirección de correo electrónico en la configuración personal[linkclose].",
    "Remove color" : "Eliminar color",
    "Event title" : "Título del evento",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "No se puede modificar la configuración de todo el día para eventos que forman parte de una serie recurrente.",
    "From" : "De",
    "To" : "Para",
    "Repeat" : "Repetir",
    "_time_::_times_" : ["vez","veces","veces"],
    "never" : "nunca",
    "on date" : "en la fecha",
    "after" : "después",
    "End repeat" : "Terminar repetición",
    "Select to end repeat" : "Seleccionar para terminar la repetición",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Este evento es la excepción a la recurrencia de una serie recurrente. No puede agregarle una regla de recurrencia.",
    "first" : "primero",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Los cambios en la regla de recurrencia sólo se aplicarán a ésta y a futuras ocurrencias.",
    "Repeat every" : "Repetir cada",
    "By day of the month" : "Por día del mes",
    "On the" : "En el",
    "_day_::_days_" : ["día","días","días"],
    "_week_::_weeks_" : ["semana","semanas","semanas"],
    "_month_::_months_" : ["mes","meses","meses"],
    "_year_::_years_" : ["año","años","años"],
    "weekday" : "día hábil",
    "weekend day" : "día de fin de semana",
    "Does not repeat" : "No se repite",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "La definición de recurrencia de este evento no está completamente soportada por Nextcloud. Si edita las opciones de recurrencia, es posible que se pierdan ciertas ocurrencias.",
    "No rooms or resources yet" : "Aún no hay salas ni recursos",
    "Resources" : "Recursos",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} asiento","{seatingCapacity} asientos","{seatingCapacity} asientos"],
    "Add resource" : "Añadir recurso",
    "Has a projector" : "Tiene un proyector",
    "Has a whiteboard" : "Tiene un pizarrón",
    "Wheelchair accessible" : "Accesible en silla de ruedas",
    "Remove resource" : "Eliminar recurso",
    "Search for resources or rooms" : "Buscar recursos o salas",
    "available" : "disponible",
    "unavailable" : "no disponible",
    "Show all rooms" : "Mostrar todas las salas",
    "Projector" : "Proyector",
    "Whiteboard" : "Pizarrón",
    "Room type" : "Tipo de sala",
    "Any" : "Cualquiera",
    "Minimum seating capacity" : "Capacidad mínima de asientos",
    "More details" : "Más detalles",
    "Update this and all future" : "Actualizar ésta y todas las siguientes",
    "Update this occurrence" : "Actualizar esta ocurrencia",
    "Public calendar does not exist" : "El calendario público no existe",
    "Maybe the share was deleted or has expired?" : "¿Quizá el recurso compartido fue eliminado o caducó?",
    "Maybe" : "Tal vez",
    "None" : "Ninguno",
    "Create" : "Crear",
    "from {formattedDate}" : "desde {formattedDate}",
    "to {formattedDate}" : "hasta {formattedDate}",
    "on {formattedDate}" : "el {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "desde {formattedDate} a las {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "hasta {formattedDate} a las {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "el {formattedDate} a las {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} a las {formattedTime}",
    "Please enter a valid date" : "Por favor, ingrese una fecha válida",
    "Please enter a valid date and time" : "Por favor, ingresa una fecha y hora válidas",
    "Select a time zone" : "Seleccionar la zona horaria",
    "Please select a time zone:" : "Por favor, seleccione una zona horaria:",
    "Pick a time" : "Elige una hora",
    "Pick a date" : "Elige una fecha",
    "Type to search time zone" : "Escribir para buscar la zona horaria",
    "Global" : "Global",
    "Holidays in {region}" : "Días feriados en {region}",
    "An error occurred, unable to read public calendars." : "Ocurrió un error, no se pueden leer los calendarios públicos.",
    "An error occurred, unable to subscribe to calendar." : "Ocurrió un error, no se pudo suscribir al calendario.",
    "Public holiday calendars" : "Calendarios públicos de días feriados",
    "Public calendars" : "Calendarios públicos",
    "No valid public calendars configured" : "No hay calendarios públicos válidos configurados",
    "Speak to the server administrator to resolve this issue." : "Comuníquese con el administrador del servidor para resolver este problema.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Los calendarios públicos de días feriados son proporcionados por Thunderbird. Los datos del calendario se descargarán desde {website}",
    "By {authors}" : "Por {authors}",
    "Subscribed" : "Suscrito",
    "Subscribe" : "Suscríbete",
    "Could not fetch slots" : "No se pudieron obtener los espacios",
    "Select a date" : "Seleccionar una fecha",
    "Select slot" : "Seleccionar espacio",
    "No slots available" : "No hay espacios disponibles",
    "The slot for your appointment has been confirmed" : "El espacio de su cita ha sido confirmado",
    "Appointment Details:" : "Detalles de la cita:",
    "Time:" : "Hora:",
    "Booked for:" : "Agendado para:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Gracias. Su reservación desde {startDate} hasta {endDate} ha sido confirmada.",
    "Book another appointment:" : "Agendar otra cita:",
    "See all available slots" : "Ver todos los espacios disponibles",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "El espacio para su cita desde {startDate} hasta {endDate} ya no está disponible.",
    "Please book a different slot:" : "Por favor agende un espacio diferente:",
    "Book an appointment with {name}" : "Agendar una cita con {name}",
    "No public appointments found for {name}" : "No se encontraron citas públicas para {name}",
    "Personal" : "Personal",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "La detección automática de la zona horaria determinó que su zona horaria sea UTC.\nLo más probable es que sea el resultado de las medidas de seguridad de su navegador web.\nPor favor, establezca su zona horaria manualmente en la configuración del calendario. ",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "No se encontró la zona horaria configurada ({timezoneId}). Volviendo a UTC.\nPor favor, cambie su zona horaria en la configuración e informe de este problema.",
    "Edit event" : "Editar evento",
    "Event does not exist" : "El evento no existe",
    "Duplicate" : "Duplicado",
    "Delete this occurrence" : "Eliminar esta ocurrencia",
    "Delete this and all future" : "Eliminar ésta y las futuras",
    "All day" : "Todo el día",
    "Managing shared access" : "Administrando el acceso compartido",
    "Deny access" : "Denegar acceso",
    "Invite" : "Invitar",
    "_User requires access to your file_::_Users require access to your file_" : ["El usuario requiere acceso a su archivo","Los usuarios requieren acceso a su archivo","Los usuarios requieren acceso a su archivo"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Adjunto que requiere acceso compartido","Adjuntos que requieren acceso compartido","Adjuntos que requieren acceso compartido"],
    "Untitled event" : "Evento sin título",
    "Close" : "Cerrar",
    "30 min" : "30 min",
    "Participants" : "Participantes",
    "Submit" : "Enviar",
    "Subscribe to {name}" : "Subscribir a {name}",
    "Export {name}" : "Exportar {name}",
    "Anniversary" : "Aniversario",
    "Appointment" : "Cita",
    "Business" : "Negocio",
    "Education" : "Educación",
    "Holiday" : "Día feriado",
    "Meeting" : "Reunión",
    "Miscellaneous" : "Misceláneo",
    "Non-working hours" : "Horario no laboral",
    "Not in office" : "Fuera de la oficina",
    "Phone call" : "Llamada telefónica",
    "Sick day" : "Día de enfermedad",
    "Special occasion" : "Ocasión especial",
    "Travel" : "Viaje",
    "Vacation" : "Vacaciones",
    "Midnight on the day the event starts" : "Medianoche en el día en el que comienza el evento",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n día antes del evento a las {formattedHourMinute}","%n días antes del evento a las {formattedHourMinute}","%n días antes del evento a las {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n semana antes del evento a las {formattedHourMinute}","%n semanas antes del evento a las {formattedHourMinute}","%n semanas antes del evento a las {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "en el día del evento a las {formattedHourMinute}",
    "at the event's start" : "al comienzo del evento",
    "at the event's end" : "al terminar el evento",
    "{time} before the event starts" : "{time} antes de que el evento comience",
    "{time} before the event ends" : "{time} antes de que el evento termine",
    "{time} after the event starts" : "{time} después de que el evento comience",
    "{time} after the event ends" : "{time} después de que el evento termine",
    "on {time}" : "a las {time}",
    "on {time} ({timezoneId})" : "a las {time} ({timezoneld})",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "Monthly" : "Mensualmente",
    "Yearly" : "Anualmente",
    "_Every %n day_::_Every %n days_" : ["Cada %n día","Cada %n días","Cada %n días"],
    "_Every %n week_::_Every %n weeks_" : ["Cada %n semana","Cada %n semanas","Cada %n semanas"],
    "_Every %n month_::_Every %n months_" : ["Cada %n mes","Cada %n meses","Cada %n meses"],
    "_Every %n year_::_Every %n years_" : ["Cada %n año","Cada %n años","Cada %n años"],
    "_on {weekday}_::_on {weekdays}_" : ["en {weekday}","en {weekdays}","en {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["el día {dayOfMonthList}","los días {dayOfMonthList}","los días {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "en el {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "en {monthNames} el {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "hasta {untilDate}",
    "_%n time_::_%n times_" : ["%n vez","%n veces","%n veces"],
    "second" : "segundo",
    "third" : "tercero",
    "fourth" : "cuarto",
    "fifth" : "quinto",
    "second to last" : "penúltimo",
    "last" : "último",
    "Untitled task" : "Tarea sin título",
    "Please ask your administrator to enable the Tasks App." : "Por favor, solicite a su administrador que habilite la aplicación de tareas.",
    "W" : "S",
    "%n more" : "%n más",
    "No events to display" : "No hay eventos para mostrar",
    "_+%n more_::_+%n more_" : ["+%n más","+%n más","+%n más"],
    "No events" : "No hay eventos",
    "Create a new event or change the visible time-range" : "Cree un nuevo evento o cambie el rango de horas visible",
    "Failed to save event" : "No se pudo guardar el evento",
    "It might have been deleted, or there was a typo in a link" : "Puede que se haya eliminado o haya una errata en un enlace",
    "It might have been deleted, or there was a typo in the link" : "Puede que se haya eliminado o haya una errata en el enlace",
    "Meeting room" : "Sala de juntas",
    "Lecture hall" : "Sala de conferencias",
    "Seminar room" : "Sala de seminarios",
    "Other" : "Otro",
    "When shared show" : "Cuando compartido, mostrar",
    "When shared show full event" : "Al compartir, mostrar el evento completo",
    "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
    "When shared hide this event" : "Al compartir, ocultar este evento ",
    "Add a location" : "Añadir ubicación",
    "Status" : "Estatus",
    "Confirmed" : "Confirmado",
    "Canceled" : "Cancelada",
    "Confirmation about the overall status of the event." : "Confirmación acerca del estado general del evento.",
    "Show as" : "Mostrar como",
    "Take this event into account when calculating free-busy information." : "Tomar en cuenta este evento al calcular la información de libre-ocupado.",
    "Categories" : "Categorías",
    "Categories help you to structure and organize your events." : "Las categorías le ayudan a estructurar y organizar sus eventos.",
    "Search or add categories" : "Buscar o añadir categorías",
    "Add this as a new category" : "Añadir esto como una nueva categoría",
    "Custom color" : "Color personalizado",
    "Special color of this event. Overrides the calendar-color." : "Color especial de este evento. Reemplazará el color del calendario.",
    "Error while sharing file" : "Error al compartir el archivo",
    "Error while sharing file with user" : "Error al compartir el archivo con el usuario",
    "Attachment {fileName} already exists!" : "¡El adjunto {fileName} ya existe!",
    "An error occurred during getting file information" : "Ocurrió un error al obtener la información del archivo",
    "An error occurred, unable to delete the calendar." : "Ocurrió un error, no se pudo eliminar el calendario.",
    "Imported {filename}" : "Importado {filename}",
    "This is an event reminder." : "Esto es un recordatorio del evento.",
    "Error while parsing a PROPFIND error" : "Error al analizar un error PROPFIND",
    "Appointment not found" : "Cita no encontrada",
    "User not found" : "No se encontró el usuario",
    "Hidden" : "Oculto",
    "can edit" : "puede editar",
    "Calendar name …" : "Nombre del calendario …",
    "Default attachments location" : "Ubicación predeterminada para adjuntos",
    "Automatic ({detected})" : "Automático ({detected})",
    "Shortcut overview" : "Vista general de atajos",
    "CalDAV link copied to clipboard." : "Enlace CalDAV copiado al portapapeles.",
    "CalDAV link could not be copied to clipboard." : "No se pudo copiar el enlace CalDAV al portapapeles.",
    "Enable birthday calendar" : "Habilitar el calendario de cumpleaños",
    "Show tasks in calendar" : "Mostrar tareas en el calendario",
    "Enable simplified editor" : "Habilitar el editor simplificado",
    "Limit the number of events displayed in the monthly view" : "Limitar el número de eventos mostrados en la vista mensual",
    "Show weekends" : "Mostrar fines de semana",
    "Show week numbers" : "Mostrar número de semana",
    "Time increments" : "Incrementos de tiempo",
    "Default calendar for incoming invitations" : "Calendario predeterminado para aceptar invitaciones",
    "Copy primary CalDAV address" : "Copiar la dirección CalDAV principal",
    "Copy iOS/macOS CalDAV address" : "Copiar la dirección iOS/macOS CalDAV",
    "Personal availability settings" : "Configuración de disponibilidad personal",
    "Show keyboard shortcuts" : "Mostrar atajos de teclado",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} invitados, {confirmedCount} confirmados",
    "Successfully appended link to talk room to location." : "Se ha añadido correctamente el enlace a la sala de conversación a la ubicación.",
    "Successfully appended link to talk room to description." : "Se ha añadido correctamente el enlace a la sala de conversación a la descripción.",
    "Error creating Talk room" : "Error al crear la sala de Talk",
    "_%n more guest_::_%n more guests_" : ["%n invitado más","%n más invitados","%n más invitados"],
    "The visibility of this event in shared calendars." : "La visibilidad de este evento en calendarios compartidos."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
