"use strict";(self.webpackChunkcalendar=self.webpackChunkcalendar||[]).push([["node_modules_nextcloud_dialogs_dist_chunks_index-BC-7VPxC_mjs"],{60640:(e,d,_)=>{_.d(d,{FilePickerVue:()=>s});const s=(0,_(85471).$V)((()=>Promise.all([_.e("vendors-node_modules_nextcloud_vue_dist_chunks_NcTextField-CfZknuqx_mjs-node_modules_webdav_d-8a252d"),_.e("vendors-node_modules_nextcloud_vue_dist_chunks_NcActionInput-pjhToEAw_mjs-node_modules_nextcl-78d26d"),_.e("vendors-node_modules_nextcloud_files_dist_index_mjs-node_modules_nextcloud_vue_dist_Component-c57add"),_.e("vendors-node_modules_nextcloud_dialogs_dist_chunks_FilePicker-CsU6FfAP_mjs")]).then(_.bind(_,8695))))}}]);
//# sourceMappingURL=calendar-node_modules_nextcloud_dialogs_dist_chunks_index-BC-7VPxC_mjs.js.map?v=39dee88a053e35955b95