OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Oppgitt e-postadresse er for lang",
    "User-Session unexpectedly expired" : "Brukerøkten utløp uventet",
    "Provided email-address is not valid" : "Oppgitt e-postadresse er ikke gyldig",
    "%s has published the calendar »%s«" : "%s har publisert kalenderen \"%s\"",
    "Unexpected error sending email. Please contact your administrator." : "Det oppsto uventet feil under sending av e-post. Kontakt din administrator.",
    "Successfully sent email to %1$s" : "Epost sendt til %1$s",
    "Hello," : "Hei,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Vi ønsker å informere deg om at %s har publisert kalenderen \"%s\".",
    "Open »%s«" : "Åpne \"%s\"",
    "Cheers!" : "Ha det!",
    "Upcoming events" : "Kommende hendelser",
    "No more events today" : "Ingen flere hendelser i dag",
    "No upcoming events" : "Ingen kommende hendelser",
    "More events" : "Flere hendelser",
    "%1$s with %2$s" : "%1$s med %2$s",
    "Calendar" : "Kalender",
    "New booking {booking}" : "Ny bestilling {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) bestilte time \"{config_display_name}\" den {date_time}.",
    "Appointments" : "Avtaler",
    "Schedule appointment \"%s\"" : "Registrer avtale \"%s\"",
    "Schedule an appointment" : "Registrer en avtale",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : "Forbered for %s",
    "Follow up for %s" : "Følg opp for %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Avtalen din \"%s\" med %s trenger bekreftelse",
    "Dear %s, please confirm your booking" : "Kjære %s, vennligst bekreft bestillingen din",
    "Confirm" : "Bekreft",
    "Appointment with:" : "Avtale med:",
    "Description:" : "Beskrivelse:",
    "This confirmation link expires in %s hours." : "Denne bekreftelseslinken utgår om %stimer.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Hvis du ønsker å avbryte avtalen, vennligst kontakt arrangøren din ved å svare på denne e-posten eller ved å besøke deres profilside.",
    "Your appointment \"%s\" with %s has been accepted" : "Avtalen din \"%s\" med %s har blitt akseptert",
    "Dear %s, your booking has been accepted." : "Kjære%s, bestillingen din har blitt akseptert.",
    "Appointment for:" : "Appointment for:",
    "Date:" : "Dato:",
    "You will receive a link with the confirmation email" : "Du vil motta en lenke med bekreftelses-e-posten",
    "Where:" : "Hvor:",
    "Comment:" : "Kommentar:",
    "You have a new appointment booking \"%s\" from %s" : "Du har en ny timebestilling \"%s\" fra %s",
    "Dear %s, %s (%s) booked an appointment with you." : "Kjære %s, %s (%s) bestilte time hos deg.",
    "Location:" : "Sted:",
    "A Calendar app for Nextcloud" : "En kalender til Nextcloud",
    "Previous day" : "Forrige dag",
    "Previous week" : "Forrige uke",
    "Previous year" : "Forrige år",
    "Previous month" : "Forrige måned",
    "Next day" : "Neste dag",
    "Next week" : "Neste uke",
    "Next year" : "Neste år",
    "Next month" : "Neste måned",
    "Create new event" : "Opprett ny hendelse",
    "Event" : "Begivenhet",
    "Today" : "I dag",
    "Day" : "Dag",
    "Week" : "Uke",
    "Month" : "Måned",
    "Year" : "År",
    "List" : "Liste",
    "Appointment link was copied to clipboard" : "Avtalelenke ble kopiert til utklippstavlen",
    "Appointment link could not be copied to clipboard" : "Avtalelenken ble ikke kopiert til utklippstavlen",
    "Preview" : "Forhåndsvis",
    "Copy link" : "Kopier lenke",
    "Edit" : "Rediger",
    "Delete" : "Slett",
    "Create new" : "Opprett ny",
    "Disable calendar \"{calendar}\"" : "Deaktiver kalender \"{calendar}\"",
    "Disable untitled calendar" : "Deaktiver kalender uten tittel",
    "Enable calendar \"{calendar}\"" : "Aktiver kalenderen \"{calendar}\"",
    "Enable untitled calendar" : "Aktiver kalender uten tittel",
    "An error occurred, unable to change visibility of the calendar." : "En feil oppsto, kan ikke endre synlighet til kalenderen.",
    "Untitled calendar" : "Kalender uten tittel",
    "Shared with you by" : "Delt med deg av",
    "Edit and share calendar" : "Rediger og del kalender",
    "Edit calendar" : "Rediger kalender",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Fjerner deling av kalenderen om {countdown} sekund","Fjerner deling av kalenderen om {countdown} sekunder"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Sletter kalenderen om {countdown} sekund","Sletter kalenderen om {countdown} sekunder"],
    "An error occurred, unable to create the calendar." : "En feil oppsto, kunne ikke opprette kalenderen",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Vennligst angi gyldig lenke (starte med http://, https://, webcal://, eller webcals://)",
    "Calendars" : "Kalendere",
    "Add new" : "Legg til ny",
    "New calendar" : "Ny kalender",
    "Name for new calendar" : "Navn på ny kalender",
    "Creating calendar …" : "Oppretter kalender ...",
    "New calendar with task list" : "Ny kalender med oppgaveliste",
    "New subscription from link (read-only)" : "Nytt abonnement fra lenke (kun lesing)",
    "Creating subscription …" : "Oppretter abonnement ...",
    "Add public holiday calendar" : "Legg til helligdagskalender",
    "Add custom public calendar" : "Legg til egendefinert offentlig kalender",
    "Calendar link copied to clipboard." : "Lenke til kalender kopiert til utklippstavle.",
    "Calendar link could not be copied to clipboard." : "Lenke til kalender kunne ikke bli kopiert til utklippstavle.",
    "Copy subscription link" : "Kopier abonnementslenke",
    "Copying link …" : "Kopierer lenke ...",
    "Copied link" : "Kopier lenke",
    "Could not copy link" : "Klarte ikke å kopiere lenken",
    "Export" : "Eksporter",
    "Untitled item" : "Element uten navn",
    "Unknown calendar" : "Ukjent kalender",
    "Could not load deleted calendars and objects" : "Kunne ikke laste slettede kalendere og objekter",
    "Could not delete calendar or event" : "Kunne ikke slette kalender eller hendelse",
    "Could not restore calendar or event" : "Kunne ikke gjenopprette kalender eller hendelse",
    "Do you really want to empty the trash bin?" : "Vil du virkelig tømme papirkurven?",
    "Empty trash bin" : "Tøm papirkurv",
    "Trash bin" : "Papirkurv",
    "Loading deleted items." : "Laster inn slettede elementer.",
    "You do not have any deleted items." : "Du har ingen slettede elementer.",
    "Name" : "Navn",
    "Deleted" : "Slettet",
    "Restore" : "Gjenopprett",
    "Delete permanently" : "Slett permanent",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Items in the trash bin are deleted after {numDays} day","Elementer i papirkurven slettes etter {numDays} dager"],
    "Could not update calendar order." : "Kunne ikke oppdatere rekkefølgen på kalendere.",
    "Shared calendars" : "Delte kalendere",
    "Deck" : "Stokk",
    "Internal link" : "Intern lenke",
    "A private link that can be used with external clients" : "En privat lenke som kan brukes med eksterne klienter",
    "Copy internal link" : "Kopier intern lenke",
    "An error occurred, unable to publish calendar." : "Det oppsto en feil, klarte ikke å publisere kalenderen.",
    "An error occurred, unable to send email." : "En feil oppsto, kan ikke sende e-post.",
    "Embed code copied to clipboard." : "Innbyggingskode kopiert til utklippstavle.",
    "Embed code could not be copied to clipboard." : "Innbyggingskode ble ikke kopiert til utklippstavle.",
    "Unpublishing calendar failed" : "Fjerne publiseringen av kalenderen feilet.",
    "Share link" : "Del lenke",
    "Copy public link" : "Kopier offentlig lenke",
    "Send link to calendar via email" : "Sende lenke til kalenderen via e-post",
    "Enter one address" : "Tast inn en adresse",
    "Sending email …" : "Sender epost ...",
    "Copy embedding code" : "Kopier innbyggingskode",
    "Copying code …" : "Kopierer kode ...",
    "Copied code" : "Kode kopiert",
    "Could not copy code" : "Klarte ikke å kopiere koden",
    "Delete share link" : "Slett delingslenke",
    "Deleting share link …" : "Sletter delingslenke ...",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Lag)",
    "An error occurred while unsharing the calendar." : "Det oppstod en feil under oppheving av deling av kalenderen.",
    "An error occurred, unable to change the permission of the share." : "En feil oppsto, kan ikke endre rettighetene til delingen.",
    "Unshare with {displayName}" : "Fjern deling med {displayName}",
    "Share with users or groups" : "Del med brukere eller grupper",
    "No users or groups" : "Ingen brukere eller grupper",
    "Failed to save calendar name and color" : "Lagring av kalendernavn og farge feilet",
    "Never show me as busy (set this calendar to transparent)" : "Vis meg aldri som opptatt (sett denne kalenderen til gjennomsiktig)",
    "Share calendar" : "Del kalender",
    "Unshare from me" : "Fjern deling fra meg",
    "Save" : "Lagre",
    "No title" : "Ingen tittel",
    "View" : "Vis",
    "Import calendars" : "Importer kalendere",
    "Please select a calendar to import into …" : "Vennligst velg en kalender å importere til ...",
    "Filename" : "Filnavn",
    "Calendar to import into" : "Kalenderen det skal importeres til",
    "Cancel" : "Avbryt",
    "_Import calendar_::_Import calendars_" : ["Importer kalender","Importer kalendere"],
    "Select the default location for attachments" : "Velg standardplassering for vedlegg",
    "Pick" : "Velg",
    "Invalid location selected" : "Invalid location selected",
    "Attachments folder successfully saved." : "Vedleggsmappen er lagret.",
    "Error on saving attachments folder." : "Feil ved lagring av vedleggsmappe.",
    "Attachments folder" : "Vedleggsmappe",
    "{filename} could not be parsed" : "{filename} kunne ikke leses",
    "No valid files found, aborting import" : "Ingen gyldig filer funnet, avbryter importering",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Vellykket importert %n hendelse","Vellykket importert %n hendelser"],
    "Import partially failed. Imported {accepted} out of {total}." : "Importen mislyktes delvis. Importerte {accepted} av {total}. ",
    "Automatic" : "Automatisk",
    "Automatic ({timezone})" : "Automatisk ({timezone})",
    "New setting was not saved successfully." : "Ny innstilling ble ikke lagret.",
    "Timezone" : "Tidssone",
    "Navigation" : "Navigasjon",
    "Previous period" : "Forrige periode",
    "Next period" : "Neste periode",
    "Views" : "Visninger",
    "Day view" : "Dagsvisning",
    "Week view" : "Ukesvisning",
    "Month view" : "Månedsvisning",
    "Year view" : "Årsvisning",
    "List view" : "Listevisning",
    "Actions" : "Handlinger",
    "Create event" : "Opprett hendelse",
    "Show shortcuts" : "Vis snarveier",
    "Editor" : "Tekstredigerer",
    "Close editor" : "Lukk tekstredigerer",
    "Save edited event" : "Lagre endret hendelse",
    "Delete edited event" : "Slett endret hendelse",
    "Duplicate event" : "Dupliser hendelse",
    "or" : "eller",
    "Calendar settings" : "Kalenderinnstillinger",
    "At event start" : "Ved hendelsens start",
    "No reminder" : "Ingen påminnelse",
    "Failed to save default calendar" : "Lagring av standard kalender feilet",
    "General" : "Generell",
    "Appearance" : "Utseende",
    "Editing" : "Rediger",
    "Default reminder" : "Standardpåminnelse",
    "Files" : "Filer",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minutt","{duration} minutter"],
    "0 minutes" : "0 minutter",
    "_{duration} hour_::_{duration} hours_" : ["{duration} time","{duration} timer"],
    "_{duration} day_::_{duration} days_" : ["{duration} dag","{duration} dager"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} uke","{duration} uker"],
    "_{duration} month_::_{duration} months_" : ["{duration} måned","{duration} måneder"],
    "_{duration} year_::_{duration} years_" : ["{duration} år","{duration} år"],
    "To configure appointments, add your email address in personal settings." : "For å konfigurere avtaler, legg til e-postadressen din i personlig innstillinger.",
    "Public – shown on the profile page" : "Offentlig – vises på profilsiden",
    "Private – only accessible via secret link" : "Privat – kun tilgjengelig via hemmelig lenke",
    "Update" : "Oppdater",
    "Appointment name" : "Navn på avtale",
    "Location" : "Sted",
    "Create a Talk room" : "Opprett et Talk-rom",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "En unik lenke vil bli generert for hver bestilt time og sendt via bekreftelses-e-posten",
    "Description" : "Beskrivelse",
    "Visibility" : "Synlighet",
    "Duration" : "Varighet",
    "Increments" : "Økninger",
    "Additional calendars to check for conflicts" : "Ekstra kalendere for å se etter konflikter",
    "Pick time ranges where appointments are allowed" : "Velg tidsrom der avtaler er tillatt",
    "to" : "til",
    "Delete slot" : "Slett tidsrom",
    "No times set" : "Ingen tidsrom satt",
    "Add" : "Legg til",
    "Monday" : "Mandag",
    "Tuesday" : "Tirsdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Lørdag",
    "Sunday" : "Søndag",
    "Weekdays" : "Ukedager",
    "Add time before and after the event" : "Legg til tid før og etter hendelsen",
    "Before the event" : "Før hendelsen",
    "After the event" : "Etter hendelsen",
    "Planning restrictions" : "Planleggingsbegrensninger",
    "Minimum time before next available slot" : "Minimumstid før neste ledige tidsrom",
    "Max slots per day" : "Maks. antall tidsrom per dag",
    "Limit how far in the future appointments can be booked" : "Begrens hvor langt frem i tid avtaler kan bestilles",
    "It seems a rate limit has been reached. Please try again later." : "Det ser ut til at en satsgrense er nådd. Prøv igjen senere.",
    "Please confirm your reservation" : "Vennligst bekreft din reservasjon",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Vi har sendt deg en e-post med detaljer. Vennligst bekreft avtalen din ved å bruke lenken i e-posten. Du kan lukke denne siden nå.",
    "Your name" : "Ditt navn",
    "Your email address" : "Din e-postadresse",
    "Please share anything that will help prepare for our meeting" : "Vennligst del alt som vil hjelpe deg med å forberede møtet vårt",
    "Could not book the appointment. Please try again later or contact the organizer." : "Kunne ikke bestille time. Prøv igjen senere eller kontakt arrangøren.",
    "Back" : "Tilbake",
    "Select conversation" : "Velg samtale",
    "on" : "på",
    "at" : "ved",
    "before at" : "før ved",
    "Notification" : "Varsel",
    "Email" : "E-post",
    "Audio notification" : "Lydvarsel",
    "Other notification" : "Andre varsel",
    "Relative to event" : "Relativt til hendelse",
    "On date" : "På dato",
    "Edit time" : "Rediger tidspunkt",
    "Save time" : "Lagre tidspunkt",
    "Remove reminder" : "Fjern påminnelse",
    "Add reminder" : "Legg til påminnelse",
    "seconds" : "sekund",
    "minutes" : "minutter",
    "hours" : "timer",
    "days" : "dager",
    "weeks" : "uker",
    "Choose a file to add as attachment" : "Velg en fil å legge til som vedlegg",
    "Choose a file to share as a link" : "Velg en fil du vil dele som en lenke",
    "Attachment {name} already exist!" : "Vedlegget {name} finnes allerede!",
    "Could not upload attachment(s)" : "Kunne ikke laste opp vedlegg",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Du er i ferd med å navigere til {host}. Er du sikker på å fortsette? Lenke: {link}",
    "Proceed" : "Fortsett",
    "No attachments" : "Ingen vedlegg",
    "Add from Files" : "Legg til fra filer",
    "Upload from device" : "Last opp fra enhet",
    "Delete file" : "Slett fil",
    "Confirmation" : "Bekreftelse",
    "_{count} attachment_::_{count} attachments_" : ["{count} vedlegg","{count} vedlegg"],
    "Suggested" : "Foreslått",
    "Available" : "Ledig",
    "Invitation accepted" : "Invitasjon akseptert",
    "Accepted {organizerName}'s invitation" : "Godtok invitasjonen til {organizerName}",
    "Participation marked as tentative" : "Deltakelse markert som foreløpig",
    "Invitation is delegated" : "Invitasjon er delegert",
    "Not available" : "Ikke ledig",
    "Invitation declined" : "Invitasjonen ble avslått",
    "Declined {organizerName}'s invitation" : "Avviste invitasjonen til {organizerName}",
    "Awaiting response" : "Venter på svar",
    "Checking availability" : "Sjekker ledighet",
    "Has not responded to {organizerName}'s invitation yet" : "Har ikke svart på {organizerName} sin invitasjon ennå",
    "chairperson" : "ordstyrer",
    "required participant" : "påkrevd deltaker",
    "non-participant" : "ikke-deltaker",
    "optional participant" : "valgfri deltaker",
    "{organizer} (organizer)" : "{organizer} (organisator)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Availability of attendees, resources and rooms" : "Ledighet til deltagere, ressurser og rom",
    "Suggestion accepted" : "Forslag akseptert",
    "Legend" : "Legende",
    "Out of office" : "Fraværende",
    "Attendees:" : "Deltakere:",
    "Done" : "Ferdig",
    "Search room" : "Søk rom",
    "Room name" : "Romnavn",
    "Check room availability" : "Sjekk rom tilgjengelighet",
    "Free" : "Ledig",
    "Busy (tentative)" : "Opptatt (foreløpig)",
    "Busy" : "Opptatt",
    "Unknown" : "Ukjent",
    "Find a time" : "Finn et tidspunkt",
    "The invitation has been accepted successfully." : "Invitasjonen er godtatt.",
    "Failed to accept the invitation." : "Kunne ikke godta invitasjonen.",
    "The invitation has been declined successfully." : "Invitasjonen har blitt avslått.",
    "Failed to decline the invitation." : "Kunne ikke avslå invitasjonen.",
    "Your participation has been marked as tentative." : "Din deltakelse er merket som foreløpig.",
    "Failed to set the participation status to tentative." : "Kunne ikke sette deltakelsesstatusen til tentativ.",
    "Accept" : "Aksepter",
    "Decline" : "Avslå",
    "Tentative" : "Foreløpig",
    "No attendees yet" : "Ingen deltakere enda",
    "Attendees" : "Deltakere",
    "Remove group" : "Fjern gruppe",
    "Remove attendee" : "Fjern deltaker",
    "Request reply" : "Be om svar",
    "Chairperson" : "Ordstyrer",
    "Required participant" : "Påkrevd deltaker",
    "Optional participant" : "Valgfri deltaker",
    "Non-participant" : "Ikke-deltaker",
    "_%n member_::_%n members_" : ["%n medlem","%n medlemmer"],
    "No match found" : "Ingen treff",
    "Note that members of circles get invited but are not synced yet." : "Merk at medlemmer av sirkler blir invitert, men ikke synkronisert enda.",
    "(organizer)" : "(organisator)",
    "Make {label} the organizer" : "Gjør {label} til organisatoren",
    "Make {label} the organizer and attend" : "Gjør {label} til organisatoren og delta",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "For å sende ut invitasjoner og håndtere svar, [linkopen]legg til e-postadressen din i personlige innstillinger[linkclose].",
    "Remove color" : "Fjern farge",
    "Event title" : "Tittel på hendelsen",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Kan ikke endre \"hel dag\"-innstillingen for hendelser som er en del av et gjentakelsessett.",
    "From" : "Fra",
    "To" : "Til",
    "Repeat" : "Gjenta",
    "_time_::_times_" : ["gang","ganger"],
    "never" : "aldri",
    "on date" : "på dato",
    "after" : "etter",
    "End repeat" : "Avslutt gjentakelse",
    "Select to end repeat" : "Velg for å avslutte gjentakelse",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Denne hendelsen er gjentakelsesunntaket for et gjentakelsessett. Du kan ikke legge til en gjentakelsesregel til den.",
    "first" : "første",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Endringer i gjentakelsesregelen vil kun gjelde for denne og alle fremtidige hendelser.",
    "Repeat every" : "Gjenta hver",
    "By day of the month" : "På en dag i måneden",
    "On the" : "På den",
    "_day_::_days_" : ["dag","dager"],
    "_week_::_weeks_" : ["uke","uker"],
    "_month_::_months_" : ["måned","måneder"],
    "_year_::_years_" : ["år","år"],
    "weekday" : "ukedag",
    "weekend day" : "helgedag",
    "Does not repeat" : "Gjentas ikke",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Gjentakelsesregelen av denne hendelsen støttes ikke fullt ut av Nextcloud. Hvis du redigerer gjentakelsesalternativene, kan visse gjentakelser gå tapt.",
    "No rooms or resources yet" : "Ingen rom eller ressurser enda",
    "Resources" : "Ressurser",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} sete","{seatingCapacity} seter"],
    "Add resource" : "Legg til ressurs",
    "Has a projector" : "Har en projektor",
    "Has a whiteboard" : "Har en tavle",
    "Wheelchair accessible" : "Tilgjengelig for rullestol",
    "Remove resource" : "Fjern ressurs",
    "Search for resources or rooms" : "Søk etter ressurser eller rom",
    "available" : "ledig",
    "unavailable" : "ikke ledig",
    "Show all rooms" : "Vis alle rom",
    "Projector" : "Projektor",
    "Whiteboard" : "Tavle",
    "Room type" : "Romtype",
    "Any" : "Hva som helst",
    "Minimum seating capacity" : "Minimum sittekapasitet",
    "More details" : "Flere detaljer",
    "Update this and all future" : "Oppdater denne og fremtidige hendelser",
    "Update this occurrence" : "Oppdater denne hendelsen",
    "Public calendar does not exist" : "Offentlig kalender finnes ikke",
    "Maybe the share was deleted or has expired?" : "Er deling slettet eller utløpt?",
    "Yes" : "Ja",
    "No" : "Nei",
    "Maybe" : "Kanskje",
    "None" : "Ingen",
    "Create" : "Opprett",
    "from {formattedDate}" : "fra {formattedDate}",
    "to {formattedDate}" : "til {formattedDate}",
    "on {formattedDate}" : "den {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "fra {formattedDate} kl. {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "til {formattedDate} kl. {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "den {formattedDate} kl. {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} kl. {formattedTime}",
    "Please enter a valid date" : "Vennligst tast inn en gyldig dato",
    "Please enter a valid date and time" : "Vennligst tast inn en gyldig dato og et tidspunkt",
    "Select a time zone" : "Velg en tidssone",
    "Please select a time zone:" : "Vennligst velg en tidssone:",
    "Pick a time" : "Velg et tidspunkt",
    "Pick a date" : "Velg en dato",
    "Type to search time zone" : "Skriv for å søke etter tidssone",
    "Global" : "Global",
    "Holidays in {region}" : "Helligdager i {region}",
    "An error occurred, unable to read public calendars." : "Det oppstod en feil, kan ikke lese offentlige kalendere.",
    "An error occurred, unable to subscribe to calendar." : "Det oppstod en feil, kan ikke abonnere på kalenderen.",
    "Public holiday calendars" : "Helligdagskalendere",
    "Public calendars" : "Offentlige kalendere",
    "No valid public calendars configured" : "Ingen gyldige offentlige kalendere er konfigurert",
    "Speak to the server administrator to resolve this issue." : "Snakk med serveradministratoren for å løse dette problemet.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Helligdagskalendere er levert av Thunderbird. Kalenderdata vil bli lastet ned fra {website}.",
    "By {authors}" : "Av {authors}",
    "Subscribed" : "Abonnerer",
    "Subscribe" : "Abonner",
    "Could not fetch slots" : "Kunne ikke hente tidsluker",
    "Select a date" : "Velg en dato",
    "Select slot" : "Velg tidsrom",
    "No slots available" : "Ingen tidsrom ledig",
    "The slot for your appointment has been confirmed" : "Tidsrommet for din avtale har blitt bekreftet",
    "Appointment Details:" : "Avtaledetaljer:",
    "Time:" : "Tid:",
    "Booked for:" : "Bestilt for:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Takk skal du ha. Bestillingen din fra {startDate} til {endDate} er bekreftet.",
    "Book another appointment:" : "Bestill en annen avtale:",
    "See all available slots" : "Se ledige tidsrom",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Tidsrommet for din avtale fra {startDate} toø {endDate} er ikke ledig lengre.",
    "Please book a different slot:" : "Vennligst bestill et annet tidsrom:",
    "Book an appointment with {name}" : "Bestill en avtale med {name}",
    "No public appointments found for {name}" : "Fant ingen offentlige avtaler for {name}",
    "Personal" : "Personlig",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Den automatiske tidssonegjenkjenningen bestemte at tidssonen din var UTC.\nDette er mest sannsynlig et resultat av sikkerhetstiltak i nettleseren din.\nVennligst still inn tidssonen manuelt i kalenderinnstillingene.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Din konfigurerte tidssone ({timezoneId}) ble ikke funnet. Faller tilbake til UTC.\nVennligst endre tidssonen din i innstillingene og rapporter dette problemet.",
    "Edit event" : "Rediger hendelse",
    "Event does not exist" : "Hendelsen finnes ikke",
    "Duplicate" : "Duplikat",
    "Delete this occurrence" : "Slett denne hendelsen",
    "Delete this and all future" : "Slett denne og fremtidige hendelser",
    "All day" : "Hele dagen",
    "Managing shared access" : "Administrere delt tilgang",
    "Deny access" : "Nekte adgang",
    "Invite" : "Invitere",
    "_User requires access to your file_::_Users require access to your file_" : ["Bruker må ha tilgang til filen din","Brukere må ha tilgang til filen din"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Vedlegg som krever delt tilgang","Vedlegg som krever delt tilgang"],
    "Untitled event" : "Hendelse uten tittel",
    "Close" : "Lukk",
    "Title" : "Navn",
    "30 min" : "30 min",
    "Participants" : "Deltakere",
    "Submit" : "Send inn",
    "Subscribe to {name}" : "Abonner på {name}",
    "Export {name}" : "Eksporter {name}",
    "Anniversary" : "Jubileum",
    "Appointment" : "Avtale",
    "Business" : "Forretninger",
    "Education" : "Utdanning",
    "Holiday" : "Helligdag",
    "Meeting" : "Møte",
    "Miscellaneous" : "Diverse",
    "Non-working hours" : "Utenfor arbeidstid",
    "Not in office" : "Ikke på kontoret",
    "Phone call" : "Telefonsamtale",
    "Sick day" : "Sykedag",
    "Special occasion" : "Spesiell anledning",
    "Travel" : "Reise",
    "Vacation" : "Ferie",
    "Midnight on the day the event starts" : "Midnatt den dagen hendelsen starter",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n dag før hendelsen kl. {formattedHourMinute}","%n dager før hendelsen kl. {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n uke før hendelsen kl. {formattedHourMinute}","%n uker før hendelsen kl. {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "på dagen for hendelsen kl. {formattedHourMinute}",
    "at the event's start" : "ved hendelsens start",
    "at the event's end" : "ved hendelsens slutt",
    "{time} before the event starts" : "{time} før hendelsen starter",
    "{time} before the event ends" : "{time} før hendelsen avsluttes",
    "{time} after the event starts" : "{time} etter at hendelsen starter",
    "{time} after the event ends" : "{time} etter at hendelsen avsluttes",
    "on {time}" : "on {time}",
    "on {time} ({timezoneId})" : "kl. {time} ({timezoneId})",
    "Week {number} of {year}" : "Uke {number} {year}",
    "Daily" : "Daglig",
    "Weekly" : "Ukentlig",
    "Monthly" : "Månedlig",
    "Yearly" : "Årlig",
    "_Every %n day_::_Every %n days_" : ["Hver %n dag","Hver %n dager"],
    "_Every %n week_::_Every %n weeks_" : ["Hver %n uke","Hver %n uker"],
    "_Every %n month_::_Every %n months_" : ["Hver %n måned","Hver %n måned"],
    "_Every %n year_::_Every %n years_" : ["Hvert %n år","Hvert %n år"],
    "_on {weekday}_::_on {weekdays}_" : ["på {weekday}","på {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["på dag {dayOfMonthList}","på dager {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "den {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "i {monthNames} den {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "til {untilDate}",
    "_%n time_::_%n times_" : ["%n gang","%n ganger"],
    "second" : "sekund",
    "third" : "tredje",
    "fourth" : "fjerde",
    "fifth" : "femte",
    "second to last" : "nest sist",
    "last" : "siste",
    "Untitled task" : "Oppgave uten tittel",
    "Please ask your administrator to enable the Tasks App." : "Ta kontakt med din administrator for å sette opp Oppgaver-appen.",
    "W" : "U",
    "%n more" : "%n mer",
    "No events to display" : "Ingen hendelser å vise",
    "_+%n more_::_+%n more_" : ["+%n mer","+%n mer"],
    "No events" : "Ingen hendelser",
    "Create a new event or change the visible time-range" : "Opprett en ny hendelse eller endre på valgt tidsrom",
    "Failed to save event" : "Lagring av hendelse feilet",
    "It might have been deleted, or there was a typo in a link" : "Det kan ha blitt slettet, eller det var en skrivefeil i en lenke",
    "It might have been deleted, or there was a typo in the link" : "Det kan ha blitt slettet, eller det var en skrivefeil i lenken",
    "Meeting room" : "Møterom",
    "Lecture hall" : "Forelesningssal",
    "Seminar room" : "Seminarrom",
    "Other" : "Annet",
    "When shared show" : "Når delt vis",
    "When shared show full event" : "Vis hele hendelsen om den deles",
    "When shared show only busy" : "Vis kun opptatt om den deles",
    "When shared hide this event" : "Skjul denne hendelsen om den deles",
    "Add a location" : "Legg til et sted",
    "Status" : "Status",
    "Confirmed" : "Bekreftet",
    "Canceled" : "Avbrutt",
    "Confirmation about the overall status of the event." : "Bekreftelse om den generelle statusen til arrangementet.",
    "Show as" : "Vis som",
    "Take this event into account when calculating free-busy information." : "Ta hensyn til denne hendelsen når det beregnes ledig-opptatt-informasjon.",
    "Categories" : "Kategorier",
    "Categories help you to structure and organize your events." : "Kategorier hjelper deg med å strukturere og organisere arrangementene dine.",
    "Search or add categories" : "Søk eller legg til kategorier",
    "Add this as a new category" : "Legg til som ny kategori",
    "Custom color" : "Tilpasset farge",
    "Special color of this event. Overrides the calendar-color." : "Spesial farge for denne hendelsen. Overstyrer kalenderfargen.",
    "Error while sharing file" : "Feil under deling av fil",
    "Error while sharing file with user" : "Feil under deling av fil med bruker",
    "Error creating a folder {folder}" : "Feil ved opprettelse av mappen {mappe}",
    "Attachment {fileName} already exists!" : "Vedlegget {fileName} eksisterer allerede!",
    "An error occurred during getting file information" : "Det oppsto en feil under henting av filinformasjon",
    "An error occurred, unable to delete the calendar." : "En feil oppsto, kan ikke slette kalenderen. ",
    "Imported {filename}" : "Importerte {filename}",
    "This is an event reminder." : "Dette er en hendelsespåminnelse.",
    "Error while parsing a PROPFIND error" : "Feil under analyse av en PROPFIND-feil",
    "Appointment not found" : "Avtale ikke funnet",
    "User not found" : "Fant ikke brukeren",
    "Hidden" : "Skjult",
    "can edit" : "kan endre",
    "Calendar name …" : "Kalendernavn…",
    "Default attachments location" : "Standard plassering for vedlegg",
    "Automatic ({detected})" : "Automatisk ({detected})",
    "Shortcut overview" : "Oversikt over snarveier",
    "CalDAV link copied to clipboard." : "CalDAV-lenke kopiert til utklippstavlen.",
    "CalDAV link could not be copied to clipboard." : "CalDAV-lenke kunne ikke bli kopiert til utklippstavlen.",
    "Enable birthday calendar" : "Aktiver fødselsdagkalender",
    "Show tasks in calendar" : "Vis oppgaver i kalender",
    "Enable simplified editor" : "Aktiver forenklet redigering",
    "Limit the number of events displayed in the monthly view" : "Begrens antall hendelser som vises i månedsvisningen",
    "Show weekends" : "Vis helger",
    "Show week numbers" : "Vis ukenummer",
    "Time increments" : "Tidsøkninger",
    "Default calendar for incoming invitations" : "Standard kalender for innkommende invitasjoner",
    "Copy primary CalDAV address" : "Kopier primær CalDAV-adresse",
    "Copy iOS/macOS CalDAV address" : "Kopier CalDAV-lenke for iOS/macOS",
    "Personal availability settings" : "Personlig ledighets-innstillinger",
    "Show keyboard shortcuts" : "Vis tastatursnarveier",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} invitert, {confirmedCount} bekreftet",
    "Successfully appended link to talk room to location." : "Lenke til talk-rom til plassering er lagt til.",
    "Successfully appended link to talk room to description." : "La til lenke til Talk-rom til beskrivelsen.",
    "Error creating Talk room" : "Feil ved opprettelse av Talk-rom",
    "_%n more guest_::_%n more guests_" : ["%n gjest til","%n flere gjester"],
    "The visibility of this event in shared calendars." : "Synlighet for denne oppføringen i delte kalendere"
},
"nplurals=2; plural=(n != 1);");
