/*!
 * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */

#emptycontent-container #emptycontent {
	color: #a9a9a9 !important;
}

.content.app-calendar.app-calendar-public-embedded {
	flex-direction: column;

	#embed-header {
		flex-wrap: wrap;
		gap: calc(var(--default-grid-baseline) * 2);
		width: 100%;
		padding: calc(var(--default-grid-baseline) * 2);
		box-sizing: border-box;
		background-color: var(--color-main-background);
		border-bottom: 1px solid var(--color-border);
		overflow: visible;
		z-index: 2000;
		display: flex;
		align-items: center;
		justify-content: space-between;

		.embed-header__date-section,
		.embed-header__share-section {
			display: flex;
			gap: 5px;
		}

		.view-button-section {
			.button {
				min-width: 75px;
			}
		}

		.datepicker-button-section {
			&__datepicker-label {
				min-width: 150px;
			}
		}

		.datepicker-button-section,
		.today-button-section,
		.view-button-section {
			button {
				// Header has only one row so the built-in spacing is not needed
				margin: 0;
			}
		}
	}

	.app-content {
		// Expand to full height (need to overwrite this because a flex column layout is used here)
		flex-basis: auto;
	}
}

#body-public {
	input#initial-state-calendar-is_embed ~ header#header {
		display: none;
	}
	.app-calendar-public {
		& + footer {
			// Only show bottom rounded corners
			border-radius: 0 0 var(--border-radius-large) var(--border-radius-large);
		}

		.app-content {
			height: calc(100% - 65px) !important; // $footer-height is hardcoded to 65px in core/css/public.scss
		}
	}
}
