OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Den angivna e-postadressen är för lång",
    "User-Session unexpectedly expired" : "Användarsessionen upphörde oväntat",
    "Provided email-address is not valid" : "Den angivna e-postadressen är inte giltig",
    "%s has published the calendar »%s«" : "%s har publicerat kalender \"%s\"",
    "Unexpected error sending email. Please contact your administrator." : "Oväntat fel vid utskick av e-post. Kontakta din administratör.",
    "Successfully sent email to %1$s" : "E-post skickad till %1$s",
    "Hello," : "Hej,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Vi vill informera dig att %s har publicerat kalendern \"%s«\"",
    "Open »%s«" : "Öppna \"%s\"",
    "Cheers!" : "Ha de fint!",
    "Upcoming events" : "Kommande händelser",
    "No more events today" : "Inga fler händelser idag",
    "No upcoming events" : "Inga kommande händelser",
    "More events" : "Fler händelser",
    "%1$s with %2$s" : "%1$s med %2$s",
    "Calendar" : "Kalender",
    "New booking {booking}" : "Ny bokning {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) bokade mötet \"{config_display_name}\" den {date_time}.",
    "Appointments" : "Möten",
    "Schedule appointment \"%s\"" : "Schemalägg möte ”%s”",
    "Schedule an appointment" : "Schemalägg ett möte",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : "Förberedelse inför %s",
    "Follow up for %s" : "Uppföljning av %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Ditt möte \"%s\" med %s behöver bekräftas",
    "Dear %s, please confirm your booking" : "Kära %s, vänligen bekräfta din bokning",
    "Confirm" : "Bekräfta",
    "Appointment with:" : "Möte med:",
    "Description:" : "Beskrivning:",
    "This confirmation link expires in %s hours." : "Bekräftelselänken slutar gälla om %s timmar.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Vänligen kontakta arrangören om du skulle vilja avboka mötet efter bekräftelse, genom att svara på denna e-post eller genom att besöka deras profil.",
    "Your appointment \"%s\" with %s has been accepted" : "Ditt möte \"%s\" med %s har accepterats",
    "Dear %s, your booking has been accepted." : "%s, din bokning har accepterats.",
    "Appointment for:" : "Möte för:",
    "Date:" : "Datum:",
    "You will receive a link with the confirmation email" : "Du kommer att få en länk med bekräftelsemailet",
    "Where:" : "Plats:",
    "Comment:" : "Kommentar:",
    "You have a new appointment booking \"%s\" from %s" : "Du har en ny mötesbokning \"%s\" från %s",
    "Dear %s, %s (%s) booked an appointment with you." : "%s, %s (%s) bokade ett möte med dig.",
    "%s has proposed a meeting" : "%s har föreslagit ett möte",
    "%s has updated a proposed meeting" : "%s har uppdaterat ett föreslaget möte",
    "%s has canceled a proposed meeting" : "%s har avbokat ett föreslaget möte",
    "Dear %s, a new meeting has been proposed" : "Hej %s, ett nytt möte har föreslagits",
    "Dear %s, a proposed meeting has been updated" : "Hej %s, ett föreslaget möte har uppdaterats",
    "Dear %s, a proposed meeting has been cancelled" : "Hej %s, ett föreslaget möte har avbokats",
    "Location:" : "Ort:",
    "Duration:" : "Varaktighet:",
    "%1$s from %2$s to %3$s" : "%1$s från %2$s till %3$s",
    "Dates:" : "Datum:",
    "Respond" : "Svara",
    "A Calendar app for Nextcloud" : "En kalender-app för Nextcloud",
    "Previous day" : "Föregående dag",
    "Previous week" : "Föregående vecka",
    "Previous year" : "Föregående år",
    "Previous month" : "Föregående månad",
    "Next day" : "Nästa dag",
    "Next week" : "Nästa vecka",
    "Next year" : "Nästa år",
    "Next month" : "Nästa månad",
    "Create new event" : "Skapa ny händelse",
    "Event" : "Händelse",
    "Today" : "Idag",
    "Day" : "Dag",
    "Week" : "Vecka",
    "Month" : "Månad",
    "Year" : "År",
    "List" : "Lista",
    "Appointment link was copied to clipboard" : "Möteslänken kopierades till urklippet",
    "Appointment link could not be copied to clipboard" : "Möteslänk kunde ej kopieras till urklipp",
    "Preview" : "Förhandsvisa",
    "Copy link" : "Kopiera länk",
    "Edit" : "Redigera",
    "Delete" : "Ta bort",
    "Appointment schedules" : "Mötesscheman",
    "Create new" : "Skapa ny",
    "Disable calendar \"{calendar}\"" : "Inaktivera kalendern \"{calendar}\"",
    "Disable untitled calendar" : "Inaktivera ej namngiven kalender",
    "Enable calendar \"{calendar}\"" : "Aktivera kalendern \"{calendar}\"",
    "Enable untitled calendar" : "Aktivera ej namngiven kalender",
    "An error occurred, unable to change visibility of the calendar." : "Ett fel inträffade, kunde inte ändra synlighet på kalendern.",
    "Untitled calendar" : "Namnlös kalender",
    "Shared with you by" : "Delad med dig av",
    "Edit and share calendar" : "Redigera och dela kalender",
    "Edit calendar" : "Redigera kalender",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Slutar dela kalendern om {countdown} sekund","Slutar dela kalendern om {countdown} sekunder"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Raderar kalendern om {countdown} sekund","Raderar kalendern om {countdown} sekunder"],
    "An error occurred, unable to create the calendar." : "Ett fel inträffade, kunde inte skapa kalender.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Ange en giltig länk (börjar med http://, https://, webcal://, eller webcals://)",
    "Calendars" : "Kalendrar",
    "Add new" : "Lägg till ny",
    "New calendar" : "Ny kalender",
    "Name for new calendar" : "Namn på nya kalendern",
    "Creating calendar …" : "Skapar kalender …",
    "New calendar with task list" : "Ny kalender med uppgiftslista",
    "New subscription from link (read-only)" : "Ny prenumeration från länk (skrivskyddad)",
    "Creating subscription …" : "Skapar prenumeration …",
    "Add public holiday calendar" : "Lägg till helgdagskalender",
    "Add custom public calendar" : "Lägg till anpassad publik kalender",
    "Calendar link copied to clipboard." : "Kalenderlänk kopierad till urklipp.",
    "Calendar link could not be copied to clipboard." : "Kalenderlänk kunde inte kopieras till urklipp.",
    "Copy subscription link" : "Kopiera prenumerationslänk",
    "Copying link …" : "Kopierar länk …",
    "Copied link" : "Länk kopierad",
    "Could not copy link" : "Kunde inte kopiera länk",
    "Export" : "Exportera",
    "Untitled item" : "Namnlöst objekt",
    "Unknown calendar" : "Okänd kalender",
    "Could not load deleted calendars and objects" : "Kunde inte ladda borttagna kalendrar och objekt",
    "Could not delete calendar or event" : "Det gick inte att ta bort kalender eller händelse",
    "Could not restore calendar or event" : "Kunde inte återställa kalender eller händelse",
    "Do you really want to empty the trash bin?" : "Vill du verkligen tömma papperskorgen?",
    "Empty trash bin" : "Töm papperskorgen",
    "Trash bin" : "Papperskorg",
    "Loading deleted items." : "Laddar borttagna objekt.",
    "You do not have any deleted items." : "Du har inga borttagna objekt.",
    "Name" : "Namn",
    "Deleted" : "Borttagen",
    "Restore" : "Återställ",
    "Delete permanently" : "Ta bort permanent",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Objekt i papperskorgen tas bort efter {numDays} dag","Objekt i papperskorgen tas bort efter {numDays} dagar"],
    "Could not update calendar order." : "Det gick inte att uppdatera kalenderordningen.",
    "Shared calendars" : "Delade kalendrar",
    "Deck" : "Deck",
    "Internal link" : "Intern länk",
    "A private link that can be used with external clients" : "En privat länk som kan användas med externa klienter",
    "Copy internal link" : "Kopiera intern länk",
    "An error occurred, unable to publish calendar." : "Ett fel inträffade, kunde inte publicera kalendern.",
    "An error occurred, unable to send email." : "Fel uppstod. Mejlet kunde inte skickas.",
    "Embed code copied to clipboard." : "Inbäddningskod kopierad till urklipp.",
    "Embed code could not be copied to clipboard." : "Inbäddningskod kunde inte kopieras till urklipp.",
    "Unpublishing calendar failed" : "Avpublicering av kalendern misslyckades",
    "Share link" : "Dela länk",
    "Copy public link" : "Kopiera offentlig länk",
    "Send link to calendar via email" : "Skicka länk till kalender via e-post",
    "Enter one address" : "Mata in en adress",
    "Sending email …" : "Skickar e-post …",
    "Copy embedding code" : "Kopiera inbäddningskod",
    "Copying code …" : "Kopierar kod …",
    "Copied code" : "Kod kopierad",
    "Could not copy code" : "Kunde inte kopiera kod",
    "Delete share link" : "Ta bort delningslänk",
    "Deleting share link …" : "Raderar delningslänk …",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Team)",
    "An error occurred while unsharing the calendar." : "Ett fel uppstod när delningen av kalendern skulle tas bort.",
    "An error occurred, unable to change the permission of the share." : "Ett fel inträffade. Det gick inte att ändra behörighet för delningen.",
    "can edit and see confidential events" : "kan redigera och se konfidentiella händelser",
    "Unshare with {displayName}" : "Sluta dela med {displayName}",
    "Share with users or groups" : "Dela med användare eller grupper",
    "No users or groups" : "Inga användare eller grupper",
    "Failed to save calendar name and color" : "Det gick inte att spara kalendernamn och färg",
    "Calendar name …" : "Kalendernamn …",
    "Never show me as busy (set this calendar to transparent)" : "Visa mig aldrig som upptagen (ställ in den här kalendern på transparent)",
    "Share calendar" : "Dela kalender",
    "Unshare from me" : "Sluta dela från mig",
    "Save" : "Spara",
    "No title" : "Ingen titel",
    "Are you sure you want to delete \"{title}\"?" : "Är du säker på att du vill ta bort \"{title}\"?",
    "Deleting proposal \"{title}\"" : "Tar bort förslaget \"{title}\"",
    "Successfully deleted proposal" : "Förslaget har tagits bort",
    "Failed to delete proposal" : "Kunde inte ta bort förslaget",
    "Failed to retrieve proposals" : "Kunde inte hämta förslag",
    "Meeting proposals" : "Mötesförslag",
    "A configured email address is required to use meeting proposals" : "En konfigurerad e-postadress krävs för att använda mötesförslag",
    "No active meeting proposals" : "Inga aktiva mötesförslag",
    "View" : "Visa",
    "Import calendars" : "Importera kalendrar",
    "Please select a calendar to import into …" : "Vänligen välj en kalender du vill importera till …",
    "Filename" : "Filnamn",
    "Calendar to import into" : "Kalender att importera till",
    "Cancel" : "Avbryt",
    "_Import calendar_::_Import calendars_" : ["Importera kalender","Importera kalendrar"],
    "Select the default location for attachments" : "Välj standardplats för bilagor",
    "Pick" : "Välj",
    "Invalid location selected" : "Ogiltig plats vald",
    "Attachments folder successfully saved." : "Mapp för bilagor har sparats ",
    "Error on saving attachments folder." : "Ett fel uppstod vid ändring av mapp för bilagor",
    "Attachments folder" : "Mapp för bilagor",
    "{filename} could not be parsed" : "{filename} kunde inte läsas",
    "No valid files found, aborting import" : "Inga giltiga filer hittades, avbryter import",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Lyckades importera %n händelse","Lyckades importera %n händelser"],
    "Import partially failed. Imported {accepted} out of {total}." : "Importen misslyckades delvis. Importerade {accepted} av {total}.",
    "Automatic" : "Automatisk",
    "Automatic ({timezone})" : "Automatisk ({timezone})",
    "New setting was not saved successfully." : "Den nya inställningen kunde inte sparas.",
    "Timezone" : "Tidszon",
    "Navigation" : "Navigering",
    "Previous period" : "Föregående period",
    "Next period" : "Nästa period",
    "Views" : "Vyer",
    "Day view" : "Översikt dag",
    "Week view" : "Översikt vecka",
    "Month view" : "Översikt månad",
    "Year view" : "Årsvy",
    "List view" : "Listvy",
    "Actions" : "Åtgärder",
    "Create event" : "Skapa händelse",
    "Show shortcuts" : "Visa genvägar",
    "Editor" : "Redigerare",
    "Close editor" : "Stäng redigeraren",
    "Save edited event" : "Spara ändrad händelse",
    "Delete edited event" : "Radera ändrad händelse",
    "Duplicate event" : "Duplicera händelse",
    "or" : "eller",
    "Calendar settings" : "Kalenderinställningar",
    "At event start" : "Vid händelsens start",
    "No reminder" : "Ingen påminnelse",
    "Failed to save default calendar" : "Det gick inte att spara standardkalendern",
    "General" : "Allmänt",
    "Availability settings" : "Inställningar för tillgänglighet",
    "CalDAV" : "CalDAV",
    "Access Nextcloud calendars from other apps and devices" : "Åtkomst till Nextcloud-kalendrar från andra appar och enheter",
    "CalDAV URL" : "CalDAV URL",
    "Server Address for iOS and macOS" : "Serveradress för iOS och macOS",
    "Appearance" : "Utseende",
    "Birthday calendar" : "Födelsedagskalender",
    "Tasks in calendar" : "Uppgifter i kalendern",
    "Weekends" : "Helger",
    "Week numbers" : "Veckonummer",
    "Limit number of events shown in Month view" : "Begränsa antalet händelser som visas i månadsvyn",
    "Density in Day and Week View" : "Täthet i dag- och vecko­vy",
    "Editing" : "Ändrar",
    "Default reminder" : "Standardpåminnelse",
    "Simple event editor" : "Enkel händelseredigerare",
    "\"More details\" opens the detailed editor" : "”Mer information” öppnar den detaljerade redigeraren",
    "Files" : "Filer",
    "Appointment schedule successfully created" : "Mötesschema skapat",
    "Appointment schedule successfully updated" : "Mötesschema uppdaterat",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minut","{duration} minuter"],
    "0 minutes" : "0 minuter",
    "_{duration} hour_::_{duration} hours_" : ["{duration} timme","{duration} timmar"],
    "_{duration} day_::_{duration} days_" : ["{duration} dag","{duration} dagar"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} vecka","{duration} veckor"],
    "_{duration} month_::_{duration} months_" : ["{duration} månad","{duration} månader"],
    "_{duration} year_::_{duration} years_" : ["{duration} år","{duration} år"],
    "To configure appointments, add your email address in personal settings." : "För att konfigurera möten, fyll i din e-postadress i dina inställningar.",
    "Public – shown on the profile page" : "Offentlig - visas på profilsidan",
    "Private – only accessible via secret link" : "Privat - endast tillgänglig via hemlig länk",
    "Appointment schedule saved" : "Mötesschema sparat",
    "Create appointment schedule" : "Skapa mötesschema",
    "Edit appointment schedule" : "Redigera mötesschema",
    "Update" : "Uppdatera",
    "Appointment name" : "Namn på möte",
    "Location" : "Plats",
    "Create a Talk room" : "Skapa ett rum i Talk",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "En unik länk kommer att genereras för varje bokat möte och skickas via bekräftelsemailet",
    "Description" : "Beskrivning",
    "Visibility" : "Synlighet",
    "Duration" : "Varaktighet",
    "Increments" : "Tidsintervall",
    "Additional calendars to check for conflicts" : "Ytterligare kalendrar att ta hänsyn till",
    "Pick time ranges where appointments are allowed" : "Välj tidsintervall där möten är tillåtna",
    "to" : "till",
    "Delete slot" : "Radera lucka",
    "No times set" : "Inga tider satta",
    "Add" : "Lägg till",
    "Monday" : "Måndag",
    "Tuesday" : "Tisdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Lördag",
    "Sunday" : "Söndag",
    "Weekdays" : "Vardagar",
    "Add time before and after the event" : "Lägg till tid innan och efter händelsen",
    "Before the event" : "Innan händelsen",
    "After the event" : "Efter händelsen",
    "Planning restrictions" : "Planeringsbegränsningar",
    "Minimum time before next available slot" : "Minimumpaus mellan möten",
    "Max slots per day" : "Maximalt antal möten per dag",
    "Limit how far in the future appointments can be booked" : "Begränsa hur långt fram i tiden möten kan bokas",
    "It seems a rate limit has been reached. Please try again later." : "Det verkar som en hastighetsbegränsning har uppnåtts. Försök igen senare.",
    "Please confirm your reservation" : "Vänligen bekräfta din reservation",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Vi har skickat dig ett e-postmeddelande med detaljer. Vänligen bekräfta ditt möte med länken som erhålls i meddelandet. Du kan stänga den här sidan nu.",
    "Your name" : "Ditt namn",
    "Your email address" : "Din e-postadress",
    "Please share anything that will help prepare for our meeting" : "Vänligen delge eventuella saker som hjälper att förbereda för vårt möte",
    "Could not book the appointment. Please try again later or contact the organizer." : "Kunde inte boka mötet. Vänligen försök igen senare eller kontakta arrangören.",
    "Back" : "Tillbaka",
    "Book appointment" : "Boka möte",
    "Error fetching Talk conversations." : "Kunde inte hämta Talk-konversationer.",
    "Conversation does not have a valid URL." : "Konversationen har ingen giltig URL.",
    "Successfully added Talk conversation link to location." : "Länk till Talk-konversation har lagts till på platsen.",
    "Successfully added Talk conversation link to description." : "Länk till Talk-konversation har lagts till i beskrivningen.",
    "Failed to apply Talk room." : "Kunde inte tillämpa rum i Talk.",
    "Talk conversation for event" : "Talk-konversation för händelse",
    "Error creating Talk conversation" : "Kunde inte skapa Talk-konversation",
    "Select a Talk Room" : "Välj ett rum i Talk",
    "Add Talk conversation" : "Lägg till Talk-konversation",
    "Fetching Talk rooms…" : "Hämtar Talk-rum...",
    "No Talk room available" : "Inget Talk-rum tillgängligt",
    "Create public conversation" : "Skapa offentlig konversation",
    "Select conversation" : "Välj konversation",
    "on" : "den",
    "at" : "kl",
    "before at" : "innan",
    "Notification" : "Notifiering",
    "Email" : "E-post",
    "Audio notification" : "Ljudmeddelande",
    "Other notification" : "Annan notifiering",
    "Relative to event" : "I förhållande till händelse",
    "On date" : "På datum",
    "Edit time" : "Ändra tid",
    "Save time" : "Lagra tid",
    "Remove reminder" : "Ta bort påminnelse",
    "Add reminder" : "Lägg till påminnelse",
    "seconds" : "sekunder",
    "minutes" : "minuter",
    "hours" : "timmar",
    "days" : "dagar",
    "weeks" : "veckor",
    "Choose a file to add as attachment" : "Välj en fil att lägga till som bilaga",
    "Choose a file to share as a link" : "Välj en fil att dela som länk",
    "Attachment {name} already exist!" : "Bilagan {name} finns redan!",
    "Could not upload attachment(s)" : "Kunde inte ladda upp bilagor",
    "You are about to navigate to {link}. Are you sure to proceed?" : "Du är på väg att navigera till {link}. Är du säker på att du vill fortsätta?",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Du är på väg att navigera till {host}. Är du säker på att du vill fortsätta? Länk: {link}",
    "Proceed" : "Fortsätt",
    "No attachments" : "Inga bilagor",
    "Add from Files" : "Lägg till från Filer",
    "Upload from device" : "Ladda upp från enheten",
    "Delete file" : "Ta bort fil",
    "Confirmation" : "Bekräftelse",
    "_{count} attachment_::_{count} attachments_" : ["{count} bilaga","{count} bilagor"],
    "Suggested" : "Föreslagen",
    "Available" : "Tillgänglig",
    "Invitation accepted" : "Inbjudan accepterad",
    "Accepted {organizerName}'s invitation" : "Accepterade inbjudan från {organizerName}",
    "Participation marked as tentative" : "Deltagande markerat som preliminärt",
    "Invitation is delegated" : "Inbjudan är delegerad",
    "Not available" : "Inte tillgänglig",
    "Invitation declined" : "Inbjudan avböjd",
    "Declined {organizerName}'s invitation" : "Avböjde inbjudan från {organizerName}",
    "Availability will be checked" : "Tillgänglighet kommer att kontrolleras",
    "Invitation will be sent" : "Inbjudan kommer att skickas",
    "Failed to check availability" : "Det gick inte att kontrollera tillgänglighet",
    "Failed to deliver invitation" : "Det gick inte att leverera inbjudan",
    "Awaiting response" : "Väntar på svar",
    "Checking availability" : "Kontrollerar tillgänglighet",
    "Has not responded to {organizerName}'s invitation yet" : "Har ej svarat på inbjudan från {organizerName} än",
    "Suggested times" : "Föreslagna tider",
    "chairperson" : "ordförande",
    "required participant" : "obligatorisk deltagare",
    "non-participant" : "icke-deltagare",
    "optional participant" : "valfri deltagare",
    "{organizer} (organizer)" : "{organizer} (arrangör)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Selected slot" : "Vald tidpunkt",
    "Availability of attendees, resources and rooms" : "Tillgänglighet för deltagare, resurser och lokaler",
    "Suggestion accepted" : "Förslaget accepterat",
    "Previous date" : "Föregående datum",
    "Next date" : "Nästa datum",
    "Legend" : "Etikett",
    "Out of office" : "Ej på plats",
    "Attendees:" : "Deltagare:",
    "local time" : "lokal tid",
    "Done" : "Klar",
    "Search room" : "Sök rum",
    "Room name" : "Rumsnamn",
    "Check room availability" : "Kontrollera rums tillgänglighet",
    "Free" : "Ledig",
    "Busy (tentative)" : "Upptagen (preliminär)",
    "Busy" : "Upptagen",
    "Unknown" : "Okänd",
    "Find a time" : "Hitta en tid",
    "The invitation has been accepted successfully." : "Inbjudan har accepterats",
    "Failed to accept the invitation." : "Misslyckades med att acceptera inbjudan.",
    "The invitation has been declined successfully." : "Inbjudan avböjdes.",
    "Failed to decline the invitation." : "Misslyckades med att tacka nej till inbjudan.",
    "Your participation has been marked as tentative." : "Ditt deltagande har markerats som preliminärt.",
    "Failed to set the participation status to tentative." : "Misslyckades med att ange deltagande som preliminärt.",
    "Accept" : "Acceptera",
    "Decline" : "Avböj",
    "Tentative" : "Preliminärt",
    "No attendees yet" : "Inga deltagare än",
    "{confirmedCount} confirmed, {waitingCount} awaiting response" : "{confirmedCount} bekräftade, {waitingCount} väntar på svar",
    "Please add at least one attendee to use the \"Find a time\" feature." : "Lägg till minst en deltagare för att använda funktionen “Hitta en tid”.",
    "Attendees" : "Deltagare",
    "_%n more attendee_::_%n more attendees_" : ["%n ytterligare deltagare","%n ytterligare deltagare"],
    "Remove group" : "Ta bort grupp",
    "Remove attendee" : "Ta bort deltagaren",
    "Request reply" : "Begär svar",
    "Chairperson" : "Ordförande",
    "Required participant" : "Obligatorisk deltagare",
    "Optional participant" : "Frivillig deltagare",
    "Non-participant" : "Icke-deltagare",
    "_%n member_::_%n members_" : ["%n medlem","%n medlemmar"],
    "Search for emails, users, contacts, contact groups or teams" : "Sök efter e-post, användare, kontakter, kontaktgrupper eller team",
    "No match found" : "Ingen träff",
    "Note that members of circles get invited but are not synced yet." : "Observera att medlemmar i cirklar blir inbjudna men är inte synkroniserade än.",
    "Note that members of contact groups get invited but are not synced yet." : "Observera att medlemmar i kontaktgrupper blir inbjudna men är inte synkroniserade än.",
    "(organizer)" : "(arrangör)",
    "Make {label} the organizer" : "Gör {label} till arrangör",
    "Make {label} the organizer and attend" : "Gör {label} arrangör och delta",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "För att kunna skicka inbjudningar och hantera svar måste du [linkopen]lägga till din e-postadress i inställningarna[linkclose].",
    "Remove color" : "Ta bort färg",
    "Event title" : "Händelsens titel",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Kan inte ändra inställning för heldag när händelsen är återkommande.",
    "From" : "Från",
    "To" : "Till",
    "Your Time" : "Din tid",
    "Repeat" : "Upprepa",
    "Repeat event" : "Upprepa händelse",
    "_time_::_times_" : ["gång","gånger"],
    "never" : "aldrig",
    "on date" : "på datum",
    "after" : "efter",
    "End repeat" : "Sluta upprepa",
    "Select to end repeat" : "Välj för att avsluta upprepning",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Den här händelsen är återkommande undantag för en upprepning. Du kan inte lägga till en regel för den.",
    "first" : "första",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Ändringar av återkommande regel gäller endast för denna och alla framtida händelser.",
    "Repeat every" : "Upprepa varje",
    "By day of the month" : "Efter dag i månaden",
    "On the" : "På den",
    "_day_::_days_" : ["dag","dagar"],
    "_week_::_weeks_" : ["vecka","veckor"],
    "_month_::_months_" : ["månad","månader"],
    "_year_::_years_" : ["år","år"],
    "On specific day" : "På specifik dag",
    "weekday" : "veckodag",
    "weekend day" : "helgdag",
    "Does not repeat" : "Upprepar inte",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Återkommande definition av denna händelse stöds inte helt av Nextcloud. Om du redigerar återfallsalternativen kan vissa återfall försvinna.",
    "No rooms or resources yet" : "Inga rum eller resurser än",
    "Resources" : "Resurser",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} plats","{seatingCapacity} platser"],
    "Add resource" : "Lägg till resurs",
    "Has a projector" : "Projektor finns",
    "Has a whiteboard" : "Whiteboard finns",
    "Wheelchair accessible" : "Tillgänglig i rullstol",
    "Remove resource" : "Ta bort resurs",
    "Search for resources or rooms" : "Sök efter resurser eller rum",
    "available" : "tillgänglig",
    "unavailable" : "ej tillgänglig",
    "Show all rooms" : "Visa alla rum",
    "Projector" : "Projektor",
    "Whiteboard" : "Whiteboard",
    "Room type" : "Rumtyp",
    "Any" : "Alla",
    "Minimum seating capacity" : "Minsta antal platser",
    "More details" : "Fler detaljer",
    "Update this and all future" : "Uppdatera denna och alla kommande",
    "Update this occurrence" : "Uppdatera denna förekomst",
    "Public calendar does not exist" : "Publik kalender finns inte",
    "Maybe the share was deleted or has expired?" : "Kanske har delningen tagits bort eller har gått ut?",
    "Remove date" : "Ta bort datum",
    "Attendance required" : "Närvaro krävs",
    "Attendance optional" : "Närvaro frivillig",
    "Remove participant" : "Ta bort deltagare",
    "Yes" : "Ja",
    "No" : "Nej",
    "Maybe" : "Kanske",
    "None" : "Ingen",
    "Select your meeting availability" : "Välj din tillgänglighet",
    "Create a meeting for this date and time" : "Skapa ett möte för detta datum och tid",
    "Create" : "Skapa",
    "No participants or dates available" : "Inga deltagare eller datum tillgängliga",
    "from {formattedDate}" : "från {formattedDate}",
    "to {formattedDate}" : "till {formattedDate}",
    "on {formattedDate}" : "på {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "från {formattedDate} kl {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "till {formattedDate} kl {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "på {formattedDate} kl {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} kl {formattedTime}",
    "Please enter a valid date" : "Ange ett giltigt datum",
    "Please enter a valid date and time" : "Ange giltigt datum och tid",
    "Select a time zone" : "Välj en tidszon",
    "Please select a time zone:" : "Välj en tidszon:",
    "Pick a time" : "Välj en tidpunkt",
    "Pick a date" : "Välj ett datum",
    "Type to search time zone" : "Skriv för att söka tidszon",
    "Global" : "Global",
    "Holidays in {region}" : "Helgdagar i {region}",
    "An error occurred, unable to read public calendars." : "Ett fel inträffade, kan inte läsa publika kalendrar.",
    "An error occurred, unable to subscribe to calendar." : "Ett fel inträffade, det går inte att prenumerera på kalendern.",
    "Public holiday calendars" : "Helgdagskalendrar",
    "Public calendars" : "Publika kalendrar",
    "No valid public calendars configured" : "Inga giltiga publika kalendrar konfigurerade",
    "Speak to the server administrator to resolve this issue." : "Kontakta serveradministratören för att lösa detta problem.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Helgdagskalendrar tillhandahålls av Thunderbird. Kalenderdata kommer att laddas ner från {website}",
    "These public calendars are suggested by the server administrator. Calendar data will be downloaded from the respective website." : "Dessa offentliga kalendrar föreslås av serveradministratören. Kalenderdata kommer att hämtas från respektive webbplats.",
    "By {authors}" : "Av {authors}",
    "Subscribed" : "Prenumeration aktiverad",
    "Subscribe" : "Prenumerera",
    "Could not fetch slots" : "Det gick inte att hämta platser",
    "Select a date" : "Välj ett datum",
    "Select slot" : "Välj tid",
    "No slots available" : "Inga tider tillgängliga",
    "The slot for your appointment has been confirmed" : "Tiden för ditt möte har bekräftats",
    "Appointment Details:" : "Mötesdetaljer:",
    "Time:" : "Tid:",
    "Booked for:" : "Bokad för:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Tack så mycket! Din bokning från {startDate} till {endDate} har bekräftats.",
    "Book another appointment:" : "Boka ytterligare möte:",
    "See all available slots" : "Se alla tillgängliga tider",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Tiden för ditt möte från {startDate} till {endDate} är inte tillgänglig längre.",
    "Please book a different slot:" : "Vänligen boka en annan tid:",
    "Book an appointment with {name}" : "Boka ett möte med {name}",
    "No public appointments found for {name}" : "Inga offentliga möten hittades för {name}",
    "Personal" : "Privat",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Den automatiska tidszon-detekteringen fastställde din tidszon till UTC.\nDetta är troligtvis resultatet av säkerhetsinställningar i din webbläsare.\nVänligen ställ in din tidszon manuellt i kalenderinställningarna.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Din tidszon ({timezoneId}) hittades inte. Återgår till UTC.\nVänligen ändra din tidszon i inställningarna och rapportera detta problem.",
    "Show unscheduled tasks" : "Visa ej schemalagda uppgifter",
    "Unscheduled tasks" : "Ej schemalagda uppgifter",
    "Availability of {displayName}" : "Tillgänglighet för {displayName}",
    "Discard event" : "Avbryt händelse",
    "Edit event" : "Redigera händelse",
    "Event does not exist" : "Händelsen existerar inte",
    "Duplicate" : "Duplicera",
    "Delete this occurrence" : "Ta bort denna förekomst",
    "Delete this and all future" : "Ta bort denna och alla kommande",
    "All day" : "Heldag",
    "Modifications wont get propagated to the organizer and other attendees" : "Ändringar kommer inte att skickas till organisatören eller andra deltagare",
    "Managing shared access" : "Hantering av delad åtkomst",
    "Deny access" : "Neka åtkomst",
    "Invite" : "Bjud in",
    "Discard changes?" : "Avbryt ändringar?",
    "Are you sure you want to discard the changes made to this event?" : "Är du säker på att du vill avbryta ändringarna som gjorts i denna händelse?",
    "_User requires access to your file_::_Users require access to your file_" : ["En användare behöver tillgång till din fil","Användare behöver tillgång till din fil"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Bilaga i behov av delat åtkomst","Bilagor i behov av delad åtkomst"],
    "Untitled event" : "Namnlös händelse",
    "Close" : "Stäng",
    "Modifications will not get propagated to the organizer and other attendees" : "Ändringar kommer inte att skickas till organisatören eller andra deltagare",
    "Meeting proposals overview" : "Översikt över mötesförslag",
    "Edit meeting proposal" : "Redigera mötesförslag",
    "Create meeting proposal" : "Skapa mötesförslag",
    "Update meeting proposal" : "Uppdatera mötesförslag",
    "Saving proposal \"{title}\"" : "Sparar förslag \"{title}\"",
    "Successfully saved proposal" : "Förslaget har sparats",
    "Failed to save proposal" : "Kunde inte spara förslaget",
    "Create a meeting for \"{date}\"? This will create a calendar event with all participants." : "Skapa ett möte för \"{date}\"? Detta kommer att skapa en kalenderhändelse med alla deltagare.",
    "Creating meeting for {date}" : "Skapar möte för {date}",
    "Successfully created meeting for {date}" : "Möte har skapats för {date}",
    "Failed to create a meeting for {date}" : "Kunde inte skapa möte för {date}",
    "Please enter a valid duration in minutes." : "Ange en giltig varaktighet i minuter.",
    "Failed to fetch proposals" : "Kunde inte hämta förslag",
    "Failed to fetch free/busy data" : "Kunde inte hämta ledig/upptagen-data",
    "Selected" : "Vald",
    "No Description" : "Ingen beskrivning",
    "No Location" : "Ingen plats",
    "Edit this meeting proposal" : "Redigera detta mötesförslag",
    "Delete this meeting proposal" : "Ta bort detta mötesförslag",
    "Title" : "Titel",
    "15 min" : "15 min",
    "30 min" : "30 min",
    "60 min" : "60 min",
    "90 min" : "90 min",
    "Participants" : "Deltagare",
    "Selected times" : "Valda tider",
    "Previous span" : "Föregående intervall",
    "Next span" : "Nästa intervall",
    "Less days" : "Färre dagar",
    "More days" : "Fler dagar",
    "Loading meeting proposal" : "Läser in mötesförslag",
    "No meeting proposal found" : "Inget mötesförslag hittades",
    "Please wait while we load the meeting proposal." : "Vänligen vänta medan vi läser in mötesförslaget.",
    "The link you followed may be broken, or the meeting proposal may no longer exist." : "Länken du följde kan vara trasig, eller så finns mötesförslaget inte längre.",
    "Thank you for your response!" : "Tack för ditt svar!",
    "Your vote has been recorded. Thank you for participating!" : "Din röst har registrerats. Tack för att du deltog!",
    "Unknown User" : "Okänd användare",
    "No Title" : "Ingen titel",
    "No Duration" : "Ingen varaktighet",
    "Select a different time zone" : "Välj en annan tidszon",
    "Submit" : "Skicka",
    "Subscribe to {name}" : "Prenumerera på {name}",
    "Export {name}" : "Exportera {name}",
    "Show availability" : "Visa tillgänglighet",
    "Anniversary" : "Jubileum",
    "Appointment" : "Bokning",
    "Business" : "Företag",
    "Education" : "Utbildning",
    "Holiday" : "Ledighet",
    "Meeting" : "Möte",
    "Miscellaneous" : "Diverse",
    "Non-working hours" : "Icke-arbetstid",
    "Not in office" : "Inte på kontoret",
    "Phone call" : "Telefonsamtal",
    "Sick day" : "Sjukdag",
    "Special occasion" : "Speciellt tillfälle",
    "Travel" : "Resa",
    "Vacation" : "Semester",
    "Midnight on the day the event starts" : "Midnatt den dagen evenemanget börjar",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n dagar före händelsen klockan {formattedHourMinute}","%n dag före händelsen klockan {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n veckor före händelsen klockan {formattedHourMinute}","%n vecka före händelsen klockan {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "på samma dag som händelsen klockan {formattedHourMinute}",
    "at the event's start" : "när händelsen börjar",
    "at the event's end" : "när händelsen slutar",
    "{time} before the event starts" : "{time} före händelsens början",
    "{time} before the event ends" : "{time} före händelsens slut",
    "{time} after the event starts" : "{time} efter händelsens början",
    "{time} after the event ends" : "{time} efter händelsens slut",
    "on {time}" : "klockan {time}",
    "on {time} ({timezoneId})" : "klockan {time} ({timezoneId})",
    "Week {number} of {year}" : "Vecka {number} år {year}",
    "Daily" : "Varje dag",
    "Weekly" : "Varje vecka",
    "Monthly" : "Varje månad",
    "Yearly" : "Årligen",
    "_Every %n day_::_Every %n days_" : ["Varje %n dag","Varje %n dagar"],
    "_Every %n week_::_Every %n weeks_" : ["Varje %n vecka","Varje %n veckor"],
    "_Every %n month_::_Every %n months_" : ["Varje %n månad","Varje %n månader"],
    "_Every %n year_::_Every %n years_" : ["Varje %n år","Varje %n år"],
    "_on {weekday}_::_on {weekdays}_" : ["på {weekday}","på {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["på dag {dayOfMonthList}","på dagar {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "på den {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {dayOfMonthList}" : "i {monthNames} på den {dayOfMonthList}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "i {monthNames} på den {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "till {untilDate}",
    "_%n time_::_%n times_" : ["%n gång","%n gånger"],
    "second" : "sekund",
    "third" : "tredje",
    "fourth" : "fjärde",
    "fifth" : "femte",
    "second to last" : "näst sist",
    "last" : "sist",
    "Untitled task" : "Namnlös uppgift",
    "Please ask your administrator to enable the Tasks App." : "Be din administratör aktivera Tasks-appen.",
    "You are not allowed to edit this event as an attendee." : "Du har inte behörighet att redigera denna händelse som deltagare.",
    "W" : "v",
    "%n more" : " %n till",
    "No events to display" : "Inga händelser att visa",
    "All participants declined" : "Alla deltagare avböjde",
    "Please confirm your participation" : "Vänligen bekräfta ditt deltagande",
    "You declined this event" : "Du avböjde denna händelse",
    "Your participation is tentative" : "Ditt deltagande är preliminärt",
    "_+%n more_::_+%n more_" : ["och %n till","och %n till"],
    "No events" : "Inga händelser",
    "Create a new event or change the visible time-range" : "Skapa ny händelse eller ändra det synliga tidspannet",
    "Failed to save event" : "Kunde inte spara händelse",
    "It might have been deleted, or there was a typo in a link" : "Den kan ha raderats eller så var länken felaktig",
    "It might have been deleted, or there was a typo in the link" : "Den kan ha raderats eller så var länken felaktig",
    "Meeting room" : "Mötesrum",
    "Lecture hall" : "Föreläsningssal",
    "Seminar room" : "Seminarierum",
    "Other" : "Annat",
    "When shared show" : "Visa om delad",
    "When shared show full event" : "Om delad, visa hela händelsen",
    "When shared show only busy" : "Om delad, visa endast upptagen",
    "When shared hide this event" : "Om delad, dölj denna händelse",
    "The visibility of this event in read-only shared calendars." : "Synligheten för denna händelse i skrivskyddade delade kalendrar.",
    "Add a location" : "Lägg till en plats",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Lägg till en beskrivning\n\n- Vad handlar mötet om\n- Punkter på dagordningen\n- Något som deltagare behöver förbereda",
    "Status" : "Status",
    "Confirmed" : "Bekräftad",
    "Canceled" : "Avbruten",
    "Confirmation about the overall status of the event." : "Bekräftelse av händelsens övergripande status.",
    "Show as" : "Visa som",
    "Take this event into account when calculating free-busy information." : "Ta hänsyn till denna händelse när ledig/upptagen tid beräknas.",
    "Categories" : "Kategorier",
    "Categories help you to structure and organize your events." : "Kategorier hjälper dig strukturera och organisera dina händelser.",
    "Search or add categories" : "Sök eller lägg till kategorier",
    "Add this as a new category" : "Lägg till som en ny kategori",
    "Custom color" : "Anpassad färg",
    "Special color of this event. Overrides the calendar-color." : "Anpassad färg på denna händelse. Åsidosätter kalenderfärgen.",
    "Error while sharing file" : "Fel vid delning av fil",
    "Error while sharing file with user" : "Ett fel uppstod vid delning av fil med användare",
    "Error creating a folder {folder}" : "Det gick inte att skapa mappen {folder}",
    "Attachment {fileName} already exists!" : "Bilagan {fileName} finns redan!",
    "Attachment {fileName} added!" : "Bilaga {fileName} tillagd!",
    "An error occurred during uploading file {fileName}" : "Ett fel uppstod vid uppladdning av filen {fileName}",
    "An error occurred during getting file information" : "Ett fel uppstod vid hämtning av filinformation",
    "Talk conversation for proposal" : "Talk-konversation för förslaget",
    "An error occurred, unable to delete the calendar." : "Ett fel inträffade, kunde inte radera kalendern.",
    "Imported {filename}" : "Importerad {filename}",
    "This is an event reminder." : "Detta är en händelsepåminnelse.",
    "Error while parsing a PROPFIND error" : "Fel vid analys av ett PROPFIND-fel",
    "Appointment not found" : "Mötet hittades inte",
    "User not found" : "Användaren hittades inte",
    "Hidden" : "Gömd",
    "can edit" : "kan redigera",
    "Calendar name …" : "Kalendernamn ...",
    "Default attachments location" : "Standardplats för bilagor",
    "Automatic ({detected})" : "Automatisk ({detected})",
    "Shortcut overview" : "Översikt av genvägar",
    "CalDAV link copied to clipboard." : "CalDAV-länk kopierad till urklipp.",
    "CalDAV link could not be copied to clipboard." : "CalDAV-länk kunde inte kopieras till urklipp.",
    "Enable birthday calendar" : "Aktivera födelsedagskalender",
    "Show tasks in calendar" : "Visa uppgifter i kalendern",
    "Enable simplified editor" : "Aktivera förenklad redigerare",
    "Limit the number of events displayed in the monthly view" : "Begränsa antalet händelser som visas i månadsvyn",
    "Show weekends" : "Visa helger",
    "Show week numbers" : "Visa veckonummer",
    "Time increments" : "Tidsintervall",
    "Default calendar for incoming invitations" : "Standardkalender för inkommande inbjudningar",
    "Copy primary CalDAV address" : "Kopiera primär CalDAV-adress",
    "Copy iOS/macOS CalDAV address" : "Kopiera iOS/macOS CalDAV-adress",
    "Personal availability settings" : "Dina tillgänglighetsinställningar",
    "Show keyboard shortcuts" : "Visa tangentbordsgenvägar",
    "Create a new public conversation" : "Skapa en ny offentlig konversation",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} inbjudna, {confirmedCount} bekräftade",
    "Successfully appended link to talk room to location." : "Länk till rum i Talk tillagd i plats.",
    "Successfully appended link to talk room to description." : "Länk till rum i Talk tillagd i beskrivningen.",
    "Error creating Talk room" : "Kunde inte skapa rum i Talk",
    "_%n more guest_::_%n more guests_" : ["%n gäst till","%n gäster till"],
    "The visibility of this event in shared calendars." : "Synligheten för denna händelse i delade kalendrar."
},
"nplurals=2; plural=(n != 1);");
