OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "L'indirizzo email è troppo lungo",
    "User-Session unexpectedly expired" : "Sessione utente scaduta in modo inatteso",
    "Provided email-address is not valid" : "L'indirizzo email fornito non è valido",
    "%s has published the calendar »%s«" : "%s ha pubblicato il calendario «%s»",
    "Unexpected error sending email. Please contact your administrator." : "Errore inatteso nell'invio dell'email. Contatta l'amministratore.",
    "Successfully sent email to %1$s" : "Email inviata a %1$s correttamente",
    "Hello," : "Ciao,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Ti vogliamo informare che %s ha pubblicato il calendario «%s». ",
    "Open »%s«" : "Apri «%s»",
    "Cheers!" : "Evviva!",
    "Upcoming events" : "Prossimi eventi",
    "No more events today" : "Non ci sono altri eventi oggi",
    "No upcoming events" : "Nessun prossimo evento",
    "More events" : "Altri eventi",
    "%1$s with %2$s" : "%1$s con %2$s",
    "Calendar" : "Calendario",
    "New booking {booking}" : "Nuova prenotazione {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) ha prenotato l'appuntamento \"{config_display_name}\" il {date_time}.",
    "Appointments" : "Appuntamenti",
    "Schedule appointment \"%s\"" : "Fissa appuntamento \"%s\"",
    "Schedule an appointment" : "Fissa un appuntamento",
    "%1$s - %2$s" : "* %1$s - %2$s",
    "Prepare for %s" : "Prepara per %s",
    "Follow up for %s" : "Azione supplementare per %s",
    "Your appointment \"%s\" with %s needs confirmation" : "L'appuntamento \"%s\" con %s richiede una conferma",
    "Dear %s, please confirm your booking" : "Gentile %s, conferma la tua prenotazione",
    "Confirm" : "Conferma",
    "Appointment with:" : "Appuntamento con:",
    "Description:" : "Descrizione:",
    "This confirmation link expires in %s hours." : "Il collegamento di conferma scade in %s ore.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Se desideri annullare l'appuntamento, contatta il tuo organizzatore rispondendo a questa email o visitando la pagina del suo profilo.",
    "Your appointment \"%s\" with %s has been accepted" : "L'appuntamento \"%s\" con %s è stato accettato",
    "Dear %s, your booking has been accepted." : "Caro/a %s, la tua prenotazione è stata accettata.",
    "Appointment for:" : "Appuntamento per:",
    "Date:" : "Data:",
    "You will receive a link with the confirmation email" : "Riceverai un collegamento con l'email di conferma",
    "Where:" : "Luogo:",
    "Comment:" : "Commento:",
    "You have a new appointment booking \"%s\" from %s" : "Hai una nuova prenotazione per un appuntamento \"%s\" da %s",
    "Dear %s, %s (%s) booked an appointment with you." : "Caro %s, %s (%s) ha prenotato un appuntamento con te.",
    "Location:" : "Posizione:",
    "Duration:" : "Durata",
    "A Calendar app for Nextcloud" : "Un'applicazione di calendario per Nextcloud",
    "A Calendar app for Nextcloud. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Like Contacts, Talk, Tasks, Deck and Circles\n* 🌐 **WebCal Support!** Want to see your favorite team's matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 **Search!** Find your events at ease\n* ☑️ **Tasks!** See tasks or Deck cards with a due date directly in the calendar\n* 🔈 **Talk rooms!** Create an associated Talk room when booking a meeting with just one click\n* 📆 **Appointment booking** Send people a link so they can book an appointment with you [using this app](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Attachments!** Add, upload and view event attachments\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Un'app Calendario per Nextcloud. Sincronizza facilmente gli eventi da diversi dispositivi con Nextcloud e modificali online.\n\n* 🚀 **Integrazione con altre app Nextcloud!** Come Contatti, Talk, Attività, Deck e Circles\n* 🌐 **Supporto WebCal!** Vuoi vedere le partite della tua squadra del cuore sul tuo calendario? Nessun problema! * 🙋 **Partecipanti!** Invita persone ai tuoi eventi\n* ⌚ **Libero/Occupato!** Controlla quando i tuoi partecipanti sono disponibili per l'incontro\n* ⏰ **Promemoria!** Ricevi avvisi per gli eventi nel tuo browser e via email\n* 🔍 **Cerca!** Trova i tuoi eventi in tutta semplicità\n* ☑️ **Attività!** Visualizza attività o schede Deck con una data di scadenza direttamente nel calendario\n* 🔈 **Sale di discussione!** Crea una sala di discussione associata quando prenoti una riunione con un solo clic\n* 📆 **Prenotazione appuntamenti** Invia un link alle persone in modo che possano prenotare un appuntamento con te [utilizzando questa app](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Allegati!** Aggiungi, carica e visualizza gli allegati dell'evento\n* 🙈 **Non stiamo reinventando la ruota!** Basato sul fantastico [librerie c-dav](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) e [fullcalendar](https://github.com/fullcalendar/fullcalendar).",
    "Previous day" : "Giorno precedente",
    "Previous week" : "Settimana precedente",
    "Previous year" : "Anno precedente",
    "Previous month" : "Mese precedente",
    "Next day" : "Giorno successivo",
    "Next week" : "Settimana successiva",
    "Next year" : "Anno succ.",
    "Next month" : "Mese successivo",
    "Create new event" : "Crea un nuovo evento",
    "Event" : "Evento",
    "Today" : "Oggi",
    "Day" : "Giorno",
    "Week" : "Settimana",
    "Month" : "Mese",
    "Year" : "Anno",
    "List" : "Elenco",
    "Appointment link was copied to clipboard" : "Il collegamento dell'appuntamento è stato copiato negli appunti",
    "Appointment link could not be copied to clipboard" : "Impossibile copiare il collegamento dell'appuntamento negli appunti",
    "Preview" : "Anteprima",
    "Copy link" : "Copia link",
    "Edit" : "Modifica",
    "Delete" : "Elimina",
    "Appointment schedules" : "Orari degli appuntamenti",
    "Create new" : "Crea nuovo",
    "Disable calendar \"{calendar}\"" : "Disabilita il calendario \"{calendar}\"",
    "Disable untitled calendar" : "Disabilita il calendario senza titolo",
    "Enable calendar \"{calendar}\"" : "Abilita il calendario \"{calendar}\"",
    "Enable untitled calendar" : "Abilita il calendario senza titolo",
    "An error occurred, unable to change visibility of the calendar." : "Si è verificato un errore, impossibile cambiare la visibilità del calendario.",
    "Untitled calendar" : "Calendario senza titolo",
    "Shared with you by" : "Condiviso con te da",
    "Edit and share calendar" : "Modifica e condividi il calendario",
    "Edit calendar" : "Modifica il calendario",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Rimozione condivisione del calendario in {countdown} secondo","Rimozione condivisione del calendario in {countdown} secondi","Rimozione condivisione del calendario in {countdown} secondi"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Eliminazione del calendario in {countdown} secondo","Eliminazione del calendario in {countdown} secondi","Eliminazione del calendario in {countdown} secondi"],
    "An error occurred, unable to create the calendar." : "Si è verificato un errore, impossibile creare il calendario.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Inserisci un collegamento valido (inizia con http://, https://, webcal://, o webcals://)",
    "Calendars" : "Calendari",
    "Add new" : "Aggiungi nuovo",
    "New calendar" : "Nuovo calendario",
    "Name for new calendar" : "Nome del nuovo calendario",
    "Creating calendar …" : "Creazione calendario...",
    "New calendar with task list" : "Nuovo calendario con elenco delle attività",
    "New subscription from link (read-only)" : "Nuova sottoscrizione da collegamento (sola lettura)",
    "Creating subscription …" : "Crea sottoscrizione...",
    "Add public holiday calendar" : "Aggiungi il calendario delle festività pubbliche",
    "Add custom public calendar" : "Aggiungi calendario pubblico personalizzato",
    "Calendar link copied to clipboard." : "Collegamento del calendario copiato negli appunti.",
    "Calendar link could not be copied to clipboard." : "Il collegamento del calendario non può essere copiato negli appunti.",
    "Copy subscription link" : "Copia collegamento di sottoscrizione",
    "Copying link …" : "Copia collegamento...",
    "Copied link" : "Collegamento copiato",
    "Could not copy link" : "Impossibile copiare il collegamento",
    "Export" : "Esporta",
    "Untitled item" : "Elemento senza titolo",
    "Unknown calendar" : "Calendario sconosciuto",
    "Could not load deleted calendars and objects" : "Impossibile caricare i calendari e gli oggetti eliminati",
    "Could not delete calendar or event" : "Impossibile eliminare il calendario o l'evento",
    "Could not restore calendar or event" : "Impossibile ripristinare il calendario o l'evento",
    "Do you really want to empty the trash bin?" : "Vuoi davvero svuotare il cestino?",
    "Empty trash bin" : "Svuota cestino",
    "Trash bin" : "Cestino",
    "Loading deleted items." : "Caricamento elementi eliminati.",
    "You do not have any deleted items." : "Non sono presenti elementi eliminati.",
    "Name" : "Nome",
    "Deleted" : "Eliminati",
    "Restore" : "Ripristina",
    "Delete permanently" : "Elimina definitivamente",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Gli elementi nel cestino verranno eliminati dopo {numDays} giorno","Gli elementi nel cestino verranno eliminati dopo {numDays} giorni","Gli elementi nel cestino verranno eliminati dopo {numDays} giorni"],
    "Could not update calendar order." : "Impossibile aggiornare l'ordine del calendario.",
    "Shared calendars" : "Calendari condivisi",
    "Deck" : "Deck",
    "Internal link" : "Collegamento interno",
    "A private link that can be used with external clients" : "Un collegamento privato che può essere utilizzato con client esterni",
    "Copy internal link" : "Copia collegamento interno",
    "An error occurred, unable to publish calendar." : "Si è verificato un errore, impossibile pubblicare il calendario.",
    "An error occurred, unable to send email." : "Si è verificato un errore, impossibile inviare il messaggio.",
    "Embed code copied to clipboard." : "Codice di incorporazione copiato negli appunti.",
    "Embed code could not be copied to clipboard." : "Impossibile copiare codice di incorporazione negli appunti.",
    "Unpublishing calendar failed" : "Rimozione calendario non riuscita",
    "Share link" : "Condividi il collegamento",
    "Copy public link" : "Copia collegamento pubblico",
    "Send link to calendar via email" : "Invia collegamento al calendario tramite email",
    "Enter one address" : "Digita un indirizzo",
    "Sending email …" : "Invio email...",
    "Copy embedding code" : "Copia codice di incorporazione",
    "Copying code …" : "Copia codice...",
    "Copied code" : "Codice copiato",
    "Could not copy code" : "Impossibile copiare il codice",
    "Delete share link" : "Elimina collegamento di condivisione",
    "Deleting share link …" : "Eliminazione collegamento di condivisione...",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Team)",
    "An error occurred while unsharing the calendar." : "Si è verificato un errore durante la rimozione della condivisione del calendario.",
    "An error occurred, unable to change the permission of the share." : "Si è verificato un errore, impossibile cambiare i permessi della condivisione.",
    "Unshare with {displayName}" : "Rimuovi condivisione con {displayName}",
    "Share with users or groups" : "Condividi con utenti o gruppi",
    "No users or groups" : "Nessun utente o gruppo",
    "Failed to save calendar name and color" : "Errore nel salvataggio del nome e del colore del calendario",
    "Never show me as busy (set this calendar to transparent)" : "Non mostrarmi mai come occupato (imposta questo calendario come trasparente)",
    "Share calendar" : "Condividi calendario",
    "Unshare from me" : "Rimuovi condivisione da me",
    "Save" : "Salva",
    "View" : "Visualizza",
    "Import calendars" : "Importa calendari",
    "Please select a calendar to import into …" : "Seleziona un calendario in cui importare...",
    "Filename" : "Nome file",
    "Calendar to import into" : "Calendario in cui importare",
    "Cancel" : "Annulla",
    "_Import calendar_::_Import calendars_" : ["Importa calendario","Importa calendari","Importa calendari"],
    "Select the default location for attachments" : "Seleziona la posizione predefinita per gli allegati",
    "Pick" : "Seleziona",
    "Invalid location selected" : "Percorso selezionato non valido",
    "Attachments folder successfully saved." : "Cartella degli allegati salvata correttamente.",
    "Error on saving attachments folder." : "Errore durante il salvataggio della cartella degli allegati.",
    "Attachments folder" : "Cartella degli allegati",
    "{filename} could not be parsed" : "{filename} non può essere analizzato",
    "No valid files found, aborting import" : "Nessun file valido trovato, importazione interrotta",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["%n evento importato con successo","%n evento importato con successo","%n evento importato con successo"],
    "Import partially failed. Imported {accepted} out of {total}." : "Importazione parzialmente non riuscita. Importati {accepted} di {total}.",
    "Automatic" : "Automatico",
    "Automatic ({timezone})" : "Automatico ({timezone})",
    "New setting was not saved successfully." : "La nuova impostazione non è stata salvata correttamente.",
    "Timezone" : "Fuso orario",
    "Navigation" : "Navigazione",
    "Previous period" : "Periodo precedente",
    "Next period" : "Periodo successivo",
    "Views" : "Viste",
    "Day view" : "Vista del giorno",
    "Week view" : "Vista della settimana",
    "Month view" : "Vista del mese",
    "Year view" : "Vista annuale",
    "List view" : "Vista Elenco",
    "Actions" : "Azioni",
    "Create event" : "Crea evento",
    "Show shortcuts" : "Mostra scorciatoie",
    "Editor" : "Editor",
    "Close editor" : "Chiudi editor",
    "Save edited event" : "Salva l'evento modificato",
    "Delete edited event" : "Elimina l'evento modificato",
    "Duplicate event" : "Evento duplicato",
    "or" : "o",
    "Calendar settings" : "Impostazioni Calendario",
    "At event start" : "Ad inizio evento",
    "No reminder" : "Nessun promemoria",
    "Failed to save default calendar" : "Fallimento nel salvare il calendario di default",
    "General" : "Generale",
    "Appearance" : "Aspetto",
    "Editing" : "Modificando",
    "Default reminder" : "Promemoria predefinito",
    "Files" : "File",
    "Appointment schedule successfully created" : "Il programma degli appuntamenti è stato creato con successo",
    "Appointment schedule successfully updated" : "Il programma degli appuntamenti è stato aggiornato con successo",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minuto","{duration} minuti","{duration} minuti"],
    "0 minutes" : "0 minuti",
    "_{duration} hour_::_{duration} hours_" : ["{duration} ora","{duration} ore","{duration} ore"],
    "_{duration} day_::_{duration} days_" : ["{duration} giorno","{duration} giorni","{duration} giorni"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} settimana","{duration} settimane","{duration} settimane"],
    "_{duration} month_::_{duration} months_" : ["{duration} mese","{duration} mesi","{duration} mesi"],
    "_{duration} year_::_{duration} years_" : ["{duration} anno","{duration} anni","{duration} anni"],
    "To configure appointments, add your email address in personal settings." : "Per configurare gli appuntamenti, aggiungi il tuo indirizzo email nelle impostazioni personali.",
    "Public – shown on the profile page" : "Pubblica – mostrata nella pagina del profilo",
    "Private – only accessible via secret link" : "Privata – accessibile solo da collegamento segreto",
    "Appointment schedule saved" : "Programma degli appuntamenti salvato",
    "Create appointment schedule" : "Crea un programma di appuntamenti",
    "Edit appointment schedule" : "Modifica il programma degli appuntamenti",
    "Update" : "Aggiorna",
    "Appointment name" : "Nome appuntamento",
    "Location" : "Luogo",
    "Create a Talk room" : "Crea una stanza di Talk",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Per ogni appuntamento prenotato verrà generato un link univoco che verrà inviato tramite l'e-mail di conferma",
    "Description" : "Descrizione",
    "Visibility" : "Visibilità",
    "Duration" : "Durata",
    "Increments" : "Incrementi",
    "Additional calendars to check for conflicts" : "Calendari aggiuntivi per controllare conflitti",
    "Pick time ranges where appointments are allowed" : "Scegli gli intervalli di ore in cui sono permessi appuntamenti",
    "to" : "a",
    "Delete slot" : "Elimina slot",
    "No times set" : "Nessuna ora impostata",
    "Add" : "Aggiungi",
    "Monday" : "Lunedì",
    "Tuesday" : "Martedì",
    "Wednesday" : "Mercoledì",
    "Thursday" : "Giovedì",
    "Friday" : "Venerdì",
    "Saturday" : "Sabato",
    "Sunday" : "Domenica",
    "Weekdays" : "Giorni feriali",
    "Add time before and after the event" : "Aggiungi tempo prima e dopo l'evento",
    "Before the event" : "Prima dell'evento",
    "After the event" : "Dopo l'evento",
    "Planning restrictions" : "Restrizioni sulla pianificazione",
    "Minimum time before next available slot" : "Tempo minimo prima del successivo slot disponibile",
    "Max slots per day" : "Slot massimi al giorno",
    "Limit how far in the future appointments can be booked" : "Limita fino a quando è possibile prenotare appuntamenti futuri",
    "It seems a rate limit has been reached. Please try again later." : "Sembra che sia stato raggiunto un limite di frequenza. Riprova più tardi.",
    "Please confirm your reservation" : "Conferma la tua prenotazione",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Ti abbiamo inviato un'email con i dettagli. Conferma il tuo appuntamento usando il collegamento nell'email. Ora puoi chiudere questa pagina.",
    "Your name" : "Il tuo nome",
    "Your email address" : "Il tuo indirizzo email",
    "Please share anything that will help prepare for our meeting" : "Condividi tutto ciò che possa aiutarci a preparare il nostro incontro",
    "Could not book the appointment. Please try again later or contact the organizer." : "Impossibile prenotare l'appuntamento. Riprova più tardi o contatta l'organizzatore.",
    "Back" : "Indietro",
    "Book appointment" : "Prenota un appuntamento",
    "Conversation does not have a valid URL." : "La conversazione non ha un URL valido",
    "Talk conversation for event" : "Conversazione di Talk per un evento",
    "Error creating Talk conversation" : "Errore durante la crezione della conversazione Talk",
    "Add Talk conversation" : "Aggiungi conversazione Talk",
    "Select conversation" : "Seleziona conversazione",
    "on" : "il",
    "at" : "alle",
    "before at" : "prima di",
    "Notification" : "Notifica",
    "Email" : "Email",
    "Audio notification" : "Notifica audio",
    "Other notification" : "Altra notifica",
    "Relative to event" : "Relativo all'evento",
    "On date" : "In data",
    "Edit time" : "Ora di modifica",
    "Save time" : "Ora di salvataggio",
    "Remove reminder" : "Rimuovi promemoria",
    "Add reminder" : "Aggiungi promemoria",
    "seconds" : "secondi",
    "minutes" : "minuti",
    "hours" : "ore",
    "days" : "giorni",
    "weeks" : "settimane",
    "Choose a file to add as attachment" : "Scegli un file da aggiungere come allegato",
    "Choose a file to share as a link" : "Scegli un file da condividere come un collegamento",
    "Attachment {name} already exist!" : "L'allegato {name} esiste già!",
    "Could not upload attachment(s)" : "Impossibile caricare gli allegati",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Stai per navigare verso {host}. Sei sicuro di procedere? Link: {link}",
    "Proceed" : "Procedi",
    "No attachments" : "Nessun allegato",
    "Add from Files" : "Aggiungi da File",
    "Upload from device" : "Carica dal dispositivo",
    "Delete file" : "Elimina file",
    "Confirmation" : "Conferma",
    "_{count} attachment_::_{count} attachments_" : ["{count} allegato","{count} allegati","{count} allegati"],
    "Suggested" : "Suggerito",
    "Available" : "Disponibile",
    "Invitation accepted" : "Invito accettato",
    "Accepted {organizerName}'s invitation" : "Invito di {organizerName} accettato",
    "Participation marked as tentative" : "Partecipazione contrassegnata come provvisoria",
    "Invitation is delegated" : "Invito delegato",
    "Not available" : "Non disponibile",
    "Invitation declined" : "Invito rifiutato",
    "Declined {organizerName}'s invitation" : "Invito di {organizerName} rifiutato",
    "Availability will be checked" : "La disponibilità verrà verificata",
    "Invitation will be sent" : "L'invito verrà inviato",
    "Failed to check availability" : "Impossibile verificare la disponibilità",
    "Failed to deliver invitation" : "Impossibile consegnare l'invito",
    "Awaiting response" : "In attesa della risposta",
    "Checking availability" : "Verifica disponibilità",
    "Has not responded to {organizerName}'s invitation yet" : "Non ha ancora risposto all'invito di {organizerName}",
    "chairperson" : "presidente",
    "required participant" : "partecipante richiesto",
    "non-participant" : "non partecipante",
    "optional participant" : "partecipante facoltativo",
    "{organizer} (organizer)" : "{organizer} (organizzatore)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Availability of attendees, resources and rooms" : "Disponibilità di partecipanti, risorse e stanze",
    "Suggestion accepted" : "Suggerimento accettato",
    "Legend" : "Legenda",
    "Out of office" : "Fuori sede",
    "Attendees:" : "Partecipanti:",
    "Done" : "Completato",
    "Search room" : "Cerca stanza",
    "Room name" : "Nome stanza",
    "Check room availability" : "Controlla la disponibilità della stanza",
    "Free" : "Libero",
    "Busy (tentative)" : "Occupato (provvisorio)",
    "Busy" : "Occupato",
    "Unknown" : "Sconosciuto",
    "Find a time" : "Trova un orario",
    "The invitation has been accepted successfully." : "L'invito è stato accettato con successo.",
    "Failed to accept the invitation." : "Impossibile accettare l'invito.",
    "The invitation has been declined successfully." : "L'invito è stato rifiutato con successo.",
    "Failed to decline the invitation." : "Impossibile rifiutare l'invito.",
    "Your participation has been marked as tentative." : "La tua partecipazione è stata contrassegnata come \"provvisoria\".",
    "Failed to set the participation status to tentative." : "Impossibile impostare lo stato di partecipazione su \"provvisorio\".",
    "Accept" : "Accetta",
    "Decline" : "Rifiuta",
    "Tentative" : "Provvisorio",
    "No attendees yet" : "Ancora nessun partecipante",
    "Attendees" : "Partecipanti",
    "Remove group" : "Rimuovi gruppo",
    "Remove attendee" : "Rimuovi partecipante",
    "Request reply" : "Richiedi risposta",
    "Chairperson" : "Presidente",
    "Required participant" : "Partecipante necessario",
    "Optional participant" : "Partecipante facoltativo",
    "Non-participant" : "Non partecipante",
    "_%n member_::_%n members_" : ["%n membro","%n membri","%n membri"],
    "Search for emails, users, contacts, contact groups or teams" : "Cerca email, utenti, contatti, gruppi di contatti o team",
    "No match found" : "Nessuna corrispondenza trovata",
    "Note that members of circles get invited but are not synced yet." : "Nota che i membri delle cerchie vengono invitati, ma non sono ancora sincronizzati.",
    "Note that members of contact groups get invited but are not synced yet." : "Tieni presente che i membri dei gruppi di contatti vengono invitati ma non vengono ancora sincronizzati.",
    "(organizer)" : "(organizzatore)",
    "Make {label} the organizer" : "Crea {label} organizzatore",
    "Make {label} the organizer and attend" : "Crea{label} l'organizzatore e partecipa",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Per inviare inviti e gestire risposte, [linkopen]aggiungi il tuo indirizzo email nelle impostazioni personali[linkclose].",
    "Remove color" : "Rimuovi colore",
    "Event title" : "Titolo dell'evento",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Impossibile modificare le impostazioni di un giorno intero per gli eventi che sono parte di un insieme di ricorrenze.",
    "From" : "Da",
    "To" : "A",
    "Repeat" : "Ripeti",
    "_time_::_times_" : ["volta","volte","volte"],
    "never" : "mai",
    "on date" : "in data",
    "after" : "dopo",
    "End repeat" : "Termina ripetizione",
    "Select to end repeat" : "Seleziona per terminare la ripetizione",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Questo evento è l'eccezione di un insieme di ricorrenze. Non puoi aggiungergli una regola di ricorrenza.",
    "first" : "primo",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Le modifiche alla regola di ricorrenza saranno applicate a questa e a tutte le future occorrenze.",
    "Repeat every" : "Ripeti ogni",
    "By day of the month" : "Per giorno del mese",
    "On the" : "Il",
    "_day_::_days_" : ["giorno","giorni","giorni"],
    "_week_::_weeks_" : ["settimana","settimane","settimane"],
    "_month_::_months_" : ["mese","mesi","mesi"],
    "_year_::_years_" : ["anno","anni","anni"],
    "On specific day" : "In un giorno specifico",
    "weekday" : "giorno feriale",
    "weekend day" : "giorno del fine settimana",
    "Does not repeat" : "Non ripete",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "La definizione di ricorrenza di questo evento non è supportata completamente da Nextcloud. Se modifichi le opzioni di ricorrenza, alcune ricorrenze potrebbero essere perse.",
    "No rooms or resources yet" : "Ancora nessuna stanza o risorsa",
    "Resources" : "Risorse",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} sedia","{seatingCapacity} sedie","{seatingCapacity} sedie"],
    "Add resource" : "Aggiungi risorsa",
    "Has a projector" : "Ha un proiettore",
    "Has a whiteboard" : "Ha una lavagna",
    "Wheelchair accessible" : "Accessibile alle carrozzine",
    "Remove resource" : "Rimuovi risorsa",
    "Search for resources or rooms" : "Cerca risorse o stanze",
    "available" : "disponibile",
    "unavailable" : "non disponibile",
    "Show all rooms" : "Mostra tutte le stanze",
    "Projector" : "Proiettore",
    "Whiteboard" : "Lavagna",
    "Room type" : "Tipo stanza",
    "Any" : "Qualsiasi",
    "Minimum seating capacity" : "Numero minimo di sedie",
    "More details" : "Maggiori dettagli",
    "Update this and all future" : "Aggiorna questa e tutte le future",
    "Update this occurrence" : "Aggiorna questa occorrenza",
    "Public calendar does not exist" : "Il calendario pubblico non esiste",
    "Maybe the share was deleted or has expired?" : "Forse la condivisione è stata eliminata o è scaduta?",
    "Yes" : "Sì",
    "No" : "No",
    "Maybe" : "Forse",
    "None" : "Nessuno",
    "Create" : "Crea",
    "from {formattedDate}" : "dal {formattedDate}",
    "to {formattedDate}" : "al {formattedDate}",
    "on {formattedDate}" : "il {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "dal {formattedDate} alle {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "al {formattedDate} alle {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "il {formattedDate} alle {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} alle {formattedTime}",
    "Please enter a valid date" : "Digita una data valida",
    "Please enter a valid date and time" : "Digita una data e un orario validi",
    "Select a time zone" : "Seleziona un fuso orario",
    "Please select a time zone:" : "Seleziona un fuso orario:",
    "Pick a time" : "Scegli un orario",
    "Pick a date" : "Scegli una data",
    "Type to search time zone" : "Digita per cercare il fuso orario",
    "Global" : "Globale",
    "Holidays in {region}" : "Festività in {region}",
    "An error occurred, unable to read public calendars." : "Si è verificato un errore, impossibile leggere i calendari pubblici.",
    "An error occurred, unable to subscribe to calendar." : "Si è verificato un errore, impossibile sottoscrivere il calendario.",
    "Public holiday calendars" : "Calendari delle festività pubbliche",
    "Public calendars" : "Calendari pubblici",
    "No valid public calendars configured" : "Nessun calendario pubblico valido configurato",
    "Speak to the server administrator to resolve this issue." : "Parla con l'amministratore del server per risolvere questo problema.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "I calendari delle festività pubbliche sono forniti da Thunderbird. I dati del calendario saranno scaricati da {website}.",
    "By {authors}" : "Di {authors}",
    "Subscribed" : "Sottoscritta",
    "Subscribe" : "Iscrizione",
    "Could not fetch slots" : "Impossibile recuperare gli slot",
    "Select a date" : "Seleziona una data",
    "Select slot" : "Seleziona slot",
    "No slots available" : "Nessuno slot disponibile",
    "The slot for your appointment has been confirmed" : "Lo slot per il tuo appuntamento è stato confermato",
    "Appointment Details:" : "Dettagli appuntamento:",
    "Time:" : "Ora:",
    "Booked for:" : "Prenotato per:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Grazie. La tua prenotazione dal {startDate} al {endDate} è stata confermata.",
    "Book another appointment:" : "Prenota un altro appuntamento:",
    "See all available slots" : "Mostra tutti gli slot disponibili",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Lo slot per il tuo appuntamento dal {startDate} al {endDate} non è più disponibile.",
    "Please book a different slot:" : "Prenota uno slot diverso:",
    "Book an appointment with {name}" : "Prenota un appuntamento con {name}",
    "No public appointments found for {name}" : "Nessun appuntamento pubblico trovato per {name}",
    "Personal" : "Personale",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Il rilevamento automatico del fuso orario ha determinato che il tuo è UTC.\nProbabilmente è il risultato di alcune misure di sicurezza del tuo browser web.\nImposta il tuo fuso orario a mano nelle impostazioni del calendario.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Il fuso orario configurato ({timezoneId}) non è stato trovato. Ripiego su UTC.\nCambia il tuo fuso orario nelle impostazioni e segnala questo problema.",
    "Availability of {displayName}" : "Disponibilità di {displayName}",
    "Edit event" : "Modifica evento",
    "Event does not exist" : "L'evento non esiste",
    "Duplicate" : "Duplicato",
    "Delete this occurrence" : "Elimina questa occorrenza",
    "Delete this and all future" : "Elimina questa e tutte le future",
    "All day" : "Tutto il giorno",
    "Modifications wont get propagated to the organizer and other attendees" : "Le modifiche non verranno propagate all'organizzatore e agli altri partecipanti",
    "Managing shared access" : "Gestire accesso condiviso",
    "Deny access" : "Nega l'accesso",
    "Invite" : "Invita",
    "_User requires access to your file_::_Users require access to your file_" : ["Gli utenti hanno bisogno di accedere al tuo file","Gli utenti hanno bisogno di accedere ai tuoi file","Gli utenti hanno bisogno di accedere ai tuoi file"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Allegato che richiede un accesso condiviso","Allegati che richiedono un accesso condiviso","Allegato che richiede un  accesso condiviso"],
    "Untitled event" : "Evento senza titolo",
    "Close" : "Chiudi",
    "Modifications will not get propagated to the organizer and other attendees" : "Le modifiche non verranno propagate all'organizzatore e agli altri partecipanti",
    "Selected" : "Selezionato",
    "Title" : "Titolo",
    "30 min" : "30 min",
    "Participants" : "Partecipanti",
    "Submit" : "Invia",
    "Subscribe to {name}" : "Sottoscrivi {name}",
    "Export {name}" : "Esporta {name}",
    "Show availability" : "Mostra disponibilità",
    "Anniversary" : "Anniversario",
    "Appointment" : "Appuntamento",
    "Business" : "Lavoro",
    "Education" : "Formazione",
    "Holiday" : "Vacanza",
    "Meeting" : "Riunione",
    "Miscellaneous" : "Varie",
    "Non-working hours" : "Ore non lavorative",
    "Not in office" : "Non in ufficio",
    "Phone call" : "Telefonata",
    "Sick day" : "Giorno di malattia",
    "Special occasion" : "Occasione speciale",
    "Travel" : "Viaggio",
    "Vacation" : "Assenza",
    "Midnight on the day the event starts" : "Mezzanotte del giorno in cui inizia l'evento",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n giorno prima dell'evento alle {formattedHourMinute}","%n giorni prima dell'evento alle {formattedHourMinute}","%n giorni prima dell'evento alle {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n settimana prima dell'evento alle {formattedHourMinute}","%n settimane prima dell'evento alle {formattedHourMinute}","%n settimane prima dell'evento alle {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "il giorno dell'evento alle {formattedHourMinute}",
    "at the event's start" : "all'inizio dell'evento",
    "at the event's end" : "alla fine dell'evento",
    "{time} before the event starts" : "{time} prima che l'evento inizi",
    "{time} before the event ends" : "{time} prima che l'evento finisca",
    "{time} after the event starts" : "{time} dopo l'inizio dell'evento",
    "{time} after the event ends" : "{time} dopo la fine dell'evento",
    "on {time}" : "il {time}",
    "on {time} ({timezoneId})" : "il {time} {timezoneId}",
    "Week {number} of {year}" : "Settimana {number} del {year}",
    "Daily" : "Quotidianamente",
    "Weekly" : "Settimanalmente",
    "Monthly" : "Mensilmente",
    "Yearly" : "Annualmente",
    "_Every %n day_::_Every %n days_" : ["Ogni %n giorno","Ogni %n giorni","Ogni %n giorni"],
    "_Every %n week_::_Every %n weeks_" : ["Ogni %n settimana","Ogni %n settimane","Ogni %n settimane"],
    "_Every %n month_::_Every %n months_" : ["Ogni %n mese","Ogni %n mesi","Ogni %n mesi"],
    "_Every %n year_::_Every %n years_" : ["Ogni %n anno","Ogni %n anni","Ogni %n anni"],
    "_on {weekday}_::_on {weekdays}_" : ["il {weekday}","i {weekdays}","i {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["il giorno {dayOfMonthList}","nei giorni {dayOfMonthList}","nei giorni {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "il {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "in {monthNames} il {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "fino al {untilDate}",
    "_%n time_::_%n times_" : ["%n volta","%n volte","%n volte"],
    "second" : "secondo",
    "third" : "terzo",
    "fourth" : "quarto",
    "fifth" : "quinto",
    "second to last" : "penultimo",
    "last" : "ultimo",
    "Untitled task" : "Attività senza titolo",
    "Please ask your administrator to enable the Tasks App." : "Chiedi al tuo amministratore di abilitare l'applicazione Attività.",
    "You are not allowed to edit this event as an attendee." : "Non ti è consentito modificare questo evento in quanto partecipante.",
    "W" : "S",
    "%n more" : "%n altri",
    "No events to display" : "Nessun evento da visualizzare",
    "All participants declined" : "Tutti i partecipanti hanno rifiutato",
    "Please confirm your participation" : "Si prega di confermare la tua partecipazione",
    "You declined this event" : "Hai rifiutato questo evento",
    "Your participation is tentative" : "La tua partecipazione è provvisoria",
    "_+%n more_::_+%n more_" : ["+%n altro","+%n altri","+%n altri"],
    "No events" : "Nessun evento",
    "Create a new event or change the visible time-range" : "Crea un nuovo evento o cambia l'intervallo di tempo visibile",
    "Failed to save event" : "Impossibile salvare l'evento",
    "It might have been deleted, or there was a typo in a link" : "Potrebbe essere stato eliminato o c'era un errore di digitazione in un collegamento",
    "It might have been deleted, or there was a typo in the link" : "Potrebbe essere stato eliminato o c'era un errore di digitazione nel collegamento",
    "Meeting room" : "Sala riunioni",
    "Lecture hall" : "Sala conferenze",
    "Seminar room" : "Sala seminari",
    "Other" : "Altro",
    "When shared show" : "Se condiviso, mostra",
    "When shared show full event" : "Se condiviso, mostra evento completo",
    "When shared show only busy" : "Se condiviso, mostra solo occupato",
    "When shared hide this event" : "Se condiviso, nascondi questo evento",
    "Add a location" : "Aggiungi un luogo",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Aggiungi una descrizione\n\n- Di cosa tratta questa riunione\n- Punti all'ordine del giorno\n- Tutto ciò che i partecipanti devono preparare",
    "Status" : "Stato",
    "Confirmed" : "Confermato",
    "Canceled" : "Annullato",
    "Confirmation about the overall status of the event." : "Conferma sullo stato complessivo dell'evento.",
    "Show as" : "Mostra come",
    "Take this event into account when calculating free-busy information." : "Considera questo evento nel calcolo delle informazioni libero-occupato.",
    "Categories" : "Categorie",
    "Categories help you to structure and organize your events." : "Le categorie ti aiutano a strutturare e organizzare i tuoi eventi.",
    "Search or add categories" : "Cerca o aggiungi categorie",
    "Add this as a new category" : "Aggiungi come una nuova categoria",
    "Custom color" : "Colore personalizzato",
    "Special color of this event. Overrides the calendar-color." : "Colore speciale di questo evento. Ignora il colore del calendario.",
    "Error while sharing file" : "Errore durante la condivisione del file",
    "Error while sharing file with user" : "Errore durante la condivisione del file con l'utente",
    "Attachment {fileName} already exists!" : "L'allegato {fileName} esiste già!",
    "An error occurred during getting file information" : "Si è verificato un errore durante l'ottenimento delle informazioni sul file.",
    "An error occurred, unable to delete the calendar." : "Si è verificato un errore, impossibile eliminare il calendario.",
    "Imported {filename}" : "Importato {filename}",
    "This is an event reminder." : "Questo è un promemoria dell'evento.",
    "Error while parsing a PROPFIND error" : "Errore durante l'elaborazione di un errore PROPFIND",
    "Appointment not found" : "Appuntamento non trovato",
    "User not found" : "Utente non trovato",
    "Hidden" : "Nascosta",
    "can edit" : "può modificare",
    "Calendar name …" : "Nome del calendario...",
    "Default attachments location" : "Posizione predefinita degli allegati",
    "Automatic ({detected})" : "Automatico ({detected})",
    "Shortcut overview" : "Riepilogo delle scorciatoie",
    "CalDAV link copied to clipboard." : "Collegamento CalDAV copiato negli appunti.",
    "CalDAV link could not be copied to clipboard." : "Impossibile copiare collegamento CalDAV negli appunti.",
    "Enable birthday calendar" : "Attiva calendario dei compleanni",
    "Show tasks in calendar" : "Mostra le attività nel calendario",
    "Enable simplified editor" : "Attiva editor semplificato",
    "Limit the number of events displayed in the monthly view" : "Limita il numero di eventi visualizzati nella vista mensile",
    "Show weekends" : "Mostra i fine settimana",
    "Show week numbers" : "Mostra i numeri delle settimane",
    "Time increments" : "Incrementi di tempo",
    "Default calendar for incoming invitations" : "Calendario predefinito per gli inviti in arrivo",
    "Copy primary CalDAV address" : "Copia indirizzo CalDAV principale",
    "Copy iOS/macOS CalDAV address" : "Copia indirizzo CalDAV iOS/macOS",
    "Personal availability settings" : "Impostazioni di disponibilità personale",
    "Show keyboard shortcuts" : "Mostra scorciatoie da tastiera",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} invitato, {confirmedCount} confermato",
    "Successfully appended link to talk room to location." : "Aggiunto correttamente il collegamento alla stanza di Talk alla posizione.",
    "Successfully appended link to talk room to description." : "Collegamento aggiunto correttamente alla stanza di Talk come descrizione.",
    "Error creating Talk room" : "Errore durante la creazione della stanza di Talk",
    "_%n more guest_::_%n more guests_" : ["%n più ospite","%n più ospiti","%n più ospiti"],
    "The visibility of this event in shared calendars." : "La visibilità di questo evento nei calendari condivisi."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
