OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "O enderezo de correo indicado é longo de máis",
    "User-Session unexpectedly expired" : "A sesión de usuario caducou inesperadamente",
    "Provided email-address is not valid" : "O enderezo de correo-e indicado non é válido",
    "%s has published the calendar »%s«" : "%s publicou o calendario «%s»",
    "Unexpected error sending email. Please contact your administrator." : "Produciuse un erro non agardado ao enviar correo. Póñase en contacto coa administración desta instancia.",
    "Successfully sent email to %1$s" : "O correo foi enviado satisfactoriamente %1$s",
    "Hello," : "Ola,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Queremos informarte de que %s publicou o calendario «%s»",
    "Open »%s«" : "Abrir «%s»",
    "Cheers!" : "Saúdos!",
    "Upcoming events" : "Próximos eventos",
    "No more events today" : "Hoxe non hai máis eventos",
    "No upcoming events" : "Non hai eventos próximos",
    "More events" : "Máis eventos",
    "%1$s with %2$s" : "%1$s con %2$s",
    "Calendar" : "Calendario",
    "New booking {booking}" : "Nova reserva {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) reservou a cita «{config_display_name}»o {date_time}.",
    "Appointments" : "Citas",
    "Schedule appointment \"%s\"" : "Programar cita «%s»",
    "Schedule an appointment" : "Programar unha cita",
    "%1$s - %2$s" : "%1$s — %2$s",
    "Prepare for %s" : "Preparar para %s",
    "Follow up for %s" : "Facer un seguimento a %s",
    "Your appointment \"%s\" with %s needs confirmation" : "A súa cita «%s» con %s necesita confirmación",
    "Dear %s, please confirm your booking" : "Estimado %s, agradecémoslle que confirme a súa reserva",
    "Confirm" : "Confirmar",
    "Appointment with:" : "Cita con:",
    "Description:" : "Descrición:",
    "This confirmation link expires in %s hours." : "Esta ligazón de confirmación caduca en %s horas.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Se, após todo,  aínda quere cancelar a cita, póñase en contacto co seu organizador respondendo a este correo ou visitando a súa páxina de perfil.",
    "Your appointment \"%s\" with %s has been accepted" : "Foi aceptada a súa cita «%s» con %s.",
    "Dear %s, your booking has been accepted." : "Estimado %s, a súa reserva foi aceptada.",
    "Appointment for:" : "Cita para:",
    "Date:" : "Data:",
    "You will receive a link with the confirmation email" : "Recibirá unha ligazón co correo de confirmación",
    "Where:" : "Onde:",
    "Comment:" : "Comentario:",
    "You have a new appointment booking \"%s\" from %s" : "Ten unha nova reserva de cita «%s» de %s",
    "Dear %s, %s (%s) booked an appointment with you." : "Estimado %s, %s (%s) reservou unha cita con Vde.",
    "%s has proposed a meeting" : "%s propuxo unha xuntanza",
    "%s has updated a proposed meeting" : "%s actualizou unha xuntanza proposta",
    "%s has canceled a proposed meeting" : "%s cancelou unha xuntanza proposta",
    "Dear %s, a new meeting has been proposed" : "Estimado %s, foi proposta unha nova xuntanza",
    "Dear %s, a proposed meeting has been updated" : "Estimado %s, foi actualizada unha xuntanza proposta",
    "Dear %s, a proposed meeting has been cancelled" : "Estimado %s, foi cancelada unha xuntanza proposta",
    "Location:" : "Lugar:",
    "Duration:" : "Duración:",
    "%1$s from %2$s to %3$s" : "%1$s de %2$s a %3$s",
    "Dates:" : "Datas:",
    "Respond" : "Responder",
    "A Calendar app for Nextcloud" : "Unha aplicación de calendario para Nextcloud",
    "A Calendar app for Nextcloud. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Like Contacts, Talk, Tasks, Deck and Circles\n* 🌐 **WebCal Support!** Want to see your favorite team's matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 **Search!** Find your events at ease\n* ☑️ **Tasks!** See tasks or Deck cards with a due date directly in the calendar\n* 🔈 **Talk rooms!** Create an associated Talk room when booking a meeting with just one click\n* 📆 **Appointment booking** Send people a link so they can book an appointment with you [using this app](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Attachments!** Add, upload and view event attachments\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Unha aplicación de Calendario para Nextcloud. Sincronice eventos doadamente desde varios dispositivos co seu Nextcloud e edíteos en liña.\n\n* 🚀 **Integración con outras aplicación de Nextcloud!** Como Contactos, Parladoiro, Tarefas, Gabeta e Círculos.\n* 🌐 **Compatibilidade con WebCal!** Quere ver os partidos do seu equipo favorito no seu calendario? Non hai problema!\n* 🙋 **Asistentes** Convide á xente aos seus eventos.\n* ⌚️ **Libre/Ocupado:** Verá cando os asistentes están dispoñíbeis\n* ⏰ **Lembretes!** Obteña alarmas para eventos no navegador e por correo-e.\n* 🔍 **Busca!** Atope os seus eventos doadamente\n* ☑️ **Tarefas!** Vexa as tarefas ou tarxetas da Gabeta con data de vencemento directamente no calendario\n* 🔈 **Salas de conversa!** Cree unha sala de conversa asociada ao reservar unha xuntanza cun só clic\n* 📆 **Reserva de citas** Envíe unha ligazón á xente para que poidan reservar unha cita con Vde. [usando esta aplicación](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Anexos!** Engadir, enviar e ver anexos de eventos\n* 🙈 **Non reinventamos a roda!** Baseada nas grandes bibliotecas [davclient.js](https://github.com/evert/davclient.js), [ical.js](https://github.com/mozilla-comm/ical.js) e [fullcalendar](https://github.com/fullcalendar/fullcalendar).",
    "Previous day" : "Día anterior",
    "Previous week" : "Semana anterior",
    "Previous year" : "Ano anterior",
    "Previous month" : "Mes anterior",
    "Next day" : "Día seguinte",
    "Next week" : "Semana seguinte",
    "Next year" : "Ano seguinte",
    "Next month" : "Mes seguinte",
    "Create new event" : "Crear un novo evento",
    "Event" : "Evento",
    "Today" : "Hoxe",
    "Day" : "Día",
    "Week" : "Semana",
    "Month" : "Mes",
    "Year" : "Ano",
    "List" : "Lista",
    "Appointment link was copied to clipboard" : "A ligazón da cita copiouse no portapapeis",
    "Appointment link could not be copied to clipboard" : "Non foi posíbel copiar a ligazón da cita no portapapeis",
    "Preview" : "Vista previa",
    "Copy link" : "Copiar a ligazón",
    "Edit" : "Editar",
    "Delete" : "Eliminar",
    "Appointment schedules" : "Calendarios de citas",
    "Create new" : "Crear novo",
    "Disable calendar \"{calendar}\"" : "Desactivar o calendario «{calendar}»",
    "Disable untitled calendar" : "Desactivar o calendario sen título",
    "Enable calendar \"{calendar}\"" : "Activar o calendario «{calendar}»",
    "Enable untitled calendar" : "Activar o calendario sen título",
    "An error occurred, unable to change visibility of the calendar." : "Produciuse un erro, non é posíbel cambiar a visibilidade do calendario.",
    "Untitled calendar" : "Calendario sen título",
    "Shared with you by" : "Compartido con Vde. por",
    "Edit and share calendar" : "Editar e compartir o calendario",
    "Edit calendar" : "Editar o calendario",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Deixar de compartir o calendario en {countdown} segundo","Deixar de compartir o calendario en {countdown} segundos"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Eliminar o calendario en {countdown} segundo","Eliminar o calendario en {countdown} segundos"],
    "An error occurred, unable to create the calendar." : "Produciuse un erro, non é posíbel crear o calendario.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Introduza unha ligazón correcta (comezando con http://, https://, webcal://, or webcals://)",
    "Calendars" : "Calendarios",
    "Add new" : "Engadir novo",
    "New calendar" : "Novo calendario",
    "Name for new calendar" : "Nome para o novo calendario",
    "Creating calendar …" : "Creando o calendario…",
    "New calendar with task list" : "Novo calendario con lista de tarefas",
    "New subscription from link (read-only)" : "Nova subscrición desde ligazón (só lectura)",
    "Creating subscription …" : "Creando subscrición …",
    "Add public holiday calendar" : "Engadir o calendario de días festivos",
    "Add custom public calendar" : "Engadir un calendario público personalizado",
    "Calendar link copied to clipboard." : "A ligazón do calendario foi copiada no portapapeis.",
    "Calendar link could not be copied to clipboard." : "Non foi posíbel copiar a ligazón do calendario no portapapeis.",
    "Copy subscription link" : "Copiar a ligazón de subscrición",
    "Copying link …" : "Copiando a ligazón…",
    "Copied link" : "Ligazón copiada",
    "Could not copy link" : "Non foi posíbel copiar a ligazón",
    "Export" : "Exportar",
    "Untitled item" : "Elemento sen título",
    "Unknown calendar" : "Calendario descoñecido",
    "Could not load deleted calendars and objects" : "Non foi posíbel cargar os calendarios e obxectos eliminados",
    "Could not delete calendar or event" : "Non foi posíbel eliminar o calendario ou o evento",
    "Could not restore calendar or event" : "Non foi posíbel restaurar o calendario ou o evento",
    "Do you really want to empty the trash bin?" : " Confirma que quere baleirar o lixo?",
    "Empty trash bin" : "Baleirar o lixo",
    "Trash bin" : "Cesto do lixo.",
    "Loading deleted items." : "Cargando elementos eliminados.",
    "You do not have any deleted items." : "Non ten ningún elemento eliminado.",
    "Name" : "Nome",
    "Deleted" : "Eliminada",
    "Restore" : "Restaurar",
    "Delete permanently" : "Eliminar definitivamente",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Os elementos do cesto do lixo elimínanse após {numDays} día","Os elementos do cesto do lixo elimínanse após {numDays} días"],
    "Could not update calendar order." : "Non foi posíbel actualizar a orde do calendario.",
    "Shared calendars" : "Calendarios compartidos",
    "Deck" : "Gabeta",
    "Internal link" : "Ligazón interna",
    "A private link that can be used with external clients" : "Unha ligazón privada que se pode usar con clientes externos",
    "Copy internal link" : "Copiar a ligazón interna",
    "An error occurred, unable to publish calendar." : "Produciuse un erro, non é posíbel publicar o calendario.",
    "An error occurred, unable to send email." : "Produciuse un erro, non é posíbel enviar o correo",
    "Embed code copied to clipboard." : "Código incrustado copiado ao portapapeis.",
    "Embed code could not be copied to clipboard." : "Non foi posíbel copiar o código incrustado no portapapeis.",
    "Unpublishing calendar failed" : "Produciuse un fallo ao deixar de publicar o calendario",
    "Share link" : "Ligazón para compartir",
    "Copy public link" : "Copiar a ligazón pública",
    "Send link to calendar via email" : "Enviar a ligazón ao calendario por correo",
    "Enter one address" : "Introduza un enderezo",
    "Sending email …" : "Enviando o correo…",
    "Copy embedding code" : "Copiar o código incrustado",
    "Copying code …" : "Copiando o código…",
    "Copied code" : "Código copiado",
    "Could not copy code" : "Non foi posíbel copiar o código",
    "Delete share link" : "Eliminar a ligazón para compartir",
    "Deleting share link …" : "Eliminando a ligazón para compartir…",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Equipo)",
    "An error occurred while unsharing the calendar." : "Produciuse un erro ao deixar de compartir o calendario.",
    "An error occurred, unable to change the permission of the share." : "Produciuse un erro, non é posíbel cambiar o permiso da compartición.",
    "can edit and see confidential events" : "pode editar e ver eventos confidenciais",
    "Unshare with {displayName}" : "Deixar de compartir con {displayName}",
    "Share with users or groups" : "Compartir con usuarios ou grupos",
    "No users or groups" : "Non hai usuarios nin grupos",
    "Failed to save calendar name and color" : "Produciuse un fallo ao gardar o nome e a cor do calendario",
    "Calendar name …" : "Nome do calendario…",
    "Never show me as busy (set this calendar to transparent)" : "Non amosarme nunca como ocupado (definir este calendario como transparente)",
    "Share calendar" : "Compartir o calendario",
    "Unshare from me" : "Deixar de compartir comigo",
    "Save" : "Gardar",
    "No title" : "Sen título",
    "Are you sure you want to delete \"{title}\"?" : "Confirma que quere eliminar «{title}»?",
    "Deleting proposal \"{title}\"" : "Eliminando a proposta «{title}»",
    "Successfully deleted proposal" : "A proposta foi eliminada satisfactoriamente",
    "Failed to delete proposal" : "Produciuse un fallo ao eliminar a proposta",
    "Failed to retrieve proposals" : "Produciuse un fallo ao recuperar a proposta",
    "Meeting proposals" : "Propostas de xuntanzas",
    "A configured email address is required to use meeting proposals" : "Precísase do seu enderezo de correo-e para usar as propostas de xuntanzas",
    "No active meeting proposals" : "Non hai propostas de xuntanza activas",
    "View" : "Ver",
    "Import calendars" : "Importar calendarios",
    "Please select a calendar to import into …" : "Seleccione un calendario para importalo a …",
    "Filename" : "Nome de ficheiro",
    "Calendar to import into" : "Calendario ao que importar",
    "Cancel" : "Cancelar",
    "_Import calendar_::_Import calendars_" : ["Importar calendario","Importar calendarios"],
    "Select the default location for attachments" : "Seleccione a localización predeterminada para os anexos",
    "Pick" : "Escoller",
    "Invalid location selected" : "Seleccionou unha localización incorrecta",
    "Attachments folder successfully saved." : "O cartafol de anexos foi gardado correctamente.",
    "Error on saving attachments folder." : "Produciuse un erro ao gardar o cartafol de anexos.",
    "Attachments folder" : "Cartafol de anexos",
    "{filename} could not be parsed" : "Non foi posíbel analizar {filename}",
    "No valid files found, aborting import" : "Non se atopou ningún ficheiro válido, cancelando a importación.",
    "_Successfully imported %n event_::_Successfully imported %n events_" : [" %n evento importado satisfactoriamente","%n eventos importados satisfactoriamente"],
    "Import partially failed. Imported {accepted} out of {total}." : "Fallou parcialmente a importación. Importáronse {accepted} de {total}.",
    "Automatic" : "Automatico",
    "Automatic ({timezone})" : "Automática ({timezone})",
    "New setting was not saved successfully." : "O novo axuste non foi fardado correctamente.",
    "Timezone" : "Fuso horario",
    "Navigation" : "Navegación",
    "Previous period" : "Período anterior",
    "Next period" : "Período seguinte",
    "Views" : "Vistas",
    "Day view" : "Vista do día",
    "Week view" : "Vista da semana",
    "Month view" : "Vista do mes",
    "Year view" : "Vista do ano",
    "List view" : "Ver como lista",
    "Actions" : "Accións",
    "Create event" : "Crear evento",
    "Show shortcuts" : "Amosar atallos",
    "Editor" : "Editor",
    "Close editor" : "Pechar o editor",
    "Save edited event" : "Gardar o evento editado",
    "Delete edited event" : "Eliminar o evento editado",
    "Duplicate event" : "Evento duplicado",
    "or" : "ou",
    "Calendar settings" : "Axustes de Calendario",
    "At event start" : "No inicio do evento",
    "No reminder" : "Non hai lembretes",
    "Failed to save default calendar" : "Produciuse un fallo ao gardar o calendario predeterminado",
    "General" : "Xeral",
    "Availability settings" : "Axustes de dispoñibilidade",
    "CalDAV" : "CalDAV",
    "Access Nextcloud calendars from other apps and devices" : "Acceder aos calendarios de Nextcloud desde outras aplicacións e dispositivos",
    "CalDAV URL" : "URL de CalDAV",
    "Server Address for iOS and macOS" : "Enderezo do servidor para iOS e macOS",
    "Appearance" : "Aparencia",
    "Birthday calendar" : "Calendario de aniversarios",
    "Tasks in calendar" : "Tarefas no calendario",
    "Weekends" : "Fins de semana",
    "Week numbers" : "Números da semana",
    "Limit number of events shown in Month view" : "Limitar o número de eventos que se amosan na vista mensual",
    "Density in Day and Week View" : "Densidade en vista diaria e semanal",
    "Editing" : "Editando",
    "Default reminder" : "Lembrete predeterminado",
    "Simple event editor" : "Editor de eventos sinxelo",
    "\"More details\" opens the detailed editor" : "«Máis detalles» abre o editor detallado",
    "Files" : "Ficheiros",
    "Appointment schedule successfully created" : "O calendario de citas foi creado correctamente",
    "Appointment schedule successfully updated" : "O calendario de citas foi actualizado correctamente",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minuto","{duration} minutos"],
    "0 minutes" : "0 minutos",
    "_{duration} hour_::_{duration} hours_" : ["{duration} hora","{duration} horas"],
    "_{duration} day_::_{duration} days_" : ["{duration} día","{duration} días"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} semana","{duration} semanas"],
    "_{duration} month_::_{duration} months_" : ["{duration} mes","{duration} meses"],
    "_{duration} year_::_{duration} years_" : ["{duration} ano","{duration} anos"],
    "To configure appointments, add your email address in personal settings." : "Para configurar citas, engada o seu enderezo de correo nos axustes persoais.",
    "Public – shown on the profile page" : "Público – amosase na páxina do perfil",
    "Private – only accessible via secret link" : "Privado – accesíbel só mediante unha ligazón secreta",
    "Appointment schedule saved" : "Gardouse o calendario de citas",
    "Create appointment schedule" : "Crear o calendario de citas",
    "Edit appointment schedule" : "Editar o calendario de citas",
    "Update" : "Actualizar",
    "Appointment name" : "Nome da cita",
    "Location" : "Localización",
    "Create a Talk room" : "Crear unha sala de Parladoiro",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Xerarase unha ligazón única para cada cita reservada e enviarase a través do correo de confirmación",
    "Description" : "Descrición",
    "Visibility" : "Visibilidade",
    "Duration" : "Duración",
    "Increments" : "Incrementos",
    "Additional calendars to check for conflicts" : "Calendarios adicionais para comprobar se hai conflitos",
    "Pick time ranges where appointments are allowed" : "Escolla intervalos de tempo nos que se permiten citas",
    "to" : "para",
    "Delete slot" : "Eliminar franxa horaria",
    "No times set" : "Non hai horarios fixados",
    "Add" : "Engadir",
    "Monday" : "luns",
    "Tuesday" : "martes",
    "Wednesday" : "mércores",
    "Thursday" : "xoves",
    "Friday" : "venres",
    "Saturday" : "sábado",
    "Sunday" : "domingo",
    "Weekdays" : "Días laborábeis",
    "Add time before and after the event" : "Engadir tempo antes e após o evento",
    "Before the event" : "Antes do evento",
    "After the event" : "Após o evento",
    "Planning restrictions" : "Restricións de planificación",
    "Minimum time before next available slot" : "Tempo mínimo antes da seguinte franxa horaria dispoñíbel",
    "Max slots per day" : "Máximo de franxas horarias por día",
    "Limit how far in the future appointments can be booked" : "Limita ata onde se poden reservar citas futuras",
    "It seems a rate limit has been reached. Please try again later." : "Semella que se acadou o límite da taxa. Tenteo de novo máis tarde.",
    "Please confirm your reservation" : "Confirme a súa reserva",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Témoslle enviado un correo cos detalles. Confirme a súa cita usando a ligazón do correo. Xa pode pechar esta páxina agora.",
    "Your name" : "O seu nome",
    "Your email address" : "O seu enderezo de correo",
    "Please share anything that will help prepare for our meeting" : "Comparta calquera cousa que axude a preparar a nosa xuntanza",
    "Could not book the appointment. Please try again later or contact the organizer." : "Non foi posíbel reservar a cita. Ténteo de novo máis tarde ou póñase en contacto co organizador.",
    "Back" : "Atras",
    "Book appointment" : "Concertar cita",
    "Error fetching Talk conversations." : "Produciuse un erro ao recuperar as conversas en Parladoiro",
    "Conversation does not have a valid URL." : "A conversa non ten un URL válido.",
    "Successfully added Talk conversation link to location." : "Engadiuse correctamente a ligazón da conversa en Parladoiro á localización.",
    "Successfully added Talk conversation link to description." : "Engadiuse correctamente a ligazón da conversa en Parladoiro á descrición.",
    "Failed to apply Talk room." : "Produciuse un fallo ao aplicar a sala de Parladoiro",
    "Talk conversation for event" : "Conversa en Parladoiro para o evento",
    "Error creating Talk conversation" : "Produciuse un erro ao crear a conversa en Parladoiro",
    "Select a Talk Room" : "Seleccionar unha sala de Parladoiro",
    "Add Talk conversation" : "Engadir unha conversa de Parladoiro",
    "Fetching Talk rooms…" : "Recuperando salas de Parladoiro…",
    "No Talk room available" : "Non hai ningunha sala de Parladoiro dispoñíbel",
    "Create public conversation" : "Crear unha conversa pública",
    "Select conversation" : "Seleccionar conversa",
    "on" : "o",
    "at" : "ás",
    "before at" : "antes dás",
    "Notification" : "Notificación",
    "Email" : "Correo-e",
    "Audio notification" : "Notificación de son",
    "Other notification" : "Outra notificación",
    "Relative to event" : "Relativo ao evento",
    "On date" : "Na data",
    "Edit time" : "Editar a hora",
    "Save time" : "Gardar a hora",
    "Remove reminder" : "Retirar o lembrete",
    "Add reminder" : "Engadir lembrete",
    "seconds" : "segundos",
    "minutes" : "minutos",
    "hours" : "horas",
    "days" : "días",
    "weeks" : "semanas",
    "Choose a file to add as attachment" : "Escoller un ficheiro para engadir como anexo",
    "Choose a file to share as a link" : "Escoller un ficheiro para compartir como ligazón",
    "Attachment {name} already exist!" : "O anexo {name} xa existe!",
    "Could not upload attachment(s)" : "Non foi posíbel enviar os anexos",
    "You are about to navigate to {link}. Are you sure to proceed?" : "Está a piques de navegar a {link}. Confirma que quere continuar? ",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Está a piques de navegar a {host}. Confirma que quere continuar? Ligazón: {link}",
    "Proceed" : "Continuar",
    "No attachments" : "Sen anexos",
    "Add from Files" : "Engadir desde Ficheiros",
    "Upload from device" : "Enviar desde o dispositivo",
    "Delete file" : "Eliminar ficheiro",
    "Confirmation" : "Confirmación",
    "_{count} attachment_::_{count} attachments_" : ["{count} anexo","{count} anexos"],
    "Suggested" : "Suxerido",
    "Available" : "Dispoñíbel",
    "Invitation accepted" : "Aceptouse o convite",
    "Accepted {organizerName}'s invitation" : "Aceptouse o convite de {organizerName}",
    "Participation marked as tentative" : "Participación marcada como provisional",
    "Invitation is delegated" : "O convite está delegado",
    "Not available" : "Non dispoñíbel",
    "Invitation declined" : "Convite declinado",
    "Declined {organizerName}'s invitation" : "Declinouse o convite de {organizerName}",
    "Availability will be checked" : "Verificarase a dispoñibilidade",
    "Invitation will be sent" : "Enviarase un convite",
    "Failed to check availability" : "Produciuse un erro ao verificar a dispoñibilidade",
    "Failed to deliver invitation" : "Produciuse un fallo ao entregar o convite.",
    "Awaiting response" : "Agardando a resposta",
    "Checking availability" : "Comprobando a dispoñibilidade",
    "Has not responded to {organizerName}'s invitation yet" : "Aínda non respondeu ao convite de {organizerName}",
    "Suggested times" : "Horarios suxeridos",
    "chairperson" : "presidente",
    "required participant" : "precísase do participante",
    "non-participant" : "non participa",
    "optional participant" : "participante opcional",
    "{organizer} (organizer)" : "{organizer} (organizador)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Selected slot" : "Franxa horaria seleccionada",
    "Availability of attendees, resources and rooms" : "Dispoñibilidade de asistentes, recursos e salas",
    "Suggestion accepted" : "Aceptouse a suxestión",
    "Previous date" : "Data anterior",
    "Next date" : "Data seguinte",
    "Legend" : "Lenda",
    "Out of office" : "Fóra da oficina",
    "Attendees:" : "Asistentes:",
    "local time" : "hora local",
    "Done" : "Feito",
    "Search room" : "Buscar sala",
    "Room name" : "Nome da sala",
    "Check room availability" : "Comprobar a dispoñibilidade de salas",
    "Free" : "Libre",
    "Busy (tentative)" : "Ocupado (provisional)",
    "Busy" : "Ocupado",
    "Unknown" : "Descoñecido",
    "Find a time" : "Atopar un momento",
    "The invitation has been accepted successfully." : "O convite foi aceptado correctamente.",
    "Failed to accept the invitation." : "Produciuse un fallo ao aceptar o convite.",
    "The invitation has been declined successfully." : "O convite foi declinado correctamente.",
    "Failed to decline the invitation." : "Produciuse un fallo ao declinar o convite.",
    "Your participation has been marked as tentative." : "A súa participación foi marcada como provisional.",
    "Failed to set the participation status to tentative." : "Produciuse un fallo ao definir o estado de participación como provisional.",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "Tentative" : "Provisional",
    "No attendees yet" : "Aínda non hai participantes",
    "{confirmedCount} confirmed, {waitingCount} awaiting response" : "{confirmedCount} confirmados, agardando a resposta de {waitingCount}",
    "Please add at least one attendee to use the \"Find a time\" feature." : "Engada polo menos un asistente para usar a funcionalidade «Atopar unha hora».",
    "Attendees" : "Asistentes",
    "_%n more attendee_::_%n more attendees_" : ["%n asistente máis","%n asistentes máis"],
    "Remove group" : "Retirar o grupo",
    "Remove attendee" : "Retirar o asistente",
    "Request reply" : "Solicitar resposta",
    "Chairperson" : "Presidente",
    "Required participant" : "Precísase do participante",
    "Optional participant" : "Participante opcional",
    "Non-participant" : "Non participa",
    "_%n member_::_%n members_" : ["%n membro","%n membros"],
    "Search for emails, users, contacts, contact groups or teams" : "Buscar por correos, usuarios, contactos, grupos ou equipos",
    "No match found" : "Non se atopou ningunha coincidencia",
    "Note that members of circles get invited but are not synced yet." : "Teña en conta que os membros dos círculos son convidados mais aínda non se sincronizan.",
    "Note that members of contact groups get invited but are not synced yet." : "Teña en conta que os membros dos grupos de contacto son convidados mais aínda non se sincronizan.",
    "(organizer)" : "(organizador)",
    "Make {label} the organizer" : "Converter a {label} en organizador",
    "Make {label} the organizer and attend" : "Converter a {label} en organizador e participante",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Para enviar convites e xestionar respostas, [linkopen]engada o seu enderezo de correo nos axustes persoais[linkclose].",
    "Remove color" : "Retirar a cor",
    "Event title" : "Título do evento",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Non é posíbel modificar a configuración de todo o día para eventos que forman parte dun conxunto de recorrencia.",
    "From" : "Desde",
    "To" : "Ata",
    "Your Time" : "A súa hora",
    "Repeat" : "Repetir",
    "Repeat event" : "Repetir o evento",
    "_time_::_times_" : ["vez","veces"],
    "never" : "nunca",
    "on date" : "na data",
    "after" : "após",
    "End repeat" : "Fin da repetición",
    "Select to end repeat" : "Seleccionar para finalizar a repetición",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Este evento é a excepción de recorrencia dun conxunto de recorrencia. Non pode engadirlle unha regra de recorrencia.",
    "first" : "primeiro",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Os cambios na regra de recorrencia só se aplicarán a esta e a todas as futuras recorrencias.",
    "Repeat every" : "Repetir cada",
    "By day of the month" : "Polo día do mes",
    "On the" : "O",
    "_day_::_days_" : ["día","días"],
    "_week_::_weeks_" : ["semana","semanas"],
    "_month_::_months_" : ["mes","meses"],
    "_year_::_years_" : ["ano","anos"],
    "On specific day" : "Nun día específico",
    "weekday" : "días laborábeis",
    "weekend day" : "días da fin de semana",
    "Does not repeat" : "Non repetir",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Nextcloud non é totalmente compatíbel coa definición de recorrencia deste evento. Se edita as opcións de recorrencia, pódense perder certas recorrencias.",
    "No rooms or resources yet" : "Aínda non hai nin salas nin recursos",
    "Resources" : "Recursos",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} asento","{seatingCapacity} asentos"],
    "Add resource" : "Engadir recurso",
    "Has a projector" : "Ten un proxector",
    "Has a whiteboard" : "Ten un encerado dixital",
    "Wheelchair accessible" : "Accesíbel para cadeiras de rodas",
    "Remove resource" : "Retirar o recurso",
    "Search for resources or rooms" : "Buscar por recursos ou aulas",
    "available" : "dispoñíbel",
    "unavailable" : "non dispoñíbel",
    "Show all rooms" : "Amosar todas as salas",
    "Projector" : "Proxector",
    "Whiteboard" : "Encerado dixital",
    "Room type" : "Tipo de sala",
    "Any" : "Calquera",
    "Minimum seating capacity" : "Capacidade mínima de asentos",
    "More details" : "Máis detalles",
    "Update this and all future" : "Actualizar esta e todas as futuras",
    "Update this occurrence" : "Actualizar esta recorrencia",
    "Public calendar does not exist" : "O calendario público non existe",
    "Maybe the share was deleted or has expired?" : "Quizais a acción foi eliminada ou caducou.",
    "Remove date" : "Retirar a data",
    "Attendance required" : "A asistencia é necesaria",
    "Attendance optional" : "A asistencia é opcional",
    "Remove participant" : "Retirar participante",
    "Yes" : "Si",
    "No" : "Non",
    "Maybe" : "Quizais",
    "None" : "Ningún",
    "Select your meeting availability" : "Seleccione a dispoñibilidade da súa xuntanza",
    "Create a meeting for this date and time" : "Crear unha xuntanza para esta data e hora",
    "Create" : "Crear",
    "No participants or dates available" : "Non hai participantes nin datas dispoñíbeis",
    "from {formattedDate}" : "desde {formattedDate}",
    "to {formattedDate}" : "ata {formattedDate}",
    "on {formattedDate}" : "o {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "desde {formattedDate} ás {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "ata {formattedDate} ás {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "o {formattedDate} ás {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} ás {formattedTime}",
    "Please enter a valid date" : "Introduza unha data válida",
    "Please enter a valid date and time" : "Introduza unha data e hora válidas",
    "Select a time zone" : "Seleccione un fuso horario",
    "Please select a time zone:" : "Seleccione un fuso horario:",
    "Pick a time" : "Escolla un momento",
    "Pick a date" : "Escolla unha data",
    "Type to search time zone" : "Escriba para buscar o fuso horario",
    "Global" : "Global",
    "Holidays in {region}" : "Festivos en {region}",
    "An error occurred, unable to read public calendars." : "Produciuse un erro, non é posíbel ler os calendarios públicos.",
    "An error occurred, unable to subscribe to calendar." : "Produciuse un erro, non é posíbel subscribirse ao calendario.",
    "Public holiday calendars" : "Calendarios de festivos",
    "Public calendars" : "Calendarios públicos",
    "No valid public calendars configured" : "Non se configurou ningún calendario público válido",
    "Speak to the server administrator to resolve this issue." : "Fale coa administración do servidor para resolver este incidente.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Os calendarios de festivos son fornecidos porThunderbird . Os datos do calendario descargaranse de {website}",
    "These public calendars are suggested by the server administrator. Calendar data will be downloaded from the respective website." : "Estes calendarios públicos son suxeridos pola administración do servidor. Os datos do calendario descargaranse do sitio web correspondente.",
    "By {authors}" : "Por {authors}",
    "Subscribed" : "Subscrito",
    "Subscribe" : "Subscribirse",
    "Could not fetch slots" : "Non foi posíbel recuperar as franxas horarias",
    "Select a date" : "Seleccione unha data",
    "Select slot" : "Seleccionar franxa horaria",
    "No slots available" : "Non hai franxas horarias dispoñíbeis",
    "The slot for your appointment has been confirmed" : "Confirmouse a franxa horaria para a súa cita",
    "Appointment Details:" : "Detalles da cita:",
    "Time:" : "Hora:",
    "Booked for:" : "Reservada por:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Grazas. Confirmouse a súa reserva do {startDate} ao {endDate}.",
    "Book another appointment:" : "Reserve outra cita:",
    "See all available slots" : "Ver todas as franxas horarias dispoñíbeis",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "A franxa horaria para a súa cita de {startDate} a {endDate} xa non está dispoñíbel.",
    "Please book a different slot:" : "Reserve unha franxa horaria diferente:",
    "Book an appointment with {name}" : "Reserve unha cita con {name}",
    "No public appointments found for {name}" : "Non se atopou ningunha cita pública para {name}",
    "Personal" : "Persoal",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "A detección automática do fuso horario determinou que o seu fuso horario fose UTC.\nIsto probabelmente sexa o resultado das medidas de seguranza do seu navegador web.\nEstabeleza o seu fuso horario manualmente nos axustes do calendario.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Non se atopou o seu fuso horario configurado ({timezoneId}). Volvendo a UTC.\nCambie o seu fuso horario nos axustes e informe deste incidente.",
    "Show unscheduled tasks" : "Amosar as tarefas non programadas",
    "Unscheduled tasks" : "Tarefas non programadas",
    "Availability of {displayName}" : "Dispoñibilidade de {displayName}",
    "Discard event" : "Desbotar o evento",
    "Edit event" : "Editar o evento",
    "Event does not exist" : "O evento non existe",
    "Duplicate" : "Duplicado",
    "Delete this occurrence" : "Eliminar esta recorrencia",
    "Delete this and all future" : "Eliminar esta e todas as futuras",
    "All day" : "Todo o día",
    "Modifications wont get propagated to the organizer and other attendees" : "As modificacións non van ser propagadas ao organizador e a outros asistentes",
    "Managing shared access" : "Xestionar o acceso compartido",
    "Deny access" : "Denegar o acceso",
    "Invite" : "Convidar",
    "Discard changes?" : "Desbotar os cambios?",
    "Are you sure you want to discard the changes made to this event?" : "Confirma que quere desbotar os cambios feitos neste evento?",
    "_User requires access to your file_::_Users require access to your file_" : ["O usuario precisa acceso ao seu ficheiro","Os usuarios precisan acceso ao seu ficheiro"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["O anexo precisa acceso compartido","Anexos que precisan acceso compartido"],
    "Untitled event" : "Evento sen título",
    "Close" : "Pechar",
    "Modifications will not get propagated to the organizer and other attendees" : "As modificacións non van ser propagadas ao organizador e a outros asistentes",
    "Meeting proposals overview" : "Vista xeral das propostas de xuntanza",
    "Edit meeting proposal" : "Editar a proposta de xuntanza",
    "Create meeting proposal" : "Crear unha proposta de xuntanza",
    "Update meeting proposal" : "Actualización da proposta de xuntanza",
    "Saving proposal \"{title}\"" : "Gardando a proposta «{title}»",
    "Successfully saved proposal" : "A proposta foi gardada satisfactoriamente",
    "Failed to save proposal" : "Produciuse un fallo ao gardar a proposta",
    "Create a meeting for \"{date}\"? This will create a calendar event with all participants." : "Crear unha xuntanza para o «{date}»? Isto creará un evento de calendario con todos os participantes.",
    "Creating meeting for {date}" : "Crear unha xuntanza para o {date}",
    "Successfully created meeting for {date}" : "Creouse satisfactoriamente unha xuntanza para o {date}",
    "Failed to create a meeting for {date}" : "Produciuse un fallo ao crear unha xuntanza para o {date}",
    "Please enter a valid duration in minutes." : "Introduza unha duración válida en minutos.",
    "Failed to fetch proposals" : "Produciuse un fallo ao recuperar as propostas",
    "Failed to fetch free/busy data" : "Produciuse un fallo ao recuperar os datos de libre/ocupado",
    "Selected" : "Seleccionado",
    "No Description" : "Sen descrición",
    "No Location" : "Sen localización",
    "Edit this meeting proposal" : "Editar esta proposta de xuntanza",
    "Delete this meeting proposal" : "Eliminar esta proposta de xuntanza",
    "Title" : "Titulo",
    "15 min" : "15 min",
    "30 min" : "30 min",
    "60 min" : "60 min",
    "90 min" : "90 min",
    "Participants" : "Participantes",
    "Selected times" : "Horarios seleccionados",
    "Previous span" : "Intervalo anterior",
    "Next span" : "Seguinte intervalo",
    "Less days" : "Menos días",
    "More days" : "Máis días",
    "Loading meeting proposal" : "Cargando a proposta de xuntanza",
    "No meeting proposal found" : "Non se atopou ningunha proposta de xuntanza",
    "Please wait while we load the meeting proposal." : "Agarde mentres cargamos a proposta de xuntanza.",
    "The link you followed may be broken, or the meeting proposal may no longer exist." : "É probábel que a ligazón que seguiu estea rachada ou que a proposta de xuntanza xa non exista.",
    "Thank you for your response!" : "Grazas pola súa resposta!",
    "Your vote has been recorded. Thank you for participating!" : "O seu voto quedou rexistrado. Grazas por participar!",
    "Unknown User" : "Usuario descoñecido",
    "No Title" : "Sen título",
    "No Duration" : "Sen duración",
    "Select a different time zone" : "Seleccione un fuso horario diferente",
    "Submit" : "Enviar",
    "Subscribe to {name}" : "Subscribirse a {name}",
    "Export {name}" : "Exportar {name}",
    "Show availability" : "Amosar a dispoñibilidade",
    "Anniversary" : "Aniversario",
    "Appointment" : "Cita",
    "Business" : "Negocios",
    "Education" : "Educación",
    "Holiday" : "Día festivo",
    "Meeting" : "Xuntanza",
    "Miscellaneous" : "Miscelánea",
    "Non-working hours" : "Horas non laborábeis",
    "Not in office" : "Fóra da oficina",
    "Phone call" : "Chamada telefónica",
    "Sick day" : "Día de enfermidade",
    "Special occasion" : "Ocasión especial",
    "Travel" : "Viaxe",
    "Vacation" : "Vacacións",
    "Midnight on the day the event starts" : "Media noite do día que comeza o evento",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n día antes do evento ás {formattedHourMinute}","%n días antes do evento ás {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n semana antes do evento ás {formattedHourMinute}","%n semanas antes do evento ás {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "o día do evento ás {formattedHourMinute}",
    "at the event's start" : "no inicio do evento",
    "at the event's end" : "no remate do evento",
    "{time} before the event starts" : "{time} antes do inicio do evento",
    "{time} before the event ends" : "{time} antes do remate do evento",
    "{time} after the event starts" : "{time} após o inicio do evento",
    "{time} after the event ends" : "{time} após que remate o evento",
    "on {time}" : "ás {time}",
    "on {time} ({timezoneId})" : "ás {time} ({timezoneId})",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Daily" : "A diario",
    "Weekly" : "Cada semana",
    "Monthly" : "Cada mes",
    "Yearly" : "Cada ano",
    "_Every %n day_::_Every %n days_" : ["Todos os días","Cada %n días"],
    "_Every %n week_::_Every %n weeks_" : ["Cada semana","Cada %n semanas"],
    "_Every %n month_::_Every %n months_" : ["Cada mes","Cada %n meses"],
    "_Every %n year_::_Every %n years_" : ["Cada ano","Cada %n anos"],
    "_on {weekday}_::_on {weekdays}_" : ["o {weekday}","os {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["o día {dayOfMonthList}","os días {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "o {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {dayOfMonthList}" : "o {dayOfMonthList} de {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "o {ordinalNumber} {byDaySet} de {monthNames}",
    "until {untilDate}" : "ata {untilDate}",
    "_%n time_::_%n times_" : ["%n vez","%n veces"],
    "second" : "segundo",
    "third" : "terceiro",
    "fourth" : "cuarto",
    "fifth" : "quinto",
    "second to last" : "penúltimo",
    "last" : "último",
    "Untitled task" : "Tarefa sen título",
    "Please ask your administrator to enable the Tasks App." : "Pregúntelle a administración desta instancia pola activación da aplicación de tarefas.",
    "You are not allowed to edit this event as an attendee." : "Vde. non ten permiso para editar este evento como asistente.",
    "W" : "S",
    "%n more" : "%n máis",
    "No events to display" : "Non hai eventos para amosar",
    "All participants declined" : "Todos os participantes declinaron",
    "Please confirm your participation" : "Agradecémoslle que confirme a súa participación",
    "You declined this event" : "Vde. declinou este evento",
    "Your participation is tentative" : "A súa participación é provisional.",
    "_+%n more_::_+%n more_" : ["+%n máis","+%n máis"],
    "No events" : "Non hai eventos",
    "Create a new event or change the visible time-range" : "Crear un novo evento ou cambiar o intervalo de tempo visíbel",
    "Failed to save event" : "Produciuse un fallo ao gardar o evento",
    "It might have been deleted, or there was a typo in a link" : "Pode que fose eliminado ou houbese un erro de dixitación nunha ligazón",
    "It might have been deleted, or there was a typo in the link" : "Pode que fose eliminado ou houbese un erro de dixitación na ligazón",
    "Meeting room" : "Sala de xuntanzas",
    "Lecture hall" : "Sala de conferencias",
    "Seminar room" : "Sala de seminarios",
    "Other" : "Outra",
    "When shared show" : "Amosar ao compartir",
    "When shared show full event" : "Amosar o evento completo ao compartir",
    "When shared show only busy" : "Amosar só o ocupado ao compartir",
    "When shared hide this event" : "Agochar este evento ao compartir",
    "The visibility of this event in read-only shared calendars." : "A visibilidade deste evento en calendarios compartidos de só lectura.",
    "Add a location" : "Engadir unha localización",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Engadir unha descrición\n\n- De que trata esta xuntanza\n- Puntos da orde do día\n- Todo o que teñan que preparar os participantes",
    "Status" : "Estado",
    "Confirmed" : "Confirmado",
    "Canceled" : "Cancelada",
    "Confirmation about the overall status of the event." : "Confirmación sobre o estado xeral do evento.",
    "Show as" : "Amosar como",
    "Take this event into account when calculating free-busy information." : "Teña en conta este evento ao calcular a información da ocupación.",
    "Categories" : "Categorías",
    "Categories help you to structure and organize your events." : "As categorías axudan a estruturar e organizar os seus eventos.",
    "Search or add categories" : "Buscar ou engadir categorías",
    "Add this as a new category" : "Engadir isto como unha nova categoría",
    "Custom color" : "Cor personalizada",
    "Special color of this event. Overrides the calendar-color." : "Cor especial deste evento. Anula a cor do calendario.",
    "Error while sharing file" : "Produciuse un erro ao compartir o ficheiro",
    "Error while sharing file with user" : "Produciuse un erro ao compartir o ficheiro co usuario",
    "Error creating a folder {folder}" : "Produciuse un erro ao crear o cartafol {folder}",
    "Attachment {fileName} already exists!" : "O anexo {fileName} xa existe!",
    "Attachment {fileName} added!" : "Engadiuse {fileName} como anexo!",
    "An error occurred during uploading file {fileName}" : "Produciuse un erro ao enviar o ficheiro {fileName}",
    "An error occurred during getting file information" : "Produciuse un erro ao obter a información do ficheiro",
    "Talk conversation for proposal" : "Conversa en Parladoiro para a proposta",
    "An error occurred, unable to delete the calendar." : "Produciuse un erro, non é posíbel eliminar o calendario.",
    "Imported {filename}" : "{filename} foi importado",
    "This is an event reminder." : "Este é un lembrete de eventos.",
    "Error while parsing a PROPFIND error" : "Produciuse un erro ao analizar un erro PROPFIND",
    "Appointment not found" : "Non se atopou a cita",
    "User not found" : "Non se atopou o usuario",
    "Hidden" : "Agochada",
    "can edit" : "pode editar",
    "Calendar name …" : "Nome do calendario…",
    "Default attachments location" : "Localización predeterminada dos anexos",
    "Automatic ({detected})" : "Automático ({detected})",
    "Shortcut overview" : "Vista xeral dos atallos",
    "CalDAV link copied to clipboard." : "Copiada a ligazón CalDAV ao portapapeis.",
    "CalDAV link could not be copied to clipboard." : "Non foi posíbel copiar a ligazón CalDAV ao portapapeis.",
    "Enable birthday calendar" : "Activar o calendario de aniversarios",
    "Show tasks in calendar" : "Amosar as tarefas no calendario",
    "Enable simplified editor" : "Activar o editor simplificado",
    "Limit the number of events displayed in the monthly view" : "Limite o número de eventos que se amosan na vista mensual",
    "Show weekends" : "Amosar os fins de semana",
    "Show week numbers" : "Amosar o número de semana",
    "Time increments" : "Incrementos de tempo",
    "Default calendar for incoming invitations" : "Calendario predeterminado para os convites entrantes",
    "Copy primary CalDAV address" : "Copiar o enderezo principal do CalDAV",
    "Copy iOS/macOS CalDAV address" : "Copiar o enderezo CalDAV de iOS/macOS",
    "Personal availability settings" : "Configuración persoal de dispoñibilidade",
    "Show keyboard shortcuts" : "Amosar os atallos de teclado",
    "Create a new public conversation" : "Crear unha nova conversa pública",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} convites, {confirmedCount} confirmados",
    "Successfully appended link to talk room to location." : "Engadiuse satisfactoriamente a ligazón á localización da sala de conversa.",
    "Successfully appended link to talk room to description." : "Engadiuse satisfactoriamente unha ligazón á descrición da  sala de conversa.",
    "Error creating Talk room" : "Produciuse un erro ao crear a sala de Parladoiro",
    "_%n more guest_::_%n more guests_" : ["%n  convidado máis","%n convidados máis"],
    "The visibility of this event in shared calendars." : "A visibilidade deste evento nos calendarios compartidos."
},
"nplurals=2; plural=(n != 1);");
