OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Надана адреса ел. пошти задовга",
    "User-Session unexpectedly expired" : "Термін дії сесії користувача несподівано завершився",
    "Provided email-address is not valid" : "Надано некоректну адресу електронної пошти ",
    "%s has published the calendar »%s«" : "%s опублікував календар \"%s\"",
    "Unexpected error sending email. Please contact your administrator." : "Виникла несподівана помилка під час надсилання електронного повідомлення. Будь ласка повідомте адміністратора.",
    "Successfully sent email to %1$s" : "Успішно надіслано лист на адресу %1$s",
    "Hello," : "Вітаємо,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Дозвольте повідомити вас, що%s опублікував календар \"%s\".",
    "Open »%s«" : "Відкрити \"%s\"",
    "Cheers!" : "Щасти!",
    "Upcoming events" : "Майбутні події",
    "No more events today" : "Подій на сьогодні не заплановано",
    "No upcoming events" : "Відсутні майбутні події",
    "More events" : "Більше подій",
    "%1$s with %2$s" : "%1$s з %2$s",
    "Calendar" : "Календар",
    "New booking {booking}" : "Нове резервування {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) запросив вас на зустріч \"{config_display_name}\", яка відбудеться {date_time}.",
    "Appointments" : "Зустрічі",
    "Schedule appointment \"%s\"" : "Запланувати зустріч \"%s\"",
    "Schedule an appointment" : "Запланувати зустріч",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : "Підготуватися до %s",
    "Follow up for %s" : "Слідкувати за %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Вашу зустріч \"%s\" з %s потрібно підтвердити",
    "Dear %s, please confirm your booking" : "Шановний(а) %s, будь ласка, підтвердіть ваше резервування",
    "Confirm" : "Підтвердити",
    "Appointment with:" : "Зустріч з:",
    "Description:" : "Опис:",
    "This confirmation link expires in %s hours." : "Термін дії посилання для підтвердженння спливає за %sгодин.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Якщо ви все ж бажаєте скасувати зустріч, будь ласка, сконтактуйте з організатором зустрічі, для цього надішліть відповідь на цей лист або відвідайте сторінку профілю.",
    "Your appointment \"%s\" with %s has been accepted" : "Вашу зустріч \"%s\" з %s було прийнято.",
    "Dear %s, your booking has been accepted." : "Шановний(а) %s, ваше резервування було прийнято.",
    "Appointment for:" : "Запрошення на зустріч для:",
    "Date:" : "Дата:",
    "You will receive a link with the confirmation email" : "Ви отримаєте посилання з підтвердженням на електронну пошту",
    "Where:" : "Місце:",
    "Comment:" : "Коментар:",
    "You have a new appointment booking \"%s\" from %s" : "%s надіслав вам запрошення на зустріч \"%s\"",
    "Dear %s, %s (%s) booked an appointment with you." : "Шановний(-а) %s! %s (%s) запросив вас на зустріч.",
    "%s has proposed a meeting" : "%s запросив(-ла) вас на зустріч",
    "%s has updated a proposed meeting" : "%s оновив(-ла) запропоновану зустріч",
    "%s has canceled a proposed meeting" : "%s скасував(-ла) запропоновану зустріч",
    "Dear %s, a new meeting has been proposed" : "Шановний(-а) %s, запрошуємо вас взяти участь у зустрічі",
    "Dear %s, a proposed meeting has been updated" : "Шановний(-а) %s, запропоновану зустріч було оновлено",
    "Dear %s, a proposed meeting has been cancelled" : "Шановний(-а) %s, запропоновану зустріч було скасовано",
    "Location:" : "Місцевість:",
    "Duration:" : "Тривалість:",
    "%1$s from %2$s to %3$s" : "%1$s з %2$s до %3$s",
    "Dates:" : "Дати:",
    "Respond" : "Відповісти",
    "A Calendar app for Nextcloud" : "Застосунок \"Календар\" для Nextcloud",
    "A Calendar app for Nextcloud. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Like Contacts, Talk, Tasks, Deck and Circles\n* 🌐 **WebCal Support!** Want to see your favorite team's matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 **Search!** Find your events at ease\n* ☑️ **Tasks!** See tasks or Deck cards with a due date directly in the calendar\n* 🔈 **Talk rooms!** Create an associated Talk room when booking a meeting with just one click\n* 📆 **Appointment booking** Send people a link so they can book an appointment with you [using this app](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Attachments!** Add, upload and view event attachments\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Календар для Nextcloud. Легко синхронізуйте події з різних пристроїв з вашим Nextcloud і редагуйте їх онлайн.\n\n* 🚀 **Інтеграція з іншими додатками Nextcloud!** Наприклад, Контакти, Чат, Завдання, Deck і Circles\n* 🌐 **Підтримка WebCal!** Хочете бачити дні матчів улюбленої команди у своєму календарі? Без проблем!\n* 🙋 **Учасники!** Запрошуйте людей на свої події\n* ⌚ **Вільний/Зайнятий!** Дивіться, коли ваші учасники можуть зустрітися\n* ⏰ **Нагадування!** Отримуйте сповіщення про події у своєму браузері та електронною поштою\n* 🔍 **Пошук!** Легко знаходьте свої події\n* ☑️ **Завдання!** Переглядайте завдання або картки Deck із терміном виконання безпосередньо в календарі\n* 🔈 **Чат-кімнати!** Створіть пов'язану чат-кімнату під час бронювання зустрічі одним кліком\n* 📆 **Бронювання зустрічей** Надішліть людям посилання, щоб вони могли забронювати зустріч з вами [за допомогою цього додатка](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Вкладення!** Додавайте, завантажуйте та переглядайте вкладення до подій\n* 🙈 **Ми не винаходимо велосипед!** На основі чудових бібліотек [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) та [fullcalendar](https://github.com/fullcalendar/fullcalendar).",
    "Previous day" : "Вчора",
    "Previous week" : "Попередній тиждень",
    "Previous year" : "Назад",
    "Previous month" : "Попередній місяць",
    "Next day" : "Завтра",
    "Next week" : "Наступний тиждень",
    "Next year" : "Наступний рік",
    "Next month" : "Наступний місяць",
    "Create new event" : "Створити нову подію",
    "Event" : "Подія",
    "Today" : "Сьогодні",
    "Day" : "День",
    "Week" : "Тиждень",
    "Month" : "Місяць",
    "Year" : "Рік",
    "List" : "Список",
    "Appointment link was copied to clipboard" : "Посилання на зустріч скопійовано до буферу обміну",
    "Appointment link could not be copied to clipboard" : "Неможливо скопіювати посилання до буферу обміну",
    "Preview" : "Перегляд",
    "Copy link" : "Копіювати посилання",
    "Edit" : "Редагувати",
    "Delete" : "Вилучити",
    "Appointment schedules" : "Заплановані зустрічі",
    "Create new" : "Додати",
    "Disable calendar \"{calendar}\"" : "Вимкнути календар \"{calendar}\"",
    "Disable untitled calendar" : "Вимкнути календар без назви",
    "Enable calendar \"{calendar}\"" : "Увімкнути календар \"{calendar}\"",
    "Enable untitled calendar" : "Увімкнути календар без назви",
    "An error occurred, unable to change visibility of the calendar." : "Помилка: неможливо змінити подання календаря.",
    "Untitled calendar" : "Календар без назви",
    "Shared with you by" : "Поділилися з вами",
    "Edit and share calendar" : "Редагувати та поділитися календарем",
    "Edit calendar" : "Редагувати календар",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Поширення календаря буде відмінено через {countdown} секунду","Поширення календаря буде відмінено через {countdown} секунд","Поширення календаря буде відмінено через {countdown} секунд","Календар буде від'єднано за {countdown} секунд"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Календар буде вилучено через {countdown} секунду","Календар буде вилучено через {countdown} секунди","Календар буде вилучено через {countdown} секунд","Календар буде вилучено через {countdown} секунд"],
    "An error occurred, unable to create the calendar." : "Помилка: неможливо створити календар.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Будь ласка, зазначте правильне посилання (має починатися з http://, https://, webcal:// або webcals://)",
    "Calendars" : "Календарі",
    "Add new" : "Створити",
    "New calendar" : "Додати календар",
    "Name for new calendar" : "Назва нового календаря",
    "Creating calendar …" : "Створення календаря...",
    "New calendar with task list" : "Новий календар зі списком завдань",
    "New subscription from link (read-only)" : "Підписатися на календар (лише для читання)",
    "Creating subscription …" : "Створення підписки...",
    "Add public holiday calendar" : "Додати календар публічних свят",
    "Add custom public calendar" : "Додати власний публічний календар",
    "Calendar link copied to clipboard." : "Посилання на календар скопійовано.",
    "Calendar link could not be copied to clipboard." : "Неможливо копіювати посилання на календар.",
    "Copy subscription link" : "Копіювати посилання на підписку",
    "Copying link …" : "Копіюю посилання...",
    "Copied link" : "Скопійоване посилання",
    "Could not copy link" : "Не вдалося cкопіювати посилання",
    "Export" : "Експорт",
    "Untitled item" : "Елемент без назви",
    "Unknown calendar" : "Невідомий календар",
    "Could not load deleted calendars and objects" : "Не вдалося завантажити календарі та об’єкти, які було раніше вилучено",
    "Could not delete calendar or event" : "Не вдалося вилучити календар або подію",
    "Could not restore calendar or event" : "Не вдалося відновити календар або подію",
    "Do you really want to empty the trash bin?" : "Ви дійсно хочете очистити кошик?",
    "Empty trash bin" : "Очистити кошик",
    "Trash bin" : "Кошик",
    "Loading deleted items." : "Завантажую вилучені елементи.",
    "You do not have any deleted items." : "У вас відсутні елементи, які було вилучено.",
    "Name" : "Назва",
    "Deleted" : "Вилучено",
    "Restore" : "Відновити",
    "Delete permanently" : "Вилучити назавжди",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Вміст кошику буде очищено через {numDays} день","Вміст кошику буде очищено через {numDays} дні","Вміст кошику буде очищено через {numDays} днів","Вміст кошику буде очищено через {numDays} днів"],
    "Could not update calendar order." : "Не вдалося оновити порядок подання календарів.",
    "Shared calendars" : "Спільні календарі",
    "Deck" : "Колода",
    "Internal link" : "Внутрішнє посилання",
    "A private link that can be used with external clients" : "Приватне посилання, яке можна буде використати із зовнішніми клієнтами.",
    "Copy internal link" : "Копіювати посилання",
    "An error occurred, unable to publish calendar." : "Помилка: неможливо опублікувати календар.",
    "An error occurred, unable to send email." : "Помилка: неможливо надіслати повідомлення.",
    "Embed code copied to clipboard." : "Код вбудування cкопійовано.",
    "Embed code could not be copied to clipboard." : "Неможливо скопіювати код вбудування.",
    "Unpublishing calendar failed" : "Не вдалося скасувати публікацію календаря",
    "Share link" : "Посилання спільного доступу",
    "Copy public link" : "Копіювати публічне посилання",
    "Send link to calendar via email" : "Надіслати посилання на календар електронною поштою",
    "Enter one address" : "Зазначте одну адресу",
    "Sending email …" : "Надсилаю повідомлення...",
    "Copy embedding code" : "Копіювати код вбудування",
    "Copying code …" : "Копіюю код...",
    "Copied code" : "Скопійований код",
    "Could not copy code" : "Не вдалося скопіювати код",
    "Delete share link" : "Вилучити посилання спільного доступу",
    "Deleting share link …" : "Вилучення посилання спільного доступу...",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (команда)",
    "An error occurred while unsharing the calendar." : "Помилка під час скасування доступу до календаря.",
    "An error occurred, unable to change the permission of the share." : "Помилка: неможливо змінити права доступу до спільного ресурсу.",
    "can edit and see confidential events" : "може редагувати та бачити конфіденційні події",
    "Unshare with {displayName}" : "Забрати спільний доступ з {displayName}",
    "Share with users or groups" : "Поділитися з користувачем або групою",
    "No users or groups" : "Відсутні користувачі або групи",
    "Failed to save calendar name and color" : "Не вдалося зберегти назву календаря та колір",
    "Calendar name …" : "Назва календаря …",
    "Never show me as busy (set this calendar to transparent)" : "Ніколи не показувати мою зайнятість (зробити календар прозорим)",
    "Share calendar" : "Поділитися календарем",
    "Unshare from me" : "Вилучити доступ для мене",
    "Save" : "Зберегти",
    "No title" : "Без назви",
    "Are you sure you want to delete \"{title}\"?" : "Дійсно вилучити \"{title}\"?",
    "Deleting proposal \"{title}\"" : "Вилучення пропонованої зустрічі \"{title}\"",
    "Successfully deleted proposal" : "Успішно вилучено пропозицію зустрічі",
    "Failed to delete proposal" : "Не вдалося вилучити запропоновану зустріч",
    "Failed to retrieve proposals" : "Не вдалося отримати пропозиції зустрічі",
    "Meeting proposals" : "Пропозиції зустрічей",
    "A configured email address is required to use meeting proposals" : "Потрібно зазначити налаштовану ел. адресу для користування пропозиціями зустрічі",
    "No active meeting proposals" : "Поки відсутні пропозиції зустрічі",
    "View" : "Подання",
    "Import calendars" : "Імпортувати календарі",
    "Please select a calendar to import into …" : "Будь ласка, оберіть до якого календаря імпортувати дані...",
    "Filename" : "Ім'я файлу",
    "Calendar to import into" : "Імпортувати до цього календаря",
    "Cancel" : "Скасувати",
    "_Import calendar_::_Import calendars_" : ["Імпортувати календар","Імпортувати календарі","Імпортувати календарі","Імпортувати календарі"],
    "Select the default location for attachments" : "Виберіть типове розташування для долучених файлів",
    "Pick" : "Вибрати",
    "Invalid location selected" : "Вибрано недійсне місце розташування",
    "Attachments folder successfully saved." : "Каталог для долучених файлів успішно збережено",
    "Error on saving attachments folder." : "Помилка під час збереження каталогу для долучених файлів",
    "Attachments folder" : "Каталог із вкладеннями",
    "{filename} could not be parsed" : "Неможливо обробити {filename}",
    "No valid files found, aborting import" : "Відсутні дійсні файли, імпорт даних скасовано",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Успішно вставлено %n подію","Успішно вставлено %n події","Успішно вставлено %n подій","Успішно вставлено %n подій"],
    "Import partially failed. Imported {accepted} out of {total}." : "Імпорт частково не вдався. Імпортовано {accepted} із {total}",
    "Automatic" : "Автоматично",
    "Automatic ({timezone})" : "Автоматично ({timezone})",
    "New setting was not saved successfully." : "Нові налаштування не було збережено.",
    "Timezone" : "Часовий пояс",
    "Navigation" : "Навігація",
    "Previous period" : "Попередній період",
    "Next period" : "Наступний період",
    "Views" : "Перегляди",
    "Day view" : "День",
    "Week view" : "Тиждень",
    "Month view" : "Місяць",
    "Year view" : "Вперед",
    "List view" : "Перелік",
    "Actions" : "Дії",
    "Create event" : "Створити подію",
    "Show shortcuts" : "Показати скорочення",
    "Editor" : "Редактор",
    "Close editor" : "Закрити редактор",
    "Save edited event" : "Закрити відредаговану подію",
    "Delete edited event" : "Вилучити відредаговану подію",
    "Duplicate event" : "Створити копію події",
    "or" : "або",
    "Calendar settings" : "Налаштування",
    "At event start" : "З початком події",
    "No reminder" : "Без нагадування",
    "Failed to save default calendar" : "Не вдалося зберегти типовий календар",
    "General" : "Загальне",
    "Availability settings" : "Налаштування доступності",
    "Access Nextcloud calendars from other apps and devices" : "Доступ до календарів у Nextcloud з інших застосунків та пристроїв",
    "Server Address for iOS and macOS" : "Адреса серверу для iOS та macOS",
    "Appearance" : "Вигляд",
    "Birthday calendar" : "Календар днів народжень",
    "Tasks in calendar" : "Завдання у календарі",
    "Weekends" : "Вихідні дні",
    "Week numbers" : "Номери тижнів",
    "Limit number of events shown in Month view" : "Обмежити кількість подій, які показуються у щомісячному поданні",
    "Density in Day and Week View" : "Щільність у щоденному та щотижневому поданні",
    "Editing" : "Редагування",
    "Default reminder" : "Нагадування",
    "Simple event editor" : "Простий редактор подій",
    "\"More details\" opens the detailed editor" : "\"Докладно\" відкриває деталізований редактор",
    "Files" : "Файли",
    "Appointment schedule successfully created" : "Графік зустрічей успішно створено",
    "Appointment schedule successfully updated" : "Графік зустрічей успішно оновлено",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} хвилина","{duration} хвилини","{duration} хвилин","{duration} хвилин"],
    "0 minutes" : "0 хвилин",
    "_{duration} hour_::_{duration} hours_" : ["{duration} година","{duration} години","{duration} годин","{duration} годин"],
    "_{duration} day_::_{duration} days_" : ["{duration} день","{duration} дні","{duration} днів","{duration} днів"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} тиждень","{duration} тижні","{duration} тижнів","{duration} тижнів"],
    "_{duration} month_::_{duration} months_" : ["{duration} місяць","{duration} місяці","{duration} місяців","{duration} місяців"],
    "_{duration} year_::_{duration} years_" : ["{duration} рік","{duration} роки","{duration} років","{duration} років"],
    "To configure appointments, add your email address in personal settings." : "Для налаштування зустрічей потрібно додати вашу електронну адресу у особистих налаштуваннях.",
    "Public – shown on the profile page" : "Показуватиметься на сторінці профілю",
    "Private – only accessible via secret link" : "Доступно тільки через приватне посилання",
    "Appointment schedule saved" : "Запрошення призначено",
    "Create appointment schedule" : "Створити графік зустрічей",
    "Edit appointment schedule" : "Редагувати графік зустрічей",
    "Update" : "Оновити",
    "Appointment name" : "Назва зустрічі",
    "Location" : "Місце",
    "Create a Talk room" : "Створіть кімнату для розмов",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Унікальне посилання буде згенеровано для кожної заброньованої зустрічі та надіслано на електронну пошту з підтвердженням.",
    "Description" : "Опис",
    "Visibility" : "Видимість",
    "Duration" : "Тривалість",
    "Increments" : "Крок",
    "Additional calendars to check for conflicts" : "Додаткові календарі, які потрібно перевірити на конфлікти",
    "Pick time ranges where appointments are allowed" : "Виберіть часові проміжки для запрошення на зустріч",
    "to" : "до",
    "Delete slot" : "Вилучити часовий проміжок",
    "No times set" : "Не вибрано час",
    "Add" : "Додати",
    "Monday" : "Понеділок",
    "Tuesday" : "Вівторок",
    "Wednesday" : "Середа",
    "Thursday" : "Четвер",
    "Friday" : "П'ятниця",
    "Saturday" : "Субота",
    "Sunday" : "Неділя",
    "Weekdays" : "Дні тижня",
    "Add time before and after the event" : "Додайте часовий проміжок до та після події",
    "Before the event" : "До події",
    "After the event" : "Після події",
    "Planning restrictions" : "Умови участі",
    "Minimum time before next available slot" : "Найменший час перед наступним можливим часовим проміжком",
    "Max slots per day" : "Максимальна кількість часових проміжків на день",
    "Limit how far in the future appointments can be booked" : "Обмежити, наскільки далеко у майбутньому можна призначити зустріч",
    "It seems a rate limit has been reached. Please try again later." : "Схоже, що вичерпано максимальну кількість спроб. Спробуйте пізніше.",
    "Please confirm your reservation" : "Будь ласка, підтвердіть резервування",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Ми надіслали вам лист з докладною інформацією щодо зустрічі. Просимо підтвердити вашу участь - для цього перейдіть за наведеним у листі посиланням. Ви можете просто закрити цю сторінку.",
    "Your name" : "Ваше ім'я",
    "Your email address" : "Ваша адреса електронної пошти",
    "Please share anything that will help prepare for our meeting" : "Будь ласка, поділіться корисними матер'ялами, які допоможуть підготоуватися до нашої зустрічі",
    "Could not book the appointment. Please try again later or contact the organizer." : "Не вдалося зарезервувати зустріч. Спробуйте пізніше або сконтактуйте з організатором.",
    "Back" : "Назад",
    "Book appointment" : "Зарезервувати зустріч",
    "Error fetching Talk conversations." : "Помилка під час отримання розмов Talk.",
    "Conversation does not have a valid URL." : "Ця розмова Talk не містить дійсної адреси URL.",
    "Successfully added Talk conversation link to location." : "Успішно додано посилання на розмову Talk до розташування",
    "Successfully added Talk conversation link to description." : "Успішно додано посилання на розмову Talk до опису",
    "Failed to apply Talk room." : "Помилка під час застосування кімнати Talk.",
    "Talk conversation for event" : "Розмова Talk для події",
    "Error creating Talk conversation" : "Помилка під час створення розмови Talk",
    "Select a Talk Room" : "Вибрати кімнату для розмов Talk",
    "Add Talk conversation" : "Додати розмову Talk",
    "Fetching Talk rooms…" : "Отримання кімнат Talk...",
    "No Talk room available" : "Відсутні кімнати Talk",
    "Create public conversation" : "Створити публічну розмову",
    "Select conversation" : "Вибрати розмову",
    "on" : "о",
    "at" : "о",
    "before at" : "до о",
    "Notification" : "Сповіщення",
    "Email" : "Ел.пошта",
    "Audio notification" : "Звукове сповіщення",
    "Other notification" : "Інше сповіщення",
    "Relative to event" : "Щодо події",
    "On date" : "Дата",
    "Edit time" : "Редагувати час",
    "Save time" : "Зберегти час",
    "Remove reminder" : "Прибрати нагадування",
    "Add reminder" : "Додати нагадування",
    "seconds" : "секунд",
    "minutes" : "хвилин",
    "hours" : "годин",
    "days" : "днів",
    "weeks" : "тижнів",
    "Choose a file to add as attachment" : "Виберіть файл для вкладення",
    "Choose a file to share as a link" : "Виберіть файл, яким ви поділитеся через посилання",
    "Attachment {name} already exist!" : "Такий долучений файл {name} вже присутній!",
    "Could not upload attachment(s)" : "Не вдалося завантажити вкладення",
    "You are about to navigate to {link}. Are you sure to proceed?" : "Ви збираєтеся перейти до {link}. Дійсно продовжити?",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Ви збираєтеся перейти на сайт {host}. Продовжити? Посилання: {link}",
    "Proceed" : "Продовжити",
    "No attachments" : "Без вкладень",
    "Add from Files" : "Додати з файлів",
    "Upload from device" : "Завантажити з пристрою",
    "Delete file" : "Вилучити файл",
    "Confirmation" : "Підтвердження",
    "_{count} attachment_::_{count} attachments_" : ["{count} долучений файл","{count} долучені файли","{count} долучених файлів","{count} долучених файлів"],
    "Suggested" : "Запропоновано",
    "Available" : "Доступно",
    "Invitation accepted" : "Запрошення прийнято",
    "Accepted {organizerName}'s invitation" : "Прийнято запрошення від {organizerName}",
    "Participation marked as tentative" : "Участь можлива",
    "Invitation is delegated" : "Запрошення делеговано",
    "Not available" : "Не доступно",
    "Invitation declined" : "Запрошення відхилено",
    "Declined {organizerName}'s invitation" : "Відхилене від {organizerName} запрошення ",
    "Availability will be checked" : "Доступність буде перевірено",
    "Invitation will be sent" : "Запрошення буде надіслано",
    "Failed to check availability" : "Не вдалося перевірити доступність",
    "Failed to deliver invitation" : "Не вдалося доставити запрошення",
    "Awaiting response" : "Очікується відповідь",
    "Checking availability" : "Перевірка доступності",
    "Has not responded to {organizerName}'s invitation yet" : "Ще не відповів на запрошення від {organizerName}",
    "Suggested times" : "Пропонований час",
    "chairperson" : "модератор",
    "required participant" : "обов'язковий учасник(-ця)",
    "non-participant" : "гість",
    "optional participant" : "необов'язковий учасник(-ця)",
    "{organizer} (organizer)" : "{organizer} (організатор)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Selected slot" : "Вибраний часовий проміжок",
    "Availability of attendees, resources and rooms" : "Доступність учасників, ресурсів і приміщень",
    "Suggestion accepted" : "Пропозицію прийнято",
    "Previous date" : "Попередня дата",
    "Next date" : "Наступна дата",
    "Legend" : "Легенда",
    "Out of office" : "Недоступно",
    "Attendees:" : "Учасники:",
    "local time" : "місцевий час",
    "Done" : "Готово",
    "Search room" : "Шукати кімнату",
    "Room name" : "Назва кімнати",
    "Check room availability" : "Перевірити доступність кімнати",
    "Free" : "Вільно",
    "Busy (tentative)" : "Зайнято (попередньо)",
    "Busy" : "Зайнято",
    "Unknown" : "Невідомо",
    "Find a time" : "Знайти час",
    "The invitation has been accepted successfully." : "Запрошення успішно прийнято.",
    "Failed to accept the invitation." : "Не вдалося прийняти запрошення.",
    "The invitation has been declined successfully." : "Запрошення відхилено.",
    "Failed to decline the invitation." : "Не вадлося відхилити запрошення.",
    "Your participation has been marked as tentative." : "Вашу участь позначено як можливу.",
    "Failed to set the participation status to tentative." : "Не вдалося встановити статус \"можливо\".",
    "Accept" : "Прийняти",
    "Decline" : "Відхилити",
    "Tentative" : "Можливо так",
    "No attendees yet" : "Поки жодного учасника",
    "{confirmedCount} confirmed, {waitingCount} awaiting response" : "{confirmedCount} підтверджено, {waitingCount} очікує на відповідь",
    "Please add at least one attendee to use the \"Find a time\" feature." : "Додайте принаймні одного учасника, щоби скористатися функціональністю \"Визначити час\"",
    "Attendees" : "Учасники",
    "_%n more attendee_::_%n more attendees_" : ["ще %n учасник","ще %n учасники","ще %n учасників","ще %n учасників"],
    "Remove group" : "Вилучити групу",
    "Remove attendee" : "Вилучити учасника",
    "Request reply" : "Запит на відповідь",
    "Chairperson" : "Модератор",
    "Required participant" : "Обов'язковий учасник",
    "Optional participant" : "Необов'язковий учасник",
    "Non-participant" : "Неучасник",
    "_%n member_::_%n members_" : ["%n учасник","%n учасника","%n учасників","%n учасників"],
    "Search for emails, users, contacts, contact groups or teams" : "Шукати у ел. листах, користувачах, контактах, групах контактів чи командах",
    "No match found" : "Збігів не знайдено",
    "Note that members of circles get invited but are not synced yet." : "Зверніть увагу, що учасники кіл отримують запрошення, але поки ще не синхронізовані.",
    "Note that members of contact groups get invited but are not synced yet." : "Учасників груп контактів було запрошено, але ще не синхронізовано.",
    "(organizer)" : "(організатор)",
    "Make {label} the organizer" : "Зробити {label} організатором",
    "Make {label} the organizer and attend" : "Зробити {label} організатором та взяти участь",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Для надсилання запрошень та отримання відповіді, [linkopen]додайте ел.адресу в особистих налаштуваннях[linkclose].",
    "Remove color" : "Вилучити колір",
    "Event title" : "Назва події",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Не вдалося змінити цілодобове налаштування для подій, які є повторювальними подіями.",
    "From" : "Від",
    "To" : "До",
    "Your Time" : "Ваш час",
    "Repeat" : "Повторювати",
    "Repeat event" : "Повторювати подію",
    "_time_::_times_" : ["раз","разів","разів","разів"],
    "never" : "завжди",
    "on date" : "дата",
    "after" : "опісля",
    "End repeat" : "Повторювати до",
    "Select to end repeat" : "Вибрати, щоби завершити повторення",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Ця подія є винятком з набору повторювальних подій. Ви не можете застосувати до нього правило повторення.",
    "first" : "перший",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Зміни до правила повторення стосуватимуться лише поточної та подальших подій.",
    "Repeat every" : "Повторювати кожний",
    "By day of the month" : "За днем місяця",
    "On the" : "У",
    "_day_::_days_" : ["день","днів","днів","дні"],
    "_week_::_weeks_" : ["тиждень","тижнів","тижнів","тижні"],
    "_month_::_months_" : ["місяць","місяців","місяців","місяці"],
    "_year_::_years_" : ["рік","років","років","роки"],
    "On specific day" : "Певного дня",
    "weekday" : "робочі дні",
    "weekend day" : "вихідні дні",
    "Does not repeat" : "Не повторюється",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Правила повторювання ціє події не повністю підтримуються у Nextcloud. Після зміни налаштувань деякі повторення можуть зникнути.",
    "No rooms or resources yet" : "Поки відсутні кімнати та ресурси",
    "Resources" : "Ресурси",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} місце","{seatingCapacity} місця","{seatingCapacity} місць","{seatingCapacity} місць"],
    "Add resource" : "Додати ресурс",
    "Has a projector" : "Має проєктор",
    "Has a whiteboard" : "Має білу дошку",
    "Wheelchair accessible" : "Доступ для інвалідних візків",
    "Remove resource" : "Вилучити ресурс",
    "Search for resources or rooms" : "Пошук ресурсів або кімнат",
    "available" : "доступне",
    "unavailable" : "недоступне",
    "Show all rooms" : "Показати всі кімнати",
    "Projector" : "Проєктор",
    "Whiteboard" : "Біла дошка",
    "Room type" : "Вид кімнати",
    "Any" : "Будь-яка",
    "Minimum seating capacity" : "Мінімальна кількість місць",
    "More details" : "Докладно",
    "Update this and all future" : "Оновити цю подію та всі наступні",
    "Update this occurrence" : "Оновити це повторення",
    "Public calendar does not exist" : "Публічний календар не існує",
    "Maybe the share was deleted or has expired?" : "Можливо спільний доступ було скасовано або він більше не дійсний?",
    "Remove date" : "Вилучити дату",
    "Attendance required" : "Участь обов'язкова",
    "Attendance optional" : "Участь необов'язкова",
    "Remove participant" : "Вилучити учасника",
    "Yes" : "Так",
    "No" : "Ні",
    "Maybe" : "Можливо.",
    "None" : "Нічого",
    "Select your meeting availability" : "Виберіть вашу доступність у зустрічі",
    "Create a meeting for this date and time" : "Створити зустріч на цю дату та час",
    "Create" : "Додати",
    "No participants or dates available" : "Відсутні доступні учасники чи дати",
    "from {formattedDate}" : "від {formattedDate}",
    "to {formattedDate}" : "до {formattedDate}",
    "on {formattedDate}" : "{formattedDate}",
    "from {formattedDate} at {formattedTime}" : "від {formattedDate} о {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "до {formattedDate} о {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "{formattedDate} о {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} о {formattedTime}",
    "Please enter a valid date" : "Будь ласка, зазначте правильну дату",
    "Please enter a valid date and time" : "Будь ласка, зазначте правильну дату та час",
    "Select a time zone" : "Вибрати часову зону",
    "Please select a time zone:" : "Виберіть часову зону:",
    "Pick a time" : "Виберіть час",
    "Pick a date" : "Виберіть дату",
    "Type to search time zone" : "Зазначте часову зону для пошуку",
    "Global" : "Загальний",
    "Holidays in {region}" : "Свята в {region}",
    "An error occurred, unable to read public calendars." : "Помилка: не вдалося прочитати публічні календарі.",
    "An error occurred, unable to subscribe to calendar." : "Помилка: не вдалося підписатися на календар.",
    "Public holiday calendars" : "Публічні календарі свят",
    "Public calendars" : "Публічні календарі",
    "No valid public calendars configured" : "Не налаштовано жодного дійсного публічного календаря",
    "Speak to the server administrator to resolve this issue." : "Зверніться до адміністратора сервера, щоб вирішити цю проблему.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Календарі публічних свят надаються Thunderbird. Календарні дані буде отримано з {website}",
    "These public calendars are suggested by the server administrator. Calendar data will be downloaded from the respective website." : "Ці публічні календарі було запропоновано адміністратором хмари. Дані календарів буде звантажено з відповідного вебсайту.",
    "By {authors}" : "Автор: {authors}",
    "Subscribed" : "Підписано",
    "Subscribe" : "Підписатися",
    "Could not fetch slots" : "Не вдалося отримати часові проміжки",
    "Select a date" : "Виберіть дату",
    "Select slot" : "Виберіть часовий проміжок",
    "No slots available" : "Відсутні доступні часові проміжки",
    "The slot for your appointment has been confirmed" : "Час вашої зустрічі підтверджено",
    "Appointment Details:" : "Деталі зустрічі:",
    "Time:" : "Час:",
    "Booked for:" : "Зарезервовано для:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Дякуємо вам. Ваше резервування від {startDate} до {endDate} підтверджено.",
    "Book another appointment:" : "Зарезервувати іншу зустріч:",
    "See all available slots" : "Дивитися усі доступні дати",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Проміжок часу для вашого запрошення від {startDate} до {endDate} більше не доступний.",
    "Please book a different slot:" : "Зарезервуйте інший часовий проміжок:",
    "Book an appointment with {name}" : "Зарезервуйте зустріч з {name}",
    "No public appointments found for {name}" : "Не знайдено публічних зустрічей для {name}",
    "Personal" : "Особисте",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Вашу часову зону автоматично встановлено як UTC.\nСкоріш за все це зумовлено безпековими обмеженнями вашого бравзера.\nБудь ласка, налаштуйте вашу часову зону  вручну у налаштуваннях календаря.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Не знайдено налаштування вашої часової зони ({timezoneId}). Не вдалося встановити типову часову зону UTC.\nБудь ласка, змініть вашу часову зону у налаштуваннях та надішліть звіт про помилку.",
    "Show unscheduled tasks" : "Показати незаплановані завдання",
    "Unscheduled tasks" : "Незаплановані завдання",
    "Availability of {displayName}" : "Доступність {displayName}",
    "Discard event" : "Відхилити подію",
    "Edit event" : "Редагувати подію",
    "Event does not exist" : "Подія відсутня",
    "Duplicate" : "Копіювати",
    "Delete this occurrence" : "Вилучити повторення",
    "Delete this and all future" : "Вилучити це та всі подальші повторення",
    "All day" : "Весь день",
    "Modifications wont get propagated to the organizer and other attendees" : "Зміни не буде надіслано організаторові та іншим учасникам",
    "Managing shared access" : "Керування спільним доступом",
    "Deny access" : "Заборонити доступ",
    "Invite" : "Запросити",
    "Discard changes?" : "Відхилити зміни?",
    "Are you sure you want to discard the changes made to this event?" : "Дійсно відхилити зміни, які було зроблено для цієї події?",
    "_User requires access to your file_::_Users require access to your file_" : ["Потрібно надати доступ до вашого файлу.","Потрібно надати доступ до вашого файлу.","Потрібно надати доступ до вашого файлу.","Потрібно надати доступ до вашого файлу."],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Для доступу до застосунку потрібний спільний доступ.","Для доступу до застосунків потрібний спільний доступ.","Для доступу до застосунків потрібний спільний доступ.","Для доступу до застосунків потрібний спільний доступ."],
    "Untitled event" : "Подія без назви",
    "Close" : "Закрити",
    "Modifications will not get propagated to the organizer and other attendees" : "Зміни не буде надіслано організаторові та іншим учасникам",
    "Meeting proposals overview" : "Огляд пропозицій зустрічей",
    "Edit meeting proposal" : "Редагувати пропозиції зустрічей",
    "Create meeting proposal" : "Створити пропозицію зустрічі",
    "Update meeting proposal" : "Оновити пропозицію зустрічі",
    "Saving proposal \"{title}\"" : "Збереження пропозиції зустрічі \"{title}\"",
    "Successfully saved proposal" : "Успішно збережено пропозицію зустрічі",
    "Failed to save proposal" : "Не вдалося зберегти пропозицію зустрічі",
    "Create a meeting for \"{date}\"? This will create a calendar event with all participants." : "Створити зустріч для \"{date}\"? Буде створено подію в календарі для всіх учасників.",
    "Creating meeting for {date}" : "Створення зустрічі для {date}",
    "Successfully created meeting for {date}" : "Успішно створено зустріч для {date}",
    "Failed to create a meeting for {date}" : "Не вдалося створити зустріч для {date}",
    "Please enter a valid duration in minutes." : "Зазначте дійсну тривалість у хвилинах.",
    "Failed to fetch proposals" : "Не вдалося отримати пропозиції зустрічей",
    "Failed to fetch free/busy data" : "Не вдалося отримати дати доступности",
    "Selected" : "Вибрано",
    "No Description" : "Без опису",
    "No Location" : "Місце не вибрано",
    "Edit this meeting proposal" : "Редагувати пропозиції зустрічей",
    "Delete this meeting proposal" : "Вилучити пропозицію зустрічі",
    "Title" : "Заголовок",
    "15 min" : "15 хв.",
    "30 min" : "30 хв",
    "60 min" : "60 хв.",
    "90 min" : "90 хв.",
    "Participants" : "Учасники",
    "Selected times" : "Вибрано час",
    "Previous span" : "Попередній проміжок",
    "Next span" : "Наступний проміжок",
    "Less days" : "Менше днів",
    "More days" : "Більше днів",
    "Loading meeting proposal" : "Завантаження пропозицій зустрічей",
    "No meeting proposal found" : "Відсутні пропозиції зустрічей",
    "Please wait while we load the meeting proposal." : "Зачекайте, доки пропозиції зустрічей завантажено.",
    "The link you followed may be broken, or the meeting proposal may no longer exist." : "Посилання, за яким ви перейшли, може бути зламане, або пропозиція зустрічі більше не доступна.",
    "Thank you for your response!" : "Дякуємо за вашу відповідь!",
    "Your vote has been recorded. Thank you for participating!" : "Ваш голос враховано. Дякуємо за участь!",
    "Unknown User" : "Невідомий користувач",
    "No Title" : "Без заголовку",
    "No Duration" : "Відсутня тривалість",
    "Select a different time zone" : "Виберіть іншу часову зону",
    "Submit" : "Відправити",
    "Subscribe to {name}" : "Підписатися на {name}",
    "Export {name}" : "Експортувати {name}",
    "Show availability" : "Показати доступність",
    "Anniversary" : "Річниця",
    "Appointment" : "Запрошення на зустріч",
    "Business" : "Робота",
    "Education" : "Освіта",
    "Holiday" : "Вихідний",
    "Meeting" : "Зустріч",
    "Miscellaneous" : "Різне",
    "Non-working hours" : "Неробочий час",
    "Not in office" : "Поза офісом",
    "Phone call" : "Телефонний дзвінок",
    "Sick day" : "Хворію",
    "Special occasion" : "Особлива подія",
    "Travel" : "Подорожую",
    "Vacation" : "Відпустка",
    "Midnight on the day the event starts" : "Опівночі в день початку події",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n день до початку події о {formattedHourMinute}","%n днів до початку події о {formattedHourMinute}","%n днів до початку події о {formattedHourMinute}","%n дні до початку події о {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n тиждень до початку події о {formattedHourMinute}","%n тижнів до початку події о {formattedHourMinute}","%n тижнів до початку події о {formattedHourMinute}","%n тижні до початку події о {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "у день події о {formattedHourMinute}",
    "at the event's start" : "на початку події",
    "at the event's end" : "наприкінці події",
    "{time} before the event starts" : "{time} до початку події",
    "{time} before the event ends" : "{time} до завершення події",
    "{time} after the event starts" : "{time} після початку події",
    "{time} after the event ends" : "{time} після завершення події",
    "on {time}" : "о {time}",
    "on {time} ({timezoneId})" : "о {time} ({timezoneId})",
    "Week {number} of {year}" : "Тиждень {number} з {year} року",
    "Daily" : "Щоденно",
    "Weekly" : "Щотижня",
    "Monthly" : "Щомісяця",
    "Yearly" : "Щороку",
    "_Every %n day_::_Every %n days_" : ["Кожен %n день","Кожні %n днів","Кожні %n днів","Кожні %n дні"],
    "_Every %n week_::_Every %n weeks_" : ["Кожен %n тиждень","Кожні %n тижнів","Кожні %n тижнів","Кожні %n тижні"],
    "_Every %n month_::_Every %n months_" : ["Кожен %n місяць","Кожні %n місяців","Кожні %n місяців","Кожні %n місяці"],
    "_Every %n year_::_Every %n years_" : ["Кожен %n рік","Кожні %n років","Кожні %n років","Кожні %n роки"],
    "_on {weekday}_::_on {weekdays}_" : ["у {weekdays}","у {weekdays}","у {weekdays}","у {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["у наступний день {dayOfMonthList}","у наступні дні {dayOfMonthList}","у наступні дні {dayOfMonthList}","у наступні дні {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "у {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {dayOfMonthList}" : "у {monthNames} в {dayOfMonthList}  ",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "у {monthNames} у {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "до {untilDate}",
    "_%n time_::_%n times_" : ["%n раз","%n разів","%n разів","%n рази"],
    "second" : "другий",
    "third" : "третій",
    "fourth" : "четвертий",
    "fifth" : "п'ятий",
    "second to last" : "з другого до останнього",
    "last" : "останній",
    "Untitled task" : "Завдання без назви",
    "Please ask your administrator to enable the Tasks App." : "Зверніться до вашого адміністратора щодо увімкнення застосунку \"Завдання\".",
    "You are not allowed to edit this event as an attendee." : "Як учасника у вас відсутній дозвіл на редагування цієї події.",
    "W" : "Тиж. ",
    "%n more" : "Ще %n подій",
    "No events to display" : "Відсутні події для показу",
    "All participants declined" : "Всі користувачі відмовилися",
    "Please confirm your participation" : "Підтвердіть вашу участь",
    "You declined this event" : "Ви відхилили цю подію",
    "Your participation is tentative" : "Ваша участь є під питанням",
    "_+%n more_::_+%n more_" : ["+%n раз ще","+%n разів ще","+%n разів ще","+%n рази ще"],
    "No events" : "Відсутні події",
    "Create a new event or change the visible time-range" : "Створити нову подію або змінити часовий проміжок",
    "Failed to save event" : "Не вдалося зберегти подію",
    "It might have been deleted, or there was a typo in a link" : "Можливо, що його було вилучено або міститься помилка у посиланні",
    "It might have been deleted, or there was a typo in the link" : "Можливо, що його було вилучено або міститься помилка у посиланні",
    "Meeting room" : "Кімната для зустрічей",
    "Lecture hall" : "Лекційна зала",
    "Seminar room" : "Кімната для занять",
    "Other" : "Інші",
    "When shared show" : "Показувати, якщо у спільному доступі",
    "When shared show full event" : "Все про подію, якщо у спільному доступі",
    "When shared show only busy" : "Показувати тільки зайнятість, якщо у спільному доступі",
    "When shared hide this event" : "Приховати подію, якщо у спільному доступі",
    "The visibility of this event in read-only shared calendars." : "Видимість події у спільних календарях тільки для читання.",
    "Add a location" : "Додати розташування",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Додайте до опису\n\n- Тема зустрічі\n- Питання до розгляду\n- До чого мають підготуватися учасники",
    "Status" : "Статус",
    "Confirmed" : "Підтверджено",
    "Canceled" : "Скасовано",
    "Confirmation about the overall status of the event." : "Підтвердження загального статусу події.",
    "Show as" : "Показати як",
    "Take this event into account when calculating free-busy information." : "Брати до уваги цю подію при розрахунку вільного/зайнятого часу.",
    "Categories" : "Категорії",
    "Categories help you to structure and organize your events." : "Категорії допомагають впорядковувати ваші події.",
    "Search or add categories" : "Шукати чи додати категорії",
    "Add this as a new category" : "Додати як нову категорію",
    "Custom color" : "Власний колір",
    "Special color of this event. Overrides the calendar-color." : "Власний колір для цієї події. Перезаписати колір календаря.",
    "Error while sharing file" : "Помилка під час надання спільного доступу до файлу",
    "Error while sharing file with user" : "Помилка під час надання доступу користувачеві",
    "Error creating a folder {folder}" : "Помилка під час надання створення каталогу {folder}",
    "Attachment {fileName} already exists!" : "Долучений файл {filename} вже присутній!",
    "Attachment {fileName} added!" : "Вкладення {fileName} додано! ",
    "An error occurred during uploading file {fileName}" : "Помилка під час завантаження файлу {fileName}",
    "An error occurred during getting file information" : "Помилка під час отримання інформації про файл",
    "Talk conversation for proposal" : "Пропонована розмова у Talk",
    "An error occurred, unable to delete the calendar." : "Помилка: неможливо вилучити календар.",
    "Imported {filename}" : "Імпортовано {filename}",
    "This is an event reminder." : "Це нагадування про подію.",
    "Error while parsing a PROPFIND error" : "Помилка під час обробки помилки PROPFIND",
    "Appointment not found" : "Запрошення на зустріч не знайдено",
    "User not found" : "Користувача не знайдено",
    "Hidden" : "Приховані",
    "can edit" : "може редагувати",
    "Calendar name …" : "Назва календаря...",
    "Default attachments location" : "Типове розташування для долучених файлів",
    "Automatic ({detected})" : "Автоматично ({detected})",
    "Shortcut overview" : "Перегляд скорочень",
    "CalDAV link copied to clipboard." : "Посилання CalDAV скопійовано.",
    "CalDAV link could not be copied to clipboard." : "Неможливо копіювати посилання CalDAV.",
    "Enable birthday calendar" : "Увімкнути календар дат народжень",
    "Show tasks in calendar" : "Показувати завдання у календарі",
    "Enable simplified editor" : "Увімкнути спрощений редактор",
    "Limit the number of events displayed in the monthly view" : "Частково показувати події у щомісячному поданні",
    "Show weekends" : "Показувати вихідні дні",
    "Show week numbers" : "Показувати номери тижнів",
    "Time increments" : "Крок",
    "Default calendar for incoming invitations" : "Типовий календар для вхідних запрошень",
    "Copy primary CalDAV address" : "Копіювати основну адресу CalDAV",
    "Copy iOS/macOS CalDAV address" : "Копіювати адресу CalDAV для iOS/macOS ",
    "Personal availability settings" : "Налаштування зайнятості",
    "Show keyboard shortcuts" : "Показати клавіатурні скорочення",
    "Create a new public conversation" : "Створити нову публічну розмову",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} запрошено, {confirmedCount} підтверджено",
    "Successfully appended link to talk room to location." : "Успішно додано посилання на розташування у кімнаті спілкування ",
    "Successfully appended link to talk room to description." : "Успішно додано посилання на віртуальну кімнату Talk до опису події.",
    "Error creating Talk room" : "Помилка при створенні віртуальної кімнати Talk",
    "_%n more guest_::_%n more guests_" : ["Ще %n гість","Ще %n гостей","Ще %n гостей","Ще %n гостей"],
    "The visibility of this event in shared calendars." : "Видимість цієї події у спільних календарях."
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
