OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Предоставеният e mail адрес е прекалено дълъг",
    "User-Session unexpectedly expired" : "Потребителската сесия неочаквано изтече",
    "Provided email-address is not valid" : "Предоставеният е-мейл адрес е невалиден",
    "%s has published the calendar »%s«" : "%s е публикувал календар »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Неочаквана грешка при изпращането на имейл. Моля, свържете се с вашия администратор.",
    "Successfully sent email to %1$s" : "Успешно изпратен имейл до %1$s",
    "Hello," : "Здравейте, ",
    "We wanted to inform you that %s has published the calendar »%s«." : "Информираме ви, че%s е публикувал календарът »%s«.",
    "Open »%s«" : "Отвори »%s«",
    "Cheers!" : "Поздрави!",
    "Upcoming events" : "Предстоящи събития",
    "No more events today" : " Няма повече събития за днес",
    "No upcoming events" : "Няма предстоящи събития",
    "More events" : "Повече събития",
    "%1$s with %2$s" : "%1$sс %2$s",
    "Calendar" : "Календар",
    "New booking {booking}" : "Нова резервация {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) резервира срещата „{config_display_name}“ на {date_time}.",
    "Appointments" : "Срещи",
    "Schedule appointment \"%s\"" : "Насрочване на среща „%s“",
    "Schedule an appointment" : "Насрочване на среща",
    "%1$s - %2$s" : "%1$s%2$s",
    "Prepare for %s" : "Подгответе се за %s",
    "Follow up for %s" : "Последващо действие за %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Вашата среща „%s“ с %s, се нуждае от потвърждение",
    "Dear %s, please confirm your booking" : "Уважаеми %s, моля, потвърдете резервацията си",
    "Confirm" : "Потвърдете",
    "Appointment with:" : "среща с",
    "Description:" : "Описание:",
    "This confirmation link expires in %s hours." : "Тази връзка за потвърждение изтича след %s часа.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Ако все пак желаете да отмените срещата, моля, свържете се с вашият организатор, като отговорите на този имейл или като посетите страницата на профила му.",
    "Your appointment \"%s\" with %s has been accepted" : "Вашата среща „%s“ с %s, беше приета",
    "Dear %s, your booking has been accepted." : "Уважаеми %s, резервацията ви е приета.",
    "Appointment for:" : "Среща в:",
    "Date:" : "Дата:",
    "You will receive a link with the confirmation email" : "Ще получите връзка с имейла за потвърждение",
    "Where:" : "Къде:",
    "Comment:" : "Коментар:",
    "You have a new appointment booking \"%s\" from %s" : "Имате нова резервация за среща „%s“ от %s",
    "Dear %s, %s (%s) booked an appointment with you." : "Уважаемият/та  %s, %s (%s) резервира среща с вас.",
    "%s has proposed a meeting" : "%s предложи среща",
    "%s has updated a proposed meeting" : "%s актуализира предложената среща",
    "%s has canceled a proposed meeting" : "%sотмени предложената среща",
    "Dear %s, a new meeting has been proposed" : "Уважаеми %s, предложена е нова среща",
    "Dear %s, a proposed meeting has been updated" : "Уважаеми %s, предложената среща е актуализирана",
    "Dear %s, a proposed meeting has been cancelled" : "Уважаеми %s, предложената среща е отменена",
    "Location:" : "Местоположение:",
    "Duration:" : "Продължителсност:",
    "%1$s from %2$s to %3$s" : "%1$sот %2$s до%3$s",
    "Dates:" : "Дати:",
    "Respond" : "Отговорете",
    "A Calendar app for Nextcloud" : "Календар за Nextcloud",
    "A Calendar app for Nextcloud. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Like Contacts, Talk, Tasks, Deck and Circles\n* 🌐 **WebCal Support!** Want to see your favorite team's matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 **Search!** Find your events at ease\n* ☑️ **Tasks!** See tasks or Deck cards with a due date directly in the calendar\n* 🔈 **Talk rooms!** Create an associated Talk room when booking a meeting with just one click\n* 📆 **Appointment booking** Send people a link so they can book an appointment with you [using this app](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Attachments!** Add, upload and view event attachments\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Приложение за календар за Nextcloud. Лесно синхронизирайте събития от различни устройства с вашия Nextcloud и ги редактирайте онлайн.\n\n* 🚀 **Интеграция с други приложения на Nextcloud!** Като Контакти, Разговори, Задачи, Тест и Кръгове\n* 🌐 **Поддръжка на WebCal!** Искате да видите мачовете на любимия си отбор в календара си? Няма проблем!\n* 🙋 **Участници!** Поканете хора на вашите събития\n* ⌚ **Свободен/Зает!** Вижте кога вашите участници са на разположение за среща\n* ⏰ **Напомняния!** Получавайте аларми за събития в браузъра си и по имейл\n* 🔍 **Търсене!** Намерете вашите събития лесно\n* ☑️ **Задачи!** Вижте задачи или карти с крайни срокове директно в календара\n* 🔈 **Стаи за разговори!** Създайте свързана стая за разговори, когато резервирате среща само с едно щракване\n* 📆 **Резервиране на среща** Изпратете на хората линк, за да могат да резервират среща с вас [използвайки това приложение](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Прикачени файлове!** Добавяйте, качвайте и преглеждайте прикачени файлове от събития\n* 🙈 **Не преоткриваме колелото!** Въз основа на страхотния [c-dav библиотека](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) и [fullcalendar](https://github.com/fullcalendar/fullcalendar) библиотеки.",
    "Previous day" : "Вчера",
    "Previous week" : "Миналата седмица",
    "Previous year" : "Предишна година",
    "Previous month" : "Предишен месец",
    "Next day" : "Утре",
    "Next week" : "Следваща седмица",
    "Next year" : "Следващата година",
    "Next month" : "Следващия месец",
    "Create new event" : "Създай ново събитие",
    "Event" : "Събитие",
    "Today" : "Днес",
    "Day" : "Ден",
    "Week" : "Седмица",
    "Month" : "Месец",
    "Year" : "Година",
    "List" : "Списък",
    "Appointment link was copied to clipboard" : "Връзката за среща е копирана в клипборда",
    "Appointment link could not be copied to clipboard" : "Връзката за среща не можа да бъде копирана в клипборда",
    "Preview" : "Визуализация",
    "Copy link" : "Копиране на връзката",
    "Edit" : "Редакция",
    "Delete" : "Изтриване",
    "Appointment schedules" : "Графици за срещи",
    "Create new" : "Създай нов",
    "Disable calendar \"{calendar}\"" : "Деактивиране на календар „{calendar}“",
    "Disable untitled calendar" : "Деактивиране на неозаглавен календар",
    "Enable calendar \"{calendar}\"" : "Активиране на календар „{calendar}“",
    "Enable untitled calendar" : "Активиране на неозаглавен календар",
    "An error occurred, unable to change visibility of the calendar." : "Възникна грешка, невъзможност да се промени видимостта на календара.",
    "Untitled calendar" : "Нов календар",
    "Shared with you by" : "Споделено с вас от",
    "Edit and share calendar" : "Редактиране и споделяне на календар",
    "Edit calendar" : "Редактиране на календар",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Прекратяване на споделянето на календара след  {countdown} секунди","Прекратяване на споделянето на календара след {countdown} секунди"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["И","Изтриване на календара след {countdown} секундии"],
    "An error occurred, unable to create the calendar." : "Възникна грешка, невъзможност да се създаде календар.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Моля, въведете валидна връзка (започваща с http://, https://, webcal://, или webcals://)",
    "Calendars" : "Kалендари",
    "Add new" : "Добави нов",
    "New calendar" : "Нов календар",
    "Name for new calendar" : "Име за нов календар",
    "Creating calendar …" : "Създаване на календар",
    "New calendar with task list" : "Нов календар със списък със задачи",
    "New subscription from link (read-only)" : "Нов абонамент от връзка (само за четене)",
    "Creating subscription …" : "Създаване на абонамент …",
    "Add public holiday calendar" : "Добавете календар на официалните празници",
    "Add custom public calendar" : "Добавете персонализиран публичен календар",
    "Calendar link copied to clipboard." : "Връзка за Календара е копирана в клипборда",
    "Calendar link could not be copied to clipboard." : "Връзката за Календара не може да се копира в клипборда",
    "Copy subscription link" : "Копиране на връзката за абониране",
    "Copying link …" : "Копиране на връзката …",
    "Copied link" : "Копирано!",
    "Could not copy link" : "Връзката не можа да се копира",
    "Export" : "Експорт /изнасям/",
    "Untitled item" : "Неозаглавен елемент",
    "Unknown calendar" : "Неизвестен календар",
    "Could not load deleted calendars and objects" : "Не можаха да се заредят изтритите календари и обекти",
    "Could not delete calendar or event" : "Не можа да се изтрие календар или събитие",
    "Could not restore calendar or event" : "Не можа да се възстанови календар или събитие",
    "Do you really want to empty the trash bin?" : "Наистина ли искате да изпразните кошчето за боклук?",
    "Empty trash bin" : "Изпразване на кошчето за боклук",
    "Trash bin" : "Кошче",
    "Loading deleted items." : "Зареждане на изтрити елементи.",
    "You do not have any deleted items." : "Нямате изтрити елементи.",
    "Name" : "Име",
    "Deleted" : "Изтрито",
    "Restore" : "Възстановяне",
    "Delete permanently" : "Изтрий завинаги",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Елементите в кошчето за боклук се изтриват след {numDays} дни","Елементите в кошчето се изтриват след {numDays} дни"],
    "Could not update calendar order." : " Невъзможност да се актуализира записът в календара",
    "Shared calendars" : "споделени календари",
    "Deck" : "Deck",
    "Internal link" : "Вътрешна връзка",
    "A private link that can be used with external clients" : "Частна връзка, която може да се използва с външни клиенти",
    "Copy internal link" : "Копиране на вътрешна връзка",
    "An error occurred, unable to publish calendar." : "Възникна грешка, невъзможност да се публикува календар.",
    "An error occurred, unable to send email." : "Възникна грешка, невъзможност да се изпрати имейл",
    "Embed code copied to clipboard." : "Кодът за вграждане е копиран в клипборда",
    "Embed code could not be copied to clipboard." : "Кодът за вграждане не можа да се копира в клипборда",
    "Unpublishing calendar failed" : "Премахването на публикуването на календара беше неуспешно",
    "Share link" : "Връзка за споделяне",
    "Copy public link" : "Копирай публичната връзка",
    "Send link to calendar via email" : "Изпрати връзката по имейл",
    "Enter one address" : "Въведете един адрес",
    "Sending email …" : "Изпращане на имейл …",
    "Copy embedding code" : "Копиране на кода за вграждане",
    "Copying code …" : "Копиране на кода …",
    "Copied code" : "Кодът е копиран",
    "Could not copy code" : "Кодът не можа да се копира",
    "Delete share link" : "Изтрий споделената връзка",
    "Deleting share link …" : "Изтриване на връзката за споделяне  ...",
    "{teamDisplayName} (Team)" : "{teamDisplayName}(Екип)",
    "An error occurred while unsharing the calendar." : "Възникна грешка при прекратяване на споделянето на календар.",
    "An error occurred, unable to change the permission of the share." : "Възникна грешка, невъзможност да се промени разрешението за споделяне ",
    "can edit and see confidential events" : "може да редактира и вижда поверителни събития",
    "Unshare with {displayName}" : "Прекратява споделянето с {displayName}",
    "Share with users or groups" : "Сподели с потребители или групи",
    "No users or groups" : "Няма потребители или групи",
    "Failed to save calendar name and color" : "Запазването на името и цвета на календара не бе успешно",
    "Calendar name …" : "Име на календар ...",
    "Never show me as busy (set this calendar to transparent)" : "Никога не ме показвай като зает (задай този календар да бъде прозрачен)",
    "Share calendar" : "Споделяне на календар",
    "Unshare from me" : "Прекратяване на споделянето от мен",
    "Save" : "Запазване",
    "No title" : "Без заглавие",
    "Are you sure you want to delete \"{title}\"?" : "Сигурни ли сте, че искате да изтриете  \"{title}\"?",
    "Deleting proposal \"{title}\"" : "Предложение за изтриване\"{title}\"",
    "Successfully deleted proposal" : "Успешно изтриване",
    "Failed to delete proposal" : "Неуспешно изтриване",
    "Failed to retrieve proposals" : "Неуспешно извличане",
    "Meeting proposals" : "Предложения за срещи",
    "A configured email address is required to use meeting proposals" : "Необходим е конфигуриран имейл адрес, за да се използват предложения за срещи",
    "No active meeting proposals" : "Няма активни предложения за срещи",
    "View" : "Изглед",
    "Import calendars" : "Импортиране на календари",
    "Please select a calendar to import into …" : "Моля, изберете календар, в който да импортирате",
    "Filename" : "Име на файла",
    "Calendar to import into" : "Избран календар за внасяне в",
    "Cancel" : "Отказ",
    "_Import calendar_::_Import calendars_" : ["Импортиране на календар","Импортиране на календари"],
    "Select the default location for attachments" : "Избор на местоположение на прикачените файлове по подразбиране",
    "Pick" : "Избирам",
    "Invalid location selected" : "Избрано е невалидно местоположение",
    "Attachments folder successfully saved." : "Папката с прикачени файлове е записана успешно.",
    "Error on saving attachments folder." : "Грешка при запазване на папката с прикачени файлове.",
    "Attachments folder" : "Папка с прикачени файлове",
    "{filename} could not be parsed" : "{filename} не можа да бъде анализиран",
    "No valid files found, aborting import" : "Не са намерени валидни файлове, прекъсване на импортирането",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Успешно импортиране на %n събития","Успешно импортиране на %n събития"],
    "Import partially failed. Imported {accepted} out of {total}." : "Импортирането е частично неуспешно. Импортирани {accepted} от {total}.",
    "Automatic" : "Автоматично",
    "Automatic ({timezone})" : "Автоматично ({timezone})",
    "New setting was not saved successfully." : " Неуспешно запазване на новата настройка.",
    "Timezone" : "Часови пояс",
    "Navigation" : "Навигация",
    "Previous period" : "Предишен период",
    "Next period" : "Следващ период",
    "Views" : "Изгледи",
    "Day view" : "Дневен изглед",
    "Week view" : "Седмичен изглед",
    "Month view" : "Месечен изглед",
    "Year view" : "Годишен преглед",
    "List view" : "Списъчен изглед",
    "Actions" : "Действия",
    "Create event" : "Създай събитие",
    "Show shortcuts" : "Показване на преките пътища",
    "Editor" : "Редактор",
    "Close editor" : "Затваряне на редактора",
    "Save edited event" : "Запиши редактираното събитие",
    "Delete edited event" : "Изтриване на редактираното събитие",
    "Duplicate event" : "Дублирано събитие",
    "or" : "или",
    "Calendar settings" : "Настройки на календар",
    "At event start" : "В началото на събитието",
    "No reminder" : "Без напомняне",
    "Failed to save default calendar" : "Неуспешно записване на календарът по подразбиране",
    "General" : "Общи",
    "Availability settings" : "Настройки за наличност",
    "CalDAV" : "CalDAV",
    "Access Nextcloud calendars from other apps and devices" : "Достъп до календари на Nextcloud от други приложения и устройства",
    "CalDAV URL" : "CalDAV URL",
    "Appearance" : "Изглед",
    "Birthday calendar" : "Календар за рожден ден",
    "Tasks in calendar" : "Задачи в календар",
    "Weekends" : "Почивни дни",
    "Week numbers" : "Номера на седмиците",
    "Limit number of events shown in Month view" : "Ограничаване на броя на събитията, показвани в месечния изглед",
    "Density in Day and Week View" : "Натовареност на дневен и седмичен изглед",
    "Editing" : "Редактиране",
    "Default reminder" : "Напомняне по подразбиране",
    "Simple event editor" : "Опростен редактор на събития",
    "\"More details\" opens the detailed editor" : "„Повече детайли“ отваря подробния редактор",
    "Files" : "Файлове",
    "Appointment schedule successfully created" : "Графикът на срещите е създаден успешно",
    "Appointment schedule successfully updated" : "Графикът на срещите бе актуализиран успешно",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} минути","{duration} минути"],
    "0 minutes" : "0 минути",
    "_{duration} hour_::_{duration} hours_" : ["{duration} часа","{duration} минути"],
    "_{duration} day_::_{duration} days_" : ["{duration} дни","{duration} дни"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} минути","{duration} седмици"],
    "_{duration} month_::_{duration} months_" : ["{duration} месеца","{duration} минути"],
    "_{duration} year_::_{duration} years_" : ["{duration} години","{duration} минути"],
    "To configure appointments, add your email address in personal settings." : "За конфигуриране на срещи, добавете своя имейл адрес в личните настройки.",
    "Public – shown on the profile page" : "Публичен – показва се на страницата на профила",
    "Private – only accessible via secret link" : "Частен – достъпен само чрез тайна връзка",
    "Appointment schedule saved" : "Графикът на срещите е запазен",
    "Create appointment schedule" : "Създайте график за срещи",
    "Edit appointment schedule" : "Редактирайте графика за срещи",
    "Update" : "Обновяване",
    "Appointment name" : "Име на срещата",
    "Location" : "Местоположение",
    "Create a Talk room" : "Създаване на стая за разговори в приложението Talk",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "За всяка резервирана среща ще бъде генерирана уникална връзка, която ще бъде изпратена чрез имейла за потвърждение",
    "Description" : "Описание",
    "Visibility" : "Видимост",
    "Duration" : "Продължителност",
    "Increments" : "Стъпки",
    "Additional calendars to check for conflicts" : "Допълнителни календари за проверка за конфликти",
    "Pick time ranges where appointments are allowed" : "Избор на периоди от време, в които срещите са разрешени",
    "to" : "до",
    "Delete slot" : "Изтриване на слот",
    "No times set" : "Няма зададени часове",
    "Add" : "Добавяне",
    "Monday" : "понеделник",
    "Tuesday" : "Вторник",
    "Wednesday" : "Сряда",
    "Thursday" : "Четвъртък",
    "Friday" : "Петък",
    "Saturday" : "Събота",
    "Sunday" : "Неделя",
    "Weekdays" : "Делнични дни",
    "Add time before and after the event" : "Добавяне на време преди и след събитието",
    "Before the event" : "Преди събитието",
    "After the event" : "След събитието",
    "Planning restrictions" : "Ограничения за планиране",
    "Minimum time before next available slot" : "Минимално време преди следващия наличен слот",
    "Max slots per day" : "Максимален брой слотове на ден",
    "Limit how far in the future appointments can be booked" : "Ограничение, колко далеч в бъдеще могат да бъдат резервирани срещи",
    "It seems a rate limit has been reached. Please try again later." : "Изглежда е достигнат лимит на скоростта. Моля, опитайте отново по-късно.",
    "Please confirm your reservation" : "Моля, потвърдете вашата резервация",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Изпратихме ви имейл с подробности. Моля, потвърдете вашата среща, като използвате връзката в имейла. Можете да затворите тази страница сега.",
    "Your name" : "Вашето име",
    "Your email address" : "Вашият имейл адрес",
    "Please share anything that will help prepare for our meeting" : "Моля, споделете всичко, което ще помогне да се подготвим за нашата среща",
    "Could not book the appointment. Please try again later or contact the organizer." : "Срещата не можа да резервира. Моля, опитайте отново по-късно или се свържете с организатора.",
    "Back" : "Назад",
    "Book appointment" : "Резервиране на срещата",
    "Error fetching Talk conversations." : "Грешка при извличане на гласовите разговори.",
    "Conversation does not have a valid URL." : "Разговорът няма валиден URL адрес",
    "Successfully added Talk conversation link to location." : "Връзката към разговора е успешно добавена.",
    "Successfully added Talk conversation link to description." : "Връзката към разговора е успешно добавена в описанието.",
    "Failed to apply Talk room." : "Неуспешно прилагане на стая за разговори.",
    "Talk conversation for event" : "Talk разговор за събитие",
    "Error creating Talk conversation" : "Грешка при създаването на разговор в Talk",
    "Select a Talk Room" : "Изберете стая за разговори",
    "Add Talk conversation" : "Добавете разговор в Talk",
    "Fetching Talk rooms…" : "Извличане на стаи за разговори…",
    "No Talk room available" : "Няма налична стая за разговори",
    "Select conversation" : "Избор на разговор",
    "on" : "на",
    "at" : "в",
    "before at" : "преди в",
    "Notification" : "Известие",
    "Email" : "Имейл",
    "Audio notification" : "Звуково известие",
    "Other notification" : "Друго известие",
    "Relative to event" : "Относно събитието",
    "On date" : "На дата",
    "Edit time" : "Редакирай времето",
    "Save time" : "Запазване на времето",
    "Remove reminder" : "Премахни напомнянето",
    "Add reminder" : "Добавяне на напомняне",
    "seconds" : "секунди",
    "minutes" : "минути",
    "hours" : "часове",
    "days" : "дни",
    "weeks" : "седмици",
    "Choose a file to add as attachment" : "Избери файл за прикачване",
    "Choose a file to share as a link" : "Изберете файл, който да споделите като връзка",
    "Attachment {name} already exist!" : " Прикаченият файл {name} вече съществува!",
    "Could not upload attachment(s)" : "Невъзможност да се пркачи файл",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Вие сте на път да навигирате до {host} . Наистина ли искате да продължите? Връзка: {link}",
    "Proceed" : "Продължете",
    "No attachments" : "Няма прикачени файлове",
    "Add from Files" : "Добавяне от файлове",
    "Upload from device" : "Качване от устройство",
    "Delete file" : "Изтриване на файл",
    "Confirmation" : "Потвърждение",
    "_{count} attachment_::_{count} attachments_" : ["{count} прикачени файлове","{count} прикачени файлове"],
    "Suggested" : "Препоръчан",
    "Available" : "Наличен.",
    "Invitation accepted" : "Поканата е приета",
    "Accepted {organizerName}'s invitation" : "Поканата на {organizerName} е приета",
    "Participation marked as tentative" : "Участието е отбелязано като условно",
    "Invitation is delegated" : "Поканата е делегирана",
    "Not available" : "Не е наличен",
    "Invitation declined" : "Поканата е отхвърлена",
    "Declined {organizerName}'s invitation" : "Поканата на {organizerName} е отхвърлена",
    "Availability will be checked" : "Наличността ще бъде проверена",
    "Invitation will be sent" : "Поканата ще бъде изпратена",
    "Failed to check availability" : "Неуспешна проверка за наличност",
    "Failed to deliver invitation" : "Неуспешно доставяне на поканата",
    "Awaiting response" : "Очаква се отговор",
    "Checking availability" : "Проверка на наличността",
    "Has not responded to {organizerName}'s invitation yet" : "Все още няма отговор на поканата на {organizerName}",
    "Suggested times" : "Предложени часове",
    "chairperson" : "председател",
    "required participant" : "задължителен участник",
    "non-participant" : "неучастник",
    "optional participant" : "участник по желание",
    "{organizer} (organizer)" : "{organizer} (organizer)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Selected slot" : "Избран слот",
    "Availability of attendees, resources and rooms" : "Наличие на присъстващи, ресурси и стаи",
    "Suggestion accepted" : "Предложението е прието",
    "Previous date" : "Предходна дата",
    "Next date" : "Следваща дата",
    "Legend" : "Легенда",
    "Out of office" : "Извън офиса",
    "Attendees:" : "Участници:",
    "local time" : "местно време",
    "Done" : "Завършено",
    "Search room" : "Търсене на стая",
    "Room name" : "Име на стаята",
    "Check room availability" : "Проверка за наличност на стая",
    "Free" : " Свободни",
    "Busy (tentative)" : "Зает (временно)",
    "Busy" : "Зает",
    "Unknown" : "Непознат",
    "Find a time" : "Намерете време",
    "The invitation has been accepted successfully." : "Поканата е приета успешно.",
    "Failed to accept the invitation." : "Неуспешно приемане на поканата.",
    "The invitation has been declined successfully." : "Поканата е отхвърлена успешно.",
    "Failed to decline the invitation." : "Неуспешно отхвърляне на поканата.",
    "Your participation has been marked as tentative." : "Участието ви е отбелязано като условно.",
    "Failed to set the participation status to tentative." : "Неуспешно задаване на състоянието за участие на условно.",
    "Accept" : "Приемам",
    "Decline" : "Отхвърляне",
    "Tentative" : "Несигурно",
    "No attendees yet" : "Все още няма участващи",
    "Please add at least one attendee to use the \"Find a time\" feature." : "Моля добавете поне един участник, за да използвате функцията „Намиране на час“.",
    "Attendees" : "Участници",
    "Remove group" : "Премахване на групата",
    "Remove attendee" : "Премахване на участник",
    "Request reply" : "Повторете заявката",
    "Chairperson" : "Председател",
    "Required participant" : "Необходим участник",
    "Optional participant" : " Участник по желание",
    "Non-participant" : "Неучастник",
    "Search for emails, users, contacts, contact groups or teams" : "Търси е-мейли, потребители, контакти, групи контакти или екипи.",
    "No match found" : "Няма намерено съвпадение",
    "Note that members of circles get invited but are not synced yet." : "Обърнете внимание, че членовете на кръговете получават покани, но все още не са синхронизирани.",
    "Note that members of contact groups get invited but are not synced yet." : "Обърнете внимание, че членовете на групите с контакти получават покани, но все още не са синхронизирани.",
    "(organizer)" : "(организатор)",
    "Make {label} the organizer" : "Направете {label} организатор",
    "Make {label} the organizer and attend" : "Направете {label} организатор и присъствайте",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "За да изпращате покани и да обработвате отговори, [отваряне на връзка] добавете вашия имейл адрес в личните настройки [затваряне на връзка].",
    "Remove color" : "Премахване на цвят",
    "Event title" : "Заглавие на събитие",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Не може да се променя целодневната настройка за събития, които са част от набор за повторение.",
    "From" : "От",
    "To" : "До",
    "Your Time" : "Вашето време",
    "Repeat" : "Да се повтаря",
    "Repeat event" : "Повторете събитието",
    "_time_::_times_" : ["пъти","пъти"],
    "never" : "никога",
    "on date" : "на дата",
    "after" : "след",
    "End repeat" : "Край на повторението",
    "Select to end repeat" : "Изберете, за да прекратите повторението",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Това събитие е изключено за повторение на набор от повторения. Не можете да добавите правило за повторение към него.",
    "first" : "първи",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Промените в правилото за повторение ще се прилагат само за това и за всички бъдещи събития.",
    "Repeat every" : "Повтаряй всеки",
    "By day of the month" : "От ден на месеца",
    "On the" : "На",
    "_day_::_days_" : ["ден","дни"],
    "_week_::_weeks_" : ["седмица","седмици"],
    "_month_::_months_" : ["месец","месеци"],
    "_year_::_years_" : ["година","години"],
    "On specific day" : "На определен ден",
    "weekday" : "делничен ден",
    "weekend day" : "Почивен ден",
    "Does not repeat" : "Не се повтаря",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Дефиницията за повторение на това събитие не се поддържа изцяло от Nextcloud. Ако се редактират опциите за повторение, някои повторения могат да бъдат загубени.",
    "No rooms or resources yet" : "Все още няма стаи или ресурси",
    "Resources" : "Ресурси",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} места","{seatingCapacity} места"],
    "Add resource" : "Добавяне на ресурс",
    "Has a projector" : "Има проектор",
    "Has a whiteboard" : "Има табло",
    "Wheelchair accessible" : "Достъпно за инвалидна количка",
    "Remove resource" : "Премахване на ресурс",
    "Search for resources or rooms" : "Търсене на ресурси или стаи",
    "available" : "наличен",
    "unavailable" : "не е наличен",
    "Show all rooms" : "Покажи всички стаи",
    "Projector" : "Проектор",
    "Whiteboard" : "Табло",
    "Room type" : "Тип стая",
    "Any" : "Всяка",
    "Minimum seating capacity" : "Минимален капацитет за сядане",
    "More details" : "Повече подробности",
    "Update this and all future" : "Актуализиране на това и на всички бъдещи",
    "Update this occurrence" : "Актуализиране на това събитие",
    "Public calendar does not exist" : "Публичният календар не съществува",
    "Maybe the share was deleted or has expired?" : "Може би споделянето е изтрито или е изтекло?",
    "Remove date" : "Премахване на дата",
    "Attendance required" : "Задължително присъствие",
    "Attendance optional" : "Присъствие по желание",
    "Remove participant" : "Премахване на участник",
    "Yes" : "Да",
    "No" : "Не",
    "Maybe" : "Може би",
    "None" : "Няма",
    "Select your meeting availability" : "Изберете Вашата възможност за среща",
    "Create a meeting for this date and time" : "Създаване на среща за тази дата и час",
    "Create" : "Създаване",
    "No participants or dates available" : "Няма налични участници или дати",
    "from {formattedDate}" : "от {formattedDate}",
    "to {formattedDate}" : "до {formattedDate}",
    "on {formattedDate}" : "на {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "от {formattedDate} в {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "до {formattedDate} в{formattedTime}",
    "on {formattedDate} at {formattedTime}" : "на {formattedDate} в {formattedTime}",
    "{formattedDate} at {formattedTime}" : " {formattedDate} в {formattedTime}",
    "Please enter a valid date" : "Моля да въведете валидна дата",
    "Please enter a valid date and time" : "Моля да въведете валидна дата и час",
    "Select a time zone" : "Изберете часова зона",
    "Please select a time zone:" : "Моля, изберете часова зона:",
    "Pick a time" : "Изберете час",
    "Pick a date" : "Изберете дата",
    "Type to search time zone" : "Въведете, за търсене на часова зона",
    "Global" : "Глобални",
    "Holidays in {region}" : "Празници в {region}",
    "An error occurred, unable to read public calendars." : "Възникна грешка, невъзможност да се четат публични календари.",
    "An error occurred, unable to subscribe to calendar." : "Възникна грешка, невъзможност за абониране за календар.",
    "Public holiday calendars" : "Календари за официални празници",
    "Public calendars" : "Публични календари",
    "No valid public calendars configured" : "Няма конфигурирани валидни публични календари",
    "Speak to the server administrator to resolve this issue." : "Говорете със сървърния администратор, за да разрешите този проблем.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Календарите с официални празници се предоставят от Thunderbird. Данните от календара ще бъдат изтеглени от {website}",
    "These public calendars are suggested by the server administrator. Calendar data will be downloaded from the respective website." : "Тези публични календари са предложени от администратора на сървъра. Данните от календара ще бъдат изтеглени от съответния уебсайт.",
    "By {authors}" : "От {authors}",
    "Subscribed" : "Абониран",
    "Subscribe" : "Абониране",
    "Could not fetch slots" : "Слотовете не можаха да бъдат извлечени",
    "Select a date" : "Избор на дата",
    "Select slot" : "Избор на слот",
    "No slots available" : "Няма налични слотове",
    "The slot for your appointment has been confirmed" : "Слотът за вашата среща е потвърден",
    "Appointment Details:" : "Подробности за срещата:",
    "Time:" : "Час:",
    "Booked for:" : "Резервирано за:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Благодарим ви. Вашата резервация от {startDate} до {endDate} е потвърдена.",
    "Book another appointment:" : "Резервиране на друга среща:",
    "See all available slots" : "Вижте всички налични слотове",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Слотът за вашата среща от {startDate} до {endDate} вече не е наличен.",
    "Please book a different slot:" : "Моля, резервирайте друг слот:",
    "Book an appointment with {name}" : "Резервиране на среща с {name}",
    "No public appointments found for {name}" : "Няма намерени публични срещи за {name}",
    "Personal" : "Лични",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Автоматичното откриване на часовата зона, определи часовата ви зона като UTC.\nТова най-вероятно е резултат от мерките за сигурност на вашия уеб браузър.\nМоля, задайте часовата си зона ръчно в настройките за календар.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Конфигурираната ви часова зона ({timezoneId}) не е намерена. Връщане към UTC.\nМоля, променете часовата си зона в настройките и докладвайте за този проблем.",
    "Show unscheduled tasks" : "Показване на непланирани задачи",
    "Unscheduled tasks" : "Непланирани задачи",
    "Availability of {displayName}" : "Наличие на {displayName}",
    "Discard event" : "Отхвърляне на събитието",
    "Edit event" : "Редакция на събитието",
    "Event does not exist" : "Събитието не съществува",
    "Duplicate" : "Дубликат",
    "Delete this occurrence" : "Изтриване на това събитие",
    "Delete this and all future" : "Изтриване на това и на всички бъдещи ",
    "All day" : "Цял ден",
    "Modifications wont get propagated to the organizer and other attendees" : "Промените няма да бъдат разпространени до организатора и другите участници",
    "Managing shared access" : "Управление на споделения достъп",
    "Deny access" : "Отказване на достъп",
    "Invite" : "Покани",
    "Discard changes?" : "Отхвърляне на промените?",
    "Are you sure you want to discard the changes made to this event?" : "Сигурни ли сте, че искате да отхвърлите промените направени в това събитие?",
    "_User requires access to your file_::_Users require access to your file_" : ["Потребителите трябва да имат достъп до вашия файл","Потребителите трябва да имат достъп до вашия файл"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Прикачени файлове, изискващи споделен достъп","Прикачени файлове, изискващи споделен достъп"],
    "Untitled event" : "Събитие без заглавие",
    "Close" : "Затвори",
    "Modifications will not get propagated to the organizer and other attendees" : "Промените няма да бъдат разпространени до организатора и другите участници",
    "Meeting proposals overview" : "Преглед на предложения за среща",
    "Edit meeting proposal" : "Редактиране на предложение за среща",
    "Create meeting proposal" : "Създайте предложение за среща",
    "Update meeting proposal" : "Актуализиране на предложение за среща",
    "Saving proposal \"{title}\"" : "Запазване на предложение \"{title}\"",
    "Successfully saved proposal" : "Успешно запазено предложение",
    "Failed to save proposal" : "Неуспешно запазване на предложение",
    "Create a meeting for \"{date}\"? This will create a calendar event with all participants." : "Създайте среща за \"{date}\"? Това ще създаде събитие в календара с всички участници.",
    "Creating meeting for {date}" : "Създаване на среща за {date}",
    "Successfully created meeting for {date}" : "Успешно създадена среща за {date}",
    "Failed to create a meeting for {date}" : "Неуспешно създаване на среща за {date}",
    "Please enter a valid duration in minutes." : "Моля въведете валидна продължителност в минути.",
    "Failed to fetch proposals" : "Неуспешно извличане на предложения",
    "Failed to fetch free/busy data" : "Неуспешно извличане на данни за заетост/свободен час",
    "Selected" : "Избранo",
    "No Description" : "Няма описание",
    "No Location" : "Няма местоположение",
    "Edit this meeting proposal" : "Редактирайте това предложение за среща",
    "Delete this meeting proposal" : "Изтрийте това предложение за среща",
    "Title" : "Заглавие",
    "15 min" : "15 мин",
    "30 min" : "30 мин",
    "60 min" : "60 мин",
    "90 min" : "90 мин",
    "Participants" : "Участници",
    "Selected times" : "Избрани часове",
    "Previous span" : "Предишен период",
    "Next span" : "Следващ период",
    "Less days" : "По-малко дни",
    "More days" : "Още дни",
    "Loading meeting proposal" : "Предложението за среща се зарежда",
    "No meeting proposal found" : "Няма намерено предложение за среща",
    "Please wait while we load the meeting proposal." : "Моля изчакайте, докато заредим предложението за среща.",
    "The link you followed may be broken, or the meeting proposal may no longer exist." : "Връзката, която сте последвали, може да е неработеща или предложението за среща може вече да не съществува.",
    "Thank you for your response!" : "Благодарим Ви за отговора!",
    "Your vote has been recorded. Thank you for participating!" : "Вашият вот е записан. Благодарим Ви за участието!",
    "Unknown User" : "Неизвестен потребител",
    "No Title" : "Без заглавие",
    "No Duration" : "Без продължителност",
    "Select a different time zone" : "Изберете друга часова зона",
    "Submit" : "Изпращане",
    "Subscribe to {name}" : "Абониране за {name}",
    "Export {name}" : "Експортиране /изнасям/ на {name}",
    "Show availability" : "Показване на наличност",
    "Anniversary" : "Годишнина",
    "Appointment" : "Среща",
    "Business" : "Бизнес",
    "Education" : "Обучение",
    "Holiday" : "Празник",
    "Meeting" : "Среща",
    "Miscellaneous" : "Разни",
    "Non-working hours" : "Неработно време",
    "Not in office" : "Не е в офиса",
    "Phone call" : "Телефонен разговор",
    "Sick day" : "Болничен ден",
    "Special occasion" : "Специален повод",
    "Travel" : "Пътуване",
    "Vacation" : "Отпуска",
    "Midnight on the day the event starts" : "Полунощ в деня, в който започва събитието",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%nдни преди събитието в {formattedHourMinute}","%nдни преди събитието в {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%nседмица преди събитието в {formattedHourMinute}","%nседмица преди събитието в {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "в деня на събитието в {formattedHourMinute}",
    "at the event's start" : "в началото на събитието",
    "at the event's end" : "в края на събитието",
    "{time} before the event starts" : "{time} преди начало на събитието",
    "{time} before the event ends" : "{time} преди край на събитието",
    "{time} after the event starts" : "{time} след началото на събитието",
    "{time} after the event ends" : "{time} след края на събитието",
    "on {time}" : "на {time}",
    "on {time} ({timezoneId})" : "на {time} ({timezoneId})",
    "Week {number} of {year}" : "Седмица {number} от {year}",
    "Daily" : "Всеки ден",
    "Weekly" : "Всяка седмица",
    "Monthly" : "Месечно",
    "Yearly" : "Годишно",
    "_Every %n day_::_Every %n days_" : ["Всеки %n ден","Всеки %n дни"],
    "_Every %n week_::_Every %n weeks_" : ["Всеки %nседмици","Всеки %n "],
    "_Every %n month_::_Every %n months_" : ["Всеки %nмесеци","Всеки %n месеци"],
    "_Every %n year_::_Every %n years_" : ["Всеки %n години","Всеки %n години"],
    "_on {weekday}_::_on {weekdays}_" : ["on {weekdays}","през {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["на дните {dayOfMonthList}","на дните {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "на {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {dayOfMonthList}" : "в {monthNames} на {dayOfMonthList}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "през {monthNames} на {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "до {untilDate}",
    "_%n time_::_%n times_" : ["%n време","%n време"],
    "second" : "секунда",
    "third" : "трети",
    "fourth" : "четвърти",
    "fifth" : "пети",
    "second to last" : "предпоследен",
    "last" : "последен",
    "Untitled task" : "Задача без заглавие",
    "Please ask your administrator to enable the Tasks App." : "Моля, помолете вашия администратор да активира приложението за Задачи.",
    "You are not allowed to edit this event as an attendee." : "Нямате право да редактирате това събитие като присъстващ.",
    "W" : "W",
    "%n more" : "%n повече",
    "No events to display" : "Няма събития за показване",
    "All participants declined" : "Всички участници отказаха",
    "Please confirm your participation" : "Моля потвърдете Вашето участие",
    "You declined this event" : "Вие отказахте това събитие",
    "Your participation is tentative" : "Участието Ви е условно",
    "_+%n more_::_+%n more_" : ["+","+%n повече"],
    "No events" : "Няма събития",
    "Create a new event or change the visible time-range" : "Създаване на ново събитие или промяна на видимия времеви диапазон",
    "Failed to save event" : "Неуспешно запазване на събитие",
    "It might have been deleted, or there was a typo in a link" : "Възможно е да е била изтрита или да е имало печатна грешка при въвеждането на връзката",
    "It might have been deleted, or there was a typo in the link" : "Възможно е да е била изтрита или да е имало печатна грешка при въвеждането на връзката",
    "Meeting room" : "Конферентна зала",
    "Lecture hall" : "Лекционна зала",
    "Seminar room" : "Зала за семинари",
    "Other" : "Други",
    "When shared show" : "Показване при споделяне",
    "When shared show full event" : "При споделяне, показвай цялото събитие",
    "When shared show only busy" : "При споделяне, показвай само статус \"зает\"",
    "When shared hide this event" : "При споделяне, скривай това събитие",
    "The visibility of this event in read-only shared calendars." : "Видимостта на това събитие в споделени календари само за четене.",
    "Add a location" : "Добавяне на местоположение",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Добавете описание\n\n- За какво е тази среща\n- Точки от дневния ред\n- Всичко, което участниците трябва да подготвят",
    "Status" : "Състояние",
    "Confirmed" : "Потвърдено",
    "Canceled" : "Отказано",
    "Confirmation about the overall status of the event." : "Потвърждение заобщото състояние на събитието.",
    "Show as" : "Показване като",
    "Take this event into account when calculating free-busy information." : " Това събитие да се вземе предвид при изчисляване на информация за заетостта.",
    "Categories" : "Категории",
    "Categories help you to structure and organize your events." : "Категориите ви помагат да структурирате и организирате вашите събития.",
    "Search or add categories" : "Търсене или прибавяне на категории",
    "Add this as a new category" : "Добави като нова категория",
    "Custom color" : "Персонализиране на цвят",
    "Special color of this event. Overrides the calendar-color." : "Специален цвят на това събитие. Сменя цвета на календара.",
    "Error while sharing file" : "Грешка при споделяне на файл",
    "Error while sharing file with user" : "Грешка при споделянето на файл с потребител",
    "Error creating a folder {folder}" : "Грешка при създаването на папка {folder}",
    "Attachment {fileName} already exists!" : " Прикаченият файл {fileName} вече съществува!",
    "Attachment {fileName} added!" : "Прикаченият файл {fileName}е добавен!",
    "An error occurred during uploading file {fileName}" : "Възникна грешка при качването на файл {fileName}",
    "An error occurred during getting file information" : "Възникна грешка при получаването на информация за файла",
    "Talk conversation for proposal" : "Talk разговор за предложение",
    "An error occurred, unable to delete the calendar." : "Възникна грешка, невъзможност да се изтрие календара.",
    "Imported {filename}" : "Импортирано {filename}",
    "This is an event reminder." : "Това е напомняне за събитие.",
    "Error while parsing a PROPFIND error" : "Грешка при синтактичния анализ на грешка в PROPFIND",
    "Appointment not found" : "Срещата не е намерена",
    "User not found" : "Потребителят не е намерен ",
    "Hidden" : "Скрит",
    "can edit" : "може да редактира",
    "Calendar name …" : "Име на календар ...",
    "Default attachments location" : "Местоположение на прикачените файлове по подразбиране",
    "Automatic ({detected})" : "Автоматично (detected})",
    "Shortcut overview" : "Преглед на пряк път",
    "CalDAV link copied to clipboard." : "Копиране на CalDAV връзка в клипборда",
    "CalDAV link could not be copied to clipboard." : "CalDAV връзката не може да бъде копирана в клипборда",
    "Enable birthday calendar" : "Активиране на календара за рожден ден",
    "Show tasks in calendar" : "Показване на задачите в календара",
    "Enable simplified editor" : "Активиране на опростен редактор",
    "Limit the number of events displayed in the monthly view" : "Ограничаване на броя на събитията, показвани в месечния изглед",
    "Show weekends" : "Покажи събота и неделя",
    "Show week numbers" : "Показвай номерата на седмиците",
    "Time increments" : "Времеви стъпки",
    "Default calendar for incoming invitations" : "Календар по подразбиране за входящи покани",
    "Copy primary CalDAV address" : "Копиране на основния CalDAV адрес",
    "Copy iOS/macOS CalDAV address" : "Копиране iOS/macOS CalDAV адрес",
    "Personal availability settings" : "Настройки за лична достъпност",
    "Show keyboard shortcuts" : "Показване на клавишни комбинации",
    "Create a new public conversation" : "Създаване на нов публичен разговор",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} поканен, {confirmedCount}потвърден",
    "Successfully appended link to talk room to location." : "Връзката към стаята за разговори е успешно добавена към местоположението.",
    "Successfully appended link to talk room to description." : "Успешно добавена връзка към стаята за разговори от описанието.",
    "Error creating Talk room" : "Грешка при създаването на Стая за разговори",
    "The visibility of this event in shared calendars." : "Видимостта на това събитие в споделени календари."
},
"nplurals=2; plural=(n != 1);");
