OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Berilgan elektron pochta manzili juda uzun",
    "User-Session unexpectedly expired" : "Foydalanuvchi-sessiyaning muddati kutilmaganda tugadi",
    "Provided email-address is not valid" : "Ko'rsatilgan elektron pochta manzili noto'g'ri",
    "%s has published the calendar »%s«" : "%s kalendarini e’lon qildi »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Email yuborishda kutilmagan xatolik yuz berdi. Iltimos, administratoringizga murojaat qiling.",
    "Successfully sent email to %1$s" : " %1$sE-pochta manziliga muvaffaqiyatli yuborildi",
    "Hello," : "Assalomu aleykum,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Bu haqda sizga xabar bermoqchi edik %s  kalendarini e’lon qildi »%s«.",
    "Open »%s«" : "ochish »%s«",
    "Cheers!" : "Salom!",
    "Upcoming events" : "Kelgusi voqealar",
    "No more events today" : "Bugun boshqa tadbirlar yo'q",
    "No upcoming events" : "Kelgusi tadbirlar yo'q",
    "More events" : "Boshqa tadbirlar",
    "%1$s with %2$s" : "%1$s bilan %2$s",
    "Calendar" : "Kalendar",
    "New booking {booking}" : "Yangi bronlash {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) uchrashuvga yozildi \"{config_display_name}\" {date_time} da.",
    "Appointments" : "Uchrashuvlar",
    "Schedule appointment \"%s\"" : "Uchrashuvni rejalashtirish \"%s\"",
    "Schedule an appointment" : "Uchrashuvni rejalashtirish",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : " %s uchun tayyorlang",
    "Follow up for %s" : " %s uchun kuzatib boring",
    "Your appointment \"%s\" with %s needs confirmation" : " \"%s\" bilan %s uchrashuvingiz tasdiqlash kerak",
    "Dear %s, please confirm your booking" : "Hurmatli %s, iltimos, bandlovingizni tasdiqlang",
    "Confirm" : "Tasdiqlang",
    "Appointment with:" : "Uchrashuv:",
    "Description:" : "Tavsif:",
    "This confirmation link expires in %s hours." : "Bu tasdiqlash havolasi muddati tugaydi  %s soatda.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Agar siz uchrashuvni bekor qilmoqchi bo'lsangiz, tashkilotchingizga ushbu xatga javob berish yoki ularning profil sahifasiga tashrif buyurish orqali murojaat qiling.",
    "Your appointment \"%s\" with %s has been accepted" : "\"%s\" bilan %s uchrashuvingiz qabul qilingan",
    "Dear %s, your booking has been accepted." : "Hurmatli %s, bandlovingiz qabul qilindi.",
    "Appointment for:" : "Uchrashuv:",
    "Date:" : "Sana:",
    "You will receive a link with the confirmation email" : "Siz tasdiqlash elektron pochtasi bilan havola olasiz",
    "Where:" : "Qayerda:",
    "Comment:" : "Izoh:",
    "You have a new appointment booking \"%s\" from %s" : "Sizda yangi uchrashuv bandi bor \"%s\" dan %s",
    "Dear %s, %s (%s) booked an appointment with you." : "Hurmatli %s, %s (%s) siz bilan uchrashuvga yozildi.",
    "%s has proposed a meeting" : "%s uchrashuv taklif qildi",
    "%s has updated a proposed meeting" : "%s taklif qilingan uchrashuvni yangiladi",
    "%s has canceled a proposed meeting" : "%s taklif qilingan uchrashuvni bekor qildi",
    "Dear %s, a new meeting has been proposed" : "Hurmatli %s, yangi uchrashuv taklif qilindi",
    "Dear %s, a proposed meeting has been updated" : "Hurmatli %s, taklif qilingan uchrashuv yangilandi",
    "Dear %s, a proposed meeting has been cancelled" : "Hurmatli %s, taklif qilingan uchrashuv bekor qilindi",
    "Location:" : "Manzil:",
    "Duration:" : "Davomiyligi:",
    "%1$s from %2$s to %3$s" : "%1$s: %2$s dan %3$s gacha",
    "Dates:" : "Sanalar:",
    "Respond" : "Javob bering",
    "A Calendar app for Nextcloud" : "Nextcloud uchun kalendar ilovasi",
    "A Calendar app for Nextcloud. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Like Contacts, Talk, Tasks, Deck and Circles\n* 🌐 **WebCal Support!** Want to see your favorite team's matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 **Search!** Find your events at ease\n* ☑️ **Tasks!** See tasks or Deck cards with a due date directly in the calendar\n* 🔈 **Talk rooms!** Create an associated Talk room when booking a meeting with just one click\n* 📆 **Appointment booking** Send people a link so they can book an appointment with you [using this app](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Attachments!** Add, upload and view event attachments\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Nextcloud uchun kalendar ilovasi. Turli qurilmalardagi voqealarni Nextcloud bilan osongina sinxronlang va ularni onlayn tahrirlang.\n\n* 🚀 **Boshqa Nextcloud ilovalari bilan integratsiya!** Kontaktlar, Talk, Tasks, Deck va Circles kabi\n* 🌐 **WebCal Support!** Taqvimingizda sevimli jamoangizning o'yin kunlarini ko'rishni xohlaysizmi? Hammasi joyida!\n* 🙋 **Ishtirokchilar!** Tadbirlaringizga odamlarni taklif qiling\n* ⌚ **Erkin/Band!** Qatnashuvchilaringiz qachon uchrashishga tayyorligini bilib oling\n* ⏰ **Eslatmalar!** Brauzeringiz ichida va elektron pochta orqali hodisalar uchun signallarni oling\n* 🔍 **Qidiring!** Voqealaringizni bemalol toping\n* ☑️ **Vazifalar!** Toʻgʻridan-toʻgʻri taqvimdagi topshiriqlar yoki tugash sanasi bilan Deck kartalarini koʻring.\n* 🔈 **Suhbat xonalari!** Uchrashuvni bron qilishda bir marta bosish bilan bog‘langan suhbat xonasi yarating\n* 📆 **Uchrashuvni band qilish** Odamlarga [ushbu ilova yordamida] siz bilan uchrashuv tayinlashlari uchun havolani yuboring (https://apps.nextcloud.com/apps/appointments)\n* 📎 **Biriktirmalar!** Tadbir qoʻshimchalarini qoʻshing, yuklang va koʻring\n* 🙈 **Biz g‘ildirakni qaytadan ixtiro qilmayapmiz!** Ajoyib [c-dav kutubxonasi](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) va [fullcalendar](https://github.com/mozilla-comm/ical.js) asosida (https://fulllendar) kutubxonalar.",
    "Previous day" : "Oldingi kun",
    "Previous week" : "Oldingi hafta",
    "Previous year" : "Oldingi yil",
    "Previous month" : "Oldingi oy",
    "Next day" : "Keyingi kun",
    "Next week" : "Keyingi hafta",
    "Next year" : "Keyingi yil",
    "Next month" : "Keyingi oy",
    "Create new event" : "Yangi tadbir yarating",
    "Event" : "Tadbir",
    "Today" : "Bugun",
    "Day" : "Kun",
    "Week" : "Hafta",
    "Month" : "Oy",
    "Year" : "Yil",
    "List" : "Ro`yxat",
    "Appointment link was copied to clipboard" : "Uchrashuv havolasi vaqtinchalik xotiraga nusxalandi",
    "Appointment link could not be copied to clipboard" : "Uchrashuv havolasini vaqtinchalik xotiraga nusxalab bo‘lmadi",
    "Preview" : "Ko‘rib chiqish",
    "Copy link" : "Havolani nusxalash",
    "Edit" : "Tahrirlash",
    "Delete" : "O'chirish",
    "Appointment schedules" : "Uchrashuvlar taqvimi",
    "Create new" : "Yangi yaratish",
    "Disable calendar \"{calendar}\"" : "Taqvimni o'chirib qo'yish \"{calendar}\"",
    "Disable untitled calendar" : "Nomsiz taqvimni o'chirib qo'ying",
    "Enable calendar \"{calendar}\"" : "Kalendarni yoqish \"{calendar}\"",
    "Enable untitled calendar" : "Nomsiz kalendarni yoqish",
    "An error occurred, unable to change visibility of the calendar." : "Xatolik yuz berdi, taqvim koʻrinishini oʻzgartirib boʻlmadi.",
    "Untitled calendar" : "Nomsiz kalendar",
    "Shared with you by" : "Siz bilan baham ko'rgan",
    "Edit and share calendar" : "Taqvimni tahrirlash va almashish",
    "Edit calendar" : "Taqvimni tahrirlash",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Taqvimni ulashish bekor qilinmoqda {countdown} sekund"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["taqvimni o'chirish {countdown} sekund"],
    "An error occurred, unable to create the calendar." : "Xatolik yuz berdi, taqvim yaratib bo‘lmadi.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Yaroqli havolani kiriting (http://, https://, webcal:// yoki webcals:// bilan boshlanadi)",
    "Calendars" : "Taqvimlar",
    "Add new" : "Yangi yaratish",
    "New calendar" : "Yangi taqvim",
    "Name for new calendar" : "Yangi taqvim uchun nom",
    "Creating calendar …" : "Taqvim yaratish...",
    "New calendar with task list" : "Vazifalar ro'yxati bilan yangi taqvim",
    "New subscription from link (read-only)" : "Havoladan yangi obuna (faqat o'qish uchun)",
    "Creating subscription …" : "Obuna yaratilmoqda…",
    "Add public holiday calendar" : "Bayramlar taqvimini qo'shing",
    "Add custom public calendar" : "Shaxsiy umumiy taqvim qo'shing",
    "Calendar link copied to clipboard." : "Taqvim havolasi vaqtinchalik xotiraga nusxalandi.",
    "Calendar link could not be copied to clipboard." : "Taqvim havolasini vaqtinchalik xotiraga nusxalab bo‘lmadi.",
    "Copy subscription link" : "Obuna havolasidan nusxa oling",
    "Copying link …" : "Havola nusxalanmoqda…",
    "Copied link" : "Nusxalangan havola",
    "Could not copy link" : "Havolani nusxalab bo‘lmadi",
    "Export" : "Eksport",
    "Untitled item" : "Nomsiz element",
    "Unknown calendar" : "Noma'lum taqvim",
    "Could not load deleted calendars and objects" : "Oʻchirilgan taqvimlar va obyektlarni yuklab boʻlmadi",
    "Could not delete calendar or event" : "Taqvim yoki tadbirni oʻchirib boʻlmadi",
    "Could not restore calendar or event" : "Taqvim yoki tadbirni tiklab bo‘lmadi",
    "Do you really want to empty the trash bin?" : "Haqiqatan ham o`chirilgan fayllar qutisini bo'shatmoqchimisiz?",
    "Empty trash bin" : "O`chirilgan fayllar qutisini bo'shatish",
    "Trash bin" : "O`chirilgan fayllar qutisi",
    "Loading deleted items." : "Oʻchirilgan elementlar yuklanmoqda.",
    "You do not have any deleted items." : "Sizda hech qanday oʻchirilgan element yoʻq.",
    "Name" : "Nom",
    "Deleted" : "O`chirilgan",
    "Restore" : "Qayta tiklangan",
    "Delete permanently" : "Butunlay o'chirish",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["O`chirilgan fayllar qutisidagi narsalar  {numDays} kundan keyin o'chiriladi."],
    "Could not update calendar order." : "Taqvim tartibini yangilab bo‘lmadi.",
    "Shared calendars" : "Umumiy taqvimlar",
    "Deck" : "Pastki qavat",
    "Internal link" : "Ichki havola",
    "A private link that can be used with external clients" : "Tashqi mijozlar bilan foydalanish mumkin bo'lgan shaxsiy havola",
    "Copy internal link" : "Ichki havoladan nusxa olish",
    "An error occurred, unable to publish calendar." : "Xatolik yuz berdi, taqvimni nashr qilib bo‘lmadi.",
    "An error occurred, unable to send email." : "Xatolik yuz berdi, xat yuborib bo‘lmadi.",
    "Embed code copied to clipboard." : "O‘rnatish kodi vaqtinchalik xotiraga nusxalandi.",
    "Embed code could not be copied to clipboard." : "O‘rnatish kodini vaqtinchalik xotiraga nusxalab bo‘lmadi.",
    "Unpublishing calendar failed" : "Taqvim nashrdan chiqarilmadi",
    "Share link" : "Havolani ulashing",
    "Copy public link" : "Umumiy havoladan nusxa oling",
    "Send link to calendar via email" : "Taqvimga havolani elektron pochta orqali yuboring",
    "Enter one address" : "Bitta manzilni kiriting",
    "Sending email …" : "Email yuborilmoqda…",
    "Copy embedding code" : "O'rnatish kodini nusxalash",
    "Copying code …" : "Kod nusxalanmoqda…",
    "Copied code" : "Kod nusxalandi",
    "Could not copy code" : "Kodni nusxalab bo‘lmadi",
    "Delete share link" : "Ulashish havolasini o'chirish",
    "Deleting share link …" : "Ulashish havolasi oʻchirilmoqda …",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Komanda)",
    "An error occurred while unsharing the calendar." : "Taqvimni ulashishni bekor qilishda xatolik yuz berdi.",
    "An error occurred, unable to change the permission of the share." : "Xatolik yuz berdi, ulashish ruxsatini o‘zgartirib bo‘lmadi.",
    "Unshare with {displayName}" : " {displayName}bilan ulashishni bekor qilish",
    "Share with users or groups" : "Foydalanuvchilar yoki guruhlar bilan baham ko'ring",
    "No users or groups" : "Foydalanuvchilar yoki guruhlar yo'q",
    "Failed to save calendar name and color" : "Taqvim nomi va rangini saqlab bo‘lmadi",
    "Calendar name …" : "Taqvim nomi …",
    "Never show me as busy (set this calendar to transparent)" : "Meni hech qachon band deb ko‘rsatma (ushbu taqvimni shaffof qilib qo‘ying)",
    "Share calendar" : "Taqvimni ulashish",
    "Unshare from me" : "Mendan baham ko'rishni bekor qilish",
    "Save" : "Saqlash",
    "No title" : "Sarlavha yo'q",
    "Are you sure you want to delete \"{title}\"?" : "Haqiqatan ham “{title}”ni o‘chirib tashlamoqchimisiz?",
    "Deleting proposal \"{title}\"" : "“{title}” taklifi oʻchirilmoqda",
    "Successfully deleted proposal" : "Taklif muvaffaqiyatli oʻchirildi",
    "Failed to delete proposal" : "Taklifni o‘chirib bo‘lmadi",
    "Failed to retrieve proposals" : "Takliflar olinmadi",
    "Meeting proposals" : "Uchrashuv takliflari",
    "A configured email address is required to use meeting proposals" : "Uchrashuv takliflaridan foydalanish uchun sozlangan elektron pochta manzili talab qilinadi",
    "No active meeting proposals" : "Faol uchrashuv takliflari yo'q",
    "View" : "Ko'rish",
    "Import calendars" : "Taqvimlarni import qilish",
    "Please select a calendar to import into …" : "Import qilish uchun taqvimni tanlang…",
    "Filename" : "Fayl nomi",
    "Calendar to import into" : "Import qilish uchun taqvim",
    "Cancel" : "Bekor qilish",
    "_Import calendar_::_Import calendars_" : ["Taqvimlarni import qilish"],
    "Select the default location for attachments" : "Qo'shimchalar uchun standart joyni tanlang",
    "Pick" : "Tanlov",
    "Invalid location selected" : "Yaroqsiz joy tanlangan",
    "Attachments folder successfully saved." : "Qo'shimchalar jildi muvaffaqiyatli saqlandi.",
    "Error on saving attachments folder." : "Qo'shimchalar jildini saqlashda xatolik yuz berdi.",
    "{filename} could not be parsed" : "{filename} tahlil qilib bo‘lmadi",
    "No valid files found, aborting import" : "Hech qanday yaroqli fayl topilmadi, import bekor qilinmoqda",
    "_Successfully imported %n event_::_Successfully imported %n events_" : [" %n tadbirlar muvaffaqiyatli import qilindi."],
    "Import partially failed. Imported {accepted} out of {total}." : "Import qisman amalga oshmadi.  {accepted} holatda amalga oshmagan {total}umumiy importdan.",
    "Automatic" : "Automatik",
    "Automatic ({timezone})" : "Automatik ({timezone})",
    "New setting was not saved successfully." : "Yangi sozlama muvaffaqiyatli saqlanmadi.",
    "Timezone" : "Vaqt mintaqasi",
    "Navigation" : "Navigatsiya",
    "Previous period" : "Oldingi davr",
    "Next period" : "Keyingi davr",
    "Views" : "Koʻrishlar",
    "Day view" : "Kunlik ko'rinish",
    "Week view" : "Hafta ko'rinishi",
    "Month view" : "Oy ko'rinishi",
    "Year view" : "Yil ko'rinishi",
    "List view" : "Ro'yxat ko'rinishi",
    "Actions" : "Faolliklar",
    "Create event" : "Tadbir yaratish",
    "Show shortcuts" : "Yorliqlarni ko'rsatish",
    "Editor" : "Tahrirchi",
    "Close editor" : "Muharrirni yoping",
    "Save edited event" : "Tahrirlangan tadbirni saqlang",
    "Delete edited event" : "Tahrirlangan tadbirni oʻchirish",
    "Duplicate event" : "Tadbirni nusxalash",
    "or" : "yoki",
    "Calendar settings" : "Taqvim sozlamalari",
    "At event start" : "Tadbir boshlanishida",
    "No reminder" : "Eslatma yo'q",
    "Failed to save default calendar" : "Standart taqvim saqlanmadi",
    "General" : "Umumiy",
    "Appearance" : "Tashqi ko'rinish",
    "Editing" : "Tahrirlash",
    "Default reminder" : "Standart eslatma",
    "Files" : "Fayllar",
    "Appointment schedule successfully created" : "Uchrashuv jadvali yaratildi",
    "Appointment schedule successfully updated" : "Uchrashuv jadvali muvaffaqiyatli yangilandi",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minut"],
    "0 minutes" : "0 minut",
    "_{duration} hour_::_{duration} hours_" : ["{duration} soat"],
    "_{duration} day_::_{duration} days_" : ["{duration} kun"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} hafta"],
    "_{duration} month_::_{duration} months_" : ["{duration} oy"],
    "_{duration} year_::_{duration} years_" : ["{duration} yil"],
    "To configure appointments, add your email address in personal settings." : "Uchrashuvlarni sozlash uchun shaxsiy sozlamalarga elektron pochta manzilingizni qo'shing.",
    "Public – shown on the profile page" : "Umumiy - profil sahifasida ko'rsatiladi",
    "Private – only accessible via secret link" : "Shaxsiy - faqat maxfiy havola orqali kirish mumkin",
    "Appointment schedule saved" : "Uchrashuv jadvali saqlandi",
    "Create appointment schedule" : "Uchrashuv jadvalini tuzing",
    "Edit appointment schedule" : "Uchrashuv jadvalini tahrirlash",
    "Update" : "Yangilash",
    "Appointment name" : "Uchrashuv nomi",
    "Location" : "Joylashuv",
    "Create a Talk room" : "Suhbat xonasi yarating",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Har bir band qilingan uchrashuv uchun noyob havola yaratiladi va tasdiqlovchi elektron pochta orqali yuboriladi",
    "Description" : "Tavsif",
    "Visibility" : "Ko'rinish",
    "Duration" : "Davomiyligi",
    "Increments" : "O'sishlar",
    "Additional calendars to check for conflicts" : "Mojarolarni tekshirish uchun qo'shimcha taqvimlar",
    "Pick time ranges where appointments are allowed" : "Uchrashuvlarga ruxsat berilgan vaqt oralig'ini tanlang",
    "to" : "ga",
    "Delete slot" : "Slotni o'chirish",
    "No times set" : "Vaqt belgilanmagan",
    "Add" : "Qo`shish",
    "Monday" : "Dushanba",
    "Tuesday" : "Seshanba",
    "Wednesday" : "Chorshanba",
    "Thursday" : "Payshanba",
    "Friday" : "Juma",
    "Saturday" : "Shanba",
    "Sunday" : "Yakshanba",
    "Weekdays" : "Dam olish kunlari",
    "Add time before and after the event" : "Tadbirdan oldin va keyin vaqt qo'shing",
    "Before the event" : "Tadbir oldidan",
    "After the event" : "Tadbirdan keyin",
    "Planning restrictions" : "Rejalashtirish cheklovlari",
    "Minimum time before next available slot" : "Keyingi mavjud slotgacha bo'lgan minimal vaqt",
    "Max slots per day" : "Kuniga maksimal slotlar",
    "Limit how far in the future appointments can be booked" : "Kelajakdagi uchrashuvlarni qancha vaqtgacha bron qilishni cheklang",
    "It seems a rate limit has been reached. Please try again later." : "Tarif chegarasiga yetganga o‘xshaydi. Keyinroq qayta urinib ko‘ring.",
    "Please confirm your reservation" : "Iltimos, bandlovingizni tasdiqlang",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Sizga batafsil ma'lumotni elektron pochta orqali yubordik. Iltimos, elektron pochtadagi havola orqali uchrashuvingizni tasdiqlang. Bu sahifani hozir yopishingiz mumkin.",
    "Your name" : "Sizning ismingiz",
    "Your email address" : "Sizning e-pochta manzilingiz",
    "Please share anything that will help prepare for our meeting" : "Iltimos, uchrashuvimizga tayyorgarlik ko'rishga yordam beradigan narsalarni baham ko'ring",
    "Could not book the appointment. Please try again later or contact the organizer." : "Uchrashuvni yozib boʻlmadi. Keyinroq qayta urinib ko‘ring yoki tashkilotchi bilan bog‘laning.",
    "Back" : "Orqaga",
    "Book appointment" : "Uchrashuvni tayinlash",
    "Error fetching Talk conversations." : "Talk suhbatlarini olishda xatolik yuz berdi.",
    "Conversation does not have a valid URL." : "Suhbatda yaroqli URL manzili yo‘q.",
    "Successfully added Talk conversation link to location." : "Muloqot suhbati havolasi joylashuvga muvaffaqiyatli qo‘shildi.",
    "Successfully added Talk conversation link to description." : "Tavsifga Talk suhbati havolasi muvaffaqiyatli qo‘shildi.",
    "Failed to apply Talk room." : "Muloqot xonasini qo‘llab bo‘lmadi.",
    "Talk conversation for event" : "Tadbir uchun suhbat",
    "Error creating Talk conversation" : "Talk suhbatini yaratishda xatolik yuz berdi",
    "Select a Talk Room" : "Suhbat xonasini tanlang",
    "Add Talk conversation" : "Talk suhbatini qo'shing",
    "Fetching Talk rooms…" : "Muloqot xonalari olinmoqda…",
    "No Talk room available" : "Suhbat xonasi mavjud emas",
    "Select conversation" : "Suhbatni tanlang",
    "on" : "da",
    "at" : "ga",
    "before at" : "oldin",
    "Notification" : "Bildirishnomalar",
    "Email" : "Email",
    "Audio notification" : "Audio xabarnoma",
    "Other notification" : "Boshqa bildirishnoma",
    "Relative to event" : "Tadbirga nisbatan",
    "On date" : "Sanada",
    "Edit time" : "Vaqtni tahrirlash",
    "Save time" : "Vaqtni saqlash",
    "Remove reminder" : "Eslatmani olib tashlash",
    "Add reminder" : "+ Eslatma qo'shish",
    "seconds" : "sekund",
    "minutes" : "minut",
    "hours" : "soat",
    "days" : "kun",
    "weeks" : "hafta",
    "Choose a file to add as attachment" : "Ilova sifatida qo'shish uchun faylni tanlang",
    "Choose a file to share as a link" : "Havola sifatida almashish uchun faylni tanlang",
    "Attachment {name} already exist!" : "Qo'shimcha{name} allaqachon mavjud!",
    "Could not upload attachment(s)" : "Biriktirma(lar)ni yuklab bo‘lmadi",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : " Siz navigatsiya qilmoqchisiz {host}. Davom etishga ishonchingiz komilmi? Havola: {link}",
    "Proceed" : "Davom etish",
    "No attachments" : "Qo‘shimchalar yo‘q",
    "Add from Files" : "Fayllardan qo'shish",
    "Upload from device" : "Qurilmadan yuklash",
    "Delete file" : "Faylni o'chirish",
    "Confirmation" : "Tasdiqlash",
    "_{count} attachment_::_{count} attachments_" : ["{count} qo'shimchalar"],
    "Suggested" : "Tavsiya etilgan",
    "Available" : "Mavjud",
    "Invitation accepted" : "Taklif qabul qilindi",
    "Accepted {organizerName}'s invitation" : "Qabul qilingan {organizerName}ning taklifnomasi",
    "Participation marked as tentative" : "Ishtirok etish taxminiy deb belgilandi",
    "Invitation is delegated" : "Taklif topshiriladi",
    "Not available" : "Mavjud emas",
    "Invitation declined" : "Taklif rad etildi",
    "Declined {organizerName}'s invitation" : "Rad etildi {organizerName}ning taklifnomasi",
    "Availability will be checked" : "Mavjudligi tekshiriladi",
    "Invitation will be sent" : "Taklifnoma yuboriladi",
    "Failed to check availability" : "Mavjudligini tekshirib bo‘lmadi",
    "Failed to deliver invitation" : "Taklifnoma yetkazilmadi",
    "Awaiting response" : "Javob kutilmoqda",
    "Checking availability" : "Mavjudligi tekshirilmoqda",
    "Has not responded to {organizerName}'s invitation yet" : " {organizerName}ning taklifiga hali javob bermadi",
    "Suggested times" : "Tavsiya etilgan vaqtlar",
    "chairperson" : "rais",
    "required participant" : "talab qilinadigan ishtirokchi",
    "non-participant" : "qatnashmaydigan",
    "optional participant" : "ixtiyoriy ishtirokchi",
    "{organizer} (organizer)" : "{organizer} (tashkilotchi)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Availability of attendees, resources and rooms" : "Ishtirokchilar, resurslar va xonalarning mavjudligi",
    "Suggestion accepted" : "Taklif qabul qilindi",
    "Previous date" : "Oldingi sana",
    "Next date" : "Keyingi sana",
    "Legend" : "Ta`rif",
    "Out of office" : "Ofisda emas",
    "Attendees:" : "Ishtirokchilar:",
    "local time" : "local time",
    "Done" : "Bajarildi",
    "Search room" : "Xonani qidirish",
    "Room name" : "Xona nomi",
    "Check room availability" : "Xona bo`shligini tekshiring",
    "Free" : "Bepul",
    "Busy (tentative)" : "Band (taxminan)",
    "Busy" : "Band",
    "Unknown" : "Noma'lum",
    "Find a time" : "Vaqt toping",
    "The invitation has been accepted successfully." : "Taklif muvaffaqiyatli qabul qilindi.",
    "Failed to accept the invitation." : "Taklifni qabul qilib bo‘lmadi.",
    "The invitation has been declined successfully." : "Taklifnoma muvaffaqiyatli rad etildi.",
    "Failed to decline the invitation." : "Taklifni rad etib bo'lmadi.",
    "Your participation has been marked as tentative." : "Sizning ishtirokingiz taxminiy deb belgilandi.",
    "Failed to set the participation status to tentative." : "Ishtirok etish holatini taxminiy qilib o‘rnatib bo‘lmadi.",
    "Accept" : "Qabul qiling",
    "Decline" : "Rad etish",
    "Tentative" : "Taxminan",
    "No attendees yet" : "Hozircha ishtirokchilar yoʻq",
    "Please add at least one attendee to use the \"Find a time\" feature." : "“Vaqt topish” funksiyasidan foydalanish uchun kamida bitta ishtirokchi qo‘shing.",
    "Attendees" : "Ishtirokchilar",
    "Remove group" : "Guruhni olib tashlash",
    "Remove attendee" : "Ishtirokchini olib tashlash",
    "Request reply" : "Javob so'rash",
    "Chairperson" : "Rais",
    "Required participant" : "Majburiy ishtirokchi",
    "Optional participant" : "Ixtiyoriy ishtirokchi",
    "Non-participant" : "Qatnashmaydigan",
    "_%n member_::_%n members_" : ["%n a'zolari"],
    "Search for emails, users, contacts, contact groups or teams" : "Elektron pochta, foydalanuvchilar, kontaktlar, aloqa guruhlari yoki jamoalarni qidiring",
    "No match found" : "Hech qanday moslik topilmadi",
    "Note that members of circles get invited but are not synced yet." : "Esda tutingki, davra a’zolari taklif qilinadi, lekin hali sinxronlanmagan.",
    "Note that members of contact groups get invited but are not synced yet." : "E'tibor bering, kontakt guruhlari a'zolari taklif qilinadi, lekin hali sinxronlanmagan.",
    "(organizer)" : "(tashkilotchi)",
    "Make {label} the organizer" : " {label} ni tashkilotchi qilish",
    "Make {label} the organizer and attend" : " {label} ni tashkilotchi va qatnashuvchi qilish",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Taklifnomalarni yuborish va javoblarni ko‘rib chiqish uchun [linkopen]shaxsiy sozlamalarga elektron pochta manzilingizni qo‘shing[linkclose].",
    "Remove color" : "Rangni olib tashlang",
    "Event title" : "Tadbir sarlavhasi",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Takrorlanishlar to‘plamining bir qismi bo‘lgan tadbirlar uchun kun bo‘yi sozlamani o‘zgartirib bo‘lmaydi.",
    "From" : "Dan",
    "To" : "Gacha",
    "Repeat" : "Takrorlash",
    "Repeat event" : "Hodisani takrorlash",
    "_time_::_times_" : ["vaqt"],
    "never" : "hech qachon",
    "on date" : "vaqtida",
    "after" : "keyin",
    "End repeat" : "Takrorlashni tugatish",
    "Select to end repeat" : "Takrorlashni tugatish uchun tanlang",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Bu hodisa takrorlanish-to'plamning takrorlanish-istisnosidir. Siz unga takrorlanish qoidasini qo'sha olmaysiz.",
    "first" : "dastlabki",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Takrorlanish qoidasiga kiritilgan o'zgartirishlar faqat shu va kelajakdagi barcha hodisalarga nisbatan qo'llaniladi.",
    "Repeat every" : "Har doim takrorlang",
    "By day of the month" : "Oy kuni bo'yicha",
    "On the" : "Ustida",
    "_day_::_days_" : ["kun"],
    "_week_::_weeks_" : ["hafta"],
    "_month_::_months_" : ["oy"],
    "_year_::_years_" : ["yil"],
    "On specific day" : "Muayyan kunda",
    "weekday" : "ish kuni",
    "weekend day" : "dam olish kuni",
    "Does not repeat" : "Takrorlanmaydi",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Ushbu hodisaning takrorlanish ta'rifi Nextcloud tomonidan to'liq qo'llab-quvvatlanmaydi. Agar siz takrorlash parametrlarini tahrir qilsangiz, ba'zi takrorlanishlar yo'qolishi mumkin.",
    "No rooms or resources yet" : "Hozircha xonalar yoki manbalar yo'q",
    "Resources" : "Resurslar",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} joylar"],
    "Add resource" : "Resurs qo'shing",
    "Has a projector" : "Proyektori bor",
    "Has a whiteboard" : "Doska bor",
    "Wheelchair accessible" : "Imtiyozlilar kirish mumkin",
    "Remove resource" : "Resursni olib tashlang",
    "Search for resources or rooms" : "Resurslar yoki xonalarni qidiring",
    "available" : "mavjud",
    "unavailable" : "mavjud emas",
    "Show all rooms" : "Barcha xonalarni ko'rsatish",
    "Projector" : "Proyektor",
    "Whiteboard" : "Oq doska",
    "Room type" : "Xona turi",
    "Any" : "Har qanday",
    "Minimum seating capacity" : "Minimal o'tiradigan joy",
    "More details" : "Batafsil ma'lumot",
    "Update this and all future" : "Buni va barcha kelajakni yangilang",
    "Update this occurrence" : "Ushbu hodisani yangilang",
    "Public calendar does not exist" : "Umumiy taqvim mavjud emas",
    "Maybe the share was deleted or has expired?" : "Ehtimol, ulashish o'chirilgan yoki muddati tugaganmi?",
    "Remove date" : "Sanani olib tashlash",
    "Attendance required" : "Ishtirok etish shart",
    "Attendance optional" : "Davomat ixtiyoriy",
    "Remove participant" : "Ishtirokchini olib tashlash",
    "Yes" : "Ha",
    "No" : "Yo`q",
    "Maybe" : "Balki",
    "None" : "Yo'q",
    "Select your meeting availability" : "Uchrashuvning mavjudligini tanlang",
    "Create a meeting for this date and time" : "Ushbu sana va vaqt uchun uchrashuv yarating",
    "Create" : "Yaratish",
    "No participants or dates available" : "Ishtirokchilar yoki sanalar mavjud emas",
    "from {formattedDate}" : " {formattedDate}dan",
    "to {formattedDate}" : " {formattedDate} gacha",
    "on {formattedDate}" : " {formattedDate}da",
    "from {formattedDate} at {formattedTime}" : " {formattedDate}dan {formattedTime}gacha",
    "to {formattedDate} at {formattedTime}" : " {formattedDate}uchun  {formattedTime}da",
    "on {formattedDate} at {formattedTime}" : " {formattedDate}dagi {formattedTime}uchun",
    "{formattedDate} at {formattedTime}" : "{formattedDate}  {formattedTime}uchun",
    "Please enter a valid date" : "Yaroqli sana kiriting",
    "Please enter a valid date and time" : "Yaroqli sana va vaqtni kiriting",
    "Select a time zone" : "Vaqt mintaqasini tanlang",
    "Please select a time zone:" : "Vaqt mintaqasini tanlang:",
    "Pick a time" : "Vaqtni tanlang",
    "Pick a date" : "Sana tanlang",
    "Type to search time zone" : "Vaqt mintaqasini qidirish uchun kiriting",
    "Global" : "Global",
    "Holidays in {region}" : " {region}da dam olish kunlari",
    "An error occurred, unable to read public calendars." : "Xatolik yuz berdi, umumiy taqvimni o‘qib bo‘lmadi.",
    "An error occurred, unable to subscribe to calendar." : "Xatolik yuz berdi, taqvimga obuna boʻlmadi.",
    "Public holiday calendars" : "Davlat bayramlari taqvimi",
    "Public calendars" : "Umumiy taqvim",
    "No valid public calendars configured" : "Yaroqli umumiy taqvim sozlanmagan",
    "Speak to the server administrator to resolve this issue." : "Ushbu muammoni hal qilish uchun server administratoriga murojaat qiling.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Davlat bayramlari kalendarlari Thunderbird tomonidan taqdim etiladi. Taqvim maʼlumotlari {website}dan yuklab olinadi",
    "These public calendars are suggested by the server administrator. Calendar data will be downloaded from the respective website." : "Ushbu umumiy taqvimlar server administratori tomonidan taklif qilinadi. Taqvim ma'lumotlari tegishli veb-saytdan yuklab olinadi.",
    "By {authors}" : " {authors}tomonidan",
    "Subscribed" : "Obuna boʻlgan",
    "Subscribe" : "Obuna boʻlish",
    "Could not fetch slots" : "Slotlarni olib bo‘lmadi",
    "Select a date" : "Sana tanlash",
    "Select slot" : "Slotni tanlash",
    "No slots available" : "Slotlar mavjud emas",
    "The slot for your appointment has been confirmed" : "Uchrashuvingiz uchun joy tasdiqlandi",
    "Appointment Details:" : "Uchrashuv tafsilotlari:",
    "Time:" : "Vaqt:",
    "Booked for:" : "Quyidagilar uchun band qilingan:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Quyidagilar uchun band qilingan: Rahmat. {startDate} dan {endDate} gacha bandlovingiz tasdiqlandi.",
    "Book another appointment:" : "Boshqa uchrashuvni bron qiling:",
    "See all available slots" : "Barcha mavjud slotlarni ko'ring",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : " {startDate} dan {endDate} gacha bo‘lgan uchrashuv uchun vaqt endi mavjud emas.",
    "Please book a different slot:" : "Iltimos, boshqa joyni band qiling:",
    "Book an appointment with {name}" : " {name} bilan uchrashuvni bron qiling",
    "No public appointments found for {name}" : " {name}bilan umumiy uchrashuvlar topilmadi",
    "Personal" : "Shaxsiy",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Vaqt mintaqasini avtomatik aniqlash sizning vaqt mintaqangiz UTC ekanligini aniqladi.\nBu, ehtimol, veb-brauzeringizning xavfsizlik choralari natijasidir.\nIltimos, taqvim sozlamalarida vaqt mintaqangizni qo‘lda o‘rnating.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Sozlangan vaqt mintaqangiz ({timezoneId}) topilmadi. UTC ga qaytish.\nSozlamalarda vaqt mintaqangizni o‘zgartiring va bu muammo haqida xabar bering.",
    "Show unscheduled tasks" : "Rejadan tashqari vazifalarni ko'rsatish",
    "Unscheduled tasks" : "Rejadan tashqari vazifalar",
    "Availability of {displayName}" : " {displayName}uchun mavjud",
    "Discard event" : "Tadbirni bekor qilish",
    "Edit event" : "Tadbirni tahrirlash",
    "Event does not exist" : "Tadbir mavjud emas",
    "Duplicate" : "Nusxa",
    "Delete this occurrence" : "Ushbu tadbirni o'chiring",
    "Delete this and all future" : "Buni va barcha keyingilarini o'chirib tashlang",
    "All day" : "Butun kun",
    "Modifications wont get propagated to the organizer and other attendees" : "O'zgartirishlar tashkilotchiga va boshqa ishtirokchilarga targ'ib qilinmaydi",
    "Managing shared access" : "Umumiy foydalanishni boshqarish",
    "Deny access" : "Kirishni rad etish",
    "Invite" : "Taklif qiling",
    "Discard changes?" : "O'zgarishlar bekor qilinsinmi?",
    "Are you sure you want to discard the changes made to this event?" : "Haqiqatan ham ushbu tadbirga kiritilgan oʻzgarishlarni bekor qilmoqchimisiz?",
    "_User requires access to your file_::_Users require access to your file_" : ["Foydalanuvchilar faylingizga kirishni talab qiladi"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Umumiy ruxsatni talab qiluvchi biriktirmalar"],
    "Untitled event" : "Nomsiz tadbir",
    "Close" : "Yopish",
    "Modifications will not get propagated to the organizer and other attendees" : "O'zgartirishlar tashkilotchiga va boshqa ishtirokchilarga targ'ib qilinmaydi",
    "Meeting proposals overview" : "Uchrashuv takliflarining umumiy ko'rinishi",
    "Edit meeting proposal" : "Uchrashuv taklifini tahrirlash",
    "Create meeting proposal" : "Uchrashuv taklifini yarating",
    "Update meeting proposal" : "Uchrashuv taklifini yangilash",
    "Saving proposal \"{title}\"" : "“{title}” taklifi saqlanmoqda",
    "Successfully saved proposal" : "Taklif muvaffaqiyatli saqlandi",
    "Failed to save proposal" : "Taklif saqlanmadi",
    "Create a meeting for \"{date}\"? This will create a calendar event with all participants." : "“{date}” uchun uchrashuv yaratilsinmi? Bu barcha ishtirokchilar bilan taqvim tadbirini yaratadi.",
    "Creating meeting for {date}" : "{date} uchun uchrashuv yaratilmoqda",
    "Successfully created meeting for {date}" : "{date} uchun uchrashuv muvaffaqiyatli yaratildi",
    "Failed to create a meeting for {date}" : "{date} uchun uchrashuv yaratib bo‘lmadi",
    "Please enter a valid duration in minutes." : "Yaroqli muddatni daqiqalarda kiriting.",
    "Failed to fetch proposals" : "Takliflarni olib bo‘lmadi",
    "Failed to fetch free/busy data" : "Boʻsh/band maʼlumotlarni olib boʻlmadi",
    "Selected" : "Tanlangan",
    "No Description" : "Tavsif yo'q",
    "No Location" : "Joylashuv yoʻq",
    "Edit this meeting proposal" : "Ushbu uchrashuv taklifini tahrirlang",
    "Delete this meeting proposal" : "Ushbu uchrashuv taklifini oʻchirib tashlang",
    "Title" : "Sarlavha",
    "15 min" : "15 min",
    "30 min" : "30 daqiqa",
    "60 min" : "60 min",
    "90 min" : "90 min",
    "Participants" : "Ishtirokchilar",
    "Selected times" : "Tanlangan vaqtlar",
    "Previous span" : "Oldingi oraliq",
    "Next span" : "Keyingi oraliq",
    "Less days" : "Kamroq kunlar",
    "More days" : "Yana kunlar",
    "Loading meeting proposal" : "Uchrashuv taklifi yuklanmoqda",
    "No meeting proposal found" : "Uchrashuv taklifi topilmadi",
    "Please wait while we load the meeting proposal." : "Iltimos, biz uchrashuv taklifini yuklaguncha kuting.",
    "The link you followed may be broken, or the meeting proposal may no longer exist." : "Siz kuzatgan havola buzilgan boʻlishi mumkin yoki uchrashuv taklifi endi mavjud boʻlmasligi mumkin.",
    "Thank you for your response!" : "Javobingiz uchun rahmat!",
    "Your vote has been recorded. Thank you for participating!" : "Sizning ovozingiz yozib olindi. Ishtirok etganingiz uchun tashakkur!",
    "Unknown User" : "Noma'lum foydalanuvchi",
    "No Title" : "Sarlavha yo'q",
    "No Duration" : "Muddati yo'q",
    "Select a different time zone" : "Boshqa vaqt mintaqasini tanlang",
    "Submit" : "Yuborish",
    "Subscribe to {name}" : " {name}ga obuna bo'ling",
    "Export {name}" : " {name}eksporti",
    "Show availability" : "Mavjudligini ko'rsatish",
    "Anniversary" : "Yubiley",
    "Appointment" : "Uchrashuv",
    "Business" : "Biznes",
    "Education" : "Ta'lim",
    "Holiday" : "Bayram",
    "Meeting" : "Uchrashuv",
    "Miscellaneous" : "Turli xil",
    "Non-working hours" : "Ishlamaydigan soatlar",
    "Not in office" : "Ofisda emas",
    "Phone call" : "Telefon qo'ng'irog'i",
    "Sick day" : "Kasal kun",
    "Special occasion" : "Maxsus voqea",
    "Travel" : "Sayohat",
    "Vacation" : "Dam olish",
    "Midnight on the day the event starts" : "Tadbir boshlangan kuni yarim tunda",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n tadbirdan bir necha kun oldin {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n tadbirdan bir necha hafta oldin{formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : " {formattedHourMinute} tadbir kuni da",
    "at the event's start" : "tadbir boshida",
    "at the event's end" : "tadbir oxirida",
    "{time} before the event starts" : "{time} tadbir boshlanishidan oldin",
    "{time} before the event ends" : "{time} tadbir tugashidan oldin",
    "{time} after the event starts" : "{time} tadbir boshlanganidan keyin",
    "{time} after the event ends" : "{time} tadbir tugaganidan keyin",
    "on {time}" : " {time}da",
    "on {time} ({timezoneId})" : " {time}da ({timezoneId})",
    "Week {number} of {year}" : " {number}haftasi {year}yilning",
    "Daily" : "Kunlik",
    "Weekly" : "Haftalik",
    "Monthly" : "Oylik",
    "Yearly" : "Yillik",
    "_Every %n day_::_Every %n days_" : ["Har %n kun"],
    "_Every %n week_::_Every %n weeks_" : ["Har %n hafta"],
    "_Every %n month_::_Every %n months_" : ["Har %n oy"],
    "_Every %n year_::_Every %n years_" : ["Har %n yil"],
    "_on {weekday}_::_on {weekdays}_" : [" {weekdays}da"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : [" {dayOfMonthList}kunda"],
    "on the {ordinalNumber} {byDaySet}" : "{ordinalNumber} {byDaySet}da",
    "in {monthNames} on the {dayOfMonthList}" : "{dayOfMonthList} da {monthNames} da",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : " {monthNames} ichida {ordinalNumber} {byDaySet}da",
    "until {untilDate}" : " {untilDate}gacha",
    "_%n time_::_%n times_" : ["%n vaqt"],
    "second" : "sekund",
    "third" : "uchinchi",
    "fourth" : "to`rtinchi",
    "fifth" : "beshinchi",
    "second to last" : "oxiridan ikkinchi",
    "last" : "oxirgi",
    "Untitled task" : "Nomsiz vazifa",
    "Please ask your administrator to enable the Tasks App." : "Iltimos, administratoringizdan Tasks ilovasini yoqishini soʻrang.",
    "You are not allowed to edit this event as an attendee." : "Siz ishtirokchi sifatida ushbu tadbirni tahrirlashingiz mumkin emas.",
    "W" : "W",
    "%n more" : "%n ko`proq",
    "No events to display" : "Ko'rsatiladigan tadbir yo'q",
    "All participants declined" : "Barcha ishtirokchilar rad etishdi",
    "Please confirm your participation" : "Iltimos, ishtirokingizni tasdiqlang",
    "You declined this event" : "Siz bu tadbirni rad etdingiz",
    "Your participation is tentative" : "Sizning ishtirokingiz taxminiy",
    "_+%n more_::_+%n more_" : ["+%n ko`p[roq"],
    "No events" : "Hech qanday tadbir yo'q",
    "Create a new event or change the visible time-range" : "Yangi hodisa yarating yoki ko'rinadigan vaqt oralig'ini o'zgartiring",
    "Failed to save event" : "Tadbirni saqlab bo‘lmadi",
    "It might have been deleted, or there was a typo in a link" : "U oʻchirilgan yoki havolada xatolik yuz bergan boʻlishi mumkin",
    "It might have been deleted, or there was a typo in the link" : "U o'chirilgan yoki havolada xatolik yuz bergan bo'lishi mumkin",
    "Meeting room" : "Uchrashuv xonasi",
    "Lecture hall" : "Ma'ruza zali",
    "Seminar room" : "Seminar xonasi",
    "Other" : "Boshqa",
    "When shared show" : "Baham ko'rilganda",
    "When shared show full event" : "Ulashganda toʻliq tadbir koʻrsatiladi",
    "When shared show only busy" : "Baham ko'rilganda faqat band ko`rsatish",
    "When shared hide this event" : "Baham ko'rilganda, bu tadbirni yashirish",
    "Add a location" : "Joy qo'shing",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Tavsif qo'shing\n\n- Bu uchrashuv nima haqida\n- Kun tartibidagi masalalar\n- Ishtirokchilar tayyorlashi kerak bo'lgan hamma narsa",
    "Status" : "Holat",
    "Confirmed" : "Tasdiqlangan",
    "Canceled" : "Bekor qilingan",
    "Confirmation about the overall status of the event." : "Tadbirning umumiy holatini tasdiqlash.",
    "Show as" : "Sifatida ko'rsatish",
    "Take this event into account when calculating free-busy information." : "Bepul band bo'lgan ma'lumotni hisoblashda ushbu hodisani hisobga oling.",
    "Categories" : "Kategoriyalar",
    "Categories help you to structure and organize your events." : "Kategoriyalar tadbirlaringizni tuzish va tartibga solishga yordam beradi.",
    "Search or add categories" : "Kategoriyalarni qidiring yoki qo'shing",
    "Add this as a new category" : "Buni yangi turkum sifatida qo'shing",
    "Custom color" : "Maxsus rang",
    "Special color of this event. Overrides the calendar-color." : "Ushbu tadbirning o'ziga xos rangi. Kalendar rangini bekor qiladi.",
    "Error while sharing file" : "Fayl almashishda xatolik yuz berdi",
    "Error while sharing file with user" : "Foydalanuvchi bilan fayl almashishda xatolik yuz berdi",
    "Error creating a folder {folder}" : "jildini yaratishda xatolik yuz berdi {folder}",
    "Attachment {fileName} already exists!" : "Qo'shimcha {fileName} allaqachon mavjud!",
    "Attachment {fileName} added!" : "{fileName} ilovasi qoʻshildi!",
    "An error occurred during uploading file {fileName}" : "{fileName} faylini yuklashda xatolik yuz berdi",
    "An error occurred during getting file information" : "Fayl ma'lumotlarini olishda xatolik yuz berdi",
    "Talk conversation for proposal" : "Taklif uchun suhbat",
    "An error occurred, unable to delete the calendar." : "Xatolik yuz berdi, kalendarni oʻchirib boʻlmadi.",
    "Imported {filename}" : "Importlandi {filename}",
    "This is an event reminder." : "Bu tadbir eslatmasi.",
    "Error while parsing a PROPFIND error" : "PROPFIND xatosini tahlil qilishda xatolik yuz berdi",
    "Appointment not found" : "Uchrashuv topilmadi",
    "User not found" : "Foydalanuvchi topilmadi",
    "Hidden" : "Yashirin",
    "can edit" : "tahrirlashi mumkin",
    "Calendar name …" : "Taqvim nomi…",
    "Default attachments location" : "Birlamchi biriktirmalar joylashuvi",
    "Automatic ({detected})" : "Automatik ({detected})",
    "Shortcut overview" : "Qisqa komandalar haqida umumiy ma'lumot",
    "CalDAV link copied to clipboard." : "CalDAV havolasi vaqtinchalik xotiraga nusxalandi.",
    "CalDAV link could not be copied to clipboard." : "CalDAV havolasini vaqtinchalik xotiraga nusxalab bo‘lmadi.",
    "Enable birthday calendar" : "Tug'ilgan kun taqvimini yoqing",
    "Show tasks in calendar" : "Taqvimdagi vazifalarni ko'rsatish",
    "Enable simplified editor" : "Soddalashtirilgan muharrirni yoqing",
    "Limit the number of events displayed in the monthly view" : "Oylik ko'rinishda ko'rsatiladigan voqealar sonini cheklang",
    "Show weekends" : "Dam olish kunlarini ko'rsatish",
    "Show week numbers" : "Hafta tartib raqamlarini ko'rsatish",
    "Time increments" : "Vaqt o'sishi",
    "Default calendar for incoming invitations" : "Kiruvchi taklifnomalar uchun standart taqvim",
    "Copy primary CalDAV address" : "Asosiy CalDAV manzilidan nusxa oling",
    "Copy iOS/macOS CalDAV address" : "iOS/macOS CalDAV manzilidan nusxa oling",
    "Personal availability settings" : "Shaxsiy ochiqlik sozlamalari",
    "Show keyboard shortcuts" : "Klaviatura yorliqlarini ko'rsatish",
    "Create a new public conversation" : "Yangi ommaviy suhbat yarating",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} taklif qilingan, {confirmedCount} tasdiqlagan",
    "Successfully appended link to talk room to location." : "Suhbat xonasiga havola muvaffaqiyatli qo‘shildi.",
    "Successfully appended link to talk room to description." : "Tavsifga suhbat xonasiga havola muvaffaqiyatli qo‘shildi.",
    "Error creating Talk room" : "Muloqot xonasini yaratishda xatolik yuz berdi",
    "_%n more guest_::_%n more guests_" : ["%n ko'proq mehmonlar"],
    "The visibility of this event in shared calendars." : "Bu tadbirning umumiy taqvimda koʻrinishi."
},
"nplurals=1; plural=0;");
