/*!
 * SPDX-FileCopyrightText: 2022 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */
.app-icon-calendar {
	background-image: url('../img/calendar-dark.svg');
  filter: var(--background-invert-if-dark);
}
