OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Ponujen elektronski naslov je predolg",
    "User-Session unexpectedly expired" : "Uporabniška seja se je nepričakovano končala",
    "Provided email-address is not valid" : "Podan elektronski naslov ni veljaven naslov",
    "%s has published the calendar »%s«" : "%s objavi koledar » %s «",
    "Unexpected error sending email. Please contact your administrator." : "Prišlo je do napake med pošiljanjem elektronskega sporočila. Stopite v stik s skrbnikom sistema.",
    "Successfully sent email to %1$s" : "Sporočilo je uspešno poslano na %1$s",
    "Hello," : "Pozdravljeni,",
    "We wanted to inform you that %s has published the calendar »%s«." : "obveščamo vas, da je uporabnik %s objavil koledar »%s«.",
    "Open »%s«" : "Odpri »%s«",
    "Cheers!" : "Lep pozdrav!",
    "Upcoming events" : "Prihajajoči dogodki",
    "No more events today" : "Danes ni več načrtovanih dogodkov",
    "No upcoming events" : "Ni prihajajočih dogodkov",
    "More events" : "Več dogodkov",
    "%1$s with %2$s" : "%1$s z %2$s",
    "Calendar" : "Koledar",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) naznani sestanek »{config_display_name}« na dan {date_time}.",
    "Appointments" : "Sestanki",
    "Schedule appointment \"%s\"" : "Načrtovanje sestanka »%s«",
    "Schedule an appointment" : "Načrtovanje sestanka",
    "%1$s - %2$s" : "%1$s – %2$s",
    "Prepare for %s" : "Pripravi za %s",
    "Follow up for %s" : "Nadaljevanje za %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Sestanek »%s« z osebo %s zahteva potrditev",
    "Dear %s, please confirm your booking" : "%s, prosim potrdite rezervacijo",
    "Confirm" : "Potrdi",
    "Appointment with:" : "Sestanek:",
    "Description:" : "Opis:",
    "This confirmation link expires in %s hours." : "Potrditvena povezava poteče po %s urah.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Če vseeno želite preklicati sestanek, stopite v stik z organizatorjem z odgovorom na njegovo elektronsko sporočilo oziroma z obiskom strani profila.",
    "Your appointment \"%s\" with %s has been accepted" : "Sestanek »%s« z osebo %s je potrjen",
    "Dear %s, your booking has been accepted." : " %s, sestanek je potrjen.",
    "Appointment for:" : "Sestanek:",
    "Date:" : "Datum:",
    "You will receive a link with the confirmation email" : "Prejeli boste elektronsko sporočilo z overitveno povezavo",
    "Where:" : "Kje:",
    "Comment:" : "Opomba",
    "Location:" : "Mesto:",
    "Duration:" : "Trajanje:",
    "A Calendar app for Nextcloud" : "Program za urejanje koledarja Nextcloud",
    "Previous day" : "Predhodni dan",
    "Previous week" : "Predhodni teden",
    "Previous year" : "Predhodno leto",
    "Previous month" : "Predhodni mesec",
    "Next day" : "Naslednji dan",
    "Next week" : "Naslednji teden",
    "Next year" : "Naslednje leto",
    "Next month" : "Naslednji mesec",
    "Create new event" : "Ustvari nov dogodek",
    "Event" : "Dogodek",
    "Today" : "Danes",
    "Day" : "Dan",
    "Week" : "Teden",
    "Month" : "Mesec",
    "Year" : "Leto",
    "List" : "Seznam",
    "Appointment link was copied to clipboard" : "Povezava sestanka je kopirana v odložišče.",
    "Appointment link could not be copied to clipboard" : "Povezave sestanka ni mogoče kopirati v odložišče.",
    "Preview" : "Predogled",
    "Copy link" : "Kopiraj povezavo",
    "Edit" : "Uredi",
    "Delete" : "Izbriši",
    "Create new" : "Ustvari novo",
    "Disable calendar \"{calendar}\"" : "Onemogoči koledar »{calendar}«",
    "Disable untitled calendar" : "Onemogoči neimenovan koledar",
    "Enable calendar \"{calendar}\"" : "Omogoči koledar »{calendar}«",
    "Enable untitled calendar" : "Omogoči neimenovan koledar",
    "An error occurred, unable to change visibility of the calendar." : "Prišlo je do napake; ni mogoče spremeniti vidnosti koledarja.",
    "Untitled calendar" : "Neimenovan koledar",
    "Shared with you by" : "Souporabo omogoča",
    "Edit and share calendar" : "Uredi in omogoči souporabo koledarja",
    "Edit calendar" : "Uredi koledar",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Souporaba koledarja bo onemogočena čez {countdown} sekundo","Souporaba koledarja bo onemogočena čez {countdown} sekundi","Souporaba koledarja bo onemogočena čez {countdown} sekunde","Souporaba koledarja bo prekinjena čez {countdown} sekund"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Koledar bo izbrisan čez {countdown} sekundo","Koledar bo izbrisan čez {countdown} sekundi","Koledar bo izbrisan čez {countdown} sekunde","Koledar bo izbrisan čez {countdown} sekund"],
    "An error occurred, unable to create the calendar." : "Prišlo je do napake, koledarja ni mogoče ustvariti.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Vpisati je treba veljavne povezave (začeti se morajo s http://, https://, webcal://, ali webcals://)",
    "Calendars" : "Koledarji",
    "Add new" : "Dodaj novo",
    "New calendar" : "Nov koledar",
    "Name for new calendar" : "Naziv novega koledarja",
    "Creating calendar …" : "Poteka ustvarjanje koledarja ...",
    "New calendar with task list" : "Nov koledar s seznamom nalog",
    "New subscription from link (read-only)" : "Naročnina prek povezave (le za branje)",
    "Creating subscription …" : "Poteka ustvarjanje naročnine ...",
    "Add public holiday calendar" : "Dodaj koledar javnih praznikov",
    "Add custom public calendar" : "Dodaj javni koledar po meri",
    "Calendar link copied to clipboard." : "Povezava koledarja je kopirana v odložišče.",
    "Calendar link could not be copied to clipboard." : "Povezave koledarja ni mogoče kopirati v odložišče.",
    "Copy subscription link" : "Kopiraj povezavo naročnine",
    "Copying link …" : "Kopiranje povezave ...",
    "Copied link" : "Kopirana povezava",
    "Could not copy link" : "Povezave ni mogoče kopirati",
    "Export" : "Izvozi",
    "Untitled item" : "Neimenovan predmet",
    "Unknown calendar" : "Neznan koledar",
    "Could not load deleted calendars and objects" : "Ni mogoče naložiti izbrisanih koledarjev in predmetov",
    "Could not delete calendar or event" : "Ni mogoče izbrisati koledarja ali dogodka",
    "Could not restore calendar or event" : "Ni mogoče obnoviti koledarja ali dogodka",
    "Do you really want to empty the trash bin?" : "Ali zares želite izprazniti smetnjak?",
    "Empty trash bin" : "Izprazni smeti",
    "Trash bin" : "Smetnjak",
    "Loading deleted items." : "Poteka nalaganje izbrisanih predmetov.",
    "You do not have any deleted items." : "Ni izbrisanih predmetov.",
    "Name" : "Ime",
    "Deleted" : "Izbrisano",
    "Restore" : "Obnovi",
    "Delete permanently" : "Izbriši trajno",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Predmeti v smetnjaku se izbrišejo po {numDays} dnevu.","Predmeti v smetnjaku se izbrišejo po {numDays} dnevih.","Predmeti v smetnjaku se izbrišejo po {numDays} dnevih.","Predmeti v smetnjaku se izbrišejo po {numDays} dnevih."],
    "Could not update calendar order." : "Ni mogoče posodobiti koledarja",
    "Shared calendars" : "Koledarji v souporabi",
    "Deck" : "Deck",
    "Internal link" : "Notranja povezava",
    "A private link that can be used with external clients" : "Zasebna povezava, ki se lahko uporablja z zunanjimi odjemalci",
    "Copy internal link" : "Kopiraj krajevno povezavo",
    "An error occurred, unable to publish calendar." : "Prišlo je do napake; koledarja ni mogoče objaviti.",
    "An error occurred, unable to send email." : "Prišlo je do napake; ni mogoče poslati elektronskega sporočila.",
    "Embed code copied to clipboard." : "Vstavljiva koda je kopirana v odložišče.",
    "Embed code could not be copied to clipboard." : "Vstavljive kode ni mogoče kopirati v odložišče.",
    "Unpublishing calendar failed" : "Preklic objave koledarja je spodletel",
    "Share link" : "Povezava za souporabo",
    "Copy public link" : "Kopiraj javno povezavo",
    "Send link to calendar via email" : "Pošlji povezavo za koledar prek elektronske pošte",
    "Enter one address" : "Vpišite en naslov",
    "Sending email …" : "Poteka pošiljanje elektronske pošte ...",
    "Copy embedding code" : "Kopiraj vstavljivo kodo",
    "Copying code …" : "Kopiranje kode ...",
    "Copied code" : "Koda je kopirana",
    "Could not copy code" : "Kode ni mogoče kopirati",
    "Delete share link" : "Izbriši povezavo za souporabo",
    "Deleting share link …" : "Poteka brisanje povezave souporabe ...",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Skupina)",
    "An error occurred while unsharing the calendar." : "Prišlo je do napake med onemogočanjem souporabe koledarja.",
    "An error occurred, unable to change the permission of the share." : "Prišlo je do napake; ni mogoče spremeniti dovoljenj souporabe.",
    "Unshare with {displayName}" : "Odstrani souporabo z uporabnikom {displayName}",
    "Share with users or groups" : "Souporaba z uporabniki in skupinami",
    "No users or groups" : "Ni uporabnikov ali skupin",
    "Failed to save calendar name and color" : "Shranjevanje imena koledarja in barve je spodletelo",
    "Share calendar" : "Omogoči souporabo koledarja",
    "Unshare from me" : "Prekini souporabo",
    "Save" : "Shrani",
    "No title" : "Ni naslova",
    "View" : "Pogled",
    "Import calendars" : "Uvozi koledarje",
    "Please select a calendar to import into …" : "Izberite koledar za uvoz ...",
    "Filename" : "Ime datoteke",
    "Calendar to import into" : "Koledar, v katerega naj se uvozi",
    "Cancel" : "Prekliči",
    "_Import calendar_::_Import calendars_" : ["Uvozi koledar","Uvozi koledarja","Uvozi koledarje","Uvozi koledarje"],
    "Select the default location for attachments" : "Izbor privzetega mesta za priloge",
    "Pick" : "Izbor",
    "Invalid location selected" : "Izbrano je neveljavno mesto",
    "Attachments folder successfully saved." : "Mapa prilog je uspešno shranjena.",
    "Error on saving attachments folder." : "Napaka med shranjevanjem mape prilog",
    "Attachments folder" : "Mapa prilog",
    "{filename} could not be parsed" : "Datoteke {filename} ni mogoče razčleniti",
    "No valid files found, aborting import" : "Ni najdenih veljavnih datotek, uvoz bo preklican",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Uspešno je uvožen %n dogodek.","Uspešno sta uvožena %n dogodka.","Uspešno so uvoženi %n dogodki.","Uspešno je uvoženih %n dogodkov."],
    "Import partially failed. Imported {accepted} out of {total}." : "Uvoz je delno spodletel. Uvoženih je {accepted} od skupno {total}.",
    "Automatic" : "Samodejno",
    "Automatic ({timezone})" : "Samodejno ({timezone})",
    "New setting was not saved successfully." : "Novih nastavitev ni bilo mogoče shraniti.",
    "Timezone" : "Časovni pas",
    "Navigation" : "Krmarjenje",
    "Previous period" : "Predhodno obdobje",
    "Next period" : "Naslednje obdobje",
    "Views" : "Pogledi",
    "Day view" : "Dnevni pogled",
    "Week view" : "Tedenski pogled",
    "Month view" : "Mesečni pogled",
    "Year view" : "Letni pogled",
    "List view" : "Seznamski pogled",
    "Actions" : "Dejanja",
    "Create event" : "Ustvari dogodek",
    "Show shortcuts" : "Pokaži tipkovne bližnjice",
    "Editor" : "Urejevalnik",
    "Close editor" : "Zapri urejevalnik",
    "Save edited event" : "Shrani spremenjen dogodek",
    "Delete edited event" : "Izbriši spremenjen dogodek",
    "Duplicate event" : "Podvoji dogodek",
    "or" : "ali",
    "Calendar settings" : "Nastavitve koledarja",
    "No reminder" : "Brez opomnika",
    "Failed to save default calendar" : "Shranjevanje privzetega koledarja je spodletelo",
    "General" : "Splošno",
    "Appearance" : "Videz",
    "Editing" : "Urejanje",
    "Default reminder" : "Privzeti opomnik",
    "Files" : "Datoteke",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minuta","{duration} minuti","{duration} minute","{duration} minut"],
    "0 minutes" : "0 minut",
    "_{duration} hour_::_{duration} hours_" : ["{duration} ura","{duration} uri","{duration} ure","{duration} ur"],
    "_{duration} day_::_{duration} days_" : ["{duration} dan","{duration} dneva","{duration} dni","{duration} dni"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} teden","{duration} tedna","{duration} tedne","{duration} tednov"],
    "_{duration} month_::_{duration} months_" : ["{duration} mesec","{duration} meseca","{duration} mesece","{duration} mesecev"],
    "_{duration} year_::_{duration} years_" : ["{duration} leto","{duration} leti","{duration} leta","{duration} let"],
    "To configure appointments, add your email address in personal settings." : "Za nastavljanje sestankov dodajte elektronski naslov med osebne nastavitve.",
    "Public – shown on the profile page" : "Javno – prikazano na strani profila",
    "Private – only accessible via secret link" : "Zasebno – dostopno le z zasebno povezavo",
    "Update" : "Posodobi",
    "Appointment name" : "Ime srečanja",
    "Location" : "Mesto",
    "Create a Talk room" : "Ustvari skupino Talk",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Enoznačna povezava bo ustvarjena za vsak rezerviran termin in poslana s potrditvenim poštnim sporočilom.",
    "Description" : "Opis",
    "Visibility" : "Vidnost",
    "Duration" : "Trajanje",
    "Increments" : "Časovno povečevanje",
    "Additional calendars to check for conflicts" : "Dodatni koledarji za preverjanje sporov",
    "Pick time ranges where appointments are allowed" : "Izbor časovnih obdobij, ko so sestanki mogoči",
    "to" : "do",
    "Delete slot" : "Izbriši termin",
    "No times set" : "Ni določenih obdobij",
    "Add" : "Dodaj",
    "Monday" : "ponedeljek",
    "Tuesday" : "torek",
    "Wednesday" : "sreda",
    "Thursday" : "četrtek",
    "Friday" : "petek",
    "Saturday" : "sobota",
    "Sunday" : "nedelja",
    "Weekdays" : "Delovni dnevi",
    "Add time before and after the event" : "Dodaj čas pred in po dogodku",
    "Before the event" : "Pred dogodkom",
    "After the event" : "Po dogodku",
    "Planning restrictions" : "Omejitve načrtovanja",
    "Minimum time before next available slot" : "Najmanjši čas do naslednjega časovnega termina",
    "Max slots per day" : "Največje število časovnih terminov na dan",
    "Limit how far in the future appointments can be booked" : "Omeji, kako daleč v prihodnost je mogoče rezervirati sestanke. ",
    "Please confirm your reservation" : "Potrdite rezervacijo",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Na elektronski naslov je bilo poslano sporočilo. Prosim, potrdite sestanek z uporabe povezave v sporočilu. To stran lahko zaprete.",
    "Your name" : "Ime",
    "Your email address" : "Elektronski naslov",
    "Please share anything that will help prepare for our meeting" : "Pošljite vse predloge in dokumente, ki so pomembni pri pripravi na srečanje.",
    "Could not book the appointment. Please try again later or contact the organizer." : "Sestanka ni mogoče rezervirati. Poskusite znova kasneje oziroma stopite v stik z organizatorjem.",
    "Back" : "Nazaj",
    "Select conversation" : "pogovora",
    "on" : "na",
    "at" : "ob",
    "before at" : "prej ob",
    "Notification" : "Obvestilo",
    "Email" : "Elektronsko sporočilo",
    "Audio notification" : "Zvočno obvestilo",
    "Other notification" : "Drugo obvestilo",
    "Relative to event" : "Relativno na dogodek",
    "On date" : "Na dan",
    "Edit time" : "Uredi čas",
    "Save time" : "Shrani čas",
    "Remove reminder" : "Odstrani opomnik",
    "Add reminder" : "Dodaj opomnik",
    "seconds" : "sekunde",
    "minutes" : "minute",
    "hours" : "ure",
    "days" : "dnevi",
    "weeks" : "tedne",
    "Choose a file to add as attachment" : "Izbor datoteke za prilogo",
    "Choose a file to share as a link" : "Izberite datoteko, ki jo želite dati v skupno rabo kot povezavo",
    "Attachment {name} already exist!" : "Priloga {name} že obstaja!",
    "Could not upload attachment(s)" : "Prilog ni mogoče poslati",
    "Proceed" : "Nadaljuj",
    "No attachments" : "Ni prilog",
    "Add from Files" : "Izbor iz datotek",
    "Upload from device" : "Pošlji z naprave",
    "Delete file" : "Izbriši datoteko",
    "Confirmation" : "Potrjevanje",
    "_{count} attachment_::_{count} attachments_" : ["{count} priloga","{count} prilogi","{count} priloge","{count} prilog"],
    "Suggested" : "Predlagano",
    "Available" : "Na voljo",
    "Invitation accepted" : "Vabilo je sprejeto.",
    "Accepted {organizerName}'s invitation" : "Sprejeto vabilo organizatorja: {organizerName}",
    "Participation marked as tentative" : "Udeležba je označena kot nedorečena",
    "Invitation is delegated" : "Povabilo je dodeljeno",
    "Not available" : "Ni na voljo",
    "Invitation declined" : "Vabilo je zavrnjeno.",
    "Declined {organizerName}'s invitation" : "Zavrnjeno vabilo organizatorja: {organizerName}",
    "Awaiting response" : "Čakajoč na odziv",
    "Checking availability" : "Preverjanje razpoložljivosti",
    "Has not responded to {organizerName}'s invitation yet" : "Še ni odgovora na na vabilo organizatorja: {organizerName}",
    "chairperson" : "vodja dogodka",
    "required participant" : "zahtevan udeleženec",
    "non-participant" : "neudeleženec",
    "optional participant" : "udeleženec na željo",
    "{organizer} (organizer)" : "{organizer} (organizator)",
    "Availability of attendees, resources and rooms" : "Razpoložljivost udeležencev, virov in sob",
    "Suggestion accepted" : "Predlog je sprejet",
    "Legend" : "Legenda",
    "Out of office" : "Službena odsotnost",
    "Attendees:" : "Udeleženci:",
    "Done" : "Končano",
    "Room name" : "Ime sobe",
    "Free" : "Prosto",
    "Busy (tentative)" : "Načrtovano delo",
    "Busy" : "Zasedeno",
    "Unknown" : "Neopredeljeno",
    "Find a time" : "Najdi čas",
    "The invitation has been accepted successfully." : "Vabilo je uspešno sprejeto.",
    "Failed to accept the invitation." : "Sprejemanje povabila je spodletelo.",
    "The invitation has been declined successfully." : "Vabilo je uspešno zavrnjeno.",
    "Failed to decline the invitation." : "Zavrnitev vabila je spodletela.",
    "Your participation has been marked as tentative." : "Vaša udeležba je označena kot nedorečena.",
    "Failed to set the participation status to tentative." : "Spreminjanje stanja udeležbe na nedorečeno je spodletelo.",
    "Accept" : "Sprejmi",
    "Decline" : "Zavrni",
    "Tentative" : "V usklajevanju",
    "No attendees yet" : "Ni še vpisanih udeležencev",
    "Attendees" : "Udeleženci",
    "Remove group" : "Odstrani skupino",
    "Remove attendee" : "Odstrani udeleženca",
    "Chairperson" : "Vodja dogodka",
    "Required participant" : "Nujna udeležba",
    "Optional participant" : "Udeležba na željo",
    "Non-participant" : "Neudeležba",
    "_%n member_::_%n members_" : ["%n član","%n člana","%n člani","%n članov"],
    "No match found" : "Ni najdenih zadetkov",
    "(organizer)" : " (skliče dogodek)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Za pošiljanje vabil in urejanje odzivov mora biti [linkopen]vaš elektronski naslov vpisan med osebnimi nastavitvami[linkclose].",
    "Remove color" : "Odstrani barvo",
    "Event title" : "Naslov dogodka",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Ni mogoče spremeniti nastavitve »celodnevno« za dogodke, ki so opredeljeni kot ponavljajoči.",
    "From" : "Od",
    "To" : "Za",
    "Repeat" : "Ponovi",
    "_time_::_times_" : [" ponovitvi"," ponovitvah"," ponovitvah"," ponovitvah"],
    "never" : "nikoli",
    "on date" : "na dan",
    "after" : "po",
    "End repeat" : "Končaj:",
    "Select to end repeat" : "Izbor končanja ponavljanja",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Ta dogodek ima vpisano izjemo ponavljanja, zato pravila ponovitve ni mogoče dodati.",
    "first" : "1.",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Spremembe ponavljajočega dogodka bodo uveljavljene za to in vse prihodnje ponovitve.",
    "Repeat every" : "Ponovi na",
    "By day of the month" : "Na dan v mesecu",
    "On the" : "Na",
    "_day_::_days_" : ["dan","dneva","dneve","dni"],
    "_week_::_weeks_" : ["teden","tedna","tedne","tednov"],
    "_month_::_months_" : ["mesec","meseca","mesece","mesecev"],
    "_year_::_years_" : ["leto","leti","leta","let"],
    "weekday" : "delovni dan",
    "weekend day" : "vikend",
    "Does not repeat" : "Se ne ponavlja",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Določilo ponavljanja tega dogodka ni v celoti podprto! Z urejanjem možnosti ponavljanja so lahko nekatera določila prepisana.",
    "No rooms or resources yet" : "Ni še določenih sob ali virov",
    "Resources" : "Viri",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} sedež","{seatingCapacity} sedeža","{seatingCapacity} sedeži","{seatingCapacity} sedežev"],
    "Add resource" : "Dodaj vir",
    "Has a projector" : "Na voljo je projektor",
    "Has a whiteboard" : "Na voljo je bela tabla",
    "Wheelchair accessible" : "Dostopno z invalidskim vozičkom",
    "Remove resource" : "Odstrani vir",
    "Search for resources or rooms" : "Poišči vire in sobe",
    "available" : "na voljo",
    "unavailable" : "ni na voljo",
    "Projector" : "Projektor",
    "Whiteboard" : "Bela tabla",
    "Room type" : "Vrsta sobe",
    "Any" : "Katerakoli",
    "Minimum seating capacity" : "Najmanjša razpoložljivost sedežev",
    "More details" : "Več podrobnosti",
    "Update this and all future" : "Posodobi to in vse prihodnje pojavitve",
    "Update this occurrence" : "Posodobi to pojavitev",
    "Public calendar does not exist" : "Javni koledar ne obstaja",
    "Maybe the share was deleted or has expired?" : "Morda je mesto souporabe izbrisano ali je časovno poteklo.",
    "Remove participant" : "Odstrani udeležence",
    "Yes" : "Da",
    "No" : "Ne",
    "Maybe" : "Morda",
    "None" : "Brez",
    "Create" : "Ustvari",
    "from {formattedDate}" : "od {formattedDate}",
    "to {formattedDate}" : "do {formattedDate}",
    "on {formattedDate}" : "na {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "od {formattedDate} ob {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "do {formattedDate} ob {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "na {formattedDate} ob {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} ob {formattedTime}",
    "Please enter a valid date" : "Vpisati je treba veljaven datum",
    "Please enter a valid date and time" : "Vpisati je treba veljaven datum in čas",
    "Select a time zone" : "Izbor časovnega pasu",
    "Please select a time zone:" : "Izbor časovnega pasu:",
    "Pick a time" : "Izbor časa",
    "Pick a date" : "Izbor datuma",
    "Type to search time zone" : "Vpišite niz za iskanje časovnega pasu",
    "Global" : "Splošno",
    "Holidays in {region}" : "Prazniki v regiji {region}",
    "Public holiday calendars" : "Koledarji praznikov",
    "Public calendars" : "Javni koledarji",
    "No valid public calendars configured" : "Ni nastavljenih veljavnih javnih koledarjev",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Javne koledarje omogoča program Thunderbird. Koledarji bodo prejeti s spletišča {website}",
    "By {authors}" : "Po {authors}",
    "Subscribed" : "Naročeno",
    "Subscribe" : "Naročilo",
    "Could not fetch slots" : "Pridobivanje podatkov o časovnih terminih je spodletelo",
    "Select a date" : "Izbor datuma",
    "Select slot" : "Izbor časovnega termina",
    "No slots available" : "Ni razpoložljivih časovnih terminov",
    "The slot for your appointment has been confirmed" : "Časovni termin sestanka je potrjen",
    "Appointment Details:" : "Podrobnosti sestanka:",
    "Time:" : "Čas:",
    "Booked for:" : "Rezervirano za:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Rezervacija od {startDate} do {endDate} je potrjena.",
    "Book another appointment:" : "Dogovorite se za drug sestanek:",
    "See all available slots" : "Pokaži vse razpoložljive termine",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Termin sestanka med {startDate} in {endDate} ni več na voljo.",
    "Please book a different slot:" : "Zabeležite si drug časovni termin:",
    "Book an appointment with {name}" : "Dogovorite se za sestanek z osebo {name}",
    "No public appointments found for {name}" : "Za uporabnika {name} ni načrtovanih javnih srečanj.",
    "Personal" : "Osebno",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Samodejno zaznavanje časovnega pasu določa časovni pas kot UTC.\nTo je najverjetneje prilagojeno na varnostne nastavitve spletnega brskalnika.\nČasovni pas lahko določite tudi ročno med nastavitvami koledarja.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Nastavljenega časovnega pasu ({timezoneId}) ni mogoče najti. Povrnjena bo nastavitev na UTC.\nČasovni pas določite ročno med nastavitvami koledarja in pošljite poročilo o napaki.",
    "Edit event" : "Uredi dogodek",
    "Event does not exist" : "Dogodek ne obstaja",
    "Duplicate" : "Podvoji",
    "Delete this occurrence" : "Izbriši to pojavitev",
    "Delete this and all future" : "Izbriši to in vse prihodnje pojavitve",
    "All day" : "Ves dan",
    "Managing shared access" : "Upravljanje z dostopom",
    "Deny access" : "Zavrni dostop",
    "Invite" : "Povabi",
    "Untitled event" : "Neimenovan dogodek",
    "Close" : "Zapri",
    "Selected" : "Izbrano",
    "Title" : "Naslov",
    "30 min" : "30 min",
    "Participants" : "Udeleženci",
    "Submit" : "Pošlji",
    "Subscribe to {name}" : "Naroči na {name}",
    "Export {name}" : "Izvozi {name}",
    "Anniversary" : "Obletnica",
    "Appointment" : "Sestanek",
    "Business" : "Posel",
    "Education" : "Izobraževanje",
    "Holiday" : "Praznik",
    "Meeting" : "Srečanje",
    "Miscellaneous" : "Razno",
    "Non-working hours" : "Nedeloven dan",
    "Not in office" : "Službena odsotnost",
    "Phone call" : "Telefonski klic",
    "Sick day" : "Bolniška odsotnost",
    "Special occasion" : "Poseben dogodek",
    "Travel" : "Potovanje",
    "Vacation" : "Dopust",
    "Midnight on the day the event starts" : "Polnoč na dan začetka dogodka",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n dan pred dogodkom ob {formattedHourMinute}","%n dni pred dogodkom ob {formattedHourMinute}","%n dni pred dogodkom ob {formattedHourMinute}","%n dni pred dogodkom ob {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n teden pred dogodkom ob {formattedHourMinute}","%n tedna pred dogodkom ob {formattedHourMinute}","%n tedne pred dogodkom ob {formattedHourMinute}","%n tednov pred dogodkom ob {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "na dan dogodka ob {formattedHourMinute}",
    "at the event's start" : "ob začetku dogodka",
    "at the event's end" : "po koncu dogodka",
    "{time} before the event starts" : "{time} pred začetkom dogodka",
    "{time} before the event ends" : "{time} pred koncem dogodka",
    "{time} after the event starts" : "{time} po začetku dogodka",
    "{time} after the event ends" : "{time} po koncu dogodka",
    "on {time}" : "ob {time}",
    "on {time} ({timezoneId})" : "ob {time} ({timezoneId})",
    "Week {number} of {year}" : "{number}. teden leta {year}",
    "Daily" : "Dnevno",
    "Weekly" : "Tedensko",
    "Monthly" : "Mesečno",
    "Yearly" : "Letno",
    "_Every %n day_::_Every %n days_" : ["ponovi vsak %n. dan","ponovi vsak %n. dan","ponovi vsak %n. dan","ponovi vsak %n. dan"],
    "_Every %n week_::_Every %n weeks_" : ["ponovi vsak %n. teden","ponovi vsak %n. teden","ponovi vsak %n. teden","ponovi vsak %n. teden"],
    "_Every %n month_::_Every %n months_" : ["ponovi vsak %n. mesec","ponovi vsak %n. mesec","ponovi vsak %n. mesec","ponovi vsak %n. mesec"],
    "_Every %n year_::_Every %n years_" : ["ponovi vsako %n. leto","ponovi vsako %n. leto","ponovi vsako %n. leto","ponovi vsako %n. leto"],
    "_on {weekday}_::_on {weekdays}_" : [":  {weekday}",":  {weekday}",":  {weekday}",":  {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : [": na {dayOfMonthList}",": na {dayOfMonthList}",": na {dayOfMonthList}",": na {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : ": {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : ": {monthNames} : {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "do {untilDate}",
    "_%n time_::_%n times_" : ["%n-krat","%n-krat","%n-krat","%n-krat"],
    "second" : "drugi",
    "third" : "3.",
    "fourth" : "4.",
    "fifth" : "5.",
    "second to last" : "predzadnji",
    "last" : "zadnji",
    "Untitled task" : "Neimenovana naloga",
    "Please ask your administrator to enable the Tasks App." : "Obvestite skrbnika, da je treba omogočiti program Tasks.",
    "W" : "T",
    "%n more" : "%n več",
    "No events to display" : "Ni dogodkov za prikaz",
    "_+%n more_::_+%n more_" : ["+%n več","+%n več","+%n več","+%n več"],
    "No events" : "Ni dogodkov",
    "Create a new event or change the visible time-range" : "Ustvarite nov dogodek, ali pa spremenite časovni obseg",
    "It might have been deleted, or there was a typo in a link" : "Morda je bil izbrisan, ali pa je napaka v zapisu povezave",
    "It might have been deleted, or there was a typo in the link" : "Morda je bil izbrisan, ali pa je napaka v zapisu povezave",
    "Meeting room" : "Soba za sestanke",
    "Lecture hall" : "Predavalnica",
    "Seminar room" : "Soba za seminarje",
    "Other" : "Drugo",
    "When shared show" : "V souporabi pokaži dogodek",
    "When shared show full event" : "V souporabi pokaži poln dogodek",
    "When shared show only busy" : "V souporabi pokaži le, da je zasedeno",
    "When shared hide this event" : "V souporabi skrij ta dogodek",
    "Add a location" : "Dodaj mesto ...",
    "Status" : "Stanje",
    "Confirmed" : "Potrjeno",
    "Canceled" : "Preklicano",
    "Confirmation about the overall status of the event." : "Potrditev splošnega stanja dogodka.",
    "Show as" : "Pokaži kot",
    "Take this event into account when calculating free-busy information." : "Ta dogodek upoštevaj pri preračunavanju podatkov o zasedenosti udeležencev.",
    "Categories" : "Kategorije",
    "Categories help you to structure and organize your events." : "Kategorije omogočajo pregledno razvrščanje in urejanje dogodkov.",
    "Search or add categories" : "Poišči oziroma dodaj kategorijo",
    "Add this as a new category" : "Dodaj kot novo kategorijo",
    "Custom color" : "Barva po meri",
    "Special color of this event. Overrides the calendar-color." : "Posebna barva dogodka prepiše privzeto barvo koledarja.",
    "Error while sharing file" : "Prišlo je do napake med souporabo datoteke",
    "Error while sharing file with user" : "Prišlo je do napake med souporabo datoteke z uporabnikom",
    "Attachment {fileName} already exists!" : "Priloga {fileName} že obstaja!",
    "An error occurred during getting file information" : "Prišlo je do napake med pridobivanjem podrobnosti datoteke",
    "An error occurred, unable to delete the calendar." : "Prišlo je do napake; ni mogoče izbrisati koledarja.",
    "Imported {filename}" : "Uvožena datoteka {filename}",
    "This is an event reminder." : "To je opomnik dogodka.",
    "Appointment not found" : "Sestanka ni mogoče najti",
    "User not found" : "Uporabnika ni mogoče najti",
    "Hidden" : "Skrito",
    "can edit" : "lahko ureja",
    "Calendar name …" : "Ime koledarja …",
    "Default attachments location" : "Privzeto mesto prilog",
    "Automatic ({detected})" : "Samodejno ({detected})",
    "Shortcut overview" : "Pregled tipkovnih bližnjic",
    "CalDAV link copied to clipboard." : "Povezava CalDAV je kopirana v odložišče.",
    "CalDAV link could not be copied to clipboard." : "Povezave CalDAV ni mogoče kopirati v odložišče.",
    "Enable birthday calendar" : "Omogoči koledar rojstnih dni",
    "Show tasks in calendar" : "Pokaži naloge v koledarju",
    "Enable simplified editor" : "Omogoči poenostavljen urejevalnik",
    "Limit the number of events displayed in the monthly view" : "Omeji število dogodkov v pogledu meseca",
    "Show weekends" : "Pokaži vikende",
    "Show week numbers" : "Pokaži številke tednov",
    "Time increments" : "Časovno povečevanje",
    "Default calendar for incoming invitations" : "Privzeti koledar za prihajajoča povabila",
    "Copy primary CalDAV address" : "Kopiraj osnovni naslov CalDAV",
    "Copy iOS/macOS CalDAV address" : "Kopiraj naslov CalDAV za iOS/macOS",
    "Personal availability settings" : "Nastavitve osebne dejavnosti",
    "Show keyboard shortcuts" : "Pokaži tipkovne bližnjice",
    "Successfully appended link to talk room to description." : "Povezava do sobe Talk je uspešno dodana v opis.",
    "Error creating Talk room" : "Prišlo je do napake med ustvarjanjem klepetalnice Talk",
    "The visibility of this event in shared calendars." : "Vidnost tega dogodka v koledarjih v souporabi."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
