OC.L10N.register(
    "calendar",
    {
    "Hello," : "Salam,",
    "Cheers!" : "Şərəfə!",
    "Calendar" : "Təqvim",
    "Confirm" : "Təsdiq edin",
    "Location:" : "Ərazi:",
    "Today" : "Bu gün",
    "Day" : "Gün",
    "Week" : "Həftə",
    "Month" : "Ay",
    "Copy link" : "linki nüsxələ",
    "Edit" : "Dəyişiklik et",
    "Delete" : "Sil",
    "New calendar" : "Yeni təqvim",
    "Export" : "Çıxarış",
    "Name" : "Ad",
    "Deleted" : "Silinib",
    "Restore" : "Geri qaytar",
    "Delete permanently" : "Həmişəlik sil",
    "Share link" : "Linki yayımla",
    "Save" : "Saxla",
    "Cancel" : "Dayandır",
    "Automatic" : "Avtomatik",
    "Actions" : "İşlər",
    "General" : "Ümumi",
    "Update" : "Yenilənmə",
    "Location" : "Yerləşdiyiniz ünvan",
    "Description" : "Açıqlanma",
    "to" : "doğru",
    "Add" : "Əlavə etmək",
    "Monday" : "Bazar ertəsi",
    "Tuesday" : "Çərşənbə axşamı",
    "Wednesday" : "Çərşənbə",
    "Thursday" : "Cümə axşamı",
    "Friday" : "Cümə",
    "Saturday" : "Şənbə",
    "Sunday" : "Bazar",
    "Your email address" : "Sizin email ünvanı",
    "Back" : "Geri",
    "Email" : "Email",
    "seconds" : "saniyələr",
    "minutes" : "dəqiqələr",
    "hours" : "saatlar",
    "days" : "günlər",
    "weeks" : "həftələr",
    "Choose a file to add as attachment" : "Əlavə ediləcək faylı seçin",
    "Done" : "Edildi",
    "Accept" : "Qəbul et",
    "Decline" : "İmtina",
    "Attendees" : "İştirakçılar",
    "Remove group" : "Qrupu sil",
    "Repeat" : "Təkrar",
    "never" : "heç vaxt",
    "Resources" : "Resurslar",
    "Yes" : "Bəli",
    "No" : "Xeyir",
    "None" : "Heç bir",
    "Subscribe" : "Abunə",
    "Personal" : "Şəxsi",
    "Edit event" : "Hadisəni dəyişdir",
    "Close" : "Bağla",
    "Daily" : "Günlük",
    "Weekly" : "Həftəlik",
    "second" : "saniyə",
    "Other" : "Digər",
    "Status" : "Status",
    "Categories" : "Kateqoriyalar",
    "Hidden" : "Gizli",
    "can edit" : "dəyişmək olar"
},
"nplurals=2; plural=(n != 1);");
