OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "L'adreça de correu electrònic proporcionada és massa llarga",
    "User-Session unexpectedly expired" : "La sessió ha caducat inesperadament",
    "Provided email-address is not valid" : "L'adreça electrònica proporcionada no és vàlida",
    "%s has published the calendar »%s«" : "%s ha publicat el calendari «%s»",
    "Unexpected error sending email. Please contact your administrator." : "S'ha produït un error inesperat en enviar el correu electrònic. Contacteu amb l'administrador.",
    "Successfully sent email to %1$s" : "Correu enviat correctament a %1$s",
    "Hello," : "Hola,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Us volem informar que %s ha publicat el calendari «%s».",
    "Open »%s«" : "Obre »%s«",
    "Cheers!" : "A reveure!",
    "Upcoming events" : "Pròxims esdeveniments",
    "No more events today" : "Avui no hi ha més esdeveniments",
    "No upcoming events" : "No hi ha propers esdeveniments",
    "More events" : "Més esdeveniments",
    "%1$s with %2$s" : "%1$s amb %2$s",
    "Calendar" : "Calendari",
    "New booking {booking}" : "Nova reserva {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) va reservar la cita \"{config_display_name}\" el {date_time}.",
    "Appointments" : "Cites",
    "Schedule appointment \"%s\"" : "Agenda la cita \"%s\"",
    "Schedule an appointment" : "Agenda una cita",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : "Preparar-se per a %s",
    "Follow up for %s" : "Seguiment de %s",
    "Your appointment \"%s\" with %s needs confirmation" : "La vostra cita \"%s\" amb %s necessita confirmació",
    "Dear %s, please confirm your booking" : "Benvolgut %s, confirmeu la vostra reserva",
    "Confirm" : "Confirma",
    "Appointment with:" : "Cita amb:",
    "Description:" : "Descripció:",
    "This confirmation link expires in %s hours." : "Aquest enllaç de confirmació caduca d'aquí a %s hores.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Si després de tot, voleu cancel·lar la cita, poseu-vos en contacte amb el vostre organitzador responent a aquest correu electrònic o visitant la seva pàgina de perfil.",
    "Your appointment \"%s\" with %s has been accepted" : "S'ha acceptat la vostra cita \"%s\" amb %s",
    "Dear %s, your booking has been accepted." : "Benvolgut %s, s'ha acceptat la vostra reserva.",
    "Appointment for:" : "Cita per a:",
    "Date:" : "Data:",
    "You will receive a link with the confirmation email" : "Rebreu un enllaç amb el correu electrònic de confirmació",
    "Where:" : "Ubicació:",
    "Comment:" : "Comentari:",
    "You have a new appointment booking \"%s\" from %s" : "Tens una nova reserva de cita \"%s\" de %s",
    "Dear %s, %s (%s) booked an appointment with you." : "Benvolgut %s, %s (%s) ha reservat una cita amb tu.",
    "Location:" : "Ubicació:",
    "A Calendar app for Nextcloud" : "Una aplicació de calendari per al Nextcloud",
    "Previous day" : "Dia anterior",
    "Previous week" : "Setmana anterior",
    "Previous year" : "Any anterior",
    "Previous month" : "Mes anterior",
    "Next day" : "Dia següent",
    "Next week" : "Setmana següent",
    "Next year" : "Any següent",
    "Next month" : "Mes següent",
    "Create new event" : "Crea un nou esdeveniment",
    "Event" : "Esdeveniment",
    "Today" : "Avui",
    "Day" : "Dia",
    "Week" : "Setmana",
    "Month" : "Mes",
    "Year" : "Any",
    "List" : "Llista",
    "Appointment link was copied to clipboard" : "L'enllaç de la cita s'ha copiat al porta-retalls",
    "Appointment link could not be copied to clipboard" : "No s'ha pogut copiar l'enllaç de la cita al porta-retalls",
    "Preview" : "Previsualitza",
    "Copy link" : "Copia l'enllaç",
    "Edit" : "Edició",
    "Delete" : "Suprimeix",
    "Appointment schedules" : "Horaris de cites",
    "Create new" : "Crea nou",
    "Disable calendar \"{calendar}\"" : "Inhabilita el calendari \"{calendar}\"",
    "Disable untitled calendar" : "Inhabilita el calendari sense títol",
    "Enable calendar \"{calendar}\"" : "Habilita el calendari \"{calendar}\"",
    "Enable untitled calendar" : "Habilita el calendari sense títol",
    "An error occurred, unable to change visibility of the calendar." : "S'ha produït un error. No s'ha canviat la visibilitat del calendari.",
    "Untitled calendar" : "Calendari sense títol",
    "Shared with you by" : "Compartit amb tu per",
    "Edit and share calendar" : "Edició i comparteix el calendari",
    "Edit calendar" : "Edició del calendari",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Deixant de compartir el calendari en {countdown} segons","S'està deixant de compartir el calendari en {countdown} segons"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Eliminant el calendari en {countdown} segons","S'està suprimint el calendari en {countdown} segons"],
    "An error occurred, unable to create the calendar." : "Ha succeït un error i no s'ha pogut crear el calendari.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Escriviu un enllaç vàlid (que comenci amb http://, https://, webcal://, o webcals://)",
    "Calendars" : "Calendaris",
    "Add new" : "Afegeix nou/nova",
    "New calendar" : "Calendari nou",
    "Name for new calendar" : "Nom per al nou calendari",
    "Creating calendar …" : "Creant el calendari …",
    "New calendar with task list" : "Calendari nou amb llista de tasques",
    "New subscription from link (read-only)" : "Nova subscripció des d'enllaç (només lectura)",
    "Creating subscription …" : "Creant la subscripció …",
    "Add public holiday calendar" : "Afegeix un calendari de festes públiques",
    "Add custom public calendar" : "Afegeix un calendari públic personalitzat",
    "Calendar link copied to clipboard." : "S'ha copiat l'enllaç del calendari al porta-retalls.",
    "Calendar link could not be copied to clipboard." : "No s'ha pogut copiar l'enllaç del calendari al porta-retalls.",
    "Copy subscription link" : "Copiar l'enllaç de subscripció",
    "Copying link …" : "Copiant l'enllaç …",
    "Copied link" : "S'ha copiat l'enllaç",
    "Could not copy link" : "No s'ha pogut copiar l'enllaç",
    "Export" : "Exporta",
    "Untitled item" : "Element sense títol",
    "Unknown calendar" : "Calendari desconegut",
    "Could not load deleted calendars and objects" : "No s'han pogut carregar els calendaris i els objectes suprimits",
    "Could not delete calendar or event" : "No s'ha pogut suprimir el calendari o l'esdeveniment",
    "Could not restore calendar or event" : "No s'ha pogut restaurar el calendari o l'esdeveniment",
    "Do you really want to empty the trash bin?" : "Realment voleu buidar la paperera?",
    "Empty trash bin" : "Buida la paperera",
    "Trash bin" : "Paperera",
    "Loading deleted items." : "S'estan carregant els elements suprimits.",
    "You do not have any deleted items." : "No teniu cap element suprimit.",
    "Name" : "Nom",
    "Deleted" : "Suprimit",
    "Restore" : "Restaura",
    "Delete permanently" : "Suprimeix de manera permanent",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Els elements de la paperera se suprimeixen al cap de {numDays} dia","Els elements de la paperera se suprimeixen al cap de {numDays} dies"],
    "Could not update calendar order." : "No s'ha pogut actualitzar l'ordre del calendari.",
    "Shared calendars" : "Calendaris compartits",
    "Deck" : "Targetes",
    "Internal link" : "Enllaç intern",
    "A private link that can be used with external clients" : "Un enllaç privat que pot utilitzar-se amb clients externs",
    "Copy internal link" : "Copia l'enllaç intern",
    "An error occurred, unable to publish calendar." : "Ha succeït un error i no ha estat possible publicar el calendari.",
    "An error occurred, unable to send email." : "Ha succeït un error i no ha estat possible enviar el correu.",
    "Embed code copied to clipboard." : "S'ha copiat el codi al porta-retalls.",
    "Embed code could not be copied to clipboard." : "No s'ha pogut copiar al porta-retalls el codi d'inserció.",
    "Unpublishing calendar failed" : "Ha fallat la des-publicació del calendari",
    "Share link" : "Enllaç d'ús compartit",
    "Copy public link" : "Copia l'enllaç públic",
    "Send link to calendar via email" : "Enviar per correu l'enllaç al calendari",
    "Enter one address" : "Escriviu una adreça",
    "Sending email …" : "S'està enviant un correu…",
    "Copy embedding code" : "Còpia del codi per inserir",
    "Copying code …" : "Copiant el codi …",
    "Copied code" : "Codi copiat",
    "Could not copy code" : "No s'ha pogut copiar el codi",
    "Delete share link" : "Suprimeix l'enllaç de compartició",
    "Deleting share link …" : "S'està suprimint l'enllaç de compartició …",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Equip)",
    "An error occurred while unsharing the calendar." : "S'ha produït un error en deixar de compartir el calendari.",
    "An error occurred, unable to change the permission of the share." : "Ha succeït un error i no s'ha pogut canviar els permisos de compartició.",
    "Unshare with {displayName}" : "S'ha deixat de compartir amb {displayName}",
    "Share with users or groups" : "Comparteix amb usuaris o grups",
    "No users or groups" : "No hi ha usuaris ni grups",
    "Failed to save calendar name and color" : "No s'ha pogut desar el nom i el color del calendari",
    "Never show me as busy (set this calendar to transparent)" : "No em mostris mai com a ocupat (configura aquest calendari com a transparent)",
    "Share calendar" : "Comparteix el calendari",
    "Unshare from me" : "Deixa de compartir",
    "Save" : "Desa",
    "View" : "Visualització",
    "Import calendars" : "Importació calendaris",
    "Please select a calendar to import into …" : "Escolliu un calendari per ser importat …",
    "Filename" : "Nom del fitxer",
    "Calendar to import into" : "Calendari a importar",
    "Cancel" : "Cancel·la",
    "_Import calendar_::_Import calendars_" : ["Importar calendari","Importació de calendaris"],
    "Select the default location for attachments" : "Seleccioneu la ubicació per defecte per als fitxers adjunts",
    "Pick" : "Tria",
    "Invalid location selected" : "La ubicació seleccionada no és vàlida",
    "Attachments folder successfully saved." : "La carpeta de fitxers adjunts s'ha desat correctament.",
    "Error on saving attachments folder." : "Error en desar la carpeta de fitxers adjunts.",
    "Attachments folder" : "Carpeta fitxers adjunts",
    "{filename} could not be parsed" : "No s'ha pogut entendre el contingut del fitxer {filename}",
    "No valid files found, aborting import" : "No s'han trobat fitxers que siguin vàlids i s'ha avortat la importació",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["S'ha importat correctament %n esdeveniment","S'ha importat correctament %n esdeveniments"],
    "Import partially failed. Imported {accepted} out of {total}." : "La importació ha fallat parcialment. S'han importat {accepted} d'un total de {total}.",
    "Automatic" : "Automàtic",
    "Automatic ({timezone})" : "Automàtic ({timezone})",
    "New setting was not saved successfully." : "No s'ha desat correctament els nous paràmetres.",
    "Timezone" : "Fus horari",
    "Navigation" : "Navegació",
    "Previous period" : "Període anterior",
    "Next period" : "Període següent",
    "Views" : "Vistes",
    "Day view" : "Vista de dia",
    "Week view" : "Vista de setmana",
    "Month view" : "Vista de mes",
    "Year view" : "Vista anual",
    "List view" : "Vista de llista",
    "Actions" : "Accions",
    "Create event" : "Crea un esdeveniment",
    "Show shortcuts" : "Mostra les dreceres",
    "Editor" : "Editor",
    "Close editor" : "Tanca l'editor",
    "Save edited event" : "Desa l'esdeveniment editat",
    "Delete edited event" : "Suprimeix l'esdeveniment editat",
    "Duplicate event" : "Esdeveniment duplicat",
    "or" : "o",
    "Calendar settings" : "Paràmetres de Calendari",
    "At event start" : "A l'inici de l'esdeveniment",
    "No reminder" : "Sense recordatoris",
    "Failed to save default calendar" : "No s'ha pogut desar el calendari predeterminat",
    "General" : "General",
    "Appearance" : "Aparença",
    "Editing" : "Edició",
    "Default reminder" : "Recordatori per defecte",
    "Files" : "Fitxers",
    "Appointment schedule successfully created" : "S'ha creat correctament la planificació de cites",
    "Appointment schedule successfully updated" : "La planificació de cites s'ha actualitzat correctament",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minut","{duration} minuts"],
    "0 minutes" : "0 minuts",
    "_{duration} hour_::_{duration} hours_" : ["{duration} hora","{duration} hores"],
    "_{duration} day_::_{duration} days_" : ["{duration} dia","{duration} dies"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} setmana","{duration} setmanes"],
    "_{duration} month_::_{duration} months_" : ["{duration} mes","{duration} mesos"],
    "_{duration} year_::_{duration} years_" : ["{duration} any","{duration} anys"],
    "To configure appointments, add your email address in personal settings." : "Per configurar cites, afegiu la vostra adreça de correu electrònic a la configuració personal.",
    "Public – shown on the profile page" : "Públic – es mostra a la pàgina de perfil",
    "Private – only accessible via secret link" : "Privat – només accessible mitjançant un enllaç secret",
    "Appointment schedule saved" : "S'ha guardat l'agenda de cites",
    "Create appointment schedule" : "Crea d'una planificació de cites",
    "Edit appointment schedule" : "Edició la planificació de cites",
    "Update" : "Actualitza",
    "Appointment name" : "Nom de la cita",
    "Location" : "Ubicació",
    "Create a Talk room" : "Crea una sala de Converses",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Un enllaç únic que es generarà per cada cita reservada i enviada mitjançant el correu electrònic de confirmació",
    "Description" : "Descripció",
    "Visibility" : "Visibilitat",
    "Duration" : "Durada",
    "Increments" : "Increments",
    "Additional calendars to check for conflicts" : "Calendaris addicionals per comprovar si hi ha conflictes",
    "Pick time ranges where appointments are allowed" : "Trieu intervals de temps on es permeten les cites",
    "to" : "a",
    "Delete slot" : "Suprimeix unitat temporal",
    "No times set" : "Sense horaris establerts",
    "Add" : "Afegeix",
    "Monday" : "Dilluns",
    "Tuesday" : "Dimarts",
    "Wednesday" : "Dimecres",
    "Thursday" : "Dijous",
    "Friday" : "Divendres",
    "Saturday" : "Dissabte",
    "Sunday" : "Diumenge",
    "Weekdays" : "Dies de la setmana",
    "Add time before and after the event" : "Afegiu temps abans i després de l'esdeveniment",
    "Before the event" : "Abans de l'esdeveniment",
    "After the event" : "Després de l’esdeveniment",
    "Planning restrictions" : "Restriccions de planificació",
    "Minimum time before next available slot" : "Temps mínim abans de la propera unitat temporal disponible",
    "Max slots per day" : "Màxim d'unitats temporals per dia",
    "Limit how far in the future appointments can be booked" : "Limiteu fins a quin punt es poden reservar cites futures",
    "It seems a rate limit has been reached. Please try again later." : "Sembla que s'ha arribat a un límit de freqüència màxima. Si us plau, torna-ho a provar més tard.",
    "Please confirm your reservation" : "Si us plau, confirmeu la vostra reserva",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "T'hem enviat un correu electrònic amb els detalls. Si us plau, confirmeu la vostra cita mitjançant l'enllaç del correu electrònic. Ja podeu tancar aquesta pàgina.",
    "Your name" : "El vostre nom",
    "Your email address" : "La vostra adreça de correu",
    "Please share anything that will help prepare for our meeting" : "Si us plau, compartiu qualsevol cosa que ajudi a preparar la nostra reunió",
    "Could not book the appointment. Please try again later or contact the organizer." : "No s'ha pogut reservar la cita. Torneu-ho a provar més tard o contacteu amb l'organitzador.",
    "Back" : "Torna",
    "Book appointment" : "Reserva cita",
    "Error fetching Talk conversations." : "S'ha produït un error en recuperar les converses a Converses.",
    "Conversation does not have a valid URL." : "La conversa no té un URL vàlid.",
    "Successfully added Talk conversation link to location." : "S'ha afegit correctament l'enllaç de Converses a la ubicació.",
    "Successfully added Talk conversation link to description." : "S'ha afegit correctament l'enllaç de Converses a la descripció.",
    "Failed to apply Talk room." : "No s'ha pogut aplicar la sala de Converses.",
    "Talk conversation for event" : "Converses per a l'esdeveniment",
    "Error creating Talk conversation" : "S'ha produït un error en crear la Converses",
    "Select a Talk Room" : "Seleccioneu una sala de Converses",
    "Add Talk conversation" : "Afegeix a Converses",
    "Fetching Talk rooms…" : "S'estan obtenint sales de Converses…",
    "No Talk room available" : "No hi ha sala de Converses disponible",
    "Select conversation" : "Seleccioneu una conversa",
    "on" : "a",
    "at" : "a",
    "before at" : "abans a les",
    "Notification" : "Notificació",
    "Email" : "Correu",
    "Audio notification" : "Notificació de so",
    "Other notification" : "Altres notificacions",
    "Relative to event" : "En relació a l'esdeveniment",
    "On date" : "A la data",
    "Edit time" : "Modifica l'hora",
    "Save time" : "Desar l'hora",
    "Remove reminder" : "Suprimeix el recordatori",
    "Add reminder" : "Afegeix un recordatori",
    "seconds" : "segons",
    "minutes" : "minuts",
    "hours" : "hores",
    "days" : "dies",
    "weeks" : "setmanes",
    "Choose a file to add as attachment" : "Trieu un fitxer per afegir als adjunts",
    "Choose a file to share as a link" : "Tria un fitxer per compartir-lo com a enllaç",
    "Attachment {name} already exist!" : "El fitxer adjunt {name} ja existeix!",
    "Could not upload attachment(s)" : "No s'han pogut pujar els fitxers adjunts",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Esteu a punt d'anar a {host}. Esteu segur de continuar? Enllaç: {link}",
    "Proceed" : "Continua",
    "No attachments" : "Sense fitxers adjunts",
    "Add from Files" : "Afegeix de Fitxers",
    "Upload from device" : "Pujada des del dispositiu",
    "Delete file" : "Suprimeix el fitxer",
    "Confirmation" : "Confirmació",
    "_{count} attachment_::_{count} attachments_" : ["{count} fitxer adjunt","{count} fitxers adjunts"],
    "Suggested" : "Suggerit",
    "Available" : "Disponible",
    "Invitation accepted" : "S'ha acceptat la invitació",
    "Accepted {organizerName}'s invitation" : "S'ha acceptat la invitació de {organizerName}",
    "Participation marked as tentative" : "Participació marcada com a provisional",
    "Invitation is delegated" : "La invitació és delegada",
    "Not available" : "No disponible",
    "Invitation declined" : "S'ha declinat la invitació",
    "Declined {organizerName}'s invitation" : "{organizerName}'s ha declinat la invitació",
    "Availability will be checked" : "Es comprovarà la disponibilitat",
    "Invitation will be sent" : "S'enviarà la invitació",
    "Failed to check availability" : "No s'ha pogut comprovar la disponibilitat",
    "Failed to deliver invitation" : "No s'ha pogut lliurar la invitació",
    "Awaiting response" : "Esperant resposta",
    "Checking availability" : "Consultant disponibilitat",
    "Has not responded to {organizerName}'s invitation yet" : "Encara no ha respost a la invitació de {organizerName}",
    "chairperson" : "responsable",
    "required participant" : "participant obligatori",
    "non-participant" : "no participant",
    "optional participant" : "participant opcional",
    "{organizer} (organizer)" : "{organizer} (organitzador)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Availability of attendees, resources and rooms" : "Disponibilitat d'assistents, recursos i espais",
    "Suggestion accepted" : "S'ha acceptat el suggeriment",
    "Legend" : "Llegenda",
    "Out of office" : "Fora de l'oficina",
    "Attendees:" : "Assistents:",
    "Done" : "Fet",
    "Search room" : "Cerca sala",
    "Room name" : "Nom de la sala",
    "Check room availability" : "Consulta la disponibilitat de l'habitació",
    "Free" : "Disponible",
    "Busy (tentative)" : "Ocupat (provisional)",
    "Busy" : "Ocupat",
    "Unknown" : "Desconegut",
    "Find a time" : "Troba un moment",
    "The invitation has been accepted successfully." : "La invitació s'ha acceptat correctament.",
    "Failed to accept the invitation." : "No s'ha pogut acceptar la invitació.",
    "The invitation has been declined successfully." : "La invitació s'ha declinat correctament.",
    "Failed to decline the invitation." : "No s'ha pogut declinar la invitació.",
    "Your participation has been marked as tentative." : "La teva participació s'ha marcat com a provisional.",
    "Failed to set the participation status to tentative." : "No s'ha pogut establir l'estat de participació com a provisional.",
    "Accept" : "Accepta",
    "Decline" : "Rebutja",
    "Tentative" : "Provisional",
    "No attendees yet" : "Encara no hi ha cap participant",
    "Attendees" : "Assistents",
    "Remove group" : "Suprimir el grup",
    "Remove attendee" : "Suprimeix el participant",
    "Request reply" : "Sol·licitar resposta",
    "Chairperson" : "Organització",
    "Required participant" : "Participació obligatòria",
    "Optional participant" : "Participació opcional",
    "Non-participant" : "Sense participació",
    "_%n member_::_%n members_" : ["{n} membre","{n} membres"],
    "Search for emails, users, contacts, contact groups or teams" : "Cerca correus electrònics, usuaris, contactes, grups de contactes o equips",
    "No match found" : "No s'ha trobat cap coincidència",
    "Note that members of circles get invited but are not synced yet." : "Tingueu en compte que els membres dels cercles són convidats però encara no es sincronitzen.",
    "Note that members of contact groups get invited but are not synced yet." : "Tingueu en compte que els membres dels grups de contacte són convidats, però encara no es sincronitzen.",
    "(organizer)" : "(organitza l'esdeveniment)",
    "Make {label} the organizer" : "Feu que {label} sigui l'organitzador",
    "Make {label} the organizer and attend" : "Feu que {label} sigui l'organitzador i assistent",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Per enviar invitacions i atendre les respostes, cal que [linkopen]afegiu la vostra adreça de correu a la vostra configuració personal[linkclose].",
    "Remove color" : "Suprimeix el color",
    "Event title" : "Títol de l'esdeveniment",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "No es pot modificar la configuració de tot el dia per als esdeveniments que formen part d'un conjunt de recurrència.",
    "From" : "De",
    "To" : "A",
    "Repeat" : "Repeteix",
    "_time_::_times_" : ["vegada","vegades"],
    "never" : "mai",
    "on date" : "el dia",
    "after" : "després de",
    "End repeat" : "Finalitza la repetició",
    "Select to end repeat" : "Seleccioneu per finalitzar repetició",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Aquest esdeveniment és l'excepció de recurrència d'un conjunt de recurrència. No hi podeu afegir una regla de recurrència.",
    "first" : "primer",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Els canvis a la regla de recurrència només afectarà en aquesta i futures ocurrències.",
    "Repeat every" : "Repeteix cada",
    "By day of the month" : "Per dia del mes",
    "On the" : "Al",
    "_day_::_days_" : ["dia","dies"],
    "_week_::_weeks_" : ["setmana","setmanes"],
    "_month_::_months_" : ["mes","mesos"],
    "_year_::_years_" : ["any","anys"],
    "On specific day" : "En un dia concret",
    "weekday" : "dia de la setmana",
    "weekend day" : "dia de cap de setmana",
    "Does not repeat" : "No es repeteix",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "La definició de recurrència d'aquest esdeveniment no és del tot compatible amb Nextcloud. Si canvieu les opcions de recurrència, es poden perdre certes recurrències.",
    "No rooms or resources yet" : "Encara no hi ha sales ni recursos",
    "Resources" : "Recursos",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} seient","{seatingCapacity} seients"],
    "Add resource" : "Afegeix un recurs",
    "Has a projector" : "Té un projector",
    "Has a whiteboard" : "Té una pissarra blanca",
    "Wheelchair accessible" : "Accessible amb cadira de rodes",
    "Remove resource" : "Suprimeix el recurs",
    "Search for resources or rooms" : "Cerca recursos o sales",
    "available" : "disponible",
    "unavailable" : "no disponible",
    "Show all rooms" : "Mostra totes les habitacions",
    "Projector" : "Projector",
    "Whiteboard" : "Pissarra blanca",
    "Room type" : "Tipus de sala",
    "Any" : "Qualsevol",
    "Minimum seating capacity" : "Capacitat mínima de seients",
    "More details" : "Més detalls",
    "Update this and all future" : "Actualitza aquesta i les futures",
    "Update this occurrence" : "Actualitza aquesta ocurrència",
    "Public calendar does not exist" : "No existeix un calendari públic",
    "Maybe the share was deleted or has expired?" : "Potser la compartició va ser esborrada o va expirar?",
    "Remove participant" : "Suprimir el participant",
    "Yes" : "Sí",
    "No" : "No",
    "Maybe" : "Potser",
    "None" : "Només una vegada",
    "Create" : "Crea",
    "from {formattedDate}" : "de {formattedDate}",
    "to {formattedDate}" : "a {formattedDate}",
    "on {formattedDate}" : "el {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "del {formattedDate} a les {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "al {formattedDate} a les {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "el {formattedDate} a les {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} a les {formattedTime}",
    "Please enter a valid date" : "Indiqueu una data vàlida",
    "Please enter a valid date and time" : "Indiqueu una data i hora vàlides",
    "Select a time zone" : "Seleccioneu una zona horària",
    "Please select a time zone:" : "Seleccioneu una zona horària:",
    "Pick a time" : "Tria una hora",
    "Pick a date" : "Tria una data",
    "Type to search time zone" : "Escriviu per cercar la zona horària",
    "Global" : "Global",
    "Holidays in {region}" : "Festius a {region}",
    "An error occurred, unable to read public calendars." : "S'ha produït un error, no es poden llegir els calendaris públics.",
    "An error occurred, unable to subscribe to calendar." : "S'ha produït un error, no es pot subscriure al calendari.",
    "Public holiday calendars" : "Calendaris de festius",
    "Public calendars" : "Calendaris públics",
    "No valid public calendars configured" : "No s'han configurat calendaris públics vàlids",
    "Speak to the server administrator to resolve this issue." : "Parleu amb l'administrador del servidor per resoldre aquest problema.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Thunderbird proporciona els calendaris de festius. Les dades del calendari es baixaran de {website}",
    "By {authors}" : "Per {authors}",
    "Subscribed" : "Subscrit",
    "Subscribe" : "Subscriu-m'hi",
    "Could not fetch slots" : "No s'han pogut obtenir les unitats temporals",
    "Select a date" : "Seleccioneu una data",
    "Select slot" : "Seleccioneu unitat temporal",
    "No slots available" : "No hi han unitats temporals disponibles",
    "The slot for your appointment has been confirmed" : "S'ha confirmat l’unitat temporal per a la vostra cita",
    "Appointment Details:" : "Detalls de la cita:",
    "Time:" : "Hora:",
    "Booked for:" : "Reservat per a:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Gràcies. La teva reserva de {startDate} a {endDate} s'ha confirmat.",
    "Book another appointment:" : "Reserva una altra cita:",
    "See all available slots" : "Consulta totes les unitat temporals disponibles",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "L’unitat temporal per a la vostra cita de {startDate} a {endDate} ja no està disponible.",
    "Please book a different slot:" : "Reserveu una unitat temporal diferent:",
    "Book an appointment with {name}" : "Reserva una cita amb {name}",
    "No public appointments found for {name}" : "No s'han trobat cites públiques per a {name}",
    "Personal" : "Personal",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "La detecció automàtica de la zona horària va determinar que la vostra zona horària fos UTC.\nÉs probable que això sigui el resultat de les mesures de seguretat del vostre navegador web.\nSi us plau, configureu la vostra zona horària manualment a la configuració del calendari.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "No s'ha trobat la vostra zona horària configurada ({timezoneId}). Tornant a l'UTC.\nCanvieu la vostra zona horària a la configuració i informeu d'aquest problema.",
    "Availability of {displayName}" : "Disponibilitat de {displayName}",
    "Edit event" : "Edita l'esdeveniment",
    "Event does not exist" : "L'esdeveniment no existeix",
    "Duplicate" : "Duplica",
    "Delete this occurrence" : "Suprimeix aquesta ocurrència",
    "Delete this and all future" : "Suprimeix aquesta i les ocurrències futures",
    "All day" : "Tot el dia",
    "Modifications wont get propagated to the organizer and other attendees" : "Les modificacions no es propagaran a l'organitzador i als altres assistents",
    "Managing shared access" : "Gestió de l'accés compartit",
    "Deny access" : "Denega l'accés",
    "Invite" : "Convida",
    "_User requires access to your file_::_Users require access to your file_" : ["L'usuari requereix accés al vostre fitxer","Els usuaris requereixen accés al vostre fitxer"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["El fitxer adjunt requereix accés compartit","Els fitxers adjunts requereixen accés compartit"],
    "Untitled event" : "Esdeveniment sense títol",
    "Close" : "Tanca",
    "Modifications will not get propagated to the organizer and other attendees" : "Les modificacions no es propagaran a l'organitzador i als altres assistents",
    "Selected" : "Seleccionat",
    "Title" : "Títol",
    "30 min" : "30 min",
    "Participants" : "Participants",
    "Submit" : "Envia",
    "Subscribe to {name}" : "Subscriure a {name}",
    "Export {name}" : "Exporta {name}",
    "Show availability" : "Mostra disponibilitat",
    "Anniversary" : "Commemoració",
    "Appointment" : "Cita",
    "Business" : "Negocis",
    "Education" : "Formació",
    "Holiday" : "Vacances",
    "Meeting" : "Reunió",
    "Miscellaneous" : "Miscel·lània",
    "Non-working hours" : "Hores no laborals",
    "Not in office" : "Fora de l'oficina",
    "Phone call" : "Trucada telefònica",
    "Sick day" : "Malaltia",
    "Special occasion" : "Ocasió especial",
    "Travel" : "Viatge",
    "Vacation" : "Vacances",
    "Midnight on the day the event starts" : "Mitjanit del dia que comença l'esdeveniment",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n dia abans de l'event a les {formattedHourMinute}","%n dies abans de l'esdeveniment a les {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n setmana abans de l'event a les  {formattedHourMinute}","%n setmanes abans de l'esdeveniment a les {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "el dia de l'esdeveniment a les {formattedHourMinute}",
    "at the event's start" : "a l'inici de l'esdeveniment",
    "at the event's end" : "al final de l'esdeveniment",
    "{time} before the event starts" : "{time} abans que comenci l'esdeveniment",
    "{time} before the event ends" : "{time} abans de que acabi l'event",
    "{time} after the event starts" : "{time} després de que comenci l'event",
    "{time} after the event ends" : "{time} després de que acabi l'event",
    "on {time}" : "a les {time}",
    "on {time} ({timezoneId})" : "a les {time} ({timezoneId})",
    "Week {number} of {year}" : "Setmana {number} del {year}",
    "Daily" : "Diàriament",
    "Weekly" : "Setmanalment",
    "Monthly" : "Mensualment",
    "Yearly" : "Anualment",
    "_Every %n day_::_Every %n days_" : ["Cada %n dia","Cada %n dies"],
    "_Every %n week_::_Every %n weeks_" : ["Cada %n setmana","Cada %n setmanes"],
    "_Every %n month_::_Every %n months_" : ["Cada %n mes","Cada %n mesos"],
    "_Every %n year_::_Every %n years_" : ["Cada %n any","Cada %n anys"],
    "_on {weekday}_::_on {weekdays}_" : ["el {weekday}","els {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["el dia {dayOfMonthList}","els dies {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "al {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {dayOfMonthList}" : "a {monthNames} al {dayOfMonthList}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "al {monthNames} al {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "fins el {untilDate}",
    "_%n time_::_%n times_" : ["%n vegada","%n vegades"],
    "second" : "segon",
    "third" : "tercer",
    "fourth" : "quart",
    "fifth" : "cinquè",
    "second to last" : "penúltim",
    "last" : "últim",
    "Untitled task" : "Tasca sense títol",
    "Please ask your administrator to enable the Tasks App." : "Demaneu al vostre administrador que habiliti l'aplicació de Tasques.",
    "You are not allowed to edit this event as an attendee." : "No teniu permès editar aquest esdeveniment com a assistent.",
    "W" : "S",
    "%n more" : "%n més",
    "No events to display" : "No hi ha esdeveniments per visualitzar",
    "All participants declined" : "Tots els participants van rebutjar",
    "Please confirm your participation" : "Si us plau, confirmeu la vostra participació",
    "You declined this event" : "Has rebutjat aquest esdeveniment",
    "Your participation is tentative" : "La vostra participació és provisional",
    "_+%n more_::_+%n more_" : ["i %n més","i %n més"],
    "No events" : "Cap esdeveniment",
    "Create a new event or change the visible time-range" : "Crea un esdeveniment nou o canvia l'interval de temps visible",
    "Failed to save event" : "No s'ha pogut desar l'esdeveniment",
    "It might have been deleted, or there was a typo in a link" : "Pot ser que s'hagi suprimit o que hi hagi un error tipogràfic en un enllaç",
    "It might have been deleted, or there was a typo in the link" : "Pot ser que s'hagi suprimit o que hi hagi un error tipogràfic a l'enllaç",
    "Meeting room" : "Sala de reunions",
    "Lecture hall" : "Sala de lectura",
    "Seminar room" : "Sala de seminaris",
    "Other" : "Altres",
    "When shared show" : "Mostrar quan es comparteix",
    "When shared show full event" : "Quan es comparteix, mostra l'esdeveniment complet",
    "When shared show only busy" : "Quan es comparteix, mostra només si està ocupat",
    "When shared hide this event" : "Quan es comparteix, amaga aquest esdeveniment",
    "Add a location" : "Afegeix una ubicació",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Afegeix una descripció\n\n- De què tracta aquesta reunió\n- Elements de l'ordre del dia\n- Qualsevol cosa que els participants hagin de preparar",
    "Status" : "Estat",
    "Confirmed" : "Confirmat",
    "Canceled" : "Cancel·lat",
    "Confirmation about the overall status of the event." : "Confirmació sobre l'estat general de l'esdeveniment.",
    "Show as" : "Mostra'm com a",
    "Take this event into account when calculating free-busy information." : "Tenir en compte aquest esdeveniment quan es calculi informació sobre disponibilitat-ocupació.",
    "Categories" : "Categories",
    "Categories help you to structure and organize your events." : "Les categories us ajuden a estructurar i organitzar els vostres esdeveniment.",
    "Search or add categories" : "Cerca o afegeix categories",
    "Add this as a new category" : "Afegeix-ho com una nova categoria",
    "Custom color" : "Color personalitzat",
    "Special color of this event. Overrides the calendar-color." : "Color especial per a aquest event. Sobreescriu el color del calendari.",
    "Error while sharing file" : "Error en compartir el fitxer",
    "Error while sharing file with user" : "S'ha produït un error en compartir el fitxer amb l'usuari",
    "Attachment {fileName} already exists!" : "El fitxer adjunt {fileName} ja existeix!",
    "An error occurred during getting file information" : "S'ha produït un error en obtenir la informació del fitxer",
    "An error occurred, unable to delete the calendar." : "S'ha produït un error. No s'ha suprimit el calendari.",
    "Imported {filename}" : "{filename} importat",
    "This is an event reminder." : "Això és un recordatori de l'esdeveniment.",
    "Error while parsing a PROPFIND error" : "S'ha produït un error en analitzar un error PROPFIND",
    "Appointment not found" : "No s'ha trobat la cita",
    "User not found" : "No s'ha trobat l'usuari",
    "Hidden" : "Ocult",
    "can edit" : "pot editar-lo",
    "Calendar name …" : "Nom del calendari …",
    "Default attachments location" : "Ubicació per defecte dels fitxers adjunts",
    "Automatic ({detected})" : "Automàtic ({detected})",
    "Shortcut overview" : "Descripció general de la drecera",
    "CalDAV link copied to clipboard." : "S'ha copiat al porta-retalls l'enllaç CalDAV.",
    "CalDAV link could not be copied to clipboard." : "No s'ha pogut copiar al porta-retalls l'enllaç CalDAV.",
    "Enable birthday calendar" : "Habilitar el calendari d'aniversaris",
    "Show tasks in calendar" : "Mostra les tasques en el calendari",
    "Enable simplified editor" : "Habilitar l'editor simplificat",
    "Limit the number of events displayed in the monthly view" : "Limita el nombre d'esdeveniments que es mostren a la vista mensual",
    "Show weekends" : "Mostra els caps de setmana",
    "Show week numbers" : "Mostra el número de la setmana",
    "Time increments" : "Increments de temps",
    "Default calendar for incoming invitations" : "Calendari predeterminat per a les invitacions entrants",
    "Copy primary CalDAV address" : "Copia l'adreça CalDAV primària",
    "Copy iOS/macOS CalDAV address" : "Copia l'adreça CalDAV iOS/macOS",
    "Personal availability settings" : "Paràmetres de disponibilitat personal",
    "Show keyboard shortcuts" : "Mostra les dreceres del teclat",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} convidats, {confirmedCount} confirmats",
    "Successfully appended link to talk room to location." : "S'ha afegit correctament l'enllaç a la sala de conversa a la ubicació.",
    "Successfully appended link to talk room to description." : "S'ha afegit l'enllaç d'una nova sala de Talk a la descripció de l'esdeveniment.",
    "Error creating Talk room" : "Ha succeït un error tractant de crear la sala a Talk",
    "_%n more guest_::_%n more guests_" : ["%n convidat més","%n convidats més"],
    "The visibility of this event in shared calendars." : "La visibilitat de l'event en calendaris compartits."
},
"nplurals=2; plural=(n != 1);");
