OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "メールアドレスが長すぎます",
    "User-Session unexpectedly expired" : "ユーザーセッションが予期せず期限切れになりました",
    "Provided email-address is not valid" : "メールアドレスが有効ではありません",
    "%s has published the calendar »%s«" : "%sをカレンダー »%s«に登録しました",
    "Unexpected error sending email. Please contact your administrator." : "メール送信時の予期せぬエラー。管理者に連絡してください。",
    "Successfully sent email to %1$s" : "%1$sへのメール送信に成功しました",
    "Hello," : "こんにちは。",
    "We wanted to inform you that %s has published the calendar »%s«." : "%sがカレンダー»%s«に登録されましたのでお知らせします。",
    "Open »%s«" : "»%s«を開く",
    "Cheers!" : "それでは！",
    "Upcoming events" : "今後のイベント",
    "No more events today" : "今日はこれ以上イベントがありません",
    "No upcoming events" : "今後のイベントはありません",
    "More events" : "その他イベント",
    "%1$s with %2$s" : "%2$sと%1$sで",
    "Calendar" : "カレンダー",
    "New booking {booking}" : "新しい予約 {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) は {date_time} に \"{config_display_name}\" の予定を予約をしました。",
    "Appointments" : "予定",
    "Schedule appointment \"%s\"" : "予定を入れる \"%s\"",
    "Schedule an appointment" : "予定を入れる",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : " %s の準備",
    "Follow up for %s" : "%s に対するフォローアップ",
    "Your appointment \"%s\" with %s needs confirmation" : "あなたの \"%s\" との予定 %s には確認が必要",
    "Dear %s, please confirm your booking" : "%s様、予定を承認してください。",
    "Confirm" : "承認",
    "Appointment with:" : "予約:",
    "Description:" : "説明:",
    "This confirmation link expires in %s hours." : "承認用リンクの有効期限は1%s時間です。",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "予定のキャンセルを希望される場合は、このメールに返信するか、主催者のプロフィールページを訪れ、主催者に連絡してください。",
    "Your appointment \"%s\" with %s has been accepted" : "あなたのアポイントメント \"%s\" が %s に受理されました。",
    "Dear %s, your booking has been accepted." : "親愛なる%s、あなたの予約は受け入れられました。",
    "Appointment for:" : "予定：",
    "Date:" : "日時:",
    "You will receive a link with the confirmation email" : "確認メールにリンクが添付されます。",
    "Where:" : "場所:",
    "Comment:" : "コメント:",
    "You have a new appointment booking \"%s\" from %s" : "新しい予定の予約 \"%s\" が %s からあります。",
    "Dear %s, %s (%s) booked an appointment with you." : "親愛なる %s、%s (%s) はあなたのアポイントメントを予約しました。",
    "Location:" : "場所：",
    "A Calendar app for Nextcloud" : "NextCloudのカレンダーアプリ",
    "Previous day" : "前日",
    "Previous week" : "前週",
    "Previous year" : "前年",
    "Previous month" : "前月",
    "Next day" : "翌日",
    "Next week" : "翌週",
    "Next year" : "来年",
    "Next month" : "翌月",
    "Create new event" : "新しいイベントを作成する",
    "Event" : "イベント",
    "Today" : "今日",
    "Day" : "日",
    "Week" : "週",
    "Month" : "月",
    "Year" : "年",
    "List" : "リスト",
    "Appointment link was copied to clipboard" : "予定リンクがクリップボードにコピーされました",
    "Appointment link could not be copied to clipboard" : "予定リンクをクリップボードにコピーできませんでした",
    "Preview" : "プレビュー",
    "Copy link" : "リンクをコピー",
    "Edit" : "編集",
    "Delete" : "削除",
    "Appointment schedules" : "予約スケジュール",
    "Create new" : "新規作成",
    "Disable calendar \"{calendar}\"" : "カレンダー \"{calendar}\" を無効化する",
    "Disable untitled calendar" : "無題のカレンダーを無効化する",
    "Enable calendar \"{calendar}\"" : "\"{calendar}\" カレンダーを有効化する",
    "Enable untitled calendar" : "無題のカレンダーを有効にする",
    "An error occurred, unable to change visibility of the calendar." : "エラーが発生したため、カレンダーの表示状態を変更できません。",
    "Untitled calendar" : "無題のカレンダー",
    "Shared with you by" : "と共有中",
    "Edit and share calendar" : "カレンダー編集、共有",
    "Edit calendar" : "カレンダー編集",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["{countdown}秒後にカレンダーの共有を解除します"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["{countdown}秒後にカレンダーを削除します"],
    "An error occurred, unable to create the calendar." : "エラーが発生したため、カレンダーを作成できません。",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "有効なリンクを入力してください（http:// や https:// 、webcal:// または webcals:// のいずれかで始まる必要があります）",
    "Calendars" : "カレンダー",
    "Add new" : "新規作成",
    "New calendar" : "新しいカレンダー",
    "Name for new calendar" : "新しいカレンダーの名前",
    "Creating calendar …" : "カレンダーを作成中 …",
    "New calendar with task list" : "タスクリスト付きの新しいカレンダー",
    "New subscription from link (read-only)" : "リンクから新規購読 (読み取り専用)",
    "Creating subscription …" : "購読を作成中 …",
    "Add public holiday calendar" : "祝日カレンダーを追加",
    "Add custom public calendar" : "カスタム公開カレンダーを追加する",
    "Calendar link copied to clipboard." : "カレンダーリンクをクリップボードにコピー",
    "Calendar link could not be copied to clipboard." : "カレンダーリンクをクリップボードにコピーできませんでした。",
    "Copy subscription link" : "購読リンクをコピー",
    "Copying link …" : "リンクをコピーしています …",
    "Copied link" : "リンクをコピーしました",
    "Could not copy link" : "リンクをコピーできませんでした",
    "Export" : "エクスポート",
    "Untitled item" : "無題の項目",
    "Unknown calendar" : "不明なカレンダー",
    "Could not load deleted calendars and objects" : "削除されたカレンダーとオブジェクトを読み込めませんでした。",
    "Could not restore calendar or event" : "カレンダーまたはイベントを復元できませんでした。",
    "Do you really want to empty the trash bin?" : "本当にゴミ箱を空にしますか？",
    "Empty trash bin" : "ゴミ箱を空にする",
    "Trash bin" : "ごみ箱",
    "Loading deleted items." : "削除された項目をロードします。",
    "You do not have any deleted items." : "削除された項目はありません。",
    "Name" : "名前",
    "Deleted" : "削除済み",
    "Restore" : "復元",
    "Delete permanently" : "完全に削除する",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["ゴミ箱の中のアイテムは {numDays} 日後に削除されます"],
    "Could not update calendar order." : "カレンダーの順番を更新できません。",
    "Shared calendars" : "共有カレンダー",
    "Deck" : "デッキ",
    "Internal link" : "内部リンク",
    "A private link that can be used with external clients" : "外部クライアントと使用できるプライベートリンク",
    "Copy internal link" : "内部リンクをコピー",
    "An error occurred, unable to publish calendar." : "エラーが発生したため、カレンダーを公開できません。",
    "An error occurred, unable to send email." : "エラーが発生したため、メールを送信できません。",
    "Embed code copied to clipboard." : "埋め込みコードをクリップボードにコピーしました。",
    "Embed code could not be copied to clipboard." : "埋め込みコードをクリップボードにコピーできませんでした。",
    "Unpublishing calendar failed" : "カレンダーの公開解除に失敗しました",
    "Share link" : "URLで共有",
    "Copy public link" : "公開リンクをコピー",
    "Send link to calendar via email" : "メールでカレンダーへのリンクを送信",
    "Enter one address" : "アドレスを1つ入力してください",
    "Sending email …" : "メールを送信中 …",
    "Copy embedding code" : "埋め込みコードをコピー",
    "Copying code …" : "コードをコピーしています …",
    "Copied code" : "コードをコピーしました",
    "Could not copy code" : "コードをコピーできませんでした",
    "Delete share link" : "共有リンクを削除",
    "Deleting share link …" : "共有リンクを削除しています …",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Team)",
    "An error occurred while unsharing the calendar." : "カレンダーの共有解除中にエラーが発生しました",
    "An error occurred, unable to change the permission of the share." : "エラーが発生したため、共有の権限を変更できませんでした。",
    "Unshare with {displayName}" : "{displayName}との共有を解除",
    "Share with users or groups" : "ユーザーまたはグループと共有する",
    "No users or groups" : "ユーザーまたはグループはありません",
    "Failed to save calendar name and color" : "カレンダー名と色の保存に失敗しました",
    "Never show me as busy (set this calendar to transparent)" : "予定ありとして表示しない (このカレンダーを透明に設定)",
    "Share calendar" : "カレンダー共有",
    "Unshare from me" : "共有を自分から解除",
    "Save" : "保存",
    "Are you sure you want to delete \"{title}\"?" : "本当に\"{title}\"を削除してもいいですか?",
    "View" : "表示",
    "Import calendars" : "カレンダーのインポート",
    "Please select a calendar to import into …" : "インポートするカレンダーを選択してください …",
    "Filename" : "ファイル名",
    "Calendar to import into" : "インポートするカレンダー",
    "Cancel" : "キャンセル",
    "_Import calendar_::_Import calendars_" : ["カレンダーのインポート"],
    "Select the default location for attachments" : "添付ファイルのデフォルト位置を選択",
    "Pick" : "選定",
    "Invalid location selected" : "選択した場所が無効",
    "Attachments folder successfully saved." : "添付ファイルフォルダーを保存しました",
    "Error on saving attachments folder." : "添付ファイルフォルダーの保存でエラーが発生しました",
    "Attachments folder" : "添付ファイルフォルダー",
    "{filename} could not be parsed" : "{filename} が解析できませんでした",
    "No valid files found, aborting import" : "有効なファイルが見つかりませんでした。インポートを中止します。",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["%nイベントのインポートに成功しました"],
    "Import partially failed. Imported {accepted} out of {total}." : "インポートが部分的に失敗しました。 {total}のうち{accepted}をインポートしました。",
    "Automatic" : "自動",
    "Automatic ({timezone})" : "自動 ({timezone})",
    "New setting was not saved successfully." : "新しい設定は正常に保存されませんでした。",
    "Timezone" : "タイムゾーン",
    "Navigation" : "ナビゲーション",
    "Previous period" : "前の期間",
    "Next period" : "次の期間",
    "Views" : "表示",
    "Day view" : "日表示",
    "Week view" : "週表示",
    "Month view" : "月表示",
    "Year view" : "年表示",
    "List view" : "リスト表示",
    "Actions" : "アクション",
    "Create event" : "イベントを作成",
    "Show shortcuts" : "概要の表示",
    "Editor" : "エディタ",
    "Close editor" : "エディタを閉じる",
    "Save edited event" : "編集したイベントを保存",
    "Delete edited event" : "編集したイベントを削除",
    "Duplicate event" : "イベントを複製",
    "or" : "或いは",
    "Calendar settings" : "カレンダー設定",
    "At event start" : "イベント開始時",
    "No reminder" : "リマインダーなし",
    "Failed to save default calendar" : "デフォルトカレンダーの保存に失敗しました",
    "General" : "一般",
    "Appearance" : "表示",
    "Editing" : "編集中",
    "Default reminder" : "既定のリマインダー",
    "Files" : "ファイル",
    "Appointment schedule successfully created" : "予約スケジュールの作成に成功しました",
    "Appointment schedule successfully updated" : "予約スケジュールの更新に成功しました",
    "_{duration} minute_::_{duration} minutes_" : ["{duration}分"],
    "0 minutes" : "0分",
    "_{duration} hour_::_{duration} hours_" : ["{duration}時間"],
    "_{duration} day_::_{duration} days_" : ["{duration}日"],
    "_{duration} week_::_{duration} weeks_" : ["{duration}週間"],
    "_{duration} month_::_{duration} months_" : ["{duration}月"],
    "_{duration} year_::_{duration} years_" : ["{duration}年"],
    "To configure appointments, add your email address in personal settings." : "予定を設定するには、個人設定であなたのメールアドレスを追加してください。",
    "Public – shown on the profile page" : "公開 - プロフィールページに表示されます。",
    "Private – only accessible via secret link" : "非公開 - 秘密のリンクからしかアクセスできません。",
    "Update" : "更新",
    "Appointment name" : "予定名",
    "Location" : "場所",
    "Create a Talk room" : "通話ルームを作成",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "予約ごとにユニークなリンクが作成され、確認メールで送信されます",
    "Description" : "説明",
    "Visibility" : "公開レベル",
    "Duration" : "期間",
    "Increments" : "インクリメント",
    "Additional calendars to check for conflicts" : "コンフリクトを確認するための追加カレンダー",
    "Pick time ranges where appointments are allowed" : "予約可能な時間帯を選ぶ",
    "to" : "終了",
    "Delete slot" : "時間枠を削除",
    "No times set" : "時間設定なし",
    "Add" : "追加",
    "Monday" : "月曜日",
    "Tuesday" : "火曜日",
    "Wednesday" : "水曜日",
    "Thursday" : "木曜日",
    "Friday" : "金曜日",
    "Saturday" : "土曜日",
    "Sunday" : "日曜日",
    "Weekdays" : "平日",
    "Add time before and after the event" : "イベント前後の時間を追加",
    "Before the event" : "開催前",
    "After the event" : "イベント終了後",
    "Planning restrictions" : "プランニングの制限",
    "Minimum time before next available slot" : "次の空きスロットまでの最短時間",
    "Max slots per day" : "1日あたりの最大スロット数",
    "Limit how far in the future appointments can be booked" : "予約可能な時間帯の制限",
    "It seems a rate limit has been reached. Please try again later." : "レート制限に達したようです。後でもう一度お試しください。",
    "Please confirm your reservation" : "あなたの予約の確認をしてください",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "詳細をメールでお送りしました。メールに記載されているリンクから予約の確認をお願いします。これでこのページを閉じることができます。",
    "Your name" : "あなたの名前",
    "Your email address" : "あなたのメールアドレス",
    "Please share anything that will help prepare for our meeting" : "会議の準備に役立つことがあれば教えてください。",
    "Could not book the appointment. Please try again later or contact the organizer." : "予約できませんでした。後でもう一度試してみるか、主催者に連絡してください。",
    "Back" : "戻る",
    "Successfully added Talk conversation link to location." : "トークへのリンクをロケーションに追加しました。",
    "Add Talk conversation" : "会話を追加",
    "Select conversation" : "会話を選択",
    "on" : "曜日",
    "at" : "で",
    "before at" : "次の時間分早めに通知",
    "Notification" : "通知",
    "Email" : "メール",
    "Audio notification" : "音声通知",
    "Other notification" : "その他の通知",
    "Relative to event" : "相対時間",
    "On date" : "日時指定",
    "Edit time" : "時刻を変更",
    "Save time" : "時刻を保存",
    "Remove reminder" : "リマインダーを削除",
    "Add reminder" : "リマインダーを追加",
    "seconds" : "秒",
    "minutes" : "分",
    "hours" : "時間",
    "days" : "日",
    "weeks" : "週",
    "Choose a file to add as attachment" : "添付として追加するファイルを選択",
    "Choose a file to share as a link" : "共有リンクにして送信するファイルを選択",
    "Attachment {name} already exist!" : "添付ファイル {name} は既に存在します！",
    "Could not upload attachment(s)" : "添付ファイルをアップロードできませんでした",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "外部の信頼できない {host} に移動しようとしています。本当に続行しますか？リンク: {link}",
    "Proceed" : "続行する",
    "No attachments" : "添付ファイル無し",
    "Add from Files" : "ファイルから追加",
    "Upload from device" : "デバイスからアップロード",
    "Delete file" : "ファイルを削除",
    "Confirmation" : "確認",
    "_{count} attachment_::_{count} attachments_" : ["{count} 個の添付ファイル"],
    "Suggested" : "提案された",
    "Available" : "利用可能",
    "Invitation accepted" : "招待を受け付けました",
    "Accepted {organizerName}'s invitation" : "{organizerName} の招待を受け入れました",
    "Participation marked as tentative" : "参加は暫定的なもの",
    "Invitation is delegated" : "招待は委任されました",
    "Not available" : "利用できません",
    "Invitation declined" : "招待は辞退しました",
    "Declined {organizerName}'s invitation" : "{organizerName} の招待を辞退しました",
    "Awaiting response" : "返答待ち",
    "Checking availability" : "空き状況の確認",
    "Has not responded to {organizerName}'s invitation yet" : "{organizerName} の招待にまだ応答していません",
    "chairperson" : "主宰者",
    "required participant" : "参加必須",
    "non-participant" : "非参加",
    "optional participant" : "任意参加",
    "{organizer} (organizer)" : "{organizer} (organizer)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Availability of attendees, resources and rooms" : "出席者、リソース、ルームの空き状況",
    "Suggestion accepted" : "提案を受け入れた",
    "Out of office" : "オフィス外",
    "Attendees:" : "参加者:",
    "Done" : "完了",
    "Search room" : "ルームを検索する",
    "Room name" : "会議室名",
    "Check room availability" : "ルームの空き状況を確認する",
    "Free" : "空き",
    "Busy (tentative)" : "ビジー (暫定)",
    "Busy" : "ビジー",
    "Unknown" : "不明",
    "Find a time" : "時間を見つける",
    "The invitation has been accepted successfully." : "招待状は正常に受理されました。",
    "Failed to accept the invitation." : "招待を受け入れることに失敗しました。",
    "The invitation has been declined successfully." : "招待は正常に辞退されました。",
    "Failed to decline the invitation." : "招待の辞退に失敗しました。",
    "Your participation has been marked as tentative." : "あなたの参加は暫定的なものとマークされました。",
    "Failed to set the participation status to tentative." : "参加ステータスを暫定に設定することに失敗した。",
    "Accept" : "承諾",
    "Decline" : "拒否",
    "Tentative" : "暫定的",
    "No attendees yet" : "出席者はまだいません",
    "Attendees" : "参加者",
    "Remove group" : "グループを削除",
    "Remove attendee" : "出席者を削除",
    "Request reply" : "返信をリクエストする",
    "Chairperson" : "主宰者",
    "Required participant" : "参加必須",
    "Optional participant" : "任意参加",
    "Non-participant" : "非参加",
    "_%n member_::_%n members_" : ["%n メンバー"],
    "Search for emails, users, contacts, contact groups or teams" : "メール、ユーザー、連絡先、連絡先グループまたはチームを検索",
    "No match found" : "一致するものが見つかりません",
    "Note that members of circles get invited but are not synced yet." : "サークルのメンバーは招待さ れますが、まだ同期されていないことに注意してください。",
    "(organizer)" : "（主催者）",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "招待を送信して返信を受け取るには、[linkopen]個人設定にメールアドレスを追加[linkclose]してください。",
    "Remove color" : "色を削除",
    "Event title" : "イベントタイトル",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "繰り返しの一部であるイベントの終日設定は変更できません。",
    "From" : "開始",
    "To" : "終了",
    "Repeat" : "繰り返し",
    "Repeat event" : "繰り返しイベント",
    "_time_::_times_" : ["回数"],
    "never" : "なし",
    "on date" : "日時指定",
    "after" : "後",
    "End repeat" : "繰り返し終了",
    "Select to end repeat" : "繰り返しの終了を選択",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "このイベントは繰り返しセットの反復例外です。それに繰り返しルールを追加することはできません。",
    "first" : "初日",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "繰り返しルールの変更は、今回および今後のすべての開催にのみ適用されます。",
    "Repeat every" : "毎日繰り返す",
    "By day of the month" : "日付",
    "On the" : "On the",
    "_day_::_days_" : ["日"],
    "_week_::_weeks_" : ["週"],
    "_month_::_months_" : ["月"],
    "_year_::_years_" : ["年"],
    "weekday" : "平日",
    "weekend day" : "週末",
    "Does not repeat" : "繰り返さない",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "このイベントの繰り返し定義は、Nextcloudでは完全にサポートされていません。繰り返しオプションを編集すると、特定の繰り返しが失われる場合があります。",
    "No rooms or resources yet" : "ルームやリソースがありません",
    "Resources" : "リソース",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} 席"],
    "Add resource" : "リソースを追加する",
    "Has a projector" : "プロジェクタ設置",
    "Has a whiteboard" : "ホワイトボードがあります",
    "Wheelchair accessible" : "車イス対応",
    "Remove resource" : "リソースを削除する",
    "Search for resources or rooms" : "リソース、ルームを検索",
    "available" : "利用可能",
    "unavailable" : "利用不可",
    "Show all rooms" : "すべてのルームを表示",
    "Projector" : "プロジェクター",
    "Whiteboard" : "ホワイトボード",
    "Room type" : "ルーム種別",
    "Any" : "Any",
    "Minimum seating capacity" : "最低座席数",
    "More details" : "詳細情報",
    "Update this and all future" : "これ以降を更新",
    "Update this occurrence" : "この出来事を更新する",
    "Public calendar does not exist" : "公開カレンダーは存在しません",
    "Maybe the share was deleted or has expired?" : "共有が削除されたか、期限切れの可能性があります",
    "Yes" : "はい",
    "No" : "いいえ",
    "Maybe" : "たぶん",
    "None" : "なし",
    "Create" : "作成",
    "from {formattedDate}" : "{formattedDate}から",
    "to {formattedDate}" : "{formattedDate}まで",
    "on {formattedDate}" : "{formattedDate} にて",
    "from {formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime}から",
    "to {formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime}まで",
    "on {formattedDate} at {formattedTime}" : "{formattedDate} の {formattedTime} に",
    "{formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime}",
    "Please enter a valid date" : "有効な日付を入力してください",
    "Please enter a valid date and time" : "有効な日付と時刻を入力してください",
    "Select a time zone" : "タイムゾーンの選択",
    "Please select a time zone:" : "タイムゾーンを選択してください：",
    "Pick a time" : "時間を指定",
    "Pick a date" : "日付を指定",
    "Type to search time zone" : "入力してタイムゾーンを検索",
    "Global" : "グローバル",
    "Holidays in {region}" : "{region} の休日",
    "An error occurred, unable to read public calendars." : "エラーが発生しました、公開カレンダーを読み込むことができません。",
    "An error occurred, unable to subscribe to calendar." : "エラーが発生したため、カレンダーを登録できません。",
    "Public holiday calendars" : "祝祭日カレンダー",
    "Public calendars" : "公開カレンダー",
    "No valid public calendars configured" : "有効な公開カレンダーが設定されていない",
    "Speak to the server administrator to resolve this issue." : "この問題を解決するには、サーバー管理者にご相談ください。",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "公開祝祭日カレンダーは Thunderbird によって提供されています。カレンダーデータは {website} からダウンロードされます",
    "By {authors}" : "{author} 記載",
    "Subscribed" : "購読",
    "Subscribe" : "購読",
    "Could not fetch slots" : "スロットを取得できませんでした",
    "Select a date" : "日付を選択",
    "Select slot" : "時間枠を選択",
    "No slots available" : "利用可能な時間枠がありません",
    "The slot for your appointment has been confirmed" : "時間枠を予約しました",
    "Appointment Details:" : "予定の詳細：",
    "Time:" : "時刻:",
    "Booked for:" : "予約済み：",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "ありがとうございます。{startDate} から {endDate} までの予約が確定しました。",
    "Book another appointment:" : "別の予約をする：",
    "See all available slots" : "利用可能なすべての時間枠",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : " {startDate} から{endDate}までの時間枠は、利用できません。",
    "Please book a different slot:" : "別の時間枠を予約してください\\:",
    "Book an appointment with {name}" : "{name} の予約をする",
    "No public appointments found for {name}" : "{name} の公開アポイントメントは見つかりませんでした",
    "Personal" : "個人",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "自動的なタイムゾーンの検出により、あなたのタイムゾーンはUTCと判断されました。\nこれはおそらく、あなたのウェブブラウザのセキュリティ対策の結果です。\nカレンダーの設定でタイムゾーンを手動で設定してください。",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "設定されたタイムゾーン ({timezoneId}) が見つかりませんでした。UTCにフォールバックします。\n設定でタイムゾーンを変更して、この問題を報告してください。",
    "Discard event" : "イベントを破棄",
    "Edit event" : "イベントを編集",
    "Event does not exist" : "イベントは存在しません",
    "Duplicate" : "複製",
    "Delete this occurrence" : "この出来事を削除",
    "Delete this and all future" : "これ以降を削除する",
    "All day" : "終日",
    "Managing shared access" : "共有アクセスの管理",
    "Deny access" : "アクセスを拒否する",
    "Invite" : "招待状",
    "Discard changes?" : "変更を破棄しますか？",
    "_User requires access to your file_::_Users require access to your file_" : ["ファイルへのアクセスが必要なユーザ"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["添付ファイルには共有アクセスが必要です"],
    "Untitled event" : "無題のイベント",
    "Close" : "閉じる",
    "Selected" : "選択済み",
    "Title" : "タイトル",
    "30 min" : "30分",
    "Participants" : "参加者",
    "Submit" : "提出する",
    "Subscribe to {name}" : "{name} を購読する",
    "Export {name}" : "エクスポート {name}",
    "Anniversary" : "記念日",
    "Appointment" : "アポイントメント",
    "Business" : "ビジネス",
    "Education" : "学校",
    "Holiday" : "休日",
    "Meeting" : "会議",
    "Miscellaneous" : "雑用",
    "Non-working hours" : "休業時間",
    "Not in office" : "欠勤",
    "Phone call" : "電話",
    "Sick day" : "体調不良",
    "Special occasion" : "特別な用事",
    "Travel" : "旅行",
    "Vacation" : "休暇",
    "Midnight on the day the event starts" : "イベント開始日の午前0時",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n イベントまでの日数 {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n イベントまでの週数 {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "イベント当日 {formattedHourMinute} で開催されます",
    "at the event's start" : "イベント開始時",
    "at the event's end" : "イベント終了時",
    "{time} before the event starts" : "イベント開始 {time} 前",
    "{time} before the event ends" : "イベント終了 {time} 前",
    "{time} after the event starts" : "イベント開始 {time} 後",
    "{time} after the event ends" : "イベント終了 {time} 後",
    "on {time}" : "on {time}",
    "on {time} ({timezoneId})" : "on {time} ({timezoneId})",
    "Week {number} of {year}" : "{year}の{number} 週",
    "Daily" : "毎日",
    "Weekly" : "毎週",
    "Monthly" : "毎月",
    "Yearly" : "毎年",
    "_Every %n day_::_Every %n days_" : ["%n日ごと"],
    "_Every %n week_::_Every %n weeks_" : ["%n週ごと"],
    "_Every %n month_::_Every %n months_" : ["%n月ごと"],
    "_Every %n year_::_Every %n years_" : ["%n年ごと"],
    "_on {weekday}_::_on {weekdays}_" : ["on {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["on days {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "on the {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "in {monthNames} on the {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "{untilDate} まで",
    "_%n time_::_%n times_" : ["%n回"],
    "second" : "２週目",
    "third" : "3日目",
    "fourth" : "4日目",
    "fifth" : "5日目",
    "second to last" : "2日目から最終日",
    "last" : "最後",
    "Untitled task" : "タイトルなしタスク",
    "Please ask your administrator to enable the Tasks App." : "「タスク」アプリを有効化のために、管理者さんにお問い合わせください",
    "W" : "W",
    "%n more" : "%n more",
    "No events to display" : "表示するイベントはありません",
    "_+%n more_::_+%n more_" : ["+%n more"],
    "No events" : "イベントはありません",
    "Create a new event or change the visible time-range" : "新規イベントの作成、または表示時間帯の変更",
    "Failed to save event" : "イベントの保存に失敗しました",
    "It might have been deleted, or there was a typo in a link" : "削除されたか、リンクに誤りがある可能性があります",
    "It might have been deleted, or there was a typo in the link" : "削除されたか、リンクに誤りがある可能性があります",
    "Meeting room" : "会議室",
    "Lecture hall" : "講堂",
    "Seminar room" : "セミナー",
    "Other" : "その他",
    "When shared show" : "共有した場合",
    "When shared show full event" : "共有時にすべてのイベントを表示",
    "When shared show only busy" : "共有時に実行中のみを表示",
    "When shared hide this event" : "共有時にこのイベントを隠す",
    "Add a location" : "住所を追加",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "説明を追加\n\n- この会議の目的\n- 議題\n- 参加者が準備する必要があるもの",
    "Status" : "ステータス",
    "Confirmed" : "確認済み",
    "Canceled" : "キャンセル済み",
    "Confirmation about the overall status of the event." : "イベント全体の状況について確認。",
    "Show as" : "として表示",
    "Take this event into account when calculating free-busy information." : "フリー・ビジー情報を計算する際には、このイベントを考慮に入れてください。",
    "Categories" : "カテゴリ",
    "Categories help you to structure and organize your events." : "カテゴリはイベントを構造化し整理するのに役立ちます。",
    "Search or add categories" : "カテゴリを検索または追加",
    "Add this as a new category" : "これを新しいカテゴリーとして追加",
    "Custom color" : "カスタム色",
    "Special color of this event. Overrides the calendar-color." : "特別なイベントの色。カレンダーの色を上書きします。",
    "Error while sharing file" : "ファイルの共有中にエラーが発生しました",
    "Error while sharing file with user" : "ユーザーとのファイルの共有中にエラーが発生しました",
    "Attachment {fileName} already exists!" : "添付ファイル {fileName} は既に存在します！",
    "An error occurred during getting file information" : "ファイル情報の取得中にエラーが発生しました",
    "An error occurred, unable to delete the calendar." : "エラーが発生したため、カレンダーを削除できません。",
    "Imported {filename}" : "インポートされた {filename}",
    "This is an event reminder." : "これはイベントのリマインダーです。",
    "Appointment not found" : "予定が見つかりません",
    "User not found" : "ユーザーが見つかりません",
    "Hidden" : "非公開",
    "can edit" : "編集を許可",
    "Calendar name …" : "カレンダー名 …",
    "Default attachments location" : "添付ファイルのデフォルト位置",
    "Automatic ({detected})" : "自動 ({detected})",
    "Shortcut overview" : "概要",
    "CalDAV link copied to clipboard." : "CalDAVリンクがクリップボードにコピーされました",
    "CalDAV link could not be copied to clipboard." : "CalDAVリンクをクリップボードにコピーできませんでした",
    "Enable birthday calendar" : "誕生日カレンダーを有効にする",
    "Show tasks in calendar" : "カレンダーにタスクを表示",
    "Enable simplified editor" : "簡易エディターを有効にする",
    "Limit the number of events displayed in the monthly view" : "月間ビューに表示されるイベント数を制限する",
    "Show weekends" : "週末を表示する",
    "Show week numbers" : "週番号を表示する",
    "Time increments" : "時間の増加",
    "Default calendar for incoming invitations" : "受信した招待状のデフォルトカレンダー",
    "Copy primary CalDAV address" : "通常のCalDAVアドレスをコピー",
    "Copy iOS/macOS CalDAV address" : "iOS/macOS用のCalDAVアドレスをコピー",
    "Personal availability settings" : "個人の稼働率設定",
    "Show keyboard shortcuts" : "キーボード ショートカット",
    "Create a new public conversation" : "公開の会話を作成",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} 招待済み, {confirmedCount} 確定",
    "Successfully appended link to talk room to location." : "トークルームへのリンクをロケーションに追加しました。",
    "Successfully appended link to talk room to description." : "通話ルームへのリンクを説明文に追加しました",
    "Error creating Talk room" : "通話ルームの作成に失敗しました",
    "_%n more guest_::_%n more guests_" : ["ゲスト %n 名追加"],
    "The visibility of this event in shared calendars." : "共有カレンダーでのこのイベントの表示。"
},
"nplurals=1; plural=0;");
