OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Η παρεχόμενη διεύθυνση email είναι πολύ μεγάλη",
    "User-Session unexpectedly expired" : "Η συνεδρία-χρήστη έληξε απότομα",
    "Provided email-address is not valid" : "Η διεύθυνση email δεν είναι έγκυρη",
    "%s has published the calendar »%s«" : "Ο/η %s έχει δημοσιεύσει το ημερολόγιο »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Απροσδόκητο σφάλμα στην αποστολή email. Παρακαλώ επικοινωνήστε με τον διαχειριστή.",
    "Successfully sent email to %1$s" : "Επιτυχής αποστολή email %1$s",
    "Hello," : "Γεια σας,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Θα θέλαμε να σας πληροφορήσουμε ότι  ο χρήστης %s δημοσίευσε το ημερολόγιο »%s«.",
    "Open »%s«" : "Άνοιγμα »%s«",
    "Cheers!" : "Με εκτίμηση!",
    "Upcoming events" : "Προσεχή γεγονότα",
    "No more events today" : "Δεν υπάρχουν άλλα γεγονότα για σήμερα",
    "No upcoming events" : "Κανένα προσεχές γεγονός",
    "More events" : "Περισσότερα γεγονότα",
    "%1$s with %2$s" : "%1$s με %2$s",
    "Calendar" : "Ημερολόγιο",
    "New booking {booking}" : "Νέα κράτηση {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) έκλεισε το ραντεβού \"{config_display_name}\" στις {date_time}.",
    "Appointments" : "Ραντεβού",
    "Schedule appointment \"%s\"" : "Προγραμματίστε ραντεβού%s",
    "Schedule an appointment" : "Προγραμματίστε ένα ραντεβού",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : "Προετοιμασία για %s",
    "Follow up for %s" : "Επόμενο για %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Το ραντεβού σας \"%s\" με %s χρειάζεται επιβεβαίωση",
    "Dear %s, please confirm your booking" : "Αγαπητέ/ή %s, παρακαλώ επιβεβαιώστε την κράτησή σας",
    "Confirm" : "Επιβεβαιώνω",
    "Appointment with:" : "Ραντεβού με:",
    "Description:" : "Περιγραφή:",
    "This confirmation link expires in %s hours." : "Αυτός ο σύνδεσμος επιβεβαίωσης λήγει σε %s ώρες",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Εάν τελικά θέλετε να ακυρώσετε το ραντεβού, επικοινωνήστε με τον διοργανωτή απαντώντας σε αυτό το email ή μεταβαίνοντας στη σελίδα του προφίλ του.",
    "Your appointment \"%s\" with %s has been accepted" : "Το ραντεβού σας \"%s\" με %s χει γίνει αποδεκτό",
    "Dear %s, your booking has been accepted." : "Αγαπητέ/ή %s, η κράτησή σας έχει γίνει αποδεκτή.",
    "Appointment for:" : "Ραντεβού για:",
    "Date:" : "Ημερομηνία:",
    "You will receive a link with the confirmation email" : "Θα λάβετε έναν σύνδεσμο με το email επιβεβαίωσης",
    "Where:" : "Που:",
    "Comment:" : "Σχόλιο:",
    "You have a new appointment booking \"%s\" from %s" : "Έχετε μια νέα κράτηση για το ραντεβού \"%s\" από τον/την %s",
    "Dear %s, %s (%s) booked an appointment with you." : "Αγαπητέ/ή %s, %s (%s) έκανε κράτηση σε ένα ραντεβού σας.",
    "%s has proposed a meeting" : "Ο/Η %s πρότεινε μια συνάντηση",
    "%s has updated a proposed meeting" : "Ο/Η %s ενημέρωσε μια προτεινόμενη συνάντηση",
    "%s has canceled a proposed meeting" : "Ο/Η %s ακύρωσε μια προτεινόμενη συνάντηση",
    "Dear %s, a new meeting has been proposed" : "Αγαπητέ/ή %s, προτείνεται μια νέα συνάντηση",
    "Dear %s, a proposed meeting has been updated" : "Αγαπητέ/ή %s, μια προτεινόμενη συνάντηση ενημερώθηκε",
    "Dear %s, a proposed meeting has been cancelled" : "Αγαπητέ/ή %s, μια προτεινόμενη συνάντηση ακυρώθηκε",
    "Location:" : "Τοποθεσία:",
    "Duration:" : "Διάρκεια:",
    "%1$s from %2$s to %3$s" : "%1$s από %2$s έως %3$s",
    "Dates:" : "Ημερομηνίες:",
    "Respond" : "Απάντηση",
    "A Calendar app for Nextcloud" : "Eφαρμογή ημερολογίου για το Nextcloud",
    "A Calendar app for Nextcloud. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Like Contacts, Talk, Tasks, Deck and Circles\n* 🌐 **WebCal Support!** Want to see your favorite team's matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 **Search!** Find your events at ease\n* ☑️ **Tasks!** See tasks or Deck cards with a due date directly in the calendar\n* 🔈 **Talk rooms!** Create an associated Talk room when booking a meeting with just one click\n* 📆 **Appointment booking** Send people a link so they can book an appointment with you [using this app](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Attachments!** Add, upload and view event attachments\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Η εφαρμογή Ημερολόγιο για το Nextcloud. Συγχρονίστε εύκολα εκδηλώσεις από διάφορες συσκευές με το Nextcloud σας και επεξεργαστείτε τις online.\n\n* 🚀 **Ενσωμάτωση με άλλες εφαρμογές Nextcloud!** Όπως Επαφές, Συνομιλία, Εργασίες, Deck και Κύκλοι\n* 🌐 **Υποστήριξη WebCal!** Θέλετε να δείτε τις αγωνιστικές της αγαπημένης σας ομάδας στο ημερολόγιό σας; Κανένα πρόβλημα!\n* 🙋 **Συμμετέχοντες!** Προσκαλέστε άτομα στις εκδηλώσεις σας\n* ⌚ **Διαθέσιμος/Απασχολημένος!** Δείτε πότε οι συμμετέχοντες είναι διαθέσιμοι για συνάντηση\n* ⏰ **Υπενθυμίσεις!** Λάβετε ειδοποιήσεις για εκδηλώσεις στον browser σας και μέσω email\n* 🔍 **Αναζήτηση!** Βρείτε εύκολα τις εκδηλώσεις σας\n* ☑️ **Εργασίες!** Δείτε εργασίες ή κάρτες Deck με ημερομηνία λήξης απευθείας στο ημερολόγιο\n* 🔈 **Δωμάτια συνομιλίας!** Δημιουργήστε ένα σχετικό δωμάτιο συνομιλίας όταν κλείνετε μια συνάντηση με ένα μόνο κλικ\n* 📆 **Κλείσιμο ραντεβού** Στείλτε στους ανθρώπους έναν σύνδεσμο ώστε να μπορούν να κλείσουν ραντεβού μαζί σας [χρησιμοποιώντας αυτήν την εφαρμογή](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Συνημμένα!** Προσθέστε, ανεβάστε και δείτε τα συνημμένα των εκδηλώσεων\n* 🙈 **Δεν ανακαλύπτουμε τον τροχό!** Βασισμένο στις εξαιρετικές βιβλιοθήκες [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) και [fullcalendar](https://github.com/fullcalendar/fullcalendar).",
    "Previous day" : "Προηγούμενη ημέρα",
    "Previous week" : "Προηγούμενη εβδομάδα",
    "Previous year" : "Προηγούμενο έτος",
    "Previous month" : "Προηγούμενος μήνας",
    "Next day" : "Επόμενη ημέρα",
    "Next week" : "Επόμενη εβδομάδα",
    "Next year" : "Επόμενο έτος",
    "Next month" : "Επόμενος μήνας",
    "Create new event" : "Δημιουργία νέου συμβάντος",
    "Event" : "Συμβάν",
    "Today" : "Σήμερα",
    "Day" : "Ημέρα",
    "Week" : "Εβδομάδα",
    "Month" : "Μήνας",
    "Year" : "Έτος",
    "List" : "Λίστα",
    "Appointment link was copied to clipboard" : "Ο σύνδεσμος του ραντεβού αντιγράφηκε στο πρόχειρο.",
    "Appointment link could not be copied to clipboard" : "Δεν ήταν δυνατή η αντιγραφή του συνδέσμου ραντεβού στο πρόχειρο.",
    "Preview" : "Προεπισκόπηση",
    "Copy link" : "Αντιγραφή συνδέσμου",
    "Edit" : "Επεξεργασία",
    "Delete" : "Διαγραφή",
    "Appointment schedules" : "Πρόγραμμα ραντεβού",
    "Create new" : "Δημιουργία νέου",
    "Disable calendar \"{calendar}\"" : "Απενεργοποίηση ημερολογίου \"{calendar}\"",
    "Disable untitled calendar" : "Απενεργοποίηση ημερολογίου χωρίς τίτλο",
    "Enable calendar \"{calendar}\"" : "Ενεργοποίηση ημερολογίου \"{calendar}\"",
    "Enable untitled calendar" : "Ενεργοποίηση ημερολογίου χωρίς τίτλο",
    "An error occurred, unable to change visibility of the calendar." : "Παρουσιάστηκε σφάλμα, δεν δύναται να αλλάξει η εμφάνιση του ημερολογίου.",
    "Untitled calendar" : "Ημερολόγιο χωρίς τίτλο",
    "Shared with you by" : "Διαμοιρασμένα μαζί σας από",
    "Edit and share calendar" : "Επεξεργασία και κοινή χρήση ημερολογίου",
    "Edit calendar" : "Επεξεργασία ημερολογίου",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Αφαίρεση κοινής χρήσης ημερολογίου σε {countdown} δεύτερα","Αφαίρεση κοινής χρήσης ημερολογίου σε {countdown} δευτερόλεπτα"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Διαγραφή ημερολογίου σε {countdown} δεύτερα","Διαγραφή ημερολογίου σε {countdown} δευτερόλεπτα"],
    "An error occurred, unable to create the calendar." : "Παρουσιάστηκε σφάλμα, δεν μπορεί να δημιουργηθεί το ημερολόγιο.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Παρακαλώ εισάγετε έγκυρο σύνδεσμο (ξεκινούν με http://, https://, webcal://, ή webcals://)",
    "Calendars" : "Ημερολόγια",
    "Add new" : "Προσθήκη νέου",
    "New calendar" : "Νέο ημερολόγιο",
    "Name for new calendar" : "Όνομα για νέο ημερολόγιο.",
    "Creating calendar …" : "Δημιουργία ημερολογίου '...'",
    "New calendar with task list" : "Νέο ημερολόγιο με λίστα εργασιών",
    "New subscription from link (read-only)" : "Νέα συνδρομή από τον σύνδεσμο (μόνο για ανάγνωση)",
    "Creating subscription …" : "Δημιουργία συνδρομής ...",
    "Add public holiday calendar" : "Προσθήκη ημερολογίου αργιών",
    "Add custom public calendar" : "Προσθήκη προσαρμοσμένου δημόσιου ημερολογίου",
    "Calendar link copied to clipboard." : "Ο σύνδεσμος ημερολογίου αντιγράφηκε στο πρόχειρο.",
    "Calendar link could not be copied to clipboard." : "Ο σύνδεσμος ημερολογίου δεν μπορεί να αντιγραφή στο πρόχειρο.",
    "Copy subscription link" : "Αντιγραφή συνδέσμου συνδρομής",
    "Copying link …" : "Αντιγραφή συνδέσμου '...'",
    "Copied link" : "Αντιγραμμένος σύνδεσμος",
    "Could not copy link" : "Ο σύνδεσμος δεν μπορεί να αντιγραφεί",
    "Export" : "Εξαγωγή",
    "Untitled item" : "Στοιχείο χωρίς όνομα",
    "Unknown calendar" : "Άγνωστο ημερολόγιο",
    "Could not load deleted calendars and objects" : "Δεν ήταν δυνατή η φόρτωση διαγραμμένων ημερολογίων και αντικειμένων",
    "Could not delete calendar or event" : "Δεν ήταν δυνατή η διαγραφή ημερολογίου ή συμβάντος",
    "Could not restore calendar or event" : "Δεν ήταν δυνατή η επαναφορά ημερολογίου ή συμβάντος",
    "Do you really want to empty the trash bin?" : "Θέλετε να αδειάσετε τον κάδο απορριμμάτων;",
    "Empty trash bin" : "Άδειασμα κάδου",
    "Trash bin" : "Κάδος απορριμμάτων",
    "Loading deleted items." : "Φόρτωση διαγραμμένων στοιχείων.",
    "You do not have any deleted items." : "Δεν έχετε διαγραμμένα στοιχεία.",
    "Name" : "Όνομα",
    "Deleted" : "Διαγράφηκε",
    "Restore" : "Επαναφορά",
    "Delete permanently" : "Οριστική διαγραφή",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Τα στοιχεία στον κάδο απορριμμάτων διαγράφονται μετά από {numDays} ημέρα","Τα στοιχεία στον κάδο απορριμμάτων διαγράφονται μετά από {numDays} ημέρες"],
    "Could not update calendar order." : "Δεν μπορεί να γίνει ενημέρωση εντολών ημερολογίου.",
    "Shared calendars" : "Κοινόχρηστα ημερολόγια",
    "Deck" : "Deck",
    "Internal link" : "Εσωτερικός σύνδεσμος",
    "A private link that can be used with external clients" : "Ένας ιδιωτικός σύνδεσμος που μπορεί να χρησιμοποιηθεί με τρίτες εφαρμογές",
    "Copy internal link" : "Αντιγραφή εσωτερικού συνδέσμου",
    "An error occurred, unable to publish calendar." : "Παρουσιάστηκε σφάλμα, δεν θα δημοσιευτεί το ημερολόγιο.",
    "An error occurred, unable to send email." : "Παρουσιάστηκε σφάλμα, δεν θα σταλεί το email.",
    "Embed code copied to clipboard." : "Ο ενσωματωμένος κώδικας αντιγράφηκε στο πρόχειρο.",
    "Embed code could not be copied to clipboard." : "Ο ενσωματωμένος κώδικας δεν μπορεί να αντιγραφεί στο πρόχειρο.",
    "Unpublishing calendar failed" : "Η κατάργηση δημοσιευμένου ημερολογίου απέτυχε",
    "Share link" : "Διαμοιρασμός συνδέσμου",
    "Copy public link" : "Αντιγραφή δημόσιου συνδέσμου",
    "Send link to calendar via email" : "Αποστολή συνδέσμου στο ημερολόγιο μέσω email",
    "Enter one address" : "Εισαγωγή μίας διεύθυνσης",
    "Sending email …" : "Αποστολή email  '...'",
    "Copy embedding code" : "Αντιγραφή ενσωματωμένου κώδικα",
    "Copying code …" : "Αντιγραφή κώδικα '...'",
    "Copied code" : "Αντιγραμμένος κώδικας",
    "Could not copy code" : "Ο κώδικας δεν μπορεί να αντιγραφεί",
    "Delete share link" : "Διαγραφή κοινόχρηστου συνδέσμου",
    "Deleting share link …" : "Διαγραφή κοινόχρηστου συνδέσμου '...'",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Ομάδα)",
    "An error occurred while unsharing the calendar." : "Προέκυψε σφάλμα κατά την κατάργηση της κοινής χρήσης του ημερολογίου.",
    "An error occurred, unable to change the permission of the share." : "Παρουσιάστηκε σφάλμα, δεν ήταν δυνατή η αλλαγή των δικαιωμάτων της κοινής χρήσης.",
    "Unshare with {displayName}" : "Κατάργηση κοινής χρήσης με {displayName}",
    "Share with users or groups" : "Κοινή χρήση με χρήστες ή ομάδες",
    "No users or groups" : "Δεν υπάρχουν χρήστες ή ομάδες",
    "Failed to save calendar name and color" : "Απέτυχε η αποθήκευση του ονόματος και του χρώματος του ημερολογίου",
    "Never show me as busy (set this calendar to transparent)" : "Να μην εμφανίζομαι ποτέ ως απασχολημένος/η (ορισμός ημερολογίου ως διαφανές)",
    "Share calendar" : "Κοινή χρήση ημερολογίου",
    "Unshare from me" : "Διακοπή διαμοιρασμού με εμένα",
    "Save" : "Αποθήκευση",
    "No title" : "Χωρίς τίτλο",
    "Are you sure you want to delete \"{title}\"?" : "Είστε σίγουρος/η ότι θέλετε να διαγράψετε το \"{title}\";",
    "Deleting proposal \"{title}\"" : "Διαγραφή πρότασης \"{title}\"",
    "Successfully deleted proposal" : "Η πρόταση διαγράφηκε επιτυχώς",
    "Failed to delete proposal" : "Αποτυχία διαγραφής πρότασης",
    "Failed to retrieve proposals" : "Αποτυχία ανάκτησης προτάσεων",
    "Meeting proposals" : "Προτάσεις συναντήσεων",
    "A configured email address is required to use meeting proposals" : "Απαιτείται ρυθμισμένη διεύθυνση email για τη χρήση προτάσεων συναντήσεων",
    "No active meeting proposals" : "Δεν υπάρχουν ενεργές προτάσεις συναντήσεων",
    "View" : "Προβολή",
    "Import calendars" : "Εισαγωγή ημερολογίων",
    "Please select a calendar to import into …" : "Παρακαλώ επιλέξτε ημερολόγιο για εισαγωγή σε  ...",
    "Filename" : "Όνομα αρχείου",
    "Calendar to import into" : " Ημερολόγιο για εισαγωγή σε ",
    "Cancel" : "Ακύρωση",
    "_Import calendar_::_Import calendars_" : ["Εισαγωγή ημερολογίου","Εισαγωγή ημερολογίων"],
    "Select the default location for attachments" : "Επιλέξτε την προεπιλεγμένη θέση για τα συνημμένα",
    "Pick" : "Επιλογή",
    "Invalid location selected" : "Επιλέχθηκε μη έγκυρη τοποθεσία",
    "Attachments folder successfully saved." : "Ο φάκελος συνημμένων αποθηκεύτηκε με επιτυχία.",
    "Error on saving attachments folder." : "Σφάλμα κατά την αποθήκευση του φακέλου συνημμένων.",
    "Attachments folder" : "Φάκελος συνημμένων",
    "{filename} could not be parsed" : "το {filename} δεν μπορεί να αναλυθεί",
    "No valid files found, aborting import" : "Δεν βρέθηκαν συμβατά αρχεία, ακύρωση εισαγωγής",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Επιτυχής εισαγωγή %n συμβάν","Επιτυχής εισαγωγή %n συμβάντων"],
    "Import partially failed. Imported {accepted} out of {total}." : "Η εισαγωγή απέτυχε εν μέρει. Εισήχθησαν {accepted} από {total}.",
    "Automatic" : "Αυτόματο",
    "Automatic ({timezone})" : "Αυτόματη ({ζώνη ώρας})",
    "New setting was not saved successfully." : "Οι νέες ρυθμίσεις δεν αποθηκεύτηκαν επιτυχώς.",
    "Timezone" : "Ζώνη ώρας",
    "Navigation" : "Πλοήγηση",
    "Previous period" : "Προηγούμενη περίοδος",
    "Next period" : "Επόμενη περίοδος",
    "Views" : "Προβολές",
    "Day view" : "Εμφάνιση ημέρας",
    "Week view" : "Εμφάνιση εβδομάδας",
    "Month view" : "Εμφάνιση μήνα",
    "Year view" : "Ετήσια προβολή",
    "List view" : "Προβολή λίστας",
    "Actions" : "Ενέργειες",
    "Create event" : "Δημιουργία συμβάντος",
    "Show shortcuts" : "Εμφάνιση συντομεύσεων",
    "Editor" : "Επεξεργαστής",
    "Close editor" : "Κλείσιμο του επεξεργαστή",
    "Save edited event" : "Αποθήκευση επεξεργασμένης εκδήλωσης",
    "Delete edited event" : "Διαγραφή επεξεργασμένης εκδήλωσης",
    "Duplicate event" : "Αντιγραφή εκδήλωσης",
    "or" : "ή",
    "Calendar settings" : "Ρυθμίσεις ημερολογίου",
    "At event start" : "Κατά την έναρξη του συμβάντος",
    "No reminder" : "Χωρίς υπενθύμιση",
    "Failed to save default calendar" : "Αποτυχία αποθήκευσης προεπιλεγμένου ημερολογίου",
    "General" : "Γενικά",
    "Appearance" : "Εμφάνιση",
    "Editing" : "Επεξεργασία",
    "Default reminder" : "Προεπιλεγμένη υπενθύμιση",
    "Files" : "Αρχεία",
    "Appointment schedule successfully created" : "Το πρόγραμμα ραντεβού δημιουργήθηκε επιτυχώς",
    "Appointment schedule successfully updated" : "Το πρόγραμμα ραντεβού ενημερώθηκε επιτυχώς",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} λεπτό","{duration} λεπτά"],
    "0 minutes" : "0  λεπτά",
    "_{duration} hour_::_{duration} hours_" : ["{duration} ώρα","{duration} ώρες"],
    "_{duration} day_::_{duration} days_" : ["{duration} ημέρα","{duration} ημέρες"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} εβδομάδα","{duration} εβδομάδες"],
    "_{duration} month_::_{duration} months_" : ["{duration} μήνα","{duration} μήνες"],
    "_{duration} year_::_{duration} years_" : ["{duration} χρόνο","{duration} χρόνια"],
    "To configure appointments, add your email address in personal settings." : "Για να ρυθμίσετε τα ραντεβού σας, προσθέστε την διεύθυνση email στις προσωπικές ρυθμίσεις",
    "Public – shown on the profile page" : "Δημόσιο - εμφανίζεται στο προφίλ",
    "Private – only accessible via secret link" : "Ιδιωτικό - προσβάσιμο μόνο μέσω κρυφού συνδέσμου",
    "Appointment schedule saved" : "Το πρόγραμμα ραντεβού αποθηκεύτηκε",
    "Create appointment schedule" : "Δημιουργία προγράμματος ραντεβού",
    "Edit appointment schedule" : "Επεξεργασία προγράμματος ραντεβού",
    "Update" : "Ενημέρωση",
    "Appointment name" : "Όνομα ραντεβού",
    "Location" : "Τοποθεσία",
    "Create a Talk room" : "Δημιουργία δωματίου Talk",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Ένας μοναδικός σύνδεσμος θα δημιουργηθεί για κάθε κλεισμένο ραντεβού και θα αποσταλεί μέσω του email επιβεβαίωσης.",
    "Description" : "Περιγραφή",
    "Visibility" : "Ορατότητα",
    "Duration" : "Διάρκεια",
    "Increments" : "Χρόνος μεταξύ δυο ραντεβού",
    "Additional calendars to check for conflicts" : "Επιπρόσθετα ημερολόγια για τον έλεγχο κωλυμάτων",
    "Pick time ranges where appointments are allowed" : "Επιλέξτε το χρονικό περιθώριο οπου επιτρέπονται τα ραντεβού",
    "to" : "προς",
    "Delete slot" : "Διαγραφή θέσης",
    "No times set" : "Δεν υπάρχουν χρόνοι",
    "Add" : "Προσθήκη",
    "Monday" : "Δευτέρα",
    "Tuesday" : "Τρίτη",
    "Wednesday" : "Τετάρτη",
    "Thursday" : "Πέμπτη",
    "Friday" : "Παρασκευή",
    "Saturday" : "Σάββατο",
    "Sunday" : "Κυριακή",
    "Weekdays" : "Καθημερινές",
    "Add time before and after the event" : "Προσθέστε χρόνο πριν και μετά από το γεγονός",
    "Before the event" : "Πριν το γεγονός",
    "After the event" : "Μετά το γεγονός",
    "Planning restrictions" : "Περιορισμοί σχεδιασμού",
    "Minimum time before next available slot" : "Ελάχιστος χρόνος πριν το επόμενο διαθέσιμο κενό",
    "Max slots per day" : "Μέγιστες θέσεις ανά ημέρα",
    "Limit how far in the future appointments can be booked" : "Περιορίστε πόσο μακριά μπορούν να κανονιστούν μελλοντικά ραντεβού",
    "It seems a rate limit has been reached. Please try again later." : "Φαίνεται ότι έχετε φτάσει το όριο ταχύτητας. Παρακαλώ δοκιμάστε ξανά αργότερα.",
    "Please confirm your reservation" : "Επιβεβαιώστε την κράτησή σας",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Σας στείλαμε ενα email με τις λεπτομέρειες. Παρακαλούμε να επιβεβαιώσετε το ραντεβού κάνοντας χρήση του συνδέσμου στο email. Μπορείτε να κλείσετε αυτή την σελίδα ",
    "Your name" : "Το όνομά σας",
    "Your email address" : "Η διεύθυνση ηλεκτρονικού ταχυδρομείου σας",
    "Please share anything that will help prepare for our meeting" : "Παρακαλούμε να μοιραστείτε οτιδήποτε θα βοηθούσε στην προετοιμασία της συνάντησης",
    "Could not book the appointment. Please try again later or contact the organizer." : "Δεν μπορέσαμε να κανουμε την κράτηση του ραντεβού. Παρακαλώ δοκιμάστε ξανά αργότερα ή επικοινωνήστε με τον διοργανωτή",
    "Back" : "Επιστροφή",
    "Book appointment" : "Κλείστε ραντεβού",
    "Error fetching Talk conversations." : "Σφάλμα ανάκτησης συνομιλιών Talk.",
    "Conversation does not have a valid URL." : "Η συνομιλία δεν έχει έγκυρη διεύθυνση URL.",
    "Successfully added Talk conversation link to location." : "Ο σύνδεσμος συνομιλίας Talk προστέθηκε επιτυχώς στην τοποθεσία.",
    "Successfully added Talk conversation link to description." : "Ο σύνδεσμος συνομιλίας Talk προστέθηκε επιτυχώς στην περιγραφή.",
    "Failed to apply Talk room." : "Αποτυχία εφαρμογής δωματίου Talk.",
    "Talk conversation for event" : "Συνομιλία Talk για συμβάν",
    "Error creating Talk conversation" : "Σφάλμα δημιουργίας συνομιλίας Talk",
    "Select a Talk Room" : "Επιλογή δωματίου Talk",
    "Add Talk conversation" : "Προσθήκη συνομιλίας Talk",
    "Fetching Talk rooms…" : "Ανάκτηση δωματίων Talk…",
    "No Talk room available" : "Δεν υπάρχει διαθέσιμο δωμάτιο Talk",
    "Select conversation" : "Επιλέξτε συνομιλία",
    "on" : "σε",
    "at" : "στις",
    "before at" : "πριν από το",
    "Notification" : "Ειδοποίηση",
    "Email" : "Ηλ. ταχυδρομείο",
    "Audio notification" : "Ηχητική ειδοποίηση",
    "Other notification" : "Άλλη ειδοποίηση",
    "Relative to event" : "Σχετικά με το συμβάν",
    "On date" : "Την ημερομηνία",
    "Edit time" : "Επεξεργασία ώρας",
    "Save time" : "Εξοικονόμηση χρόνου",
    "Remove reminder" : "Διαγραφή υπενθύμισης",
    "Add reminder" : "Προσθήκη υπενθύμισης",
    "seconds" : "δευτερόλεπτα",
    "minutes" : "λεπτά",
    "hours" : "ώρες",
    "days" : "ημέρες",
    "weeks" : "εβδομάδες",
    "Choose a file to add as attachment" : "Επιλέξτε ένα αρχείο για να προσθέσετε ως συνημμένο",
    "Choose a file to share as a link" : "Επιλέξτε ένα αρχείο για κοινή χρήση ως σύνδεσμο",
    "Attachment {name} already exist!" : "Το συνημμένο {name} υπάρχει ήδη",
    "Could not upload attachment(s)" : "Δεν ήταν δυνατή η μεταφόρτωση συνημμένου(-ων)",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Πρόκειται να μεταβείτε στο {host}. Είστε σίγουρος/η ότι θέλετε να συνεχίσετε; Σύνδεσμος: {link}",
    "Proceed" : "Συνέχεια",
    "No attachments" : "Χωρίς συνημμένα",
    "Add from Files" : "Προσθήκη από τα Αρχεία",
    "Upload from device" : "Μεταφόρτωση από συσκευή",
    "Delete file" : "Διαγραφή αρχείου",
    "Confirmation" : "Επιβεβαίωση",
    "_{count} attachment_::_{count} attachments_" : ["{count} συνημμένo","{count} συνημμένα"],
    "Suggested" : "Προτεινόμενο",
    "Available" : "Διαθέσιμα",
    "Invitation accepted" : "Η πρόσκληση έγινε αποδεκτή.",
    "Accepted {organizerName}'s invitation" : "Αποδοχή της πρόσκλησης του/της {organizerName}",
    "Participation marked as tentative" : "Η συμμετοχή χαρακτηρίστηκε ως με επιφύλαξη",
    "Invitation is delegated" : "Η πρόσκληση παραπέμφθηκε",
    "Not available" : "Δεν είναι διαθέσιμο",
    "Invitation declined" : "Η πρόσκληση απορρίφθηκε.",
    "Declined {organizerName}'s invitation" : "Απόρριψη της πρόσκλησης του {organizerName}",
    "Availability will be checked" : "Θα ελεγχθεί η διαθεσιμότητα",
    "Invitation will be sent" : "Η πρόσκληση θα αποσταλεί",
    "Failed to check availability" : "Αποτυχία ελέγχου διαθεσιμότητας",
    "Failed to deliver invitation" : "Αποτυχία αποστολής πρόσκλησης",
    "Awaiting response" : "Αναμονή απάντησης",
    "Checking availability" : "Έλεγχος διαθεσιμότητας",
    "Has not responded to {organizerName}'s invitation yet" : "Δεν έχετε απαντήσει ακόμα στην πρόσκληση του/της {organizerName}",
    "Suggested times" : "Προτεινόμενες ώρες",
    "chairperson" : "πρόεδρος",
    "required participant" : "απαιτούμενος συμμετέχων",
    "non-participant" : "μη συμμετέχων",
    "optional participant" : "προαιρετικός συμμετέχων",
    "{organizer} (organizer)" : "{organizer} (διοργανωτής)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Availability of attendees, resources and rooms" : "Διαθεσιμότητα των συμμετεχόντων, των πόρων και των δωματίων",
    "Suggestion accepted" : "Η πρόταση έγινε αποδεκτή",
    "Previous date" : "Προηγούμενη ημερομηνία",
    "Next date" : "Επόμενη ημερομηνία",
    "Legend" : "Υπόμνημα",
    "Out of office" : "Εκτός γραφείου",
    "Attendees:" : "Συμμετέχοντες:",
    "local time" : "τοπική ώρα",
    "Done" : "Ολοκληρώθηκε",
    "Search room" : "Αναζήτηση δωματίου",
    "Room name" : "Όνομα δωματίου",
    "Check room availability" : "Ελέγξτε τη διαθεσιμότητα δωματίου",
    "Free" : "Ελεύθερος",
    "Busy (tentative)" : "Απασχολημένος (με επιφύλαξη)",
    "Busy" : "Απασχολημένος",
    "Unknown" : "Άγνωστο",
    "Find a time" : "Εύρεση ώρας",
    "The invitation has been accepted successfully." : "Η πρόσκληση έγινε αποδεκτή",
    "Failed to accept the invitation." : "Αποτυχία αποδοχής της πρόσκλησης",
    "The invitation has been declined successfully." : "Η πρόσκληση έχει απορριφθεί επιτυχώς",
    "Failed to decline the invitation." : "Αποτυχία απόρριψης της πρόσκλησης",
    "Your participation has been marked as tentative." : "Η συμμετοχή έχει χαρακτηρίστεί ως δοκιμαστική",
    "Failed to set the participation status to tentative." : "Αποτυχία αλλαγής κατάστασης συμμετοχής σε δοκιμαστική.",
    "Accept" : "Αποδοχή",
    "Decline" : "Απόρριψη",
    "Tentative" : "Με επιφύλαξη",
    "No attendees yet" : "Δεν υπάρχουν ακόμη συμμετέχοντες",
    "Please add at least one attendee to use the \"Find a time\" feature." : "Παρακαλούμε προσθέστε τουλάχιστον έναν συμμετέχοντα για να χρησιμοποιήσετε τη λειτουργία \"Εύρεση ώρας\".",
    "Attendees" : "Συμμετέχοντες",
    "Remove group" : "Αφαίρεση ομάδας",
    "Remove attendee" : "Κατάργηση του συμμετέχοντα",
    "Request reply" : "Αίτημα απάντησης",
    "Chairperson" : "Επικεφαλής",
    "Required participant" : "Απαιτείται συμμετοχή",
    "Optional participant" : "Προαιρετική συμμετοχή",
    "Non-participant" : "Μη-συμμετέχοντας",
    "_%n member_::_%n members_" : ["%n μέλος","%n μέλη"],
    "Search for emails, users, contacts, contact groups or teams" : "Αναζήτηση emails, χρηστών, επαφών, ομάδων επαφών ή ομάδων",
    "No match found" : "Δεν βρέθηκε αποτέλεσμα",
    "Note that members of circles get invited but are not synced yet." : "Σημειώστε ότι τα μέλη των κύκλων προσκαλούνται αλλά δεν έχουν συγχρονιστεί ακόμα.",
    "Note that members of contact groups get invited but are not synced yet." : "Σημειώστε ότι τα μέλη των ομάδων επαφών προσκέονται αλλά δεν συγχρονίζονται ακόμα.",
    "(organizer)" : "(διοργανωτής)",
    "Make {label} the organizer" : "Ορισμός {label} ως διοργανωτή",
    "Make {label} the organizer and attend" : "Ορισμός {label} ως διοργανωτή και συμμετέχοντα",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Για να στείλετε προσκλήσεις και να χειριστείτε τις απαντήσεις, [linkopen]προσθέστε το email σας στις προσωπικές ρυθμίσεις [linkclose].",
    "Remove color" : "Αφαίρεση χρώματος",
    "Event title" : "Τίτλος γεγονότος",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Δεν είναι δυνατή η τροποποίηση της ρύθμισης ολοήμερου συμβάντος που αποτελεί μέρος σετ-επανάληψης.",
    "From" : "Από",
    "To" : "Έως",
    "Repeat" : "Επανάληψη",
    "Repeat event" : "Επανάληψη συμβάντος",
    "_time_::_times_" : ["φορά","φορές"],
    "never" : "ποτέ",
    "on date" : "την ημερομηνία",
    "after" : "μετά",
    "End repeat" : "Τέλος επανάληψης",
    "Select to end repeat" : "Επιλέξτε για διακοπή επανάληψης",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Αυτό το συμβάν είναι επανάληψη-εξαίρεση ενός σετ-επανάληψης. Δεν μπορείτε να προσθέσετε κανόνα επανάληψης σε αυτό.",
    "first" : "πρώτο",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Οι αλλαγές στον κανόνα-επανάληψης θα ισχύουν μόνο για αυτό και για όλα τα μελλοντικά συμβάντα.",
    "Repeat every" : "Επανάληψη κάθε",
    "By day of the month" : "Την ημέρα του μήνα",
    "On the" : "Στο",
    "_day_::_days_" : ["ημέρα","ημέρες"],
    "_week_::_weeks_" : ["εβδομάδα","εβδομάδες"],
    "_month_::_months_" : ["μήνας","μήνες"],
    "_year_::_years_" : ["έτος","έτη"],
    "On specific day" : "Σε συγκεκριμένη ημέρα",
    "weekday" : "καθημερινή",
    "weekend day" : "ημέρα Σαββατοκύριακου",
    "Does not repeat" : "Δεν επαναλαμβάνεται",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Ο τρόπος επανάληψης αυτού του συμβάντος δεν υποστηρίζεται πλήρως από το Nextcloud. Αν επεξεργαστείτε τις επιλογές επανάληψης, ορισμένες επαναλήψεις ενδέχεται να χαθούν.",
    "No rooms or resources yet" : "Κανένα δωμάτιο ή πόροι ακόμα",
    "Resources" : "Πηγές",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} θέση","{seatingCapacity} θέσεις"],
    "Add resource" : "Προσθήκη πηγής",
    "Has a projector" : "Έχει προβολέα",
    "Has a whiteboard" : "Έχει λευκό πίνακα γραφής",
    "Wheelchair accessible" : "Προσβάσιμο με αναπηρικό καρότσι",
    "Remove resource" : "Αφαίρεση πόρου",
    "Search for resources or rooms" : "Αναζήτηση για πόρους ή δωμάτια",
    "available" : "διαθέσιμο",
    "unavailable" : "μη διαθέσιμο",
    "Show all rooms" : "Εμφάνιση όλων των δωματίων",
    "Projector" : "Projector",
    "Whiteboard" : "Λευκός πίνακας",
    "Room type" : "Τύπος δωματίου",
    "Any" : "Οποιοδήποτε",
    "Minimum seating capacity" : "Ελάχιστος αριθμός θέσεων",
    "More details" : "Λεπτομέρειες",
    "Update this and all future" : "Ενημερώστε αυτό και όλα τα μελλοντικά",
    "Update this occurrence" : "Ενημερώστε αυτό το περιστατικό",
    "Public calendar does not exist" : "Το δημόσιο ημερολόγιο δεν υπάρχει",
    "Maybe the share was deleted or has expired?" : "Ίσως το κοινόχρηστο διαγράφηκε ή δεν υπάρχει;",
    "Remove date" : "Αφαίρεση ημερομηνίας",
    "Attendance required" : "Υποχρεωτική παρουσία",
    "Attendance optional" : "Προαιρετική παρουσία",
    "Remove participant" : "Αφαίρεση συμμετέχοντα",
    "Yes" : "Ναι",
    "No" : "Όχι",
    "Maybe" : "Ίσως",
    "None" : "Καμία",
    "Select your meeting availability" : "Επιλέξτε τη διαθεσιμότητά σας για τη συνάντηση",
    "Create a meeting for this date and time" : "Δημιουργία συνάντησης για αυτήν την ημερομηνία και ώρα",
    "Create" : "Δημιουργία",
    "No participants or dates available" : "Δεν υπάρχουν διαθέσιμοι συμμετέχοντες ή ημερομηνίες",
    "from {formattedDate}" : "από {formattedDate}",
    "to {formattedDate}" : "έως {formattedDate}",
    "on {formattedDate}" : "σε {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "από {formattedDate} στις {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "έως {formattedDate} στις {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "σε {formattedDate} στις {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} στις {formattedTime}",
    "Please enter a valid date" : "Παρακαλώ εισάγετε έγκυρη ημερομηνία",
    "Please enter a valid date and time" : "Παρακαλώ εισάγετε έγκυρη ημερομηνία και ώρα",
    "Select a time zone" : "Επιλέξτε μια ζώνη ώρας",
    "Please select a time zone:" : "Παρακαλούμε επιλέξτε χρονική ζώνη:",
    "Pick a time" : "Επιλογή ώρας",
    "Pick a date" : "Επιλογή ημερομηνίας",
    "Type to search time zone" : "Πληκτρολογήστε για αναζήτηση χρονικής ζώνης",
    "Global" : "Καθολικό",
    "Holidays in {region}" : "Αργίες σε {region}",
    "An error occurred, unable to read public calendars." : "Παρουσιάστηκε ένα σφάλμα, αδυναμία ανάγνωσης δημόσιων ημερολογίων.",
    "An error occurred, unable to subscribe to calendar." : "Παρουσιάστηκε ένα σφάλμα, αδυναμία εγγραφής στο ημερολόγιο.",
    "Public holiday calendars" : "Ημερολόγια δημόσιων αργιών",
    "Public calendars" : "Δημόσια ημερολόγια",
    "No valid public calendars configured" : "Δεν έχουν διαμορφωθεί έγκυρα δημόσια ημερολόγια",
    "Speak to the server administrator to resolve this issue." : "Μιλήστε με τον διαχειριστή του διακομιστή για να επιλυθεί αυτό το πρόβλημα.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Τα ημερολόγια δημόσιων αργιών παρέχονται από το Thunderbird. Τα δεδομένα του ημερολογίου θα ληφθούν από το {website}",
    "These public calendars are suggested by the server administrator. Calendar data will be downloaded from the respective website." : "Αυτά τα δημόσια ημερολόγια προτείνονται από τον διαχειριστή του διακομιστή. Τα δεδομένα των ημερολογίων θα κατέβουν από τον αντίστοιχο ιστότοπο.",
    "By {authors}" : "Από {authors}",
    "Subscribed" : "Εγγεγραμμένο",
    "Subscribe" : "Εγγραφή",
    "Could not fetch slots" : "Αδυναμία ανάκτησης χρονικών θυρών",
    "Select a date" : "Επιλέξτε μια ημερομηνία",
    "Select slot" : "Επιλογή θέσης",
    "No slots available" : "Καμμια διαθέσιμη θέση",
    "The slot for your appointment has been confirmed" : "H θέση σας για το ραντεβού σας έχει επιβεβαιωθεί",
    "Appointment Details:" : "Λεπτομέρειες Ραντεβού",
    "Time:" : "Ώρα:",
    "Booked for:" : "Κρατηση για",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Ευχαριστούμε. Η κράτησή σας απο {startDate} εώς {endDate} έχει επιβεβαιωθεί.",
    "Book another appointment:" : "Κλείστε ένα άλλο ραντεβού:",
    "See all available slots" : "Δείτε όλες τις διαθέσιμες θέσεις",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Το κενό για το ραντεβού σας απο {startDate} to {endDate} δεν είναι διαθέσιμο πιά.",
    "Please book a different slot:" : "Παρακαλώ καντε κράτηση σε διαφορετικό κενό:",
    "Book an appointment with {name}" : "Κάντε κράτηση για ραντεβού με τον/την {name}",
    "No public appointments found for {name}" : "Δεν βρέθηκαν ραντεβού για τον/την {name}",
    "Personal" : "Προσωπικά",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Η αυτόματη επιλογή χρονικής ζώνης καθορίστηκε σε UTC.\nΑυτό συμβαίνει συνήθως λόγω ρυθμίσεων ασφαλείας του περιηγητή σας.\nΠαρακαλούμε επιλέξτε τη χρονική ζώνη χειροκίνητα από τις ρυθμίσεις ημερολογίου.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Η χρονική ζώνη ({timezoneId}) που καθορίσατε δεν βρέθηκε. Επαναφορά σε UTC.\nΠαρακαλούμε αλλάξτε τη χρονική ζώνη σας από τις ρυθμίσεις και αναφέρετε το σφάλμα.",
    "Show unscheduled tasks" : "Εμφάνιση μη προγραμματισμένων εργασιών",
    "Unscheduled tasks" : "Μη προγραμματισμένες εργασίες",
    "Availability of {displayName}" : "Διαθεσιμότητα του/της {displayName}",
    "Discard event" : "Απόρριψη συμβάντος",
    "Edit event" : "Επεξεργασία συμβάντος",
    "Event does not exist" : "Δεν υπάρχει το γεγονός",
    "Duplicate" : "Διπλότυπο",
    "Delete this occurrence" : "Διαγράψτε το περιστατικό",
    "Delete this and all future" : "Διαγράψτε αυτό και όλα τα μελλοντικά",
    "All day" : "Ολοήμερο",
    "Modifications wont get propagated to the organizer and other attendees" : "Οι τροποποιήσεις δεν θα διαδοθούν στον διοργανωτή και τους άλλους συμμετέχοντες",
    "Managing shared access" : "Διαχείριση κοινής πρόσβασης",
    "Deny access" : "Άρνηση πρόσβασης",
    "Invite" : "Πρόσκληση",
    "Discard changes?" : "Απόρριψη αλλαγών;",
    "Are you sure you want to discard the changes made to this event?" : "Είστε σίγουρος/η ότι θέλετε να απορρίψετε τις αλλαγές που έγιναν σε αυτό το συμβάν;",
    "_User requires access to your file_::_Users require access to your file_" : ["Ο χρήστης απαιτεί πρόσβαση στο αρχείο σας","Οι χρήστες χρειάζονται πρόσβαση στο αρχείο σας"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Συνημμένο που απαιτεί κοινόχρηστη πρόσβαση","Συνημμένα που απαιτούν κοινόχρηστη πρόσβαση"],
    "Untitled event" : "Συμβάν χωρίς τίτλο",
    "Close" : "Κλείσιμο",
    "Modifications will not get propagated to the organizer and other attendees" : "Οι τροποποιήσεις δεν θα διαδοθούν στον διοργανωτή και τους άλλους συμμετέχοντες",
    "Meeting proposals overview" : "Επισκόπηση προτάσεων συναντήσεων",
    "Edit meeting proposal" : "Επεξεργασία πρότασης συνάντησης",
    "Create meeting proposal" : "Δημιουργία πρότασης συνάντησης",
    "Update meeting proposal" : "Ενημέρωση πρότασης συνάντησης",
    "Saving proposal \"{title}\"" : "Αποθήκευση πρότασης \"{title}\"",
    "Successfully saved proposal" : "Η πρόταση αποθηκεύτηκε επιτυχώς",
    "Failed to save proposal" : "Αποτυχία αποθήκευσης πρότασης",
    "Create a meeting for \"{date}\"? This will create a calendar event with all participants." : "Δημιουργία συνάντησης για \"{date}\"; Αυτό θα δημιουργήσει ένα συμβάν ημερολογίου με όλους τους συμμετέχοντες.",
    "Creating meeting for {date}" : "Δημιουργία συνάντησης για {date}",
    "Successfully created meeting for {date}" : "Η συνάντηση για {date} δημιουργήθηκε επιτυχώς",
    "Failed to create a meeting for {date}" : "Αποτυχία δημιουργίας συνάντησης για {date}",
    "Please enter a valid duration in minutes." : "Παρακαλώ εισάγετε μια έγκυρη διάρκεια σε λεπτά.",
    "Failed to fetch proposals" : "Αποτυχία ανάκτησης προτάσεων",
    "Failed to fetch free/busy data" : "Αποτυχία ανάκτησης δεδομένων ελεύθερου/απασχολημένου χρόνου",
    "Selected" : "Επιλεγμένο",
    "No Description" : "Χωρίς περιγραφή",
    "No Location" : "Χωρίς τοποθεσία",
    "Edit this meeting proposal" : "Επεξεργασία αυτής της πρότασης συνάντησης",
    "Delete this meeting proposal" : "Διαγραφή αυτής της πρότασης συνάντησης",
    "Title" : "Τίτλος",
    "15 min" : "15 λεπτά",
    "30 min" : "30 λεπτά",
    "60 min" : "60 λεπτά",
    "90 min" : "90 λεπτά",
    "Participants" : "Συμμετέχοντες",
    "Selected times" : "Επιλεγμένες ώρες",
    "Previous span" : "Προηγούμενο διάστημα",
    "Next span" : "Επόμενο διάστημα",
    "Less days" : "Λιγότερες ημέρες",
    "More days" : "Περισσότερες ημέρες",
    "Loading meeting proposal" : "Φόρτωση πρότασης συνάντησης",
    "No meeting proposal found" : "Δεν βρέθηκε πρόταση συνάντησης",
    "Please wait while we load the meeting proposal." : "Παρακαλώ περιμένετε ενώ φορτώνουμε την πρόταση συνάντησης.",
    "The link you followed may be broken, or the meeting proposal may no longer exist." : "Ο σύνδεσμος που ακολουθήσατε μπορεί να είναι σπασμένος ή η πρόταση συνάντησης μπορεί να μην υπάρχει πλέον.",
    "Thank you for your response!" : "Σας ευχαριστούμε για την απάντησή σας!",
    "Your vote has been recorded. Thank you for participating!" : "Η ψήφος σας καταγράφηκε. Σας ευχαριστούμε για τη συμμετοχή!",
    "Unknown User" : "Άγνωστος Χρήστης",
    "No Title" : "Χωρίς Τίτλο",
    "No Duration" : "Χωρίς Διάρκεια",
    "Select a different time zone" : "Επιλογή διαφορετικής ζώνης ώρας",
    "Submit" : "Υποβολή",
    "Subscribe to {name}" : "Εγγραφείτε στον {name}",
    "Export {name}" : "Εξαγωγη {name}",
    "Show availability" : "Εμφάνιση διαθεσιμότητας",
    "Anniversary" : "Επέτειος",
    "Appointment" : "Ραντεβού",
    "Business" : "Επιχείρηση",
    "Education" : "Εκπαίδευση",
    "Holiday" : "Διακοπές",
    "Meeting" : "Συνάντηση",
    "Miscellaneous" : "Διάφορα",
    "Non-working hours" : "Μη εργάσιμες ώρες",
    "Not in office" : "Εκτός γραφείου",
    "Phone call" : "Τηλεφωνική κλήση",
    "Sick day" : "Ημέρα ανάρρωσης",
    "Special occasion" : "Ειδική περίπτωση",
    "Travel" : "Ταξίδι",
    "Vacation" : "Διακοπές",
    "Midnight on the day the event starts" : "Τα μεσάνυχτα της ημέρας που ξεκινά το γεγονός",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n ημέρα πριν το γεγονός σε {formattedHourMinute}","%n ημέρες πριν το γεγονός σε {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n εβδομάδα πριν το γεγονός σε {formattedHourMinute}","%n εβδομάδες πριν το γεγονός σε {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "την ημέρα της γεγονότος σε {formattedHourMinute}",
    "at the event's start" : "στην έναρξη του γεγονότος",
    "at the event's end" : "στο τέλος του γεγονότος",
    "{time} before the event starts" : "{time} πριν την έναρξη του γεγονότος",
    "{time} before the event ends" : "{time} πριν τη λήξη του γεγονότος",
    "{time} after the event starts" : "{time} μετά την έναρξη του γεγονότος",
    "{time} after the event ends" : "{time} μετά τη λήξη του γεγονότος",
    "on {time}" : "στις {time}",
    "on {time} ({timezoneId})" : "στις {time} ({timezoneId})",
    "Week {number} of {year}" : "Εβδομάδα {number} του {year}",
    "Daily" : "Ημερησίως",
    "Weekly" : "Εβδομαδιαίως",
    "Monthly" : "Μηνιαίως",
    "Yearly" : "Ετησίως",
    "_Every %n day_::_Every %n days_" : ["Κάθε %n ημέρα","Κάθε %n ημέρες"],
    "_Every %n week_::_Every %n weeks_" : ["Κάθε %n εβδομάδα","Κάθε %n εβδομάδες"],
    "_Every %n month_::_Every %n months_" : ["Κάθε %n μήνα","Κάθε %n μήνες"],
    "_Every %n year_::_Every %n years_" : ["Κάθε %n χρόνο","Κάθε %n χρόνια"],
    "_on {weekday}_::_on {weekdays}_" : ["σε {weekday}","σε {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["σε ημέρα {dayOfMonthList}","σε ημέρες {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "την {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {dayOfMonthList}" : "τους {monthNames} στις {dayOfMonthList}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "τον {monthNames} στις {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "έως {untilDate}",
    "_%n time_::_%n times_" : ["%n φορά","%n φορές"],
    "second" : "δευτερόλεπτο",
    "third" : "τρίτο",
    "fourth" : "τέταρτο",
    "fifth" : "πέμπτο",
    "second to last" : "προτελευταίο",
    "last" : "τελευταίο",
    "Untitled task" : "Εργασία χωρίς τίτλο",
    "Please ask your administrator to enable the Tasks App." : "Παρακαλώ ζητήστε από τον διαχειριστή την ενεργοποίηση της εφαρμογής Εργασίες.",
    "You are not allowed to edit this event as an attendee." : "Δεν επιτρέπεται η επεξεργασία αυτού του συμβάντος ως συμμετέχοντας.",
    "W" : "Εβδ",
    "%n more" : "%n επιπλέον",
    "No events to display" : "Κανένα γεγονός για εμφάνιση",
    "All participants declined" : "Όλοι οι συμμετέχοντες αρνήθηκαν",
    "Please confirm your participation" : "Παρακαλώ επιβεβαιώστε τη συμμετοχή σας",
    "You declined this event" : "Αρνηθήκατε αυτό το συμβάν",
    "Your participation is tentative" : "Η συμμετοχή σας είναι προσωρινή",
    "_+%n more_::_+%n more_" : ["+ %n επιπλέον","+ %n επιπλέον"],
    "No events" : "Κανένα γεγονός",
    "Create a new event or change the visible time-range" : "Δημιουργήστε ένα νέο γεγονός ή αλλάξτε το χρονικό όριο εμφάνισης.",
    "Failed to save event" : "Αποτυχία αποθήκευσης συμβάντος",
    "It might have been deleted, or there was a typo in a link" : "Ίσως έχει διαγραφεί, ή υπάρχει λάθος στην πληκτρολόγηση του συνδέσμου.",
    "It might have been deleted, or there was a typo in the link" : "Ίσως έχει διαγραφεί, ή υπάρχει λάθος στην πληκτρολόγηση του συνδέσμου.",
    "Meeting room" : "Δωμάτιο σύσκεψης",
    "Lecture hall" : "Αίθουσα διδασκαλίας",
    "Seminar room" : "Χώρος σεμιναρίων",
    "Other" : "Άλλο",
    "When shared show" : "Εμφάνιση με τον διαμοιρασμό",
    "When shared show full event" : "Προβολή πλήρους συμβάντος, όταν κοινοποιείται",
    "When shared show only busy" : "Όταν είναι σε κοινή χρήση να προβάλλονται μόνο απασχολημένοι ",
    "When shared hide this event" : "Απόκρυψη αυτού του συμβάντος, όταν κοινοποιείται",
    "Add a location" : "Προσθήκη τοποθεσίας",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Προσθέστε μια περιγραφή\n\n- Τι αφορά αυτή η συνάντηση\n- Θέματα ημερήσιας διάταξης\n- Οτιδήποτε πρέπει να προετοιμάσουν οι συμμετέχοντες",
    "Status" : "Κατάσταση",
    "Confirmed" : "Επιβεβαιώθηκε",
    "Canceled" : "Ακυρώθηκε",
    "Confirmation about the overall status of the event." : "Επιβεβαίωση της συνολικής κατάστασης του γεγονότος.",
    "Show as" : "Εμφάνιση ως",
    "Take this event into account when calculating free-busy information." : "Λαβετε υποψιν αυτο το γεγονός οταν υπολογίζετε την πληροφορια διαθεσιμος-κατειλημμένος",
    "Categories" : "Κατηγορίες",
    "Categories help you to structure and organize your events." : "Οι κατηγορίες σας βοηθούν να δομήσετε και να οργανώσετε τα γεγονότα σας",
    "Search or add categories" : "Αναζήτηση ή προσθήκη κατηγοριών",
    "Add this as a new category" : "Προσθήκη αυτού σε νέα κατηγορία",
    "Custom color" : "Προσαρμοσμένο χρώμα",
    "Special color of this event. Overrides the calendar-color." : "Ειδικό χρώμα αυτού του γεγονότος. Υπερισχύει του ημερολογίου.",
    "Error while sharing file" : "Σφάλμα κατά τον διαμοιρασμό αρχείου",
    "Error while sharing file with user" : "Σφάλμα κατά την κοινή χρήση του αρχείου με τον χρήστη",
    "Error creating a folder {folder}" : "Σφάλμα δημιουργίας φακέλου {folder}",
    "Attachment {fileName} already exists!" : "Το συνημμένο {fileName} υπάρχει ήδη!",
    "Attachment {fileName} added!" : "Το συνημμένο {fileName} προστέθηκε!",
    "An error occurred during uploading file {fileName}" : "Παρουσιάστηκε σφάλμα κατά τη μεταφόρτωση του αρχείου {fileName}",
    "An error occurred during getting file information" : "Εμφανίστηκε σφάλμα κατά τη λήψη πληροφοριών αρχείου",
    "An error occurred, unable to delete the calendar." : "Παρουσιάστηκε σφάλμα, δεν δύναται να διαγραφή το ημερολόγιο.",
    "Imported {filename}" : "Εισηγμένο {filename}",
    "This is an event reminder." : "Αυτή είναι μια υπενθύμιση γεγονότος.",
    "Error while parsing a PROPFIND error" : "Σφάλμα κατά την ανάλυση σφάλματος PROPFIND",
    "Appointment not found" : "Το ραντεβού δεν βρέθηκε",
    "User not found" : "Ο/Η χρήστης δεν βρέθηκε",
    "Hidden" : "Κρυφός",
    "can edit" : "δυνατότητα επεξεργασίας",
    "Calendar name …" : "Όνομα ημερολογίου …",
    "Default attachments location" : "Προεπιλεγμένη τοποθεσία συνημμένων",
    "Automatic ({detected})" : "Αυτόματα ({detected})",
    "Shortcut overview" : "Επισκόπηση συντόμευσης",
    "CalDAV link copied to clipboard." : "Αντιγράφηκε στο πρόχειρο ο σύνδεσμος CalDAV",
    "CalDAV link could not be copied to clipboard." : "Δεν αντιγράφηκε στο πρόχειρο ο σύνδεσμος CalDAV",
    "Enable birthday calendar" : "Ενεργοποίηση ημερολογίου γενεθλίων",
    "Show tasks in calendar" : "Εμφάνιση εργασιών στο ημερολόγιο",
    "Enable simplified editor" : "Ενεργοποίηση απλοποιημένου προγράμματος επεξεργασίας",
    "Limit the number of events displayed in the monthly view" : "Περιορισμός του αριθμού των συμβάντων που εμφανίζονται στη μηνιαία προβολή",
    "Show weekends" : "Εμφάνιση σαββατοκύριακων",
    "Show week numbers" : "Εμφάνιση αριθμού εβδομάδας",
    "Time increments" : "Χρόνος μεταξύ δυο ραντεβού",
    "Default calendar for incoming invitations" : "Προεπιλεγμένο ημερολόγιο για εισερχόμενες προσκλήσεις",
    "Copy primary CalDAV address" : "Αντιγραφή κύριας διεύθυνσης CalDAV",
    "Copy iOS/macOS CalDAV address" : "Αντιγραφή διεύθυνσης iOS/macOS CalDAV",
    "Personal availability settings" : "Ρυθμίσεις προσωπικής διαθεσιμότητας",
    "Show keyboard shortcuts" : "Εμφάνιση συντομεύσεων πληκτρολογίου",
    "Create a new public conversation" : "Δημιουργία νέας δημόσιας συνομιλίας",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} προσκεκλημένοι, {confirmedCount} επιβεβαιωμένοι",
    "Successfully appended link to talk room to location." : "Προστέθηκε επιτυχώς σύνδεσμος δωματίου Talk στην τοποθεσία.",
    "Successfully appended link to talk room to description." : "Ο σύνδεσμος στο δωμάτιο Talk προστέθηκε με επιτυχία στην περιγραφή.",
    "Error creating Talk room" : "Σφάλμα δημιουργίας δωματίου Talk",
    "_%n more guest_::_%n more guests_" : ["%n ακόμη ένας επισκέπτης","%n ακόμη επισκέπτες"],
    "The visibility of this event in shared calendars." : "Η ορατότητα του γεγονότος στα ημερολόγια κοινής χρήσης."
},
"nplurals=2; plural=(n != 1);");
