OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "A megadott e-mail-cím túl hosszú",
    "User-Session unexpectedly expired" : "A felhasználói munkamenet váratlanul lejárt",
    "Provided email-address is not valid" : "A megadott e-mail-cím nem érvényes",
    "%s has published the calendar »%s«" : "%s közzétette ezt a naptárt: „%s”",
    "Unexpected error sending email. Please contact your administrator." : "Váratlan hiba üzenetküldéskor. Lépjen kapcsolatba a rendszergazdával.",
    "Successfully sent email to %1$s" : "E-mail sikeresen elküldve ide: %1$s",
    "Hello," : "Üdv,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Tájékoztatjuk, hogy %s közzétette ezt a naptárat: „%s”.",
    "Open »%s«" : "„%s” megnyitása",
    "Cheers!" : "Üdv!",
    "Upcoming events" : "Közelgő események",
    "No more events today" : "Ma nincs több esemény",
    "No upcoming events" : "Nincsenek közelgő események",
    "More events" : "További események",
    "%1$s with %2$s" : "%1$s – %2$s",
    "Calendar" : "Naptár",
    "New booking {booking}" : "Új foglalás: {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) ekkorra foglalta le a(z) „{config_display_name}” találkozót: {date_time}.",
    "Appointments" : "Találkozók",
    "Schedule appointment \"%s\"" : "A(z) „%s” találkozó ütemezése",
    "Schedule an appointment" : "Találkozó ütemezése",
    "%1$s - %2$s" : "%1$s – %2$s",
    "Prepare for %s" : "Előkészülés erre: %s",
    "Follow up for %s" : "Utókövetés ehhez: %s",
    "Your appointment \"%s\" with %s needs confirmation" : "A(z) „%s” találkozójához (a következővel: %s) megerősítés szükséges",
    "Dear %s, please confirm your booking" : "Kedves %s, erősítse meg a foglalását",
    "Confirm" : "Megerősítés",
    "Appointment with:" : "Találkozó vele:",
    "Description:" : "Leírás:",
    "This confirmation link expires in %s hours." : "Ez a megerősítő hivatkozás %s óra múlva lejár.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Ha mégis le akarja mondani a találkozót, lépjen kapcsolatba a szervezővel úgy, hogy válaszol erre a levélre vagy felkeresi a profiloldalát.",
    "Your appointment \"%s\" with %s has been accepted" : "A(z) „%s” találkozóját (a következővel: %s) elfogadta",
    "Dear %s, your booking has been accepted." : "Kedves %s, a foglalását elfogadták.",
    "Appointment for:" : "Találkozó ehhez:",
    "Date:" : "Dátum:",
    "You will receive a link with the confirmation email" : "Egy hivatkozást fog kapni a megerősítő e-mailben",
    "Where:" : "Hely:",
    "Comment:" : "Megjegyzés:",
    "You have a new appointment booking \"%s\" from %s" : "Új találkozófoglalása van: „%s” a következőtől: %s",
    "Dear %s, %s (%s) booked an appointment with you." : "Kedves %s, %s (%s) lefoglalt egy találkozót Önnel.",
    "%s has proposed a meeting" : "%s javasolt egy találkozót",
    "%s has updated a proposed meeting" : "%s frissített egy javasolt találkozót",
    "%s has canceled a proposed meeting" : "%s lemondott egy javasolt találkozót",
    "Dear %s, a new meeting has been proposed" : "Kedves %s, új találkozót javasoltak",
    "Dear %s, a proposed meeting has been updated" : "Kedves %s, egy javasolt találkozót frissítettek",
    "Dear %s, a proposed meeting has been cancelled" : "Kedves %s, egy javasolt találkozót lemondtak",
    "Location:" : "Hely:",
    "Duration:" : "Időtartam:",
    "%1$s from %2$s to %3$s" : "%1$s %2$s-től %3$s-ig",
    "Dates:" : "Dátumok:",
    "Respond" : "Válasz",
    "A Calendar app for Nextcloud" : "Naptár alkalmazás a Nextcloudhoz",
    "A Calendar app for Nextcloud. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Like Contacts, Talk, Tasks, Deck and Circles\n* 🌐 **WebCal Support!** Want to see your favorite team's matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 **Search!** Find your events at ease\n* ☑️ **Tasks!** See tasks or Deck cards with a due date directly in the calendar\n* 🔈 **Talk rooms!** Create an associated Talk room when booking a meeting with just one click\n* 📆 **Appointment booking** Send people a link so they can book an appointment with you [using this app](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Attachments!** Add, upload and view event attachments\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Naptár alkalmazás a Nextcloudhoz. Szinkronizálja könnyedén az eseményeit több eszközről könnyedén a Nextcloudjával, és szerkessze őket online.\n* 🚀 **Integráció más Nextcloud alkalmazásokkal!** Például a Névjegyekkel, a Beszélgetéssel, a Feladatokkal, a Kártyákkal és a Körökkel.\n* 🌐 **WebCal-támogatás!** Szeretné a kedvenc csapata meccsnapját látni a naptárban? Semmi probléma!\n* 🙋 **Résztvevők!** Hívjon meg másokat az eseményekre.\n* ⌚️ **Szabad vagy foglalt?** Nézze meg, mikor érnek rá a résztvevők a találkozóra.\n* ⏰ **Emlékeztetők!** Riasztást kaphat az eseményekről a böngészőjében és e-mailben.\n* 🔍 **Keresés!** Találja meg egyszerűen az eseményeit.\n* ☑️ **Feladatok!** Tekintse meg a feladatokat vagy kártyákat, a határidejükkel együtt, közvetlenül a naptárában.\n* 🔈 **Beszélgetés szobák!** Hozzon létre kapcsolódó Beszélgetés szobát egy kattintással, amikor találkozót foglal.\n* 📆 **Találkozó szervezése!** Küldjön egy hivatkozást, hogy találkozót foglalhassanak Önnel [ezzel az alkalmazással](https://apps.nextcloud.com/apps/appointments).\n* 📎 **Mellékletek!** Adja hozzá, töltse fel és tekintse meg a mellékleteket.\n* 🙈 **Mi nem találjuk fel újra a kereket!** A nagyszerű [c-dav](https://github.com/nextcloud/cdav-library), az [ical.js](https://github.com/mozilla-comm/ical.js) és a [fullcalendar](https://github.com/fullcalendar/fullcalendar) programkönyvtárakra építünk.",
    "Previous day" : "Előző nap",
    "Previous week" : "Előző hét",
    "Previous year" : "Előző év",
    "Previous month" : "Előző hónap",
    "Next day" : "Következő nap",
    "Next week" : "Következő hét",
    "Next year" : "Köv. év",
    "Next month" : "Következő hónap",
    "Create new event" : "Új esemény létrehozása",
    "Event" : "Esemény",
    "Today" : "Ma",
    "Day" : "Nap",
    "Week" : "Hét",
    "Month" : "Hónap",
    "Year" : "Év",
    "List" : "Lista",
    "Appointment link was copied to clipboard" : "Találkozóhivatkozás vágólapra másolva",
    "Appointment link could not be copied to clipboard" : "A találkozóhivatkozást nem sikerült a vágólapra másolni",
    "Preview" : "Előnézet",
    "Copy link" : "Hivatkozás másolása",
    "Edit" : "Szerkesztés",
    "Delete" : "Törlés",
    "Appointment schedules" : "Találkozók ütemezése",
    "Create new" : "Új létrehozása",
    "Disable calendar \"{calendar}\"" : "A(z) „{calendar}” naptár letiltása",
    "Disable untitled calendar" : "Névtelen naptár letiltása",
    "Enable calendar \"{calendar}\"" : "A(z) „{calendar}” naptár engedélyezése",
    "Enable untitled calendar" : "Névtelen naptár engedélyezése",
    "An error occurred, unable to change visibility of the calendar." : "Hiba lépett fel, a naptár kinézetét nem lehet megváltoztatni.",
    "Untitled calendar" : "Névtelen naptár",
    "Shared with you by" : "Önnel megosztotta:",
    "Edit and share calendar" : "Naptár szerkesztése és megosztása",
    "Edit calendar" : "Naptár szerkesztése",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Megosztás leállítása {countdown} másodperc múlva","Megosztás leállítása {countdown} másodperc múlva"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Naptár törlése {countdown} másodperc múlva","Naptár törlése {countdown} másodperc múlva"],
    "An error occurred, unable to create the calendar." : "Hiba történt, a naptárat nem lehet létrehozni.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Érvényes hivatkozást adjon meg (ezek egyikével kezdődjön: http://, https://, webcal://, vagy webcals://)",
    "Calendars" : "Naptárak",
    "Add new" : "Új hozzáadása",
    "New calendar" : "Új naptár",
    "Name for new calendar" : "Új naptár neve",
    "Creating calendar …" : "Naptár létrehozása…",
    "New calendar with task list" : "Új naptár feladatlistával",
    "New subscription from link (read-only)" : "Új feliratkozás hivatkozásból (csak olvasható)",
    "Creating subscription …" : "Feliratkozás létrehozása…",
    "Add public holiday calendar" : "Ünnepnapok naptárának hozzáadása",
    "Add custom public calendar" : "Egyéni nyilvános naptár hozzáadása",
    "Calendar link copied to clipboard." : "Naptári hivatkozás vágólapra másolva.",
    "Calendar link could not be copied to clipboard." : "Naptári hivatkozást nem lehet vágólapra másolni.",
    "Copy subscription link" : "Feliratkozási hivatkozás másolása",
    "Copying link …" : "Hivatkozás másolása…",
    "Copied link" : "Hivatkozás másolva",
    "Could not copy link" : "A hivatkozást nem lehet másolni",
    "Export" : "Exportálás",
    "Untitled item" : "Névtelen elem",
    "Unknown calendar" : "Ismeretlen naptár",
    "Could not load deleted calendars and objects" : "A törölt naptárak és objektumok nem tölthetők be",
    "Could not delete calendar or event" : "A naptár vagy esemény nem törölhető",
    "Could not restore calendar or event" : "A naptár vagy esemény nem állítható helyre",
    "Do you really want to empty the trash bin?" : "Biztos, hogy üríti a kukát?",
    "Empty trash bin" : "Kuka ürítése",
    "Trash bin" : "Kuka",
    "Loading deleted items." : "Törölt elemek betöltése.",
    "You do not have any deleted items." : "Nincsenek törölt elemei.",
    "Name" : "Név",
    "Deleted" : "Törölt",
    "Restore" : "Helyreállítás",
    "Delete permanently" : "Végleges törlés",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["A kukában lévő elemek {numDays} nap után törölve lesznek","A kukában lévő elemek {numDays} nap után törölve lesznek"],
    "Could not update calendar order." : "Nem sikerült frissíteni a naptárak sorrendjét.",
    "Shared calendars" : "Megosztott naptárak",
    "Deck" : "Kártyák",
    "Internal link" : "Belső hivatkozás",
    "A private link that can be used with external clients" : "Privát hivatkozás, amely külső kliensekkel használhat",
    "Copy internal link" : "Belső hivatkozás másolása",
    "An error occurred, unable to publish calendar." : "Hiba lépett fel, nem lehet közzétenni a naptárat.",
    "An error occurred, unable to send email." : "Hiba lépett fel, nem lehet e-mailt küldeni.",
    "Embed code copied to clipboard." : "A beágyazó kód vágólapra másolva.",
    "Embed code could not be copied to clipboard." : "A beágyazó kód vágólapra másolása sikertelen.",
    "Unpublishing calendar failed" : "Naptár közzétételének visszavonása sikertelen",
    "Share link" : "Megosztás hivatkozással",
    "Copy public link" : "Nyilvános hivatkozás másolása",
    "Send link to calendar via email" : "Naptárhivatkozás küldése e-mailben",
    "Enter one address" : "Adjon meg egy címet",
    "Sending email …" : "E-mail küldése…",
    "Copy embedding code" : "Beágyazó kód másolása",
    "Copying code …" : "Kód másolása…",
    "Copied code" : "Kód lemásolva",
    "Could not copy code" : "A kódot nem lehet másolni",
    "Delete share link" : "Megosztási hivatkozás törlése",
    "Deleting share link …" : "Megosztott hivatkozás törlése…",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (csapat)",
    "An error occurred while unsharing the calendar." : "Hiba történt a naptár megosztásának megszüntetése során.",
    "An error occurred, unable to change the permission of the share." : "Hiba történt, nem lehet megváltoztatni a megosztás jogosultságait.",
    "can edit and see confidential events" : "szerkesztheti és láthatja a bizalmas eseményeket",
    "Unshare with {displayName}" : "Megosztás megszüntetése a következővel: {displayName}",
    "Share with users or groups" : "Megosztás felhasználókkal vagy csoportokkal",
    "No users or groups" : "Nincsenek felhasználók vagy csoportok",
    "Failed to save calendar name and color" : "A naptár nevének és színének mentése sikertelen",
    "Calendar name …" : "Naptár neve…",
    "Never show me as busy (set this calendar to transparent)" : "Sose jelenítse meg elfoglaltnak (naptár átlátszóra állítása)",
    "Share calendar" : "Naptár megosztása",
    "Unshare from me" : "Megosztás visszavonása",
    "Save" : "Mentés",
    "No title" : "Nincs cím",
    "Are you sure you want to delete \"{title}\"?" : "Biztos, hogy törli ezt: „{title}”?",
    "Deleting proposal \"{title}\"" : "A(z) „{title}” javaslat törlése",
    "Successfully deleted proposal" : "Javaslat sikeresen törölve",
    "Failed to delete proposal" : "A javaslat törlése sikertelen",
    "Failed to retrieve proposals" : "A javaslatok lekérése sikertelen",
    "Meeting proposals" : "Találkozójavaslatok",
    "A configured email address is required to use meeting proposals" : "A találkozójavaslatok használatához beállított e-mail-cím szükséges",
    "No active meeting proposals" : "Nincsenek aktív találkozójavaslatok",
    "View" : "Nézet",
    "Import calendars" : "Naptárak importálása",
    "Please select a calendar to import into …" : "Válasszon naptárat, amelybe importál…",
    "Filename" : "Fájlnév",
    "Calendar to import into" : "Naptár importálva ide:",
    "Cancel" : "Mégse",
    "_Import calendar_::_Import calendars_" : ["Naptár importálása","Naptárak importálása"],
    "Select the default location for attachments" : "Válassza ki a mellékletek alapértelmezett helyét",
    "Pick" : "Válasszon",
    "Invalid location selected" : "Érvénytelen hely választva",
    "Attachments folder successfully saved." : "A mellékletek mappa sikeresen mentve.",
    "Error on saving attachments folder." : "Hiba a mellékletek mappa mentése során.",
    "Attachments folder" : "Mellékletek mappa",
    "{filename} could not be parsed" : "A {filename} nem dolgozható fel",
    "No valid files found, aborting import" : "Nem található érvényes fájl, importálás megszakítva",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["%n esemény sikeresen importálva","%n esemény sikeresen importálva"],
    "Import partially failed. Imported {accepted} out of {total}." : "Az importálás részlegesen sikertelen. {accepted} / {total} lett importálva.",
    "Automatic" : "Automatikus",
    "Automatic ({timezone})" : "Automatikus ({timezone})",
    "New setting was not saved successfully." : "Az új beállítások nem lettek elmentve.",
    "Timezone" : "Időzóna",
    "Navigation" : "Navigáció",
    "Previous period" : "Előző időszak",
    "Next period" : "Következő időszak",
    "Views" : "Megtekintések",
    "Day view" : "Nap nézet",
    "Week view" : "Hét nézet",
    "Month view" : "Hónap nézet",
    "Year view" : "Év nézet",
    "List view" : "Lista nézet",
    "Actions" : "Műveletek",
    "Create event" : "Esemény létrehozása",
    "Show shortcuts" : "Gyorsbillentyűk megjelenítése",
    "Editor" : "Szerkesztő",
    "Close editor" : "Szerkesztő bezárása",
    "Save edited event" : "Szerkesztett esemény mentése",
    "Delete edited event" : "Szerkesztett esemény törlése",
    "Duplicate event" : "Esemény megkettőzése",
    "or" : "vagy",
    "Calendar settings" : "Naptár beállításai",
    "At event start" : "Az esemény kezdetekor",
    "No reminder" : "Nincs emlékeztető",
    "Failed to save default calendar" : "Az alapértelmezett naptár mentése sikertelen",
    "General" : "Általános",
    "Availability settings" : "Elérhetőség beállításai",
    "CalDAV" : "CalDAV",
    "Access Nextcloud calendars from other apps and devices" : "Nextcloud naptárak elérése más alkalmazásokból és eszközökről",
    "CalDAV URL" : "CalDAV-webcím",
    "Appearance" : "Megjelenés",
    "Birthday calendar" : "Születésnapok naptára",
    "Tasks in calendar" : "Feladatok a naptárban",
    "Weekends" : "Hétvégék",
    "Week numbers" : "Hetek száma",
    "Limit number of events shown in Month view" : "A havi nézetben megjelenített események számának korlátozása",
    "Density in Day and Week View" : "Sűrűség a napi és a heti nézetben",
    "Editing" : "Szerkesztés",
    "Default reminder" : "Alapértelmezett emlékeztető",
    "Simple event editor" : "Egyszerű eseményszerkesztő",
    "\"More details\" opens the detailed editor" : "A „További részletek” megnyitja a részletes szerkesztőt",
    "Files" : "Fájlok",
    "Appointment schedule successfully created" : "Találkozó ütemezése sikeresen létrehozva",
    "Appointment schedule successfully updated" : "Találkozó ütemezése sikeresen frissítve",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} perc","{duration} perc"],
    "0 minutes" : "0 perc",
    "_{duration} hour_::_{duration} hours_" : ["{duration} óra","{duration} óra"],
    "_{duration} day_::_{duration} days_" : ["{duration} nap","{duration} nap"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} hét","{duration} hét"],
    "_{duration} month_::_{duration} months_" : ["{duration} hónap","{duration} hónap"],
    "_{duration} year_::_{duration} years_" : ["{duration} év","{duration} év"],
    "To configure appointments, add your email address in personal settings." : "A találkozók testreszabásához adja hozzá az e-mail-címét a személyes beállításokban.",
    "Public – shown on the profile page" : "Nyilvános – megjelenik a profiloldalán",
    "Private – only accessible via secret link" : "Privát – csak titkos hivatkozáson keresztül érhető el",
    "Appointment schedule saved" : "Találkozó ütemezése mentve",
    "Create appointment schedule" : "Találkozóütemezés létrehozása",
    "Edit appointment schedule" : "Találkozóütemezés szerkesztése",
    "Update" : "Frissítés",
    "Appointment name" : "Találkozó neve",
    "Location" : "Hely",
    "Create a Talk room" : "Beszélgetés szoba létrehozása",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Egy egyéni hivatkozás lesz előállítva minden egyes lefoglalt találkozóhoz, és el lesz küldve a megerősítő e-mailben",
    "Description" : "Leírás",
    "Visibility" : "Láthatóság",
    "Duration" : "Időtartam",
    "Increments" : "Lépésköz",
    "Additional calendars to check for conflicts" : "További naptárak az ütközés-ellenőrzéshez",
    "Pick time ranges where appointments are allowed" : "Válasszon időszakokat, amikor a találkozók engedélyezettek",
    "to" : "–",
    "Delete slot" : "Idősáv törlése",
    "No times set" : "Nincs idő megadva",
    "Add" : "Hozzáadás",
    "Monday" : "hétfő",
    "Tuesday" : "kedd",
    "Wednesday" : "szerda",
    "Thursday" : "csütörtök",
    "Friday" : "péntek",
    "Saturday" : "szombat",
    "Sunday" : "vasárnap",
    "Weekdays" : "Hétköznapok",
    "Add time before and after the event" : "Idő hozzáadása az esemény előtt és után",
    "Before the event" : "Esemény előtt",
    "After the event" : "Esemény után",
    "Planning restrictions" : "Tervezési korlátozások",
    "Minimum time before next available slot" : "A következő szabad idősáv előtti minimális idő",
    "Max slots per day" : "Napi idősávok legnagyobb száma",
    "Limit how far in the future appointments can be booked" : "Korlátozás, hogy mennyivel előre lehessen találkozót foglalni",
    "It seems a rate limit has been reached. Please try again later." : "Úgy néz ki, hogy elérte a forgalomkorlátot. Próbálja újra később",
    "Please confirm your reservation" : "Erősítse meg a foglalását",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Küldtünk egy e-mailt a részletekkel. Erősítse meg a találkozót a levélben található hivatkozással. Bezárhatja ezt az oldalt.",
    "Your name" : "Az Ön neve",
    "Your email address" : "Az Ön e-mail-címe",
    "Please share anything that will help prepare for our meeting" : "Osszon meg mindent, amely segít a találkozóra felkészüléshez",
    "Could not book the appointment. Please try again later or contact the organizer." : "A találkozót nem sikerült lefoglalni. Próbálja újra, vagy lépjen kapcsolatba a szervezővel.",
    "Back" : "Vissza",
    "Book appointment" : "Találkozó lefoglalása",
    "Error fetching Talk conversations." : "Hiba a beszélgetések lekérésekor.",
    "Conversation does not have a valid URL." : "A beszélgetés nem tartalmaz érvényes webcímet.",
    "Successfully added Talk conversation link to location." : "Beszélgetés hivatkozás sikeresen hozzáadva a helyhez.",
    "Successfully added Talk conversation link to description." : "Beszélgetés hivatkozás sikeresen hozzáadva a leíráshoz.",
    "Failed to apply Talk room." : "A Beszélgetés szoba alkalmazás sikertelen.",
    "Talk conversation for event" : "Eseményhez tartozó beszélgetés",
    "Error creating Talk conversation" : "Hiba a Beszélgetés szoba létrehozása során",
    "Select a Talk Room" : "Válasszon Beszélgetés szobát",
    "Add Talk conversation" : "Beszélgetés hozzáadása",
    "Fetching Talk rooms…" : "Beszélgetés szobák lekérése…",
    "No Talk room available" : "Nem érhető el Beszélgetés szoba",
    "Create public conversation" : "Nyilvános beszélgetés létrehozása",
    "Select conversation" : "Válasszon beszélgetést",
    "on" : "be",
    "at" : "ekkor: ",
    "before at" : "előtt",
    "Notification" : "Értesítés",
    "Email" : "E-mail",
    "Audio notification" : "Hangértesítés",
    "Other notification" : "Egyéb értesítés",
    "Relative to event" : "Az eseményhez viszonyítva",
    "On date" : "Időpontban",
    "Edit time" : "Idő szerkesztése",
    "Save time" : "Időpont mentése",
    "Remove reminder" : "Értesítés eltávolítása",
    "Add reminder" : "Emlékeztető hozzáadása",
    "seconds" : "másodpercek",
    "minutes" : "perc",
    "hours" : "órák",
    "days" : "napok",
    "weeks" : "hét",
    "Choose a file to add as attachment" : "Válasszon mellékletként hozzáadandó fájlt",
    "Choose a file to share as a link" : "Válasszon fájlt a hivatkozással történő megosztáshoz",
    "Attachment {name} already exist!" : "A(z) {name} melléklet már létezik.",
    "Could not upload attachment(s)" : "Nem sikerült feltölteni a mellékleteket",
    "You are about to navigate to {link}. Are you sure to proceed?" : "Arra készül, hogy ide navigáljon: {link}. Biztos, hogy folytatja?",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Arra készül, hogy ide navigáljon: {host}. Biztos, hogy folytatja? Hivatkozás: {link}",
    "Proceed" : "Folytatás",
    "No attachments" : "Nincsenek mellékletek",
    "Add from Files" : "Hozzáadás a Fájlokból",
    "Upload from device" : "Feltöltés az eszközről",
    "Delete file" : "Fájl törlése",
    "Confirmation" : "Megerősítés",
    "_{count} attachment_::_{count} attachments_" : ["{count} melléklet","{count} melléklet"],
    "Suggested" : "Javasolt",
    "Available" : "Elérhető",
    "Invitation accepted" : "Meghívás elfogadva",
    "Accepted {organizerName}'s invitation" : "Elfogadta {organizerName} meghívását",
    "Participation marked as tentative" : "A részvétel feltételesként jelölve",
    "Invitation is delegated" : "Meghívás átruházva",
    "Not available" : "Nem érhető el",
    "Invitation declined" : "Meghívás elutasítva",
    "Declined {organizerName}'s invitation" : "Elutasította {organizerName} meghívását",
    "Availability will be checked" : "Az elérhetőség ellenőrizve lesz",
    "Invitation will be sent" : "Meghívó lesz küldve",
    "Failed to check availability" : "Az elérhetőség ellenőrzése sikertelen",
    "Failed to deliver invitation" : "A meghívó kézbesítése sikertelen",
    "Awaiting response" : "Válaszra várakozik",
    "Checking availability" : "Elérhetőség ellenőrzése",
    "Has not responded to {organizerName}'s invitation yet" : "Még nem válaszolt {organizerName} meghívására",
    "Suggested times" : "Javasolt időszakok",
    "chairperson" : "elnök",
    "required participant" : "szükséges résztvevő",
    "non-participant" : "nem résztvevő",
    "optional participant" : "nem kötelező résztvevő",
    "{organizer} (organizer)" : "{organizer} (szervező)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Selected slot" : "Választott idősáv",
    "Availability of attendees, resources and rooms" : "A résztvevők, az erőforrások és a szobák rendelkezésre állása",
    "Suggestion accepted" : "Javaslat elfogadva",
    "Previous date" : "Előző dátum",
    "Next date" : "Következő dátum",
    "Legend" : "Jelmagyarázat",
    "Out of office" : "Irodán kívül",
    "Attendees:" : "Résztvevők:",
    "local time" : "helyi idő",
    "Done" : "Kész",
    "Search room" : "Szoba keresése",
    "Room name" : "Szoba neve",
    "Check room availability" : "Szoba elérhetőségének ellenőrzése",
    "Free" : "Szabad",
    "Busy (tentative)" : "Foglalt (feltételes)",
    "Busy" : "Foglalt",
    "Unknown" : "Ismeretlen",
    "Find a time" : "Idő keresése",
    "The invitation has been accepted successfully." : "A meghívása sikeresen elfogadva.",
    "Failed to accept the invitation." : "A meghívás elfogadása sikertelen.",
    "The invitation has been declined successfully." : "A meghívás sikeresen elutasítva.",
    "Failed to decline the invitation." : "A meghívás elutasítása sikertelen.",
    "Your participation has been marked as tentative." : "A részvétele feltételesnek lett jelölve.",
    "Failed to set the participation status to tentative." : "A részvétele feltételesként megadása sikertelen.",
    "Accept" : "Elfogadás",
    "Decline" : "Elutasítás",
    "Tentative" : "Feltételes",
    "No attendees yet" : "Még nincs résztvevő",
    "{confirmedCount} confirmed, {waitingCount} awaiting response" : "{confirmedCount} megerősítve, {waitingCount} válaszra vár",
    "Please add at least one attendee to use the \"Find a time\" feature." : "Az „Idő keresése” funkcióhoz adjon hozzá legalább egy résztvevőt.",
    "Attendees" : "Résztvevők",
    "_%n more attendee_::_%n more attendees_" : ["%n további résztvevő","%n további résztvevő"],
    "Remove group" : "Csoport eltávolítása",
    "Remove attendee" : "Résztvevő eltávolítása",
    "Request reply" : "Válasz kérése",
    "Chairperson" : "Elnök",
    "Required participant" : "Kötelező résztvevő",
    "Optional participant" : "Nem kötelező résztvevő",
    "Non-participant" : "Nem résztvevő",
    "_%n member_::_%n members_" : ["%n tag","%n tag"],
    "Search for emails, users, contacts, contact groups or teams" : "E-mail-címek, felhasználók, névjegyek, névjegycsoportok vagy csapatok",
    "No match found" : "Nem található egyezés",
    "Note that members of circles get invited but are not synced yet." : "Vegye figyelembe, hogy a kör tagjai meg lettek hívva, de még nincsenek szinkronizálva.",
    "Note that members of contact groups get invited but are not synced yet." : "Vegye figyelembe, hogy a névjegycsoportok tagjai meg lettek hívva, de még nincsenek szinkronizálva.",
    "(organizer)" : "(szervező)",
    "Make {label} the organizer" : "{label} beállítása szervezőnek",
    "Make {label} the organizer and attend" : "{label} beállítása szervezőnek és résztvevőnek",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Meghívók elküldéséhez és a válaszok kezeléséhez [linkopen]adja meg e-mail-címét a személyes beállításokban[linkclose].",
    "Remove color" : "Szín eltávolítása",
    "Event title" : "Esemény címe",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Az ismétlődő események egész napos beállítása nem módosítható.",
    "From" : "Ettől:",
    "To" : "Eddig:",
    "Your Time" : "Saját idő",
    "Repeat" : "Ismétlés",
    "Repeat event" : "Esemény ismétlése",
    "_time_::_times_" : ["alkalommal","alkalommal"],
    "never" : "soha",
    "on date" : "dátumon",
    "after" : "után",
    "End repeat" : "Ismétlés vége",
    "Select to end repeat" : "Válassza az ismétlés befejezéséhez",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Ez az esemény egy ismétlődő esemény nem ismétlődő kivétele. Nem adhat hozzá ismétlődési szabályt.",
    "first" : "első",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Az ismétlődési szabály változásai csak erre és minden jövőbeli eseményre vonatkoznak.",
    "Repeat every" : "Ismétlés minden",
    "By day of the month" : "A hónap ezen napján",
    "On the" : "Ekkor: ",
    "_day_::_days_" : ["nap","nap"],
    "_week_::_weeks_" : ["hét","hét"],
    "_month_::_months_" : ["hónap","hónapok"],
    "_year_::_years_" : ["év","évek"],
    "On specific day" : "Adott napon",
    "weekday" : "hétköznap",
    "weekend day" : "hétvége",
    "Does not repeat" : "Nem ismétlődik",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Az esemény ismétlődésének megadását a Nextcloud nem támogatja teljes mértékben. Az ismétlődési lehetőségek szerkesztésekor bizonyos ismétlődések elveszhetnek.",
    "No rooms or resources yet" : "Még nincsenek szobák vagy erőforrások",
    "Resources" : "Erőforrások",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} hely","{seatingCapacity} hely"],
    "Add resource" : "Erőforrás hozzáadása",
    "Has a projector" : "Van kivetítő",
    "Has a whiteboard" : "Van fehér tábla",
    "Wheelchair accessible" : "Kerekesszékkel megközelíthető",
    "Remove resource" : "Erőforrás eltávolítása",
    "Search for resources or rooms" : "Szobák vagy erőforrások keresése",
    "available" : "elérhető",
    "unavailable" : "nem érhető el",
    "Show all rooms" : "Összes szoba megjelenítése",
    "Projector" : "Kivetítő",
    "Whiteboard" : "Tábla",
    "Room type" : "Szoba típusa",
    "Any" : "Bármely",
    "Minimum seating capacity" : "Ülőhelyek legkisebb száma",
    "More details" : "További részletek",
    "Update this and all future" : "Ezen és az összes jövőbeli frissítése",
    "Update this occurrence" : "Ezen előfordulás frissítése",
    "Public calendar does not exist" : "Nyilvános naptár nem létezik",
    "Maybe the share was deleted or has expired?" : "Lehet, hogy a megosztást törölték, vagy lejárt?",
    "Remove date" : "Dátum eltávolítása",
    "Attendance required" : "A részvétel kötelező",
    "Attendance optional" : "A részvétel nem kötelező",
    "Remove participant" : "Résztvevő eltávolítása",
    "Yes" : "Igen",
    "No" : "Nem",
    "Maybe" : "Talán",
    "None" : "Egyik sem",
    "Select your meeting availability" : "Válassza ki a saját elérhetőségét",
    "Create a meeting for this date and time" : "Találkozó létrehozása erre a dátumra és időre",
    "Create" : "Létrehozás",
    "No participants or dates available" : "Nincs elérhető résztvevő vagy dátum",
    "from {formattedDate}" : "ettől: {formattedDate}",
    "to {formattedDate}" : "eddig: {formattedDate}",
    "on {formattedDate}" : "ekkor: {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "ettől: {formattedDate} {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "eddig: {formattedDate} {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "ekkor: {formattedDate} {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime}",
    "Please enter a valid date" : "Adjon meg egy érvényes dátumot",
    "Please enter a valid date and time" : "Adjon meg egy érvényes dátumot és időt",
    "Select a time zone" : "Időzóna kiválasztása",
    "Please select a time zone:" : "Válasszon egy időzónát:",
    "Pick a time" : "Válasszon egy időt",
    "Pick a date" : "Válasszon egy dátumot",
    "Type to search time zone" : "Gépeljen az időzóna kereséséhez",
    "Global" : "Globális",
    "Holidays in {region}" : "Ünnepnapok itt: {region}",
    "An error occurred, unable to read public calendars." : "Hiba történt, a nyilvános naptárak nem olvashatók.",
    "An error occurred, unable to subscribe to calendar." : "Hiba történt, nem lehet feliratkozni a naptárra.",
    "Public holiday calendars" : "Ünnepnapok naptára",
    "Public calendars" : "Nyilvános naptárak",
    "No valid public calendars configured" : "Nincsenek érvényes naptárak beállítva",
    "Speak to the server administrator to resolve this issue." : "A probléma megoldásához beszéljen a rendszergazdával.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Az ünnepnapok naptárát a Thunderbird biztosítja. A naptáradatok innen lesznek letöltve: {website}.",
    "These public calendars are suggested by the server administrator. Calendar data will be downloaded from the respective website." : "Ezeket a nyilvános naptárakat a kiszolgáló rendszergazdája javasolta. A naptáradatok a megfelelő webhelyekről lesznek letöltve.",
    "By {authors}" : "Szerzők: {authors}",
    "Subscribed" : "Feliratkozva",
    "Subscribe" : "Feliratkozás",
    "Could not fetch slots" : "Nem sikerült lekérni a helyeket",
    "Select a date" : "Válasszon dátumot",
    "Select slot" : "Válasszon idősávot",
    "No slots available" : "Nincs elérhető idősáv",
    "The slot for your appointment has been confirmed" : "A találkozó idősávja megerősítésre került",
    "Appointment Details:" : "Találkozó részletei:",
    "Time:" : "Idő:",
    "Booked for:" : "Részére lefoglalva:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Köszönjük. A(z) {startdate} és {stopdate} közti foglalása megerősítésre került",
    "Book another appointment:" : "Másik találkozó lefoglalása:",
    "See all available slots" : "Összes elérhető idősáv megtekintése",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "A(z) {startdate} és {stopdate} közti találkozójának idősávja már nem érhető el.",
    "Please book a different slot:" : "Foglaljon egy másik idősávban:",
    "Book an appointment with {name}" : "Találkozó lefoglalása a következővel: {name}",
    "No public appointments found for {name}" : "Nem találhatók nyilvános találkozók a következővel: {name}",
    "Personal" : "Személyes",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Az automatikus időzóna-észlelés UTC-nek észlelte az időzónáját.\nEz valószínűleg a böngésző biztonsági beállításai miatt van.\nÁllítsa be az időzónáját kézzel a naptárbeállításokban.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "A beállított időzóna ({timezoneId}) nem található. Visszaállás UTC-re.\nMódosítsa az időzónát a beállításokban, és jelentse be ezt a hibát.",
    "Show unscheduled tasks" : "Nem ütemezett feladatok megjelenítése",
    "Unscheduled tasks" : "Nem ütemezett feladatok",
    "Availability of {displayName}" : "{displayName} elérhetősége",
    "Discard event" : "Esemény elvetése",
    "Edit event" : "Esemény szerkesztése",
    "Event does not exist" : "Az esemény nem létezik",
    "Duplicate" : "Kettőzés",
    "Delete this occurrence" : "Ezen előfordulás törlése",
    "Delete this and all future" : "Ezen és az összes jövőbeli törlése",
    "All day" : "Egész napos",
    "Modifications wont get propagated to the organizer and other attendees" : "A módosításokat a szervező és a többi résztvevő nem fogja megkapni",
    "Managing shared access" : "Közös hozzáférés kezelése",
    "Deny access" : "Hozzáférés megtagadása",
    "Invite" : "Meghívás",
    "Discard changes?" : "Változtatások elvetése?",
    "Are you sure you want to discard the changes made to this event?" : "Biztos, hogy elveti az esemény változtatásait?",
    "_User requires access to your file_::_Users require access to your file_" : ["Egy felhasználónak szüksége van a fájlja elérésére","Több felhasználónak szüksége van a fájlja elérésére"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Közös hozzáférést igénylő melléklet","Közös hozzáférést igénylő mellékletek"],
    "Untitled event" : "Névtelen esemény",
    "Close" : "Bezárás",
    "Modifications will not get propagated to the organizer and other attendees" : "A módosításokat a szervező és a többi résztvevő nem fogja megkapni",
    "Meeting proposals overview" : "Találkozójavaslatok áttekintése",
    "Edit meeting proposal" : "Találkozójavaslat szerkesztése",
    "Create meeting proposal" : "Találkozójavaslat létrehozása",
    "Update meeting proposal" : "Találkozójavaslat frissítése",
    "Saving proposal \"{title}\"" : "A(z) „{title}” javaslat mentése",
    "Successfully saved proposal" : "Javaslat sikeresen mentve",
    "Failed to save proposal" : "A javaslat mentése sikertelen",
    "Create a meeting for \"{date}\"? This will create a calendar event with all participants." : "Találkozó létrehozása ekkorra: „{date}”? Ez létrehozza a naptáreseményt az összes résztvevővel.",
    "Creating meeting for {date}" : "Találkozó létrehozása ekkorra: {date}",
    "Successfully created meeting for {date}" : "Találkozó sikeresen létrehozva ekkorra: {date}",
    "Failed to create a meeting for {date}" : "Nem sikerült a találkozó létrehozása ekkorra: {date}",
    "Please enter a valid duration in minutes." : "Adjon meg egy érvényes hosszt percekben.",
    "Failed to fetch proposals" : "A javaslatok letöltése sikertelen",
    "Failed to fetch free/busy data" : "A foglaltsági adatok lekérése sikertelen",
    "Selected" : "Kijelölt",
    "No Description" : "Nincs leírás",
    "No Location" : "Nincs hely",
    "Edit this meeting proposal" : "Találkozójavaslat szerkesztése",
    "Delete this meeting proposal" : "Találkozójavaslat törlése",
    "Title" : "Cím",
    "15 min" : "15 perc",
    "30 min" : "30 perc",
    "60 min" : "60 perc",
    "90 min" : "90 perc",
    "Participants" : "Résztvevők",
    "Selected times" : "Kiválasztott elemek",
    "Previous span" : "Előző időszak",
    "Next span" : "Következő időszak",
    "Less days" : "Kevesebb nap",
    "More days" : "Több nap",
    "Loading meeting proposal" : "Találkozójavaslat betöltése",
    "No meeting proposal found" : "Nem található találkozójavaslat",
    "Please wait while we load the meeting proposal." : "Kis türelmet, amíg a találkozójavaslat betöltődik.",
    "The link you followed may be broken, or the meeting proposal may no longer exist." : "A követett hivatkozás lehet, hogy hibás, vagy lehet, hogy a találkozójavaslat már nem létezik.",
    "Thank you for your response!" : "Köszönjük a válaszát!",
    "Your vote has been recorded. Thank you for participating!" : "A szavazat rögzítve lett. Köszönjük, hogy részt vett!",
    "Unknown User" : "Ismeretlen felhasználó",
    "No Title" : "Nincs cím",
    "No Duration" : "Nincs hossz",
    "Select a different time zone" : "Válasszon másik időzónát",
    "Submit" : "Beküldés",
    "Subscribe to {name}" : "Feliratkozás erre: {name}",
    "Export {name}" : "{name} exportálása",
    "Show availability" : "Elérhetőség megjelenítése",
    "Anniversary" : "Évforduló",
    "Appointment" : "Találkozó",
    "Business" : "Üzleti",
    "Education" : "Oktatás",
    "Holiday" : "Szabadság",
    "Meeting" : "Találkozó",
    "Miscellaneous" : "Egyéb",
    "Non-working hours" : "Nem munkaidő",
    "Not in office" : "Nem irodában",
    "Phone call" : "Telefonhívás",
    "Sick day" : "Betegszabadság",
    "Special occasion" : "Különleges alkalom",
    "Travel" : "Utazás",
    "Vacation" : "Nyaralás",
    "Midnight on the day the event starts" : "Az esemény kezdetének napján éjfélkor",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n nappal az esemény előtt {formattedHourMinute}-kor","%n nappal az esemény előtt {formattedHourMinute}-kor"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n héttel az esemény előtt {formattedHourMinute}-kor","%n héttel az esemény előtt {formattedHourMinute}-kor"],
    "on the day of the event at {formattedHourMinute}" : "az esemény napján {formattedHourMinute}-kor",
    "at the event's start" : "az esemény kezdetén",
    "at the event's end" : "az esemény végén",
    "{time} before the event starts" : "{time} idővel az esemény kezdete előtt",
    "{time} before the event ends" : "{time} idővel az esemény vége előtt",
    "{time} after the event starts" : "{time} idővel az esemény kezdete után",
    "{time} after the event ends" : "{time} idővel az esemény vége után",
    "on {time}" : "{time}-kor",
    "on {time} ({timezoneId})" : "{time}-kor ({timezoneId})",
    "Week {number} of {year}" : "{year} {number}. hete",
    "Daily" : "Naponta",
    "Weekly" : "Hetente",
    "Monthly" : "Havonta",
    "Yearly" : "Évente",
    "_Every %n day_::_Every %n days_" : ["%n naponta","%n naponta"],
    "_Every %n week_::_Every %n weeks_" : ["%n hetente","%n hetente"],
    "_Every %n month_::_Every %n months_" : ["%n havonta","%n havonta"],
    "_Every %n year_::_Every %n years_" : ["%n évente","%n évente"],
    "_on {weekday}_::_on {weekdays}_" : ["ezen a napon: {weekdays}","ezen a napon: {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["a hónap ezen napjain: {dayOfMonthList}","a hónap ezen napjain: {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "ekkor: {ordinalNumber}. {byDaySet}",
    "in {monthNames} on the {dayOfMonthList}" : "{monthNames} hónapban ekkor: {dayOfMonthList}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "{monthNames} hónapban ekkor: {ordinalNumber}. {byDaySet}",
    "until {untilDate}" : "eddig: {untilDate}",
    "_%n time_::_%n times_" : ["%n alkalommal","%n alkalommal"],
    "second" : "másodperc",
    "third" : "harmadik",
    "fourth" : "negyedik",
    "fifth" : "ötödik",
    "second to last" : "utolsó előtti",
    "last" : "utolsó",
    "Untitled task" : "Névtelen feladat",
    "Please ask your administrator to enable the Tasks App." : "Kérje meg a rendszergazdát, hogy engedélyezze a Feladatok alkalmazást.",
    "You are not allowed to edit this event as an attendee." : "Résztvevőként nem szerkesztheti ezt az eseményt.",
    "W" : "H",
    "%n more" : "%n további",
    "No events to display" : "Nincs megjelenítendő esemény",
    "All participants declined" : "Az összes résztvevő elutasította",
    "Please confirm your participation" : "Erősítse meg a részvételét",
    "You declined this event" : "Elutasította ezt az eseményt",
    "Your participation is tentative" : "A részvétele feltételes",
    "_+%n more_::_+%n more_" : ["+%n további","+%n további"],
    "No events" : "Nincs esemény",
    "Create a new event or change the visible time-range" : "Hozzon létre egy új eseményt, vagy módosítsa a látható időtartományt",
    "Failed to save event" : "Az esemény mentése sikertelen",
    "It might have been deleted, or there was a typo in a link" : "Lehet, hogy törölték, vagy elgépelés volt egy hivatkozásban",
    "It might have been deleted, or there was a typo in the link" : "Lehet, hogy törölték, vagy elgépelés volt a hivatkozásban",
    "Meeting room" : "Tárgyalóterem",
    "Lecture hall" : "Előadóterem",
    "Seminar room" : "Szemináriumterem",
    "Other" : "Egyéb",
    "When shared show" : "Megjelenítés megosztáskor",
    "When shared show full event" : "A teljes esemény megjelenítése megosztáskor",
    "When shared show only busy" : "Csak a foglaltság megjelenítése megosztáskor",
    "When shared hide this event" : "Az esemény elrejtése megosztáskor",
    "The visibility of this event in read-only shared calendars." : "Az esemény láthatósága az írásvédett megosztott naptárakban.",
    "Add a location" : "Helyszín hozzáadása",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Adjon hozzá egy leírást\n\n- Miről szól ez a találkozó\n- Napirendi pontok\n- Bármi, amivel a résztvevőknek készülniük kell",
    "Status" : "Állapot",
    "Confirmed" : "Elfogadva",
    "Canceled" : "Lemondva",
    "Confirmation about the overall status of the event." : "Megerősítés az esemény általános állapotáról.",
    "Show as" : "Megjelenítés mint",
    "Take this event into account when calculating free-busy information." : "Ezen esemény figyelembe vétele a foglaltsági információk kiszámításakor.",
    "Categories" : "Kategóriák",
    "Categories help you to structure and organize your events." : "A kategóriák segítenek az események strukturálásában és megszervezésében.",
    "Search or add categories" : "Kategóriák keresése vagy hozzáadása",
    "Add this as a new category" : "Hozzáadás új kategóriaként",
    "Custom color" : "Egyéni szín",
    "Special color of this event. Overrides the calendar-color." : "Megkülönböztető szín ehhez az eseményhez. Felülírja a naptár színét.",
    "Error while sharing file" : "Hiba a fájl megosztása során",
    "Error while sharing file with user" : "Hiba a fájl felhasználóval történő megosztása során",
    "Error creating a folder {folder}" : "Hiba a(z) {folder} mappa létrehozása során",
    "Attachment {fileName} already exists!" : "A(z) {fileName} melléklet már létezik.",
    "Attachment {fileName} added!" : "A(z) {fileName} melléklet hozzáadva!",
    "An error occurred during uploading file {fileName}" : "Hiba történt a(z) {fileName} fájl feltöltése során",
    "An error occurred during getting file information" : "Hiba történt a fájlinformációk lekérése során",
    "Talk conversation for proposal" : "Javaslathoz tartozó beszélgetés",
    "An error occurred, unable to delete the calendar." : "Hiba lépett fel, a naptárat nem lehet törölni.",
    "Imported {filename}" : "{filename} importálva",
    "This is an event reminder." : "Ez egy eseményemlékeztető.",
    "Error while parsing a PROPFIND error" : "Hiba történt a PROPFIND hiba feldolgozása során",
    "Appointment not found" : "A találkozó nem található",
    "User not found" : "A felhasználó nem található",
    "Hidden" : "Rejtett",
    "can edit" : "szerkesztheti",
    "Calendar name …" : "Naptár neve…",
    "Default attachments location" : "Mellékletek alapértelmezett helye",
    "Automatic ({detected})" : "Automatikus ({detected})",
    "Shortcut overview" : "Gyorsbillentyűk áttekintése",
    "CalDAV link copied to clipboard." : "CalDAV hivatkozás vágólapra másolva.",
    "CalDAV link could not be copied to clipboard." : "A CalDAV hivatkozást nem lehet vágólapra másolni.",
    "Enable birthday calendar" : "Születésnapok naptárának engedélyezése",
    "Show tasks in calendar" : "Feladatok megjelenítése a naptárban",
    "Enable simplified editor" : "Egyszerűsített szerkesztő engedélyezése",
    "Limit the number of events displayed in the monthly view" : "A havi nézetben megjelenített események számának korlátozása",
    "Show weekends" : "Hétvégék megjelenítése",
    "Show week numbers" : "Hetek számának megjelenítése",
    "Time increments" : "Idő lépésköze",
    "Default calendar for incoming invitations" : "Alapértelmezett naptár a bejövő meghívásokhoz",
    "Copy primary CalDAV address" : "Elsődleges CalDAV-cím másolása",
    "Copy iOS/macOS CalDAV address" : "iOS/macOS CalDAV cím másolása",
    "Personal availability settings" : "Személyes elérhetőség beállításai",
    "Show keyboard shortcuts" : "Billentyűparancsok megjelenítése",
    "Create a new public conversation" : "Új nyilvános beszélgetés létrehozása",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} meghívva, {confirmedCount} megereősítve",
    "Successfully appended link to talk room to location." : "A hely hivatkozásának beszélgetési szobához történő hozzáfűzése sikeres.",
    "Successfully appended link to talk room to description." : "Beszélgetés szoba hivatkozásának a leíráshoz csatolása sikeres.",
    "Error creating Talk room" : "Hiba a Beszélgetés szoba létrehozásakor",
    "_%n more guest_::_%n more guests_" : ["%n további vendég","%n további vendég"],
    "The visibility of this event in shared calendars." : "Az esemény láthatósága a megosztott naptárakban."
},
"nplurals=2; plural=(n != 1);");
