OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Emandako helbide elektronikoa luzeegia da",
    "User-Session unexpectedly expired" : "Erabiltzaile-saioa ustekabean iraungi da",
    "Provided email-address is not valid" : "Emandako helbide elektronikoa ez da baliozkoa",
    "%s has published the calendar »%s«" : "%s erabiltzaileak »%s« egutegia argitaratu du",
    "Unexpected error sending email. Please contact your administrator." : "Ustekabeko errorea posta elektronikoa bidaltzean. Jarri harremanetan zure administratzailearekin.",
    "Successfully sent email to %1$s" : "Posta elektronikoa ondo bidali zaio %1$s(r)i",
    "Hello," : "Kaixo,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Jakinarazi nahi dizugu %s erabiltzaileak »%s« egutegia argitaratu duela",
    "Open »%s«" : " Ireki »%s«",
    "Cheers!" : "Topa!",
    "Upcoming events" : "Hurrengo gertaerak",
    "No more events today" : "Ez dago gertaera gehiagorik gaurkoz.",
    "No upcoming events" : "Ez dago gertaerarik datozen egunetan.",
    "More events" : "Gertaera gehiago",
    "%1$s with %2$s" : "%1$s %2$s(r)ekin",
    "Calendar" : "Egutegia",
    "New booking {booking}" : "Erreserba berria {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) \"{config_display_name}\" hitzordua erreserbatu du {date_time}-etan.",
    "Appointments" : "Hitzorduak",
    "Schedule appointment \"%s\"" : "Antolatu \"%s\" hitzordua",
    "Schedule an appointment" : "Antolatu hitzordu bat",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : "Prestatu %s-rentzat",
    "Follow up for %s" : "%s-(r)en jarraipena",
    "Your appointment \"%s\" with %s needs confirmation" : "Zure \"%s\" hitzorduak %s-(r)ekin berrespena behar du",
    "Dear %s, please confirm your booking" : " %s estimatua, berretsi zure erreserba",
    "Confirm" : "Berretsi",
    "Appointment with:" : "Hitzordua honekin:",
    "Description:" : "Deskribapena:",
    "This confirmation link expires in %s hours." : "Berrespen-esteka hau %s ordu barru iraungiko da.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Azken finean hitzordua bertan behera utzi nahi baduzu, jarri harremanetan antolatzailearekin, mezu elektroniko honi erantzunez edo bere profileko orria bisitatuz.",
    "Your appointment \"%s\" with %s has been accepted" : "Zure \"%s\" hitzordua %s-(r)ekin onartua izan da",
    "Dear %s, your booking has been accepted." : " %spreziatua, zure erreserba onartu da.",
    "Appointment for:" : "Hitzordua:",
    "Date:" : "Data:",
    "You will receive a link with the confirmation email" : "Esteka bat jasoko duzu berrespen-mezu elektronikoarekin",
    "Where:" : "Non:",
    "Comment:" : "Iruzkina:",
    "You have a new appointment booking \"%s\" from %s" : "\"%s\" hitzordu berri bat duzu %s-tik",
    "Dear %s, %s (%s) booked an appointment with you." : " %s estimatua, %s (%s)-k zurekin hitzordua erreserbatu du.",
    "%s has proposed a meeting" : "%s-k bilera bat proposatu du",
    "%s has updated a proposed meeting" : "%s-k eguneratu du bilera baten proposamena",
    "%s has canceled a proposed meeting" : "%s-k bertan behera utzi du proposatutako bilera bat",
    "Dear %s, a new meeting has been proposed" : "Kaixo %s, bilera bat proposatu da",
    "Dear %s, a proposed meeting has been updated" : "Kaixo %s, proposatutako bilera bat eguneratu da",
    "Dear %s, a proposed meeting has been cancelled" : "Kaixo %s, proposatutako bilera bat bertan behera geratu da",
    "Location:" : "Kokapena:",
    "Duration:" : "Iraupena:",
    "Dates:" : "Datak:",
    "Respond" : "Erantzun",
    "A Calendar app for Nextcloud" : "Nextclouderako egutegi app-a",
    "A Calendar app for Nextcloud. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Like Contacts, Talk, Tasks, Deck and Circles\n* 🌐 **WebCal Support!** Want to see your favorite team's matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 **Search!** Find your events at ease\n* ☑️ **Tasks!** See tasks or Deck cards with a due date directly in the calendar\n* 🔈 **Talk rooms!** Create an associated Talk room when booking a meeting with just one click\n* 📆 **Appointment booking** Send people a link so they can book an appointment with you [using this app](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Attachments!** Add, upload and view event attachments\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : " Nextclouderako Egutegia aplikazioa. Hainbat gailutatik datozen gertaerak sinkronizatu eta editatu linean.\n\n🚀 ** Nextclouden beste aplikazioekin integratzen da!** Hala nola, Kontaktuak, Hizketaldia, Zereginak, Deck eta Zirkuluak\n*🌐 *** WebCal onartzen du! Zure taldearen partidak ikusi nahi duzu zure egutegian?  Ez dago arazorik!\n *🙋 **Parteartzailek! Gonbidatu jendea zure ekitaldietara.\n*⌚ ** Libre/Lanpetuta!** Ikusi zure partaideak noiz dauden biltzeko prest.\n*⏰ ** Oroigarriak!!  Zure nabigatzailearen barruan eta posta elektronikoaren bidez gertaeretarako alarmak lortzea.\n🔍 ** Bilatzailea! Aurkitu zure ekitaldiak lasai.\n*☑️** Zereginak!** Ikusi zereginak egutegian zuzenean ezarritako datarekin.\n*🔈** Hizketaldiak!!** Bilera bat erreserbatzean, elkarrizketa gela asoziatu bat sortu, klik bakar batez.\n*📆** Hitzordua erreserbatu*** Bidali esteka bat pertsonei zurekin hitzordua erreserbatu ahal izateko [aplikazio hau erabiliz] (https://apps.nextcloud.com/apps/appointments)\n* 📎** Eranskinak! Gehitu, igo eta ikusi ekitaldien eranskinak.\n*🙈** Ez gara gurpila berrasmatzen ari!** Liburutegi handian oinarrituta  [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js] (https://github.com/mozilla-comm/ical.js) eta [full calendar] (https://github.com/fullcalendar/fullcalendar).",
    "Previous day" : "Aurreko eguna",
    "Previous week" : "Aurreko astea",
    "Previous year" : "Aurreko urtea",
    "Previous month" : "Aurreko hilabetea",
    "Next day" : "Hurrengo eguna",
    "Next week" : "Hurrengo astea",
    "Next year" : "Hurrengo urtea",
    "Next month" : "Hurrengo hilabetea",
    "Create new event" : "Sortu gertaera berria",
    "Event" : "Gertaera",
    "Today" : "Gaur",
    "Day" : "Eguna",
    "Week" : "Astea",
    "Month" : "Hilabetea",
    "Year" : "Urtea",
    "List" : "Zerrenda",
    "Appointment link was copied to clipboard" : "Hitzorduaren esteka arbelean kopiatu da",
    "Appointment link could not be copied to clipboard" : "Hitzorduaren esteka ezin izan da arbelean kopiatu",
    "Preview" : "Aurrebista",
    "Copy link" : "Kopiatu esteka",
    "Edit" : "Editatu",
    "Delete" : "Ezabatu",
    "Appointment schedules" : "Hitzorduen ordutegiak",
    "Create new" : "Sortu berria",
    "Disable calendar \"{calendar}\"" : "Desgaitu \"{calendar}\" egutegia",
    "Disable untitled calendar" : "Desgaitu izenbururik gabeko egutegia",
    "Enable calendar \"{calendar}\"" : "Gaitu \"{calendar}\" egutegia",
    "Enable untitled calendar" : "Gaitu izenbururik gabeko egutegia",
    "An error occurred, unable to change visibility of the calendar." : "Errore bat gertatu da, ezin da egutegiaren ikusgaitasuna aldatu.",
    "Untitled calendar" : "Izenik gabeko egutegia",
    "Shared with you by" : "Zurekin partekatuta honengatik:",
    "Edit and share calendar" : "Editatu eta partekatu egutegia",
    "Edit calendar" : "Editatu egutegia",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Egutegia partekatzea kenduko da segundo {countdown} barru","Egutegia partekatzea kenduko da {countdown} segundo barru"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Egutegia ezabatuko da segundo {countdown} barru","Egutegia ezabatuko da {countdown} segundo barru"],
    "An error occurred, unable to create the calendar." : "Errore bat gertatu da, ezin da egutegia sortu.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Sartu baliozko esteka bat (hauetako batekin hasi behar du: http://, https://, webcal:// edo webcals://)",
    "Calendars" : "Egutegiak",
    "Add new" : "Gehitu berria",
    "New calendar" : "Egutegi berria",
    "Name for new calendar" : "Egutegi berriaren izena",
    "Creating calendar …" : "Egutegia sortzen …",
    "New calendar with task list" : "Egutegi berria eginkizun-zerrendarekin",
    "New subscription from link (read-only)" : "Harpidetza berria estekatik (irakurtzeko soilik)",
    "Creating subscription …" : "Harpidetza sortzen ...",
    "Add public holiday calendar" : "Gehitu opor publikoen egutegia",
    "Add custom public calendar" : "Gehitu egutegi publiko pertsonalizatua",
    "Calendar link copied to clipboard." : "Egutegiko esteka arbelera kopiatu da.",
    "Calendar link could not be copied to clipboard." : "Ezin izan da egutegiko esteka arbelera kopiatu.",
    "Copy subscription link" : "Kopiatu harpidetza esteka",
    "Copying link …" : "Esteka kopiatzen …",
    "Copied link" : "Esteka kopiatuta",
    "Could not copy link" : "Ezin izan da esteka kopiatu",
    "Export" : "Esportatu",
    "Untitled item" : "Izen gabeko elementua",
    "Unknown calendar" : "Egutegi ezezaguna",
    "Could not load deleted calendars and objects" : "Ezin izan dira ezabatutako egutegi eta elementuak kargatu",
    "Could not delete calendar or event" : "Ezin izan da egutegi edo gertaera ezabatu",
    "Could not restore calendar or event" : "Ezin izan da egutegia edo gertaera berezarri",
    "Do you really want to empty the trash bin?" : "Ziur zaude zakarrontzia hustu nahi duzula?",
    "Empty trash bin" : "Hustu zakarrontzia",
    "Trash bin" : "Zakarrontzia",
    "Loading deleted items." : "Ezabatutako elementuak kargatzen.",
    "You do not have any deleted items." : "Ez duzu ezabatutako elementurik.",
    "Name" : "Izena",
    "Deleted" : "Ezabatuta",
    "Restore" : "Berrezarri",
    "Delete permanently" : "Ezabatu betirako",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Zakarrontziko elementuak egun {numDays} igaro ondoren ezabatzen dira","Zakarrontziko elementuak {numDays} egun igaro ondoren ezabatzen dira"],
    "Could not update calendar order." : "Ezin da egutegi-eskaera eguneratu.",
    "Shared calendars" : "Partekatutako egutegiak",
    "Deck" : "Deck",
    "Internal link" : "Barneko esteka",
    "A private link that can be used with external clients" : "Kanpoko bezeroengatik erabili ahal den esteka pribatua",
    "Copy internal link" : "Kopiatu barne-esteka",
    "An error occurred, unable to publish calendar." : "Errore bat gertatu da, ezin da egutegia argitaratu",
    "An error occurred, unable to send email." : "Errore bat gertatu da, ezin da posta elektronikoa bidali.",
    "Embed code copied to clipboard." : "Kapsulatze-kodea arbelera kopiatu da.",
    "Embed code could not be copied to clipboard." : "Ezin izan da kapsulatze-kodea arbelera kopiatu.",
    "Unpublishing calendar failed" : "Egutegia desargitaratzeak huts egin du",
    "Share link" : "Partekatu esteka",
    "Copy public link" : "Kopiatu esteka publikoa",
    "Send link to calendar via email" : "Bidali esteka egutegira posta elektroniko bidez",
    "Enter one address" : "Sartu helbide bat",
    "Sending email …" : "Posta elektronikoa bidaltzen …",
    "Copy embedding code" : "Kopiatu kapsulatze-kodea",
    "Copying code …" : "Kodea kopiatzen …",
    "Copied code" : "Kodea kopiatuta",
    "Could not copy code" : "Ezin izan da kodea kopiatu",
    "Delete share link" : "Ezabatu partekatze esteka",
    "Deleting share link …" : "Partekatze esteka ezabatzen  ...",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Lantaldea)",
    "An error occurred while unsharing the calendar." : "Errorea gertatu da egutegia partekatzeari uztean.",
    "An error occurred, unable to change the permission of the share." : "Errore bat gertatu da, ezin da partekatzearen baimena aldatu.",
    "Unshare with {displayName}" : "Utzi {displayName} erabiltzailearekin partekatzeari",
    "Share with users or groups" : "Partekatu erabiltzaile edo taldeekin",
    "No users or groups" : "Ez dago erabiltzaile edota talderik",
    "Failed to save calendar name and color" : "Ezin izan da egutegiaren izena eta kolorea gorde",
    "Calendar name …" : "Egutegiaren izena …",
    "Never show me as busy (set this calendar to transparent)" : "Ez erakutsi inoiz okupatuta nagoenik (ezarri egutegi hau garden gisa)",
    "Share calendar" : "Partekatu egutegia",
    "Unshare from me" : "Kendu nirekin partekatzea",
    "Save" : "Gorde",
    "No title" : "Izenbururik ez",
    "Are you sure you want to delete \"{title}\"?" : "Ziur zaude \"{title}\" ezabatu nahi duzula?",
    "Deleting proposal \"{title}\"" : "Ezabatze-proposamena \"{title}\"",
    "Successfully deleted proposal" : "Proposamena behar bezala ezabatu da",
    "Failed to delete proposal" : "Errorea proposamena ezabatzean",
    "Failed to retrieve proposals" : "Ezin izan da proposamenak berreskuratu",
    "Meeting proposals" : "Bilera proposamenak",
    "A configured email address is required to use meeting proposals" : "Konfiguratutako helbide elektronikoa beharrezkoa da bilera proposamenak erabiltzeko",
    "No active meeting proposals" : "Ez dago bilera proposamen aktiborik",
    "View" : "Ikusi",
    "Import calendars" : "Inportatu egutegiak",
    "Please select a calendar to import into …" : "Hautatu egutegia hona inportatzeko ...",
    "Filename" : "Fitxategi-izena",
    "Calendar to import into" : "Hona inportatzeko egutegia",
    "Cancel" : "Ezeztatu",
    "_Import calendar_::_Import calendars_" : ["Inportatu egutegia","Inportatu egutegiak"],
    "Select the default location for attachments" : "Hautatu eranskinen kokaleku lehenetsia",
    "Pick" : "Aukeratu",
    "Invalid location selected" : "Kokaleku baliogabea hautatu da",
    "Attachments folder successfully saved." : "Eranskinen karpeta behar bezala gorde da.",
    "Error on saving attachments folder." : "Errore bat gertatu da eranskinen karpeta gordetzean.",
    "Attachments folder" : "Eranskinen karpeta",
    "{filename} could not be parsed" : "{filename} ezin da analizatu",
    "No valid files found, aborting import" : "Ez da baliodun fitxategirik aurkitu, inportazioa bertan behera uzten",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["%n gertaera behar bezala inportatu dira","%n gertaera behar bezala inportatu dira"],
    "Import partially failed. Imported {accepted} out of {total}." : "Inportazioak huts egin du hein batean. Guztira {total} ziren, {accepted} inportatu dira.",
    "Automatic" : "Automatikoa",
    "Automatic ({timezone})" : "Automatikoa ({timezone})",
    "New setting was not saved successfully." : "Ezarpen berria ez da behar bezala gorde.",
    "Timezone" : "Ordu-zona",
    "Navigation" : "Nabigazioa",
    "Previous period" : "Aurreko aldia",
    "Next period" : "Hurrengo aldia",
    "Views" : "Ikuspegiak",
    "Day view" : "Egun ikuspegia",
    "Week view" : "Aste ikuspegia",
    "Month view" : "Hilabete ikuspegia",
    "Year view" : "Urte ikuspegia",
    "List view" : "Zerrenda ikuspegia",
    "Actions" : "Ekintzak",
    "Create event" : "Sortu gertaera",
    "Show shortcuts" : "Erakutsi lasterbideak",
    "Editor" : "Editorea",
    "Close editor" : "Itxi editorea",
    "Save edited event" : "Gorde editatutako gertaera",
    "Delete edited event" : "Ezabatu editatutako gertaera",
    "Duplicate event" : "Bikoiztu gertaera",
    "or" : "edo",
    "Calendar settings" : "Egutegiaren ezarpenak",
    "At event start" : "Gertaeraren hasieran",
    "No reminder" : "Gogorarazpenik ez",
    "Failed to save default calendar" : "Egutegi lehenetsia gordetzeak huts egin du",
    "General" : "Orokorra",
    "Appearance" : "Itxura",
    "Editing" : "Edizioa",
    "Default reminder" : "Gogorarazpen lehenetsia",
    "Files" : "Fitxategiak",
    "Appointment schedule successfully created" : "Hitzorduaren ordutegia ondo sortu da",
    "Appointment schedule successfully updated" : "Hitzorduaren ordutegia ondo eguneratu da",
    "_{duration} minute_::_{duration} minutes_" : ["minutu {duration}","{duration} minutu"],
    "0 minutes" : "0 minutu",
    "_{duration} hour_::_{duration} hours_" : ["ordu {duration}","{duration} ordu"],
    "_{duration} day_::_{duration} days_" : ["egun {duration}","{duration} egun"],
    "_{duration} week_::_{duration} weeks_" : ["aste {duration}","{duration} aste"],
    "_{duration} month_::_{duration} months_" : ["hilabete {duration}","{duration} hilabete"],
    "_{duration} year_::_{duration} years_" : ["urte {duration}","{duration} urte"],
    "To configure appointments, add your email address in personal settings." : "Hitzorduak konfiguratzeko, gehitu zure e-posta helbidea ezarpen pertsonaletan.",
    "Public – shown on the profile page" : "Publikoa – profil-orrian erakusten da",
    "Private – only accessible via secret link" : "Pribatua – esteka sekretu bidez soilik ikus daiteke",
    "Appointment schedule saved" : "Hitzorduen ordutegia gordeta",
    "Create appointment schedule" : "Sortu hitzorduaren ordutegia",
    "Edit appointment schedule" : "Editatu hitzorduaren ordutegia",
    "Update" : "Eguneratu",
    "Appointment name" : "Hitzorduaren izena:",
    "Location" : "Kokapena",
    "Create a Talk room" : "Sortu Talk gela bat",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Erreserbatutako hitzordu bakoitzeko esteka esklusibo bat sortuko da eta berrespen-mezu bidez bidaliko da",
    "Description" : "Deskribapena",
    "Visibility" : "Ikusgarritasuna",
    "Duration" : "Iraupena",
    "Increments" : "Gehikuntzak",
    "Additional calendars to check for conflicts" : "Gatazkak egiaztatzeko egutegi gehigarriak",
    "Pick time ranges where appointments are allowed" : "Aukeratu hitzorduetan onartzen diren denbora tarteak",
    "to" : "honi",
    "Delete slot" : "Ezabatu tartea",
    "No times set" : "Ez dago denborarik ezarrita",
    "Add" : "Gehitu",
    "Monday" : "Astelehena",
    "Tuesday" : "Asteartea",
    "Wednesday" : "Asteazkena",
    "Thursday" : "Osteguna",
    "Friday" : "Ostirala",
    "Saturday" : "Larunbata",
    "Sunday" : "Igandea",
    "Weekdays" : "Astegunak",
    "Add time before and after the event" : "Gehitu denbora gertaera baino lehen eta ostean",
    "Before the event" : "Gertaera baino lehen",
    "After the event" : "Gertarearen ostean",
    "Planning restrictions" : "Planifikatze murrizketak",
    "Minimum time before next available slot" : "Denbora minimoa hurrengo tarte eskuragarriarentzat",
    "Max slots per day" : "Tarte kopuru maximoa egunero",
    "Limit how far in the future appointments can be booked" : "Mugatu hitzorduak etorkizuneko zein puntura arte erreserba daitezkeen",
    "It seems a rate limit has been reached. Please try again later." : "Badirudi datu-mugara iritsi zarela. Mesedez, saiatu berriro geroago.",
    "Please confirm your reservation" : "Berretsi zure erreserba",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Mezu elektroniko bat bidali dizugu xehetasunekin. Mesedez, berretsi zure hitzordua mezu elektronikoaren esteka erabiliz. Orrialde hau itxi dezakezu orain.",
    "Your name" : "Zure izena",
    "Your email address" : "Zure e-posta",
    "Please share anything that will help prepare for our meeting" : "Mesedez, partekatu gure bilera prestatzen lagunduko duen edozer",
    "Could not book the appointment. Please try again later or contact the organizer." : "Ezin izan da hitzordua erreserbatu. Saiatu berriro geroago edo jarri harremanetan administratzalearekin.",
    "Back" : "Itzuli",
    "Book appointment" : "Erreserbatu hitzordua",
    "Error fetching Talk conversations." : "Errorea Hizketaldiaken elkarrizketak eskuratzean.",
    "Conversation does not have a valid URL." : "Elkarrizketak ez dauka baliozko URLrik.",
    "Successfully added Talk conversation link to location." : "Hizketaldiaken elkarrizketa arrakastaz lotu da kokapenarekin.",
    "Successfully added Talk conversation link to description." : "Hizketaldiaken elkarrizketa arrakastaz lotu da deskribapenarekin.",
    "Failed to apply Talk room." : "Errorea Hizketaldi-gela aplikatzean.",
    "Error creating Talk conversation" : "Errorea Hizketaldiak elkarrizketa sortzean",
    "Select a Talk Room" : "Hautatu Hizketaldiak gela bat",
    "Select conversation" : "Hautatu elkarrizketa",
    "on" : "noiz",
    "at" : "non",
    "before at" : "lehenago hemen",
    "Notification" : "Jakinarazpena",
    "Email" : "Mezu elektronikoa",
    "Audio notification" : "Audio jakinarazpena",
    "Other notification" : "Bestelako jakinarazpena",
    "Relative to event" : "Gertaerarekiko",
    "On date" : "Epean",
    "Edit time" : "Editatu ordua",
    "Save time" : "Gorde ordua",
    "Remove reminder" : "Kendu gogorarazpena",
    "Add reminder" : "Gehitu gogorarazpena",
    "seconds" : "duela segundu batzuk",
    "minutes" : "minutu",
    "hours" : "ordu",
    "days" : "egun",
    "weeks" : "aste",
    "Choose a file to add as attachment" : "Aukeratu fitxategia eranskin gisa gehitzeko",
    "Choose a file to share as a link" : "Aukeratu fitxategi bat esteka bezala partekatzeko",
    "Attachment {name} already exist!" : "Dagoeneko existitzen da {name} eranskina!",
    "Could not upload attachment(s)" : "Ezinezkoa izan da eranskina(k) igotzea",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Hona nabigatzera zoaz:.{host}.  Ziur aurrera egin nahi duzula? Esteka: {link}",
    "Proceed" : "Jarraitu",
    "No attachments" : "Eranskinik ez",
    "Add from Files" : "Gehitu Fitxategietatik",
    "Upload from device" : "Igo gailutik",
    "Delete file" : "Ezabatu fitxategia",
    "Confirmation" : "Berrespena",
    "_{count} attachment_::_{count} attachments_" : ["Eranskin {count}","{count} eranskin"],
    "Suggested" : "Iradokituta",
    "Available" : "Erabilgarri",
    "Invitation accepted" : "Gonbidapena onartuta",
    "Accepted {organizerName}'s invitation" : "{organizerName}(r)en gonbidapena onartuta",
    "Participation marked as tentative" : "Partaidetza behin-behineko gisa markatu da",
    "Invitation is delegated" : "Gonbidapena eskuordetuta dago",
    "Not available" : "Ez dago erabilgarri",
    "Invitation declined" : "Gonbidapena ukatuta",
    "Declined {organizerName}'s invitation" : "{organizerName}(r)en gonbidapena ukatuta",
    "Awaiting response" : "Erantzunaren zain",
    "Checking availability" : "Erabilgarritasuna egiaztatzen",
    "Has not responded to {organizerName}'s invitation yet" : "Oraindik ez dio {organizerName} erabiltzailearen gonbidapenari erantzun",
    "chairperson" : "mahaiburua",
    "required participant" : "beharrezko partaidea",
    "non-participant" : "ez da partaidea",
    "optional participant" : "hautazko partaidea",
    "{organizer} (organizer)" : "{organizer} (kudeatzailea)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Availability of attendees, resources and rooms" : "Partaide, baliabide eta gelen eskuragarritasuna",
    "Suggestion accepted" : "Iradokizuna onartuta",
    "Legend" : "Legenda",
    "Out of office" : "Bulegotik kanpo",
    "Attendees:" : "Parte-hartzaileak:",
    "Done" : "Egina",
    "Search room" : "Bilatu gela",
    "Room name" : "Gelaren izena",
    "Check room availability" : "Egiaztatu gelaren eskuragarritasuna",
    "Free" : "Libre",
    "Busy (tentative)" : "Lanpetuta (behin-behinean)",
    "Busy" : "Lanpetua",
    "Unknown" : "Ezezaguna",
    "Find a time" : "Bilatu noiz",
    "The invitation has been accepted successfully." : "Gonbidapena behar bezala onartu da.",
    "Failed to accept the invitation." : "Huts egin du gonbidapena onartzen.",
    "The invitation has been declined successfully." : "Gonbidapena behar bezala baztertu da.",
    "Failed to decline the invitation." : "Huts egin du gonbidapena baztertzen.",
    "Your participation has been marked as tentative." : "Zure parte hartzea behin-behineko gisa markatu da.",
    "Failed to set the participation status to tentative." : "Huts egin du zure parte hartzea behin-behineko gisa ezartzen.",
    "Accept" : "Onartu",
    "Decline" : "Uko egin",
    "Tentative" : "Behin behinekoa",
    "No attendees yet" : "Partaiderik ez oraindik",
    "Attendees" : "Partaideak",
    "Remove group" : "Ezabatu taldea",
    "Remove attendee" : "Kendu partaidea",
    "Request reply" : "Eskaera erantzuna",
    "Chairperson" : "Mahaiburua",
    "Required participant" : "Beharrezko partaidea",
    "Optional participant" : "Hautazko partaidea",
    "Non-participant" : "Ez da partaidea",
    "_%n member_::_%n members_" : ["kide %n","%n kide"],
    "No match found" : "Ez da emaitzarik aurkitu",
    "Note that members of circles get invited but are not synced yet." : "Kontuan izan zirkuluetako kideek gonbidapena jasotzen dutela baina ez direla oraindik sinkronizatzen.",
    "Note that members of contact groups get invited but are not synced yet." : "Kontuan izan kontaktu taldeetako kideek gonbidapena jasotzen dutela baina ez direla oraindik sinkronizatzen.",
    "(organizer)" : "(antolatzailea)",
    "Make {label} the organizer" : "Egin {label} antolatzaile",
    "Make {label} the organizer and attend" : "Egin {label} antolatzaile eta parte-hartzaile",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Gonbidapenak bidali eta erantzunak kudeatzeko, [linkopen] gehitu zure posta helbidea ezarpen pertsonaletan[linkclose].",
    "Remove color" : "Kendu kolorea",
    "Event title" : "Gertaeraren izenburua",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Ezin da egun osoko ezarpena aldatu errepikapen multzo baten parte diren gertaeretarako. ",
    "From" : "Nork",
    "To" : "Nori",
    "Repeat" : "Errepikatu",
    "_time_::_times_" : ["aldiz","aldiz"],
    "never" : "inoiz ez",
    "on date" : "epean",
    "after" : "gero",
    "End repeat" : "Amaitu errepikapena",
    "Select to end repeat" : "Hautatu errepikapena amaitzeko",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Ekitaldi hau errepikapen multzo bateko errepikapen salbuespena da. Ezin diozu errepikapen-araurik gehitu.",
    "first" : "lehena",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Errepikapen arauan egindako aldaketak gertaera honentzat eta etorkizunekoentzat bakarrik aplikatuko dira.",
    "Repeat every" : "Errepikatu zenbatero",
    "By day of the month" : "Hileko egunaren arabera",
    "On the" : "Honetan",
    "_day_::_days_" : ["egun","egun"],
    "_week_::_weeks_" : ["aste","aste"],
    "_month_::_months_" : ["hilabete","hilabete"],
    "_year_::_years_" : ["urte","urte"],
    "weekday" : "asteguna",
    "weekend day" : "asteburuko eguna",
    "Does not repeat" : "Ez errepikatu",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Gertaera honen errepikapen definizioa ez du guztiz onartzen Nextcloud-ek. Errepikapen aukerak editatzen badituzu, errepikapen batzuk galdu litezke.",
    "No rooms or resources yet" : "Oraindik ez dago gelarik edo baliabiderik",
    "Resources" : "Baliabideak",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} eserleku ","{seatingCapacity}  eserleku "],
    "Add resource" : "Gehitu baliabidea",
    "Has a projector" : "Proiektore bat dauka",
    "Has a whiteboard" : "Arbel zuria dauka",
    "Wheelchair accessible" : "Gurpil-aulkientzako sarbidea",
    "Remove resource" : "Kendu baliabidea",
    "Search for resources or rooms" : "Bilatu baliabideak edo gelak",
    "available" : "erabilgarri",
    "unavailable" : "ez erabilgarri",
    "Show all rooms" : "Erakutsi gela guztiak",
    "Projector" : "Proiektorea",
    "Whiteboard" : "Arbel zuria",
    "Room type" : "Gela mota",
    "Any" : "Edozein",
    "Minimum seating capacity" : "Gutxieneko eserleku kopurua",
    "More details" : "Xehetasun gehiago",
    "Update this and all future" : "Eguneratu hau eta etorkizuneko guztiak",
    "Update this occurrence" : "Eguneratu gertaera hau",
    "Public calendar does not exist" : "Egutegi publikoa ez da existitzen",
    "Maybe the share was deleted or has expired?" : "Agian, partekatutakoa ezabatu egin da edo iraungita geratu da?",
    "Remove participant" : "Partehartzailea borratu",
    "Yes" : "Bai",
    "No" : "Ez",
    "Maybe" : "Agian",
    "None" : "Bat ere ez",
    "Create" : "Sortu",
    "from {formattedDate}" : "{formattedDate}tik ",
    "to {formattedDate}" : "{formattedDate} arte ",
    "on {formattedDate}" : "{formattedDate}an",
    "from {formattedDate} at {formattedTime}" : "{formattedDate}ko {formattedTime}tik",
    "to {formattedDate} at {formattedTime}" : "{formattedDate}ko {formattedTime} arte",
    "on {formattedDate} at {formattedTime}" : "{formattedDate}ko {formattedTime}etan",
    "{formattedDate} at {formattedTime}" : "{formattedDate}ko {formattedTime}etan",
    "Please enter a valid date" : "Sartu baliozko data",
    "Please enter a valid date and time" : "Sartu baliozko data eta ordua",
    "Select a time zone" : "Hautatu ordu-zona",
    "Please select a time zone:" : "Aukeratu ordu-zona bat:",
    "Pick a time" : "Aukeratu ordua",
    "Pick a date" : "Aukeratu eguna",
    "Type to search time zone" : "Idatzi ordu-zona bilatzeko",
    "Global" : "Orokorra",
    "Holidays in {region}" : "Oporrak {region}(e)n",
    "An error occurred, unable to read public calendars." : "Errorea gertatu da, ezin izan dira egutegi publikoak irakurri.",
    "An error occurred, unable to subscribe to calendar." : "Errore bat gertatu da, ezin izan da egutegira harpidetu.",
    "Public holiday calendars" : "Opor publikoen egutegiak",
    "Public calendars" : "Egutegi publikoak",
    "No valid public calendars configured" : "Ez dago baliozko egutegi publikorik konfiguratuta",
    "Speak to the server administrator to resolve this issue." : "Hitz egin zerbitzariko administratzailearekin arazo hau konpontzeko.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Jaiegun egutegi publikoak Thunderbird-ek hornitzen ditu. Egutegiaren datuak {website}(e)tik deskargatuko dira.",
    "By {authors}" : "{authors} egina",
    "Subscribed" : "Harpidetua",
    "Subscribe" : "Harpidetu",
    "Could not fetch slots" : "Ezin izan dira plazak eskuratu",
    "Select a date" : "Hautatu data bat",
    "Select slot" : "Hautatu tartea",
    "No slots available" : "Ez dago tarterik eskuragarri",
    "The slot for your appointment has been confirmed" : "Zure hitzorduaren tartea berretsi da",
    "Appointment Details:" : "Hitzorduaren xehetasunak:",
    "Time:" : "Noiz:",
    "Booked for:" : "Honetarako erreserbatuta:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Eskerrik asko. {startDate}tik {endDate} arteko erreserba berretsi da.",
    "Book another appointment:" : "Erreserbatu beste hitzordu bat",
    "See all available slots" : "Ikusi eskuragarri dauden tarte guztiak",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "{startDate}tik {endDate} arteko zure hitzorduaren tartea ez dago jada erabilgarri.",
    "Please book a different slot:" : "Mesedez erreserbatu beste tarte bat:",
    "Book an appointment with {name}" : "Hitzordu bat erreserbatu {name}(r)ekin",
    "No public appointments found for {name}" : "Ez da hitzordu publikorik aurkitu {name}rentzat",
    "Personal" : "Pertsonala",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Ordu-eremu detekzio automatikoak zehaztu du zure ordu-eremua UTC dela. \nHau seguru aski zure nabigatzailearen segurtasun neurrien ondorio da.\nZehaztu ezazu zure ordu-eremua eskuz egutegiaren ezarpenetan.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Ezarrita daukazun ordu-eremua ({timezoneId}) ez da aurkitu. UTC-ra itzultzen.\nMesedez, aldatu zure ordu-eremua ezarpenetan eta eman arazoaren berri.",
    "Edit event" : "Editatu gertaera",
    "Event does not exist" : "Ez dago gertaera hori",
    "Duplicate" : "Bikoiztu",
    "Delete this occurrence" : "Ezabatu gertaera hau",
    "Delete this and all future" : "Ezabatu hau eta etorkizunekoak",
    "All day" : "Egun osoa",
    "Managing shared access" : "Sarbide partekatua kudeatzea",
    "Deny access" : "Ukatu sarbidea",
    "Invite" : "Gonbidatu",
    "_User requires access to your file_::_Users require access to your file_" : ["Erabiltzaileek zure fitxategirako sarbidea behar dute","Erabiltzaileek zure fitxategietarako sarbidea behar dute"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Sarbide partekatua behar duen eranskina","Sarbide partekatua behar duten eranskinak"],
    "Untitled event" : "Izenik gabeko gertaera",
    "Close" : "Itxi",
    "Selected" : "Hautatua",
    "Title" : "Izenburua",
    "30 min" : "30 min",
    "Participants" : "Parte hartzaileak",
    "Submit" : "Bidali",
    "Subscribe to {name}" : "Harpidetu {name}",
    "Export {name}" : "Esportatu {name}",
    "Anniversary" : "Urtebetetzea",
    "Appointment" : "Hitzordua",
    "Business" : "Lana",
    "Education" : "Hezkuntza",
    "Holiday" : "Jaieguna",
    "Meeting" : "Bilera",
    "Miscellaneous" : "Askotarikoa",
    "Non-working hours" : "Laneko orduetatik kanpo",
    "Not in office" : "Ez nago bulegoan",
    "Phone call" : "Telefono-deia",
    "Sick day" : "Gaixorik",
    "Special occasion" : "Gertaera berezia",
    "Travel" : "Bidaian",
    "Vacation" : "Oporretan",
    "Midnight on the day the event starts" : "Gauerdian gertaera hasten den egunean",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["Egun %n gertaera hasi baino lehen {formattedHourMinute}(e)tan","%n egun gertaera hasi baino lehen {formattedHourMinute}etan"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : [" aste %n gertaera hasi baino lehen {formattedHourMinute}(e)tan","%n aste gertaera hasi baino lehen {formattedHourMinute}etan"],
    "on the day of the event at {formattedHourMinute}" : "Gertaeraren egunean {formattedHourMinute}etan",
    "at the event's start" : "gertaera hasieran",
    "at the event's end" : "gertaera amaieran",
    "{time} before the event starts" : "gertaera hasi baino {time} lehenago",
    "{time} before the event ends" : "gertaera amaitu baino {time} lehenago",
    "{time} after the event starts" : "gertaera hasi baino {time} geroago",
    "{time} after the event ends" : "gertaera amaitu baino {time} geroago",
    "on {time}" : "{time}etan",
    "on {time} ({timezoneId})" : "{time}etan ({timezoneId})",
    "Week {number} of {year}" : "{year}ko {number}. astea",
    "Daily" : "Egunero",
    "Weekly" : "Astero",
    "Monthly" : "Hilabetero",
    "Yearly" : "Urtero",
    "_Every %n day_::_Every %n days_" : ["Egunero","%n egunetik behin"],
    "_Every %n week_::_Every %n weeks_" : ["Astero","%n astetik behin"],
    "_Every %n month_::_Every %n months_" : ["Hilabetero","%n hilabetetik behin"],
    "_Every %n year_::_Every %n years_" : ["Urtero","%n urtetik behin"],
    "_on {weekday}_::_on {weekdays}_" : ["{weekday}","{weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["{dayOfMonthList} egunean","{dayOfMonthList} egunetan"],
    "on the {ordinalNumber} {byDaySet}" : "{ordinalNumber}. {byDaySet}an",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "{monthNames}ko {ordinalNumber}. {byDaySet}an",
    "until {untilDate}" : "{untilDate} arte",
    "_%n time_::_%n times_" : ["%n","%naldiz"],
    "second" : "bigarrean",
    "third" : "hirugarrena",
    "fourth" : "laugarrena",
    "fifth" : "bosgarrena",
    "second to last" : "bigarren azkena",
    "last" : "azkena",
    "Untitled task" : "Izenik gabeko zeregina",
    "Please ask your administrator to enable the Tasks App." : "Mesedez eskatu administratzaileari Tasks aplikazioa gaitu dezan.",
    "W" : "A. ",
    "%n more" : "%n gehiago",
    "No events to display" : "Ez dago bistaratzeko gertaerarik",
    "_+%n more_::_+%n more_" : ["+ %n","+ %n"],
    "No events" : "Ez dago gertaerarik",
    "Create a new event or change the visible time-range" : "Sortu gertaera berria edo aldatu ikusgai dagoen epea",
    "Failed to save event" : "Gertaera gordetzeak huts egin du",
    "It might have been deleted, or there was a typo in a link" : "Baliteke ezabatua izana, edo estekaren batean akatsa egotea.",
    "It might have been deleted, or there was a typo in the link" : "Baliteke ezabatua izana, edo estekan akatsa egotea.",
    "Meeting room" : "Bilera gela",
    "Lecture hall" : "Konferentzia-gela",
    "Seminar room" : "Mintegia",
    "Other" : "Bestelakoa",
    "When shared show" : "Partekatzean erakutsi",
    "When shared show full event" : "Partekatzean erakutsi gertaera osoa",
    "When shared show only busy" : "Partekatzean okupatua bezala erakutsi soilik",
    "When shared hide this event" : "Partekatzean ezkutatu gertaera hau",
    "Add a location" : "Gehitu kokapen bat",
    "Status" : "Egoera",
    "Confirmed" : "Berretsita",
    "Canceled" : "Utzita",
    "Confirmation about the overall status of the event." : "Baieztapena gertaeraren egoera orokorrari buruz.",
    "Show as" : "Erakutsi honela",
    "Take this event into account when calculating free-busy information." : "Kontuan izan gertaera hau libre-lanpetuta informazio kalkuluetan.",
    "Categories" : "Kategoriak",
    "Categories help you to structure and organize your events." : "Kategoriak lagungarri zaizkizu gertaerak egituratu eta antolatzeko.",
    "Search or add categories" : "Bilatu edo gehitu kategoriak",
    "Add this as a new category" : "Gehitu hau kategoria berri bezala",
    "Custom color" : "Kolore pertsonalizatua",
    "Special color of this event. Overrides the calendar-color." : "Gertaera honen kolorea berezia da. Egutegi kolorea baliogabetzen du.",
    "Error while sharing file" : "Errorea fitxategia partekatzean",
    "Error while sharing file with user" : "Errorea fitxategia erabiltzailearekin partekatzean",
    "Error creating a folder {folder}" : "Errorea {karpeta} karpeta bat sortzean",
    "Attachment {fileName} already exists!" : "{fileName} eranskina dagoeneko badago!",
    "An error occurred during getting file information" : "Errore bat gertatu da fitxategiaren informazioa eskuratzean",
    "An error occurred, unable to delete the calendar." : "Errore bat gertatu da, ezin da egutegia ezabatu.",
    "Imported {filename}" : "{filename} inportatuta",
    "This is an event reminder." : "Hau gertaera baten gogorarazpena da.",
    "Error while parsing a PROPFIND error" : "Errore bat gertatu da PROPFIND errore bat analizatzean",
    "Appointment not found" : "Ez da hitzordua aurkitu",
    "User not found" : "Ez da erabiltzailea aurkitu",
    "Hidden" : "Ezkutuan",
    "can edit" : "editatu dezake",
    "Calendar name …" : "Egutegiaren izena ...",
    "Default attachments location" : "Eranskinen kokaleku lehenetsia",
    "Automatic ({detected})" : "Automatikoa ({detected})",
    "Shortcut overview" : "Lasterbideen informazio orokorra",
    "CalDAV link copied to clipboard." : "CalDAV esteka arbelera kopiatu da.",
    "CalDAV link could not be copied to clipboard." : "Ezin izan da CalDAV helbidea arbelera kopiatu.",
    "Enable birthday calendar" : "Gaitu urtebetetzeen egutegia",
    "Show tasks in calendar" : "Erakutsi zereginak egutegian",
    "Enable simplified editor" : "Gaitu editore sinplifikatua",
    "Limit the number of events displayed in the monthly view" : "Mugatu hileroko ikuspegian bistaratzen diren gertaeren kopurua",
    "Show weekends" : "Erakutsi asteburuak",
    "Show week numbers" : "Erakutsi aste zenbakiak",
    "Time increments" : " \nDenbora-gehikuntzak",
    "Default calendar for incoming invitations" : "Jasotako gonbidapenetarako egutegi lehenetsia",
    "Copy primary CalDAV address" : "Kopiatu CalDAV helbide nagusia",
    "Copy iOS/macOS CalDAV address" : "Kopiatu iOS/macOS CalDAV helbidea",
    "Personal availability settings" : "Eskuragarritasun pertsonalaren ezarpenak",
    "Show keyboard shortcuts" : "Erakutsi teklatuaren lasterbideak",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} gonbidatuta, {confirmedCount} berretsita",
    "Successfully appended link to talk room to location." : "Ondo erantsi zaio esteka hizketa-gelaren kokalekuari.",
    "Successfully appended link to talk room to description." : "Ondo erantsi zaio esteka hizketa gelaren deskribapenari.",
    "Error creating Talk room" : "Errorea Talk gela sortzean",
    "_%n more guest_::_%n more guests_" : ["gonbidatu gehiago %n","%n gonbidatu gehiago"],
    "The visibility of this event in shared calendars." : "Gertaera honen ikusgarritasuna egutegi partekatuetan"
},
"nplurals=2; plural=(n != 1);");
