OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "La direición de corréu electrónicu apurrida ye mui llonga",
    "User-Session unexpectedly expired" : "La sesión del usuariu caducó inesperadamente",
    "Provided email-address is not valid" : "La direición de corréu electrónicu apurrida nun ye válida",
    "%s has published the calendar »%s«" : "%s espublizó'l calendariu «%s»",
    "Unexpected error sending email. Please contact your administrator." : "Prodúxose un error inesperáu al unviar el mensaxe. Ponte en contautu col alministrador.",
    "Successfully sent email to %1$s" : "El mensaxe unvióse a %1$s correutamente",
    "Hello," : "Hola,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Queremos informate que %s espublizó'l calendariu «%s».",
    "Open »%s«" : "Abrir «%s»",
    "Cheers!" : "¡Saludos!",
    "Upcoming events" : "Eventos próximos",
    "No more events today" : "Nun hai más eventos pa güei",
    "No upcoming events" : "Nun hai eventos próximos",
    "More events" : "Más eventos",
    "%1$s with %2$s" : "%1$s con %2$s",
    "Calendar" : "Calendariu",
    "New booking {booking}" : "Reserva nueva «{booking}»",
    "Appointments" : "Cites",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Confirm" : "Confirmar",
    "Description:" : "Descripción:",
    "Date:" : "Data:",
    "You will receive a link with the confirmation email" : "Vas recibir un enllaz col mensaxe de confirmación",
    "Where:" : "Ónde:",
    "Comment:" : "Comentariu:",
    "Location:" : "Llugar:",
    "Previous day" : "Día anterior",
    "Previous week" : "Selmana pasada",
    "Previous year" : "Añu pasáu",
    "Previous month" : "Mes pasáu",
    "Next day" : "Día siguiente",
    "Next week" : "La selmana que vien",
    "Next year" : "Añu siguiente",
    "Next month" : "Mes siguiente",
    "Create new event" : "Crear un eventu",
    "Event" : "Eventu",
    "Today" : "Güei",
    "Day" : "Día",
    "Week" : "Selmana",
    "Month" : "Mes",
    "Year" : "Añu",
    "List" : "Llista",
    "Preview" : "Previsualizar",
    "Copy link" : "Copiar l'enllaz",
    "Edit" : "Editar",
    "Delete" : "Desaniciar",
    "Disable calendar \"{calendar}\"" : "Desactivar el calendariu «{calendar}»",
    "Disable untitled calendar" : "Desactivar el calendariu ensin títulu",
    "Enable calendar \"{calendar}\"" : "¿Quies activar el calendariu «{calendar}»?",
    "Enable untitled calendar" : "Activar el calendariu ensin títulu",
    "An error occurred, unable to change visibility of the calendar." : "Prodúxose un error, nun ye posible camudar la visibilidá del calendariu.",
    "Untitled calendar" : "Calendariu ensin títulu",
    "Edit and share calendar" : "Editar y comaprtir el calendariu",
    "Edit calendar" : "Editar el calendariu",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Va dexar de compartise'l calendariu en {countdown} segundu","Va dexar de compartise'l calendariu en {countdown} segundos"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Va desaniciase'l calendariu en {countdown} segundu","Va desaniciase'l calendariu en {countdown} segundos"],
    "An error occurred, unable to create the calendar." : "Prodúxose un error, nun ye posible crear el calendariu.",
    "Calendars" : "Calendarios",
    "New calendar" : "Calendariu nuevu",
    "Name for new calendar" : "Nome del calendariu nuevu",
    "Creating calendar …" : "Creando'l calendariu…",
    "Creating subscription …" : "Creando la soscripción…",
    "Calendar link copied to clipboard." : "L'enllaz del calendariu copióse nel cartafueyu.",
    "Calendar link could not be copied to clipboard." : "L'enllaz del calendariu nun se pudo copiar nel cartafueyu.",
    "Copy subscription link" : "Copiar l'enllaz de soscripción",
    "Copying link …" : "Copiando l'enllaz …",
    "Copied link" : "L'enllaz copióse",
    "Could not copy link" : "Nun se pudo copiar l'enllaz",
    "Export" : "Esportar",
    "Untitled item" : "Elementu ensin nome",
    "Unknown calendar" : "Calendariu desconocíu",
    "Could not load deleted calendars and objects" : "Nun se pudieron desaniciar los calendarios y los oxetos",
    "Could not delete calendar or event" : "Nun se pudo desaniciar el calendariu o l'eventu",
    "Could not restore calendar or event" : "Nun se pudo restaurar el calendariu o l'eventu",
    "Do you really want to empty the trash bin?" : "¿De xuru que quies balerar la papelera de reciclaxe?",
    "Empty trash bin" : "Balerar la papelera",
    "Trash bin" : "Papelera",
    "Loading deleted items." : "Cargando los elementos desaniciaos.",
    "You do not have any deleted items." : "Nun tienes nengún elementu desaniciáu.",
    "Name" : "Nome",
    "Deleted" : "Desanicióse",
    "Restore" : "Restaurar",
    "Delete permanently" : "Desaniciar permanentemente",
    "Could not update calendar order." : "Nun se pudo anovar l'orde del calendariu.",
    "Deck" : "Tarxeteru",
    "Internal link" : "Enllaz internu",
    "A private link that can be used with external clients" : "Un enllaz priváu que se pue usar con veceros esternos",
    "Copy internal link" : "Copiar l'enllaz internu",
    "An error occurred, unable to publish calendar." : "Prodúxose un error, nun ye posible espublizar el calendariu.",
    "An error occurred, unable to send email." : "Prodúxose un error, nun ye posible unviar el mensaxe.",
    "Embed code copied to clipboard." : "El códigu incrustáu copióse nel cartafueyu.",
    "Embed code could not be copied to clipboard." : "El códigu incrustáu nun se pudo copiar nel cartafueyu.",
    "Share link" : "Compartir l'enllaz",
    "Copy public link" : "Copiar l'enllaz públicu",
    "Send link to calendar via email" : "Unviar l'enllaz del calendariu per corréu electrónicu",
    "Enter one address" : "Introduz una direción",
    "Sending email …" : "Unviando'l mensaxe…",
    "Copy embedding code" : "Copiar el códigu pa empotrar",
    "Copying code …" : "Copiando'l códigu …",
    "Copied code" : "Copióse'l códigu",
    "Could not copy code" : "Nun se pudo copiar el códigu",
    "Delete share link" : "Desaniciar esti enllaz d'usu compartíu",
    "Deleting share link …" : "Desaniciando l'enllaz d'usu compartíu…",
    "An error occurred while unsharing the calendar." : "Prodúxose un error mentanto se dexaba de compartir el calendariu.",
    "An error occurred, unable to change the permission of the share." : "Prodúxose un error, nun ye posible camudar el permisu del elementu compartíu.",
    "Unshare with {displayName}" : "Dexar de compartir con {displayName}",
    "Share with users or groups" : "Compartir con usuarios o grupos",
    "No users or groups" : "Nun hai nengún usuariu nin grupu",
    "Failed to save calendar name and color" : "Nun se pue guardar el nome y el color del calendariu",
    "Share calendar" : "Compartir el calendariu",
    "Save" : "Guardar",
    "View" : "Ver",
    "Import calendars" : "Importar calendarios",
    "Please select a calendar to import into …" : "Seleiciona un calendariu al qu'importar …",
    "Filename" : "Nome del ficheru",
    "Cancel" : "Encaboxar",
    "Invalid location selected" : "Seleicionóse una llocalización inválida",
    "Automatic" : "Automáticu",
    "Navigation" : "Navegación",
    "Previous period" : "Periodu anterior",
    "Next period" : "Periodu siguiente",
    "Views" : "Vistes",
    "Day view" : "Vista de díes",
    "Week view" : "Vista de selmanes",
    "Month view" : "Vista de meses",
    "Year view" : "Vista d'años",
    "List view" : "Vista de llista",
    "Actions" : "Aiciones",
    "Create event" : "Crear un eventu",
    "Show shortcuts" : "Amosar los atayos",
    "Editor" : "Editor",
    "Close editor" : "Zarrar l'editor",
    "Save edited event" : "Guardar l'eventu editáu",
    "Delete edited event" : "Desaniciar l'eventu desaniciáu",
    "Duplicate event" : "Duplicar l'eventu",
    "or" : "o",
    "Calendar settings" : "Configuración del calendariu",
    "No reminder" : "Nun hai nengún recordatoriu",
    "Failed to save default calendar" : "Nun se pue guardar el calendariu predetermináu",
    "General" : "Xeneral",
    "Appearance" : "Aspeutu",
    "Default reminder" : "Recordatoriu predetermináu",
    "Files" : "Ficheros",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minutu","{duration} minutos"],
    "0 minutes" : "0 minutos",
    "_{duration} hour_::_{duration} hours_" : ["{duration} hora","{duration} hores"],
    "_{duration} day_::_{duration} days_" : ["{duration} día","{duration} díes"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} selmana","{duration} selmanes"],
    "_{duration} month_::_{duration} months_" : ["{duration} mes","{duration} meses"],
    "_{duration} year_::_{duration} years_" : ["{duration} añu","{duration} años"],
    "Update" : "Anovar",
    "Location" : "Llocalización",
    "Create a Talk room" : "Crear una sala de Talk",
    "Description" : "Descripción",
    "Visibility" : "Visibilidá",
    "Duration" : "Duración",
    "to" : "pa",
    "Delete slot" : "Desaniciar la ralura",
    "Add" : "Amestar",
    "Monday" : "Llunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Xueves",
    "Friday" : "Vienres",
    "Saturday" : "Sábadu",
    "Sunday" : "Domingu",
    "Weekdays" : "Díes de la selmana",
    "Your email address" : "La to direición de corréu electrónicu",
    "Back" : "Atrás",
    "Notification" : "Avisu",
    "Email" : "Corréu electrónicu",
    "Audio notification" : "Avisu d'audiu",
    "Other notification" : "Otru avisu",
    "Edit time" : "Editar la hora",
    "Save time" : "Guardar la hora",
    "Remove reminder" : "Quitar el recordatoriu",
    "seconds" : "segundos",
    "minutes" : "minutos",
    "hours" : "Hores",
    "days" : "díes",
    "weeks" : "selmanes",
    "Delete file" : "Desaniciar el ficheru",
    "Confirmation" : "Confirmación",
    "Available" : "Disponible",
    "Invitation accepted" : "Invitación aceptada",
    "Not available" : "Nun ta disponible",
    "Invitation declined" : "Invitación refugada",
    "Awaiting response" : "Esperando pola rempuesta",
    "Checking availability" : "Comprobando la disponibilidá",
    "Has not responded to {organizerName}'s invitation yet" : "Nun respondió a la invitación de: {organizerName}",
    "Suggestion accepted" : "Suxerencia aceptada",
    "Legend" : "Lleenda",
    "Out of office" : "Fuera de la oficina",
    "Attendees:" : "Asistentes:",
    "Done" : "Fecho",
    "Room name" : "Nome de la sala",
    "Busy" : "Ocupáu",
    "Find a time" : "Atopar una hora",
    "The invitation has been accepted successfully." : "La invitación aceptóse correutamente.",
    "Failed to accept the invitation." : "Nun se pue aceptar la invitación",
    "The invitation has been declined successfully." : "La invitación refugóse correutamente.",
    "Failed to decline the invitation." : "Nun se pue refugar la invitación",
    "Your participation has been marked as tentative." : "La to participación marcóse como provisional.",
    "Failed to set the participation status to tentative." : "Nun se pudo afitar l'estáu de la participación a provisional",
    "Accept" : "Aceptar",
    "Decline" : "Refugar",
    "Tentative" : "Provisional",
    "No attendees yet" : "Nun hai nengún asistente",
    "Attendees" : "Asistentes",
    "Remove group" : "Quitar el grupu",
    "_%n member_::_%n members_" : ["%n miembru","%n miembros"],
    "No match found" : "Nun s'atopó nenguna coincidencia",
    "Remove color" : "Quitar el color",
    "Event title" : "Títulu del eventu",
    "From" : "De",
    "To" : "Pa",
    "Repeat" : "Repitir",
    "never" : "enxamás",
    "first" : "primer",
    "_day_::_days_" : ["día","díes"],
    "_week_::_weeks_" : ["selmana","selmanes"],
    "_month_::_months_" : ["mes","meses"],
    "_year_::_years_" : ["añu","años"],
    "Resources" : "Recursos",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} asientu","{seatingCapacity} asientos"],
    "Has a projector" : "Tien proyeutor",
    "Has a whiteboard" : "Tien pizarra",
    "Projector" : "Proyeutor",
    "Whiteboard" : "Pizarra",
    "More details" : "Mas detalles",
    "Yes" : "Sí",
    "No" : "Non",
    "None" : "Nada",
    "Create" : "Crear",
    "Please enter a valid date" : "Introduz una data válida",
    "Pick a date" : "Escueyi una data",
    "Global" : "Global",
    "An error occurred, unable to read public calendars." : "Prodúxose un error, nun ye posible lleer los calendariu públicos.",
    "An error occurred, unable to subscribe to calendar." : "Prodúxose un error, nun ye posible soscribise al calendariu.",
    "Subscribe" : "Soscribise",
    "Time:" : "Hora:",
    "Personal" : "Personal",
    "Edit event" : "Editar eventu",
    "Event does not exist" : "L'eventu nun esiste",
    "All day" : "Tol día",
    "Invite" : "Convidar",
    "Untitled event" : "Eventu ensin títulu",
    "Close" : "Zarrar",
    "Title" : "Títulu",
    "Participants" : "Participantes",
    "Submit" : "Unviar",
    "Miscellaneous" : "Miscelanea",
    "Daily" : "Caldía",
    "Weekly" : "Selmanalmente",
    "_Every %n day_::_Every %n days_" : ["Cada %n día","Cada %n díes"],
    "_Every %n week_::_Every %n weeks_" : ["Cada %n selmana","Cada %n selmanes"],
    "_Every %n month_::_Every %n months_" : ["Cada %n mes","Cada %n meses"],
    "_Every %n year_::_Every %n years_" : ["Cada %n añu","Cada %n años"],
    "_%n time_::_%n times_" : ["%n vegada","%n vegaes"],
    "second" : "segundu",
    "third" : "tercer",
    "fourth" : "cuartu",
    "fifth" : "quintu",
    "Untitled task" : "Xera ensin títulu",
    "Please ask your administrator to enable the Tasks App." : "Pidi al alministrador qu'active l'aplicación Xeres.",
    "W" : "S",
    "%n more" : "%n más",
    "_+%n more_::_+%n more_" : ["+%n más","+%n más"],
    "No events" : "Nun hai nengún eventu",
    "Failed to save event" : "Nun se pue guardar l'eventu",
    "When shared show full event" : "Cuando se comparta amosar l'eventu completu",
    "When shared show only busy" : "Cuando se comparta amosar namás si ta ocupáu",
    "When shared hide this event" : "Cuando se comparta anubrir l'eventu",
    "Status" : "Estáu",
    "Canceled" : "Anulóse",
    "Categories" : "Categories",
    "Error while sharing file" : "Hebo un error mentanto se compartía'l ficheru",
    "Error while sharing file with user" : "Hebo un error mentanto se compartía'l ficheru col usuariu",
    "An error occurred during getting file information" : "Prodúxose un error demientres se consiguía la información del ficheru",
    "An error occurred, unable to delete the calendar." : "Prodúxose un error, nun ye posible desaniciar el calendariu",
    "Imported {filename}" : "Importóse «{filename}»",
    "This is an event reminder." : "Esto ye un recordatoriu del eventu.",
    "User not found" : "Nun s'atopó l'usuariu",
    "Hidden" : "Anubrióse",
    "Calendar name …" : "Nome del calendariu…",
    "CalDAV link copied to clipboard." : "L'enllaz CalDAV copióse nel cartafueyu.",
    "CalDAV link could not be copied to clipboard." : "L'enllaz CalDAV nun se pudo copiar nel cartafueyu.",
    "Enable birthday calendar" : "Activar el calendariu de los cumpleaños",
    "Show tasks in calendar" : "Amosar les xeres nel calendariu",
    "Enable simplified editor" : "Activar l'editor simplificáu",
    "Limit the number of events displayed in the monthly view" : "Llendar el númberu d'eventos amosaos na vista de meses",
    "Show weekends" : "Amosar les fines de selmana",
    "Show week numbers" : "Amosar los númberos de selmana",
    "Copy primary CalDAV address" : "Copiar la direición CalDAV primaria",
    "Copy iOS/macOS CalDAV address" : "Copiar la direición CalDAV d'iOS/macOS",
    "Personal availability settings" : "Configuración de la disponibilidá personal",
    "Show keyboard shortcuts" : "Amosar los atayos del tecáu",
    "Error creating Talk room" : "Hebo un error al crear la sala de Talk",
    "_%n more guest_::_%n more guests_" : ["%n convidáu más","%n convidaos más"]
},
"nplurals=2; plural=(n != 1);");
