OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Anuani ya barua pepe iliyotolewa ni ndefu sana",
    "User-Session unexpectedly expired" : "Kipindi cha mtumiaji kiliisha muda wake bila kutarajiwa",
    "Provided email-address is not valid" : "Anuani ya barua pepe iliyotolewa si halali",
    "%s has published the calendar »%s«" : "%s wamechapisha kalenda>>\n1%s <<",
    "Unexpected error sending email. Please contact your administrator." : "Makosa ya utumaji wa barua pepe yasiyotarajiwa\nTafadhali wasiliana na msimamizi/mtawala",
    "Successfully sent email to %1$s" : "Barua pepe iliyotumwa imefanikiwa kwa 1%1$s",
    "Hello," : "Hallo,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Tulitaka kukujulisha kwamba %s\nwamechapisha kalenda >> %s <<.",
    "Open »%s«" : "Fungua >> %s <<",
    "Cheers!" : "Hongera!",
    "Upcoming events" : "Matukio yajayo",
    "No more events today" : "Hakuna matukio zaidi leo",
    "No upcoming events" : "Hakuna matukio yajayo",
    "More events" : "Matukio zaidi",
    "%1$s with %2$s" : "%1$s kwa %2$s",
    "Calendar" : "Calendar",
    "New booking {booking}" : "Nafasi mpya iliyoshikwa {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) muadi ulioshikwa\" {config_display_name}\" katika {date_time}",
    "Appointments" : "Miadi",
    "Schedule appointment \"%s\"" : "Panga muadi \"%s\"",
    "Schedule an appointment" : "Panga muadi",
    "%1$s - %2$s" : "%1$s-%2$s",
    "Prepare for %s" : "Jiandae kwa %s",
    "Follow up for %s" : "Fuatilia kwa %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Muadi wako %sna %s unahitaji uthibitisho",
    "Dear %s, please confirm your booking" : "Ndugu %s, tafadhali thibitisha nafasi yako iliyoshikwa",
    "Confirm" : "Thibitisha",
    "Appointment with:" : "Muadi na:",
    "Description:" : "Maelezo",
    "This confirmation link expires in %s hours." : "Uthibitisho huu unaunganisha iliyoisha muda %s masaa",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Kama unatamani kughairi muadi baada ya yote, tafadhali wasiliana na mratibu wako kwa kujibu barua pepe hii au kwa kutembelea wasifu wa kurasa zao.",
    "Your appointment \"%s\" with %s has been accepted" : "Muadi wako\"%s\" na %s umekubaliwa",
    "Dear %s, your booking has been accepted." : "Ndugu %s, nafasi yako uliyoshika imekubaliwa",
    "Appointment for:" : "Muadi kwa:",
    "Date:" : "Tarehe:",
    "You will receive a link with the confirmation email" : "Utapokea kiungio na uthibitisho wa barua pepe",
    "Where:" : "Wapi:",
    "Comment:" : "Maoni",
    "You have a new appointment booking \"%s\" from %s" : "Una muadi mpya wa nafasi uliyoshika\" %s tangu %s",
    "Dear %s, %s (%s) booked an appointment with you." : "Ndugu %s, %s (%s ) walishika nafasi ya muadi na wewe.",
    "%s has proposed a meeting" : "%s amependekeza mkutano",
    "%s has updated a proposed meeting" : "%s amesasisha mkutano unaopendekezwa",
    "%s has canceled a proposed meeting" : "%s ameghairi mkutano uliopendekezwa",
    "Dear %s, a new meeting has been proposed" : "Mpendwa %s, mkutano mpya umependekezwa",
    "Dear %s, a proposed meeting has been updated" : "Mpendwa %s, mkutano unaopendekezwa umesasishwa",
    "Dear %s, a proposed meeting has been cancelled" : "Mpendwa %s, mkutano unaopendekezwa umeghairiwa",
    "Location:" : "Eneo:",
    "Duration:" : "Muda:",
    "%1$s from %2$s to %3$s" : "%1$s tangu %2$s mpaka %3$s",
    "Dates:" : "Tarehe:",
    "Respond" : "Jibu",
    "A Calendar app for Nextcloud" : "App ya Calendar kwa Nextcloud",
    "A Calendar app for Nextcloud. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Like Contacts, Talk, Tasks, Deck and Circles\n* 🌐 **WebCal Support!** Want to see your favorite team's matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 **Search!** Find your events at ease\n* ☑️ **Tasks!** See tasks or Deck cards with a due date directly in the calendar\n* 🔈 **Talk rooms!** Create an associated Talk room when booking a meeting with just one click\n* 📆 **Appointment booking** Send people a link so they can book an appointment with you [using this app](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Attachments!** Add, upload and view event attachments\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "App ya Calendar ya Nextcloud. Sawazisha matukio kutoka kwa vifaa mbalimbali kwa urahisi na Nextcloud yako na uyahariri mtandaoni.\n\n* 🚀 **Muunganisho na programu zingine za Nextcloud!** Kama vile Anwani, Maongezi, Majukumu, Staha na Miduara\n* 🌐 **Usaidizi wa Wavuti!** Je, ungependa kuona siku za mechi za timu unayopenda kwenye kalenda yako? Hakuna tatizo!\n* 🙋 **Waliohudhuria!** Alika watu kwenye matukio yako\n* ⌚ **Bila/Bure!** Angalia wakati waliohudhuria wanapatikana ili kukutana\n* ⏰ **Vikumbusho!** Pata kengele za matukio ndani ya kivinjari chako na kupitia barua pepe\n* 🔍 **Tafuta!** Pata matukio yako kwa urahisi\n* ☑️ **Kazi!** Angalia kazi au Kadi za Staha zilizo na tarehe ya kukamilisha moja kwa moja kwenye kalenda\n* 🔈 **Vyumba vya maongezi!** Unda chumba cha Maongezi husika unapohifadhi mkutano kwa mbofyo mmoja tu\n* 📆 **Kuhifadhi miadi** Tumia watu kiungo ili waweze kuweka miadi nawe [kwa kutumia programu hii](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Viambatisho!** Ongeza, pakia na tazama viambatisho vya tukio\n* 🙈 **Hatubuni tena gurudumu!** Kulingana na [c-dav maktaba] kuu (https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) na [fullcalendar] (https://github.com/fullcalendar/fullcalendar) maktaba. ",
    "Previous day" : "Siku iliyopita",
    "Previous week" : "Wiki iliyopita",
    "Previous year" : "Mwaka uliopita",
    "Previous month" : "Mwezi uliopita",
    "Next day" : "Siku inayofuata",
    "Next week" : "Wiki ijayo",
    "Next year" : "Mwaka ujao",
    "Next month" : "Mwezi ujao",
    "Create new event" : "Tengeneza tukio jipya",
    "Event" : "Tukio",
    "Today" : "Leo",
    "Day" : "Siku",
    "Week" : "Wiki",
    "Month" : "Mwezi",
    "Year" : "Mwaka",
    "List" : "Orodha",
    "Appointment link was copied to clipboard" : "Kiungio cha muadi kilinakiliwa kwenye clipboard",
    "Appointment link could not be copied to clipboard" : "Kiungio cha muadi hakikuweza kunakiliwa kwenye clipboard",
    "Preview" : "Mwonekano wa awali",
    "Copy link" : "Nakili kiungio",
    "Edit" : "Hariri",
    "Delete" : "Futa",
    "Appointment schedules" : "Ratiba za miadi",
    "Create new" : "Tengeneza mpya",
    "Disable calendar \"{calendar}\"" : "Fifisha kalenda{calendar}",
    "Disable untitled calendar" : "Fifisha kalenda isiyo na jina",
    "Enable calendar \"{calendar}\"" : "Wezesha kalenda{calendar}",
    "Enable untitled calendar" : "Wezesha kalenda isiyo na jina",
    "An error occurred, unable to change visibility of the calendar." : "Makosa yametokea, fifisha kubadili mwonekano wa kalenda",
    "Untitled calendar" : "Kalenda isiyo na jina",
    "Shared with you by" : "Imeshirikishwa na wewe na",
    "Edit and share calendar" : "Hariri na shirikisha kalenda",
    "Edit calendar" : "Hariri kalenda",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Unsharing the calendar in {countdown} second","Kutoshirikisha kalenda katika{countdown} kwa sekunde"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Deleting the calendar in {countdown} second","Kufuta kalenda katika {countdown} kwa sekunde"],
    "An error occurred, unable to create the calendar." : "Kosa limetokea, fifisha kutengeneza kalenda",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Tafadhali ingiza kiungio halisi (anza na http://, https://, webcal://, or webcals://)",
    "Calendars" : "Kalenda",
    "Add new" : "Ongeza mpya",
    "New calendar" : "Calendar mpya",
    "Name for new calendar" : "Jina la kalenda",
    "Creating calendar …" : "Kutengeneza kalenda",
    "New calendar with task list" : "Kalenda mpya na orodha ya kazi",
    "New subscription from link (read-only)" : "Usajili mpya kutoka katika kiungo (soma-tu)",
    "Creating subscription …" : "Tengeneza usajili",
    "Add public holiday calendar" : "Ongeza kalenda ya likizo ya umma",
    "Add custom public calendar" : "Ongeza kalenda ya wateja wa umma",
    "Calendar link copied to clipboard." : "Kiungo cha kalenda kimenakiliwa kwenye clipboard.",
    "Calendar link could not be copied to clipboard." : "Kiungo cha kalenda hakikuweza kunakiliwa kwenye clipboard",
    "Copy subscription link" : "Nakili kiungio cha usajili",
    "Copying link …" : "Nakili kiungio",
    "Copied link" : "Kiungio kilichonakiliwa",
    "Could not copy link" : "Isingeweza kunakili kiungio",
    "Export" : "Agiza",
    "Untitled item" : "Kipengele kisichotajwa",
    "Unknown calendar" : "Kalenda isiyojulikana",
    "Could not load deleted calendars and objects" : "Haikuwaza kupakia kalenda na vitu vilivyofutwa",
    "Could not delete calendar or event" : "Haikuweza kufuta kalenda au matukio",
    "Could not restore calendar or event" : "Haikuweza kuhifadhi upya kalenda au matukio",
    "Do you really want to empty the trash bin?" : "Je, unataka kuweka tupu chombo cha takataka?",
    "Empty trash bin" : "Weka tupu chombo cha takataka",
    "Trash bin" : "Chombo cha takataka",
    "Loading deleted items." : "Inapakia vitu vilivyofutwa",
    "You do not have any deleted items." : "Huna vitu vyovyote vilivyofutwa",
    "Name" : "Jina",
    "Deleted" : "Vilivyofutwa",
    "Restore" : "Hifadhi upya",
    "Delete permanently" : "Futa moja kwa moja",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Items in the trash bin are deleted after {numDays} day","Vipengee vilivyo kwenye pipa la uchafu hufutwa baada ya siku {numDays}"],
    "Could not update calendar order." : "Haikuweza kusasisha mtiririko wa kalenda",
    "Shared calendars" : "Calendar zilizoshirikishwa",
    "Deck" : "Deki",
    "Internal link" : "Kiungo cha ndani",
    "A private link that can be used with external clients" : "Kiungo cha binafsi ambacho kinaweza kutumiwa na wateja wa nje",
    "Copy internal link" : "Nakili kiungo cha ndani",
    "An error occurred, unable to publish calendar." : "Kosa limetokea, haiwezeshi kuchapisha kalenda",
    "An error occurred, unable to send email." : "Kosa limetokea, haiwezeshi kutuma barua pepe",
    "Embed code copied to clipboard." : "Pachika code iliyonakiliwa kwenye clipboard",
    "Embed code could not be copied to clipboard." : "Code iliyopachikwa haikuweza kunakiliwa kwenye clipboard",
    "Unpublishing calendar failed" : "Imeshindwa kubatilisha uchapishaji wa kalenda",
    "Share link" : "Shirikisha kiungo",
    "Copy public link" : "Nakili kiungo cha umma",
    "Send link to calendar via email" : "Tuma kiungo kwenye kalenda kupitia barua pepe",
    "Enter one address" : "Ingiza anwuani moja",
    "Sending email …" : "Inatuma barua pepe",
    "Copy embedding code" : "Nakili msimbo uliyopachikwa",
    "Copying code …" : "Nakili msimbo",
    "Copied code" : "Msimbo ulionakiliwa",
    "Could not copy code" : "Haikuweza kunakili msimbo",
    "Delete share link" : "Futa kiungo cha kushiriki",
    "Deleting share link …" : "Inafuta kiungo cha kushiriki",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Timu)",
    "An error occurred while unsharing the calendar." : "Kosa limetokea wakati wa kutoshirikisha kalenda",
    "An error occurred, unable to change the permission of the share." : "Kosa limetokea, haiwezi kubadili ruhusa za kushirikisha",
    "can edit and see confidential events" : "anaweza kuhariri na kuona matukio ya siri",
    "Unshare with {displayName}" : "Acha kushirikisha na {displayName}",
    "Share with users or groups" : "Shiriki na watumiaji au makundi",
    "No users or groups" : "Hakuna watumiaji au makundi",
    "Failed to save calendar name and color" : "Imeshindwa kuhifadhi jina la kalenda na rangi",
    "Calendar name …" : "Jina la kalenda …",
    "Never show me as busy (set this calendar to transparent)" : "Usinioneshe kama bize (panga kalenda hii kwa uwazi)",
    "Share calendar" : "Shirikisha kalenda",
    "Unshare from me" : "Batilisha kushiriki kutoka kwangu",
    "Save" : "Hifadhi",
    "No title" : "Hakuna kichwa",
    "Are you sure you want to delete \"{title}\"?" : "Je, una uhakika unataka kufuta \"{title}\"?",
    "Deleting proposal \"{title}\"" : "Inafuta pendekezol \"{title}\"",
    "Successfully deleted proposal" : "Imefaulu kufuta pendekezo",
    "Failed to delete proposal" : "Imeshindwa kufuta pendekezo",
    "Failed to retrieve proposals" : "Imeshindwa kupata mapendekezo",
    "Meeting proposals" : "Mapendekezo ya mkutano",
    "A configured email address is required to use meeting proposals" : "Anwani ya barua pepe iliyosanidiwa inahitajika ili kutumia mapendekezo ya mkutano",
    "No active meeting proposals" : "Hakuna mapendekezo ya mkutano yanayoendelea",
    "View" : "Angalia",
    "Import calendars" : "Agiza kalenda",
    "Please select a calendar to import into …" : "Tafadhali chagua kalenda ya kuagiza ndani ya",
    "Filename" : "Jina la faili",
    "Calendar to import into" : "Kalenda ya kuagiza ndani ya",
    "Cancel" : "Sitisha/Futa/ghaili",
    "_Import calendar_::_Import calendars_" : ["Import calendar","Ingiza kalenda"],
    "Select the default location for attachments" : "Chagua eneo la chaguo msingi kwa maambatanisho",
    "Pick" : "Chagua",
    "Invalid location selected" : "Eneo batili limechaguliwa",
    "Attachments folder successfully saved." : "Folda ya viambatanisho imehifadhiwa kwa ukamilifu.",
    "Error on saving attachments folder." : "Kosa katika uhifadhi wa folda ya viambatanisho.",
    "Attachments folder" : "Folda ya viambatisho",
    "{filename} could not be parsed" : "{filename}haikuweza kuchanganuliwa",
    "No valid files found, aborting import" : "Hakuna mafaili halali yaliyopatikana, katisha uagizaji",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Successfully imported %n event","Kikamilifu imeingiza matukio %n"],
    "Import partially failed. Imported {accepted} out of {total}." : "Imeshindwa kuingiza kiasi. Imeingizwa {accepted}kati ya {total}",
    "Automatic" : "Moja kwa moja",
    "Automatic ({timezone})" : "Kiotomatiki ({timezone})",
    "New setting was not saved successfully." : "Mipangilio mipya haikuweza kuhifadhiwa kikamilifu.",
    "Timezone" : "Muda wa mahali",
    "Navigation" : "Uendeshaji",
    "Previous period" : "Kipindi kilichopita",
    "Next period" : "Kipindi kijacho",
    "Views" : "Mionekano",
    "Day view" : "Mwonekano wa siku",
    "Week view" : "Mwaonekano wa wiki",
    "Month view" : "Mwonekano wa mwezi",
    "Year view" : "Mwonekano wa mwaka",
    "List view" : "Mwonekano wa orodha",
    "Actions" : "Matendo",
    "Create event" : "Tengeneza matukio",
    "Show shortcuts" : "Onesha mikato",
    "Editor" : "Mhariri",
    "Close editor" : "Funga mhariri",
    "Save edited event" : "Hifadhi tukio liliohaririwa",
    "Delete edited event" : "Futa tukio lililohaririwa",
    "Duplicate event" : "Zalisha tukio",
    "or" : "au",
    "Calendar settings" : "Mipangilio ya kalenda",
    "At event start" : "Katika kuanza kwa tukio",
    "No reminder" : "Hakuna kikumbushio",
    "Failed to save default calendar" : "Imeshindwa kuhifadhi kalenda ya chaguo-msingi",
    "General" : "Kuu",
    "Availability settings" : "Mipangilio ya upatikanaji",
    "CalDAV" : "CalDAV",
    "Access Nextcloud calendars from other apps and devices" : "Fikia kalenda za Nextcloud kutoka kwa programu na vifaa vingine",
    "CalDAV URL" : "URL ya CalDAV ",
    "Server Address for iOS and macOS" : "Anwani ya Seva ya iOS na macOS",
    "Appearance" : "Mwonekano",
    "Birthday calendar" : "Kalenda ya siku ya kuzaliwa",
    "Tasks in calendar" : "Majukumu katika kalenda",
    "Weekends" : "Mwishoni mwa wiki",
    "Week numbers" : "Nambari za wiki",
    "Limit number of events shown in Month view" : "Kikomo cha idadi ya matukio yanayoonyeshwa katika mwonekano wa Mwezi",
    "Density in Day and Week View" : "Msongamano katika Mwonekano wa Siku na Wiki",
    "Editing" : "Inahariri",
    "Default reminder" : "Kikumbusho cha chaguo-msingi",
    "Simple event editor" : "Mhariri wa tukio rahisi",
    "\"More details\" opens the detailed editor" : "\"Maelezo zaidi\" hufungua kihariri cha kina",
    "Files" : "Faili",
    "Appointment schedule successfully created" : "Ratiba ya miadi imetengenezwa kikamilifu",
    "Appointment schedule successfully updated" : "Ratiba ya miadi imesasishwa kikamilifu",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minute","{duration}dakika"],
    "0 minutes" : "Dakika 0",
    "_{duration} hour_::_{duration} hours_" : ["{duration} hour","{duration} masaa"],
    "_{duration} day_::_{duration} days_" : ["{duration} day","{duration} siku"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} week","{duration} wiki"],
    "_{duration} month_::_{duration} months_" : ["{duration} month","{duration} miezi"],
    "_{duration} year_::_{duration} years_" : ["{duration} year","{duration} miaka"],
    "To configure appointments, add your email address in personal settings." : "Kusanidi miadi, ongeza barua pepe yako katika mipangilio binafsi",
    "Public – shown on the profile page" : "Imeoneshwa kwa umma kwenye ukurasa wa wasifu",
    "Private – only accessible via secret link" : "Inapatikana kwa faragha pekee kupitia kiungo cha siri",
    "Appointment schedule saved" : "Ratiba ya muadi imehifadhiwa",
    "Create appointment schedule" : "Tengeneza ratiba ya muadi",
    "Edit appointment schedule" : "Hariri ratiba ya muadi",
    "Update" : "Sasisha",
    "Appointment name" : "Jina la muadi",
    "Location" : "Mahali/eneo",
    "Create a Talk room" : "Tengeneza chumba cha mazungumzo",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Kiungo cha kipekee kitazalishwa kwa kila muadi uliokatishiwa nafasi na kutumwa kupitia barua pepe iliyothibitishwa",
    "Description" : "Maelezo",
    "Visibility" : "Mwonekano",
    "Duration" : "Muda",
    "Increments" : "Maongezeko",
    "Additional calendars to check for conflicts" : "Kalenda ya nyongeza kwa kuangalia migogoro",
    "Pick time ranges where appointments are allowed" : "Chagua safu za wakati ambapo miadi inaruhusiwa",
    "to" : "kwa",
    "Delete slot" : "Futa slot",
    "No times set" : "Hakuna muda uliowekwa",
    "Add" : "Ongeza",
    "Monday" : "Jumatatu",
    "Tuesday" : "Jumanne",
    "Wednesday" : "Jumatano",
    "Thursday" : "Alhamisi",
    "Friday" : "Ijumaa",
    "Saturday" : "Jumamosi",
    "Sunday" : "Jumapili",
    "Weekdays" : "Siku za wiki",
    "Add time before and after the event" : "Ongeza muda kabla na baada ya tukio",
    "Before the event" : "Kabla ya tukio",
    "After the event" : "Baada ya tukio",
    "Planning restrictions" : "Kupanga mazuio/vikwazo",
    "Minimum time before next available slot" : "Kiwango cha chini cha muda kabla ya slot inayofuata inayopatikana",
    "Max slots per day" : "Kiwango cha juu cha slots kwa siku",
    "Limit how far in the future appointments can be booked" : "Zuia ni kwa kiwango gani wakati ujao miadi inaweza kukatishiwa nafasi",
    "It seems a rate limit has been reached. Please try again later." : "Inaonekana kiwango cha juu kimefikiwa.\nTafadhali jaribu tena baadaye.",
    "Please confirm your reservation" : "Tafadhali thibitisha kutoridhishwa kwako",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Tulikutumia barua pepe yenye maelekezo.\nTafadhali thibitisha muadi wako kwa kutumia kiungo katika barua pepe. Unaweza kufunga ukurasa huu sasa.",
    "Your name" : "Jina lako",
    "Your email address" : "Anwani yako ya barua pepe",
    "Please share anything that will help prepare for our meeting" : "Tafadhali shirikisha kitu chochote kitakachosaidia kuandaliwa kwa mkutano wetu",
    "Could not book the appointment. Please try again later or contact the organizer." : "Haikuweza kukatisha nafasi ya muadi.\nTafadhali jaribu tena baadaye au wasiliana na mratibu.",
    "Back" : "Rudi",
    "Book appointment" : "Katisha nafasi ya muadi",
    "Error fetching Talk conversations." : "Hitilafu katika kuleta mazungumzo ya Talk",
    "Conversation does not have a valid URL." : "Mazungumzo hayana URL halisi",
    "Successfully added Talk conversation link to location." : "Kiungo cha mazungumzo ya Talk kimeongezwa kikamilifu katika eneo",
    "Successfully added Talk conversation link to description." : "Kiungo cha mazungumzo ya Talk kwa maelekezo kimeongezwa kikamilifu",
    "Failed to apply Talk room." : "Imeshindwa kuomba chumba cha Talk",
    "Talk conversation for event" : "Mazungumzo ya Talk kwa tukio",
    "Error creating Talk conversation" : "Hitilafu kutengeneza mzungumzo ya Talk",
    "Select a Talk Room" : "Chagua chumba cha Talk",
    "Add Talk conversation" : "Ongeza mazungumzo ya Talk",
    "Fetching Talk rooms…" : "Inaleta vyumba vya Talk",
    "No Talk room available" : "Hakuna vyumba vya Talk vinavyopatikana",
    "Create public conversation" : "Unda mazungumzo ya umma",
    "Select conversation" : "Chagua mazungumzo",
    "on" : "Juu ya",
    "at" : "Katika",
    "before at" : "kabla ya katika",
    "Notification" : "Taarifa",
    "Email" : "Barua pepe",
    "Audio notification" : "Taarifa ya sauti",
    "Other notification" : "Taarifa zingine",
    "Relative to event" : "Uhusiano kwa tukio",
    "On date" : "Kwa tarehe",
    "Edit time" : "Hariri muda",
    "Save time" : "Hifadhi muda",
    "Remove reminder" : "Ondoa kikumbushio",
    "Add reminder" : "Ongeza kikumbushio",
    "seconds" : "sekunde",
    "minutes" : "dakika",
    "hours" : "masaa",
    "days" : "siku",
    "weeks" : "wiki",
    "Choose a file to add as attachment" : "Chagua faili kuongeza kama kiambatanisho",
    "Choose a file to share as a link" : "Chagua faili kushirikisha kama kiungo",
    "Attachment {name} already exist!" : "Kiambatanishi{name}kipo tayari",
    "Could not upload attachment(s)" : "Haikuweza kupakia viambatanisho(s)",
    "You are about to navigate to {link}. Are you sure to proceed?" : "Unakaribia kuelekea kwenye {link}. Je, una uhakika wa kuendelea?",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Unakaribia kwenda kwa {host}\nUnauhakika wa kuendelea? Kiungo:{link}",
    "Proceed" : "Endelea",
    "No attachments" : "Hakuna viambatanisho",
    "Add from Files" : "Ongeza kutoka katika faili",
    "Upload from device" : "Pakia kutoka katika kifaa",
    "Delete file" : "Futa faili",
    "Confirmation" : "Uthibitisho",
    "_{count} attachment_::_{count} attachments_" : ["{count} attachment","{count} viambatanisho"],
    "Suggested" : "Iliyopendekezwa",
    "Available" : "Inayopatikana",
    "Invitation accepted" : "Mwaliko umekubaliwa",
    "Accepted {organizerName}'s invitation" : "Imekubaliwa{organizerName}'s mwaliko",
    "Participation marked as tentative" : "Ushiriki umetiwa alama kuwa wa majaribio",
    "Invitation is delegated" : "Mwaliko umekabidhiwa",
    "Not available" : "Haipatikani",
    "Invitation declined" : "Mwaliko umekataliwa",
    "Declined {organizerName}'s invitation" : "Mwaliko {organizerName}uliokataliwa",
    "Availability will be checked" : "Upatikanaji utaangaliwa",
    "Invitation will be sent" : "Mwaliko utatumwa",
    "Failed to check availability" : "Imeshindwa kuangalia upatikanaji",
    "Failed to deliver invitation" : "Imeshindwa kuwasilisha mwaliko",
    "Awaiting response" : "Inasubiri majibu",
    "Checking availability" : "Inaangalia upatikanaji",
    "Has not responded to {organizerName}'s invitation yet" : "Anapaswa kuitika kwa {organizerName} bado mwaliko",
    "Suggested times" : "Mida iliyopendekezwa",
    "chairperson" : "mwenyekiti",
    "required participant" : "mshiriki anayetakiwa",
    "non-participant" : "hakuna mshiriki",
    "optional participant" : "mshiriki mbadala",
    "{organizer} (organizer)" : "{organizer} (mratibu)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Selected slot" : "Nafasi iliyochaguliwa",
    "Availability of attendees, resources and rooms" : "Upatikanaji wa wahudhuriaji, maliasili na vyumba",
    "Suggestion accepted" : "Pendekezo limekubaliwa",
    "Previous date" : "Tarehe iliyopita",
    "Next date" : "Tarehe inayofuata ",
    "Legend" : "Hadithi",
    "Out of office" : "Nje ya ofisi",
    "Attendees:" : "Wahudhuriaji",
    "local time" : "Muda wa ndani",
    "Done" : "Imefanyika",
    "Search room" : "Tafuta chumba",
    "Room name" : "Jina la chumba",
    "Check room availability" : "Tafuta chumba kinachopatikana",
    "Free" : "Huru",
    "Busy (tentative)" : "Bize (vumilivu)",
    "Busy" : "Bize",
    "Unknown" : "Haijulikani",
    "Find a time" : "Tafuta muda",
    "The invitation has been accepted successfully." : "Mwaliko umekubaliwa kikamilifu",
    "Failed to accept the invitation." : "Mwaliko umeshindwa kukubaliwa",
    "The invitation has been declined successfully." : "Mwaliko umekataliwa kikamilifu ",
    "Failed to decline the invitation." : "Imeshindwa kukataa mwaliko",
    "Your participation has been marked as tentative." : "Ushiriki wako umewekewa alama kawa wa uvumilivu",
    "Failed to set the participation status to tentative." : "Imeshindwa kupanga hadhi ya ushiriki kwa uvumilivu",
    "Accept" : "Kubali",
    "Decline" : "Kataa",
    "Tentative" : "Vumilivu",
    "No attendees yet" : "Hakuna mhudhuriaji bado",
    "{confirmedCount} confirmed, {waitingCount} awaiting response" : "{confirmedCount} imethibitishwa, {waitingCount} inasubiri jibu",
    "Please add at least one attendee to use the \"Find a time\" feature." : "Tafadhali ongeza angalau mhudhuliaji mmoja wa kutumia sifa ya \"Tafuta muda\"",
    "Attendees" : "Wahudhuriaji",
    "_%n more attendee_::_%n more attendees_" : ["%n more attendee","%n zaidi waliohudhuria"],
    "Remove group" : "Ondoa kundi",
    "Remove attendee" : "Ondoa mhudhuriaji",
    "Request reply" : "Omba mrejesho",
    "Chairperson" : "Mwenyekiti",
    "Required participant" : "Mshiriki anayetakiwa",
    "Optional participant" : "Mshiriki mbadala",
    "Non-participant" : "Hakuna mshiriki",
    "_%n member_::_%n members_" : ["%n member","%n wanachama"],
    "Search for emails, users, contacts, contact groups or teams" : "Utafutaji wa barua pepe, watumiaji, namba, namba za makundi au timu",
    "No match found" : "Haikupatikana inayofanana",
    "Note that members of circles get invited but are not synced yet." : "Nukuu kwamba mzunguko wa wanachama wanapata kualikwa lakini bado hawajasawazishwa.",
    "Note that members of contact groups get invited but are not synced yet." : "Nukuu kwamba wanachama wa nambaza makundi wanapata kualikwa lakini bado hawajasawazishwa.",
    "(organizer)" : "(Mratibu)",
    "Make {label} the organizer" : "Tengeneza{label}kuwa mratibu",
    "Make {label} the organizer and attend" : "Tengeneza {label}kuwa mratibu na kuhudhuria",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Kutuma nje mialiko na majibu yaliyoshughulikiwa, [kiungo kiko wazi] ongeza anwani ya barua pepe yako katika mipangilio binafsi [kiungo kimefungwa]",
    "Remove color" : "Ondoa rangi",
    "Event title" : "Kichwa cha tukio",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Haiwezi kuboresha mpangilio wa siku nzima kwa tukio ambalo ni sehemu ya set ya kujirudia.",
    "From" : "Tangu/ kutoka",
    "To" : "Mpaka/ hadi",
    "Your Time" : "Muda wako",
    "Repeat" : "Rudia",
    "Repeat event" : "Rudia tukio",
    "_time_::_times_" : ["time","mara"],
    "never" : "kamwe",
    "on date" : "kwa tarehe",
    "after" : "baada ya",
    "End repeat" : "Maliza kurudia",
    "Select to end repeat" : "Chagua kumaliza kurudia",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Tukio hili ni mbadala unaojirudia wa set inayojirudia. Huwezi kuongeza kwake sheria inayojirudia.",
    "first" : "kwanza",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Mabadiliko kwa sheria inayojirudia yatafanya kazi tu kwa hii na matukio yajayo.",
    "Repeat every" : "Rudia kila",
    "By day of the month" : "Kwa siku ya mwezi",
    "On the" : "Juu ya",
    "_day_::_days_" : ["day","siku"],
    "_week_::_weeks_" : ["week","wiki"],
    "_month_::_months_" : ["month","miezi"],
    "_year_::_years_" : ["year","miaka"],
    "On specific day" : "Kwa siku maalum",
    "weekday" : "siku za wiki",
    "weekend day" : "siku ya wikendi",
    "Does not repeat" : "Hairudii",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Ufafanuzi wa kujirudia wa tukio hili haukubaliwi kikamilifu na Nextcloud. Ukihariri chaguo za kujirudia, baadhi ya marudio yanaweza kupotea.",
    "No rooms or resources yet" : "Bado hakuna vyumba au nyenzo",
    "Resources" : "Rasilimali/nyenzo",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} seat","{seatingCapacity} nafasi"],
    "Add resource" : "Ongeza rasilimali",
    "Has a projector" : "Ana projekta",
    "Has a whiteboard" : "Ana ubao mweupe",
    "Wheelchair accessible" : "Kiti cha mataili kinaweza kufikiwa",
    "Remove resource" : "Ondoa rasilimali",
    "Search for resources or rooms" : "Tafuta rasilimali au chumba",
    "available" : "Inapatikana",
    "unavailable" : "Haipatikani",
    "Show all rooms" : "Onesha vyumba vyote",
    "Projector" : "Projekta",
    "Whiteboard" : "Ubao mweupe",
    "Room type" : "Aina ya chumba",
    "Any" : "Yoyote",
    "Minimum seating capacity" : "Kiwango cha chini cha uwezo wa ukaaji",
    "More details" : "Maelezo ya ziada",
    "Update this and all future" : "Sasisha hii na zote wakati ujao",
    "Update this occurrence" : "Sasisha mabadiliko haya",
    "Public calendar does not exist" : "Kalenda ya umma haipatikani",
    "Maybe the share was deleted or has expired?" : "Labda ushirikishaji umefutwa au umeisha muda wake",
    "Remove date" : "Ondoa tarehe",
    "Attendance required" : "Mahudhurio yanahitajika",
    "Attendance optional" : "Mahudhurio ya hiari",
    "Remove participant" : "Ondoa washiriki",
    "Yes" : "Ndiyo",
    "No" : "Hapana",
    "Maybe" : "Labda",
    "None" : "Hakuna",
    "Select your meeting availability" : "Chagua upatikanaji wa mkutano wako",
    "Create a meeting for this date and time" : "Unda mkutano wa tarehe na wakati huu",
    "Create" : "Tengeneza",
    "No participants or dates available" : "Hakuna washiriki au tarehe zinazopatikana",
    "from {formattedDate}" : "kutoka{formattedDate}",
    "to {formattedDate}" : "mpaka{formattedDate}",
    "on {formattedDate}" : "juu ya {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "tangu{formattedDate}katika\n{formattedTime}",
    "to {formattedDate} at {formattedTime}" : "mpaka{formattedDate}katika\n{formattedTime}",
    "on {formattedDate} at {formattedTime}" : "juu ya {formattedDate}katika\n{formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} katika {formattedTime}",
    "Please enter a valid date" : "Tafadhali ingiza tarehe halisi",
    "Please enter a valid date and time" : "Tafadhali ingiza muda na tarehe halisi",
    "Select a time zone" : "Chagua eneo la muda",
    "Please select a time zone:" : "Tafadhali chagua eneo la muda",
    "Pick a time" : "Chagua muda",
    "Pick a date" : "Chagua tarehe",
    "Type to search time zone" : "Andika kutafuta eneo la muda",
    "Global" : "Kidunia",
    "Holidays in {region}" : "Likizo katika {region}",
    "An error occurred, unable to read public calendars." : "Hitilafu imetokea, haiwezi kusoma kalenda ya umma",
    "An error occurred, unable to subscribe to calendar." : "Hitilafu imetokea, haiwezi kujisajili kwenye kalenda",
    "Public holiday calendars" : "Kalenda za likizo za umma",
    "Public calendars" : "Kalenda za umma",
    "No valid public calendars configured" : "Hakuna kalenda halisi iliyosanidiwa",
    "Speak to the server administrator to resolve this issue." : "Zungumza na msimamizi wa seva kutatua jambo hili",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Kalenda za umma za likizo zinagawiwa na Thunderbird. Data za kalenda zitapakuliwa kutoka {website}",
    "These public calendars are suggested by the server administrator. Calendar data will be downloaded from the respective website." : "Kalenda hizi za umma zinapendekezwa na msimamizi wa seva. Data ya kalenda itapakuliwa kutoka kwenye tovuti husika.",
    "By {authors}" : "Na{authors}",
    "Subscribed" : "Iliyojisajili",
    "Subscribe" : "Jisajili",
    "Could not fetch slots" : "Haikuweza kuleta slots",
    "Select a date" : "Chagua tarehe",
    "Select slot" : "Chagua slot",
    "No slots available" : "Hakuna slot inayopatikana",
    "The slot for your appointment has been confirmed" : "Slot kwa muadi wako imethibitishwa",
    "Appointment Details:" : "Maelezo ya kina ya muadi",
    "Time:" : "Muda",
    "Booked for:" : "Imekatishiwa nafasi kwa:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Asante. Ukatishaji wako wa nafasi kutoka {startDate}kwenda{endDate} umethibitishwa",
    "Book another appointment:" : "Katisha nafasi ya muadi mwingine",
    "See all available slots" : "Ona slot zote zinzopatikana",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Slot kwa muadi wako kutoka {startDate} kwenda {endDate} haupatikani tena",
    "Please book a different slot:" : "Tafadhali katisha nafasi ya slot nyingine",
    "Book an appointment with {name}" : "Katisha nafasi ya muadi na {name}",
    "No public appointments found for {name}" : "Hakuna muadi wa umma uliopatikana kwa {name}",
    "Personal" : "Binafsi",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Ugunduzi wa moja kwa moja wa saa za eneo uliamua muda wa eneo lako kuwa UTC\nHii inawezekana zaidi haya ni matokeo ya hatua za usalama za kivinjari chako cha wavuti",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Muda wako wa eneo uliosanidiwa ({timezoneId}) haukupatikana. Kuangukia nyuma kwa UTC\nTafadhali badili muda wako wa eneo katika mipangilio na toa taarifa ya jambo hili.",
    "Show unscheduled tasks" : "Onyesha kazi ambazo hazijaratibiwa",
    "Unscheduled tasks" : "Kazi ambazo hazijaratibiwa",
    "Availability of {displayName}" : "Upatikanaji wa {displayName}",
    "Discard event" : "Tupa tukio",
    "Edit event" : "Hariri tukio",
    "Event does not exist" : "Tukio halipatikani",
    "Duplicate" : "Zalisha",
    "Delete this occurrence" : "Futa tukio hili",
    "Delete this and all future" : "Futa hii na muda wote ujao",
    "All day" : "Siku yote",
    "Modifications wont get propagated to the organizer and other attendees" : "Marekebisho hayataenezwa kwa mratibu na wahudhuriaji wengine",
    "Managing shared access" : "Dhibiti ufikikaji shirikishi",
    "Deny access" : "Zuia ufikikaji",
    "Invite" : "Alika",
    "Discard changes?" : "Unataka kufuta mabadiliko?",
    "Are you sure you want to discard the changes made to this event?" : "Je, una uhakika unataka kufuta mabadiliko yaliyofanywa kwenye tukio hili?",
    "_User requires access to your file_::_Users require access to your file_" : ["User requires access to your file","Watumiaji wanahitaji ufikiaji wa faili yako"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Attachment requires shared access","Viambatanisho vinavyohitaji ufikiaji wa pamoja"],
    "Untitled event" : "Tukio lisilotajwa",
    "Close" : "Funga",
    "Modifications will not get propagated to the organizer and other attendees" : "Marekebisho hayataenezwa kwa mratibu na wahudhuriaji wengine",
    "Meeting proposals overview" : "Muhtasari wa mapendekezo ya mkutano",
    "Edit meeting proposal" : "Hariri pendekezo la mkutano",
    "Create meeting proposal" : "Tengeneza pendekezo la mkutano",
    "Update meeting proposal" : "Sasisha pendekezo la mkutano",
    "Saving proposal \"{title}\"" : "Inahifadhi pendekezo \"{title}\"",
    "Successfully saved proposal" : "Imefaulu kuhifadhi pendekezo",
    "Failed to save proposal" : "Imeshindwa kuhifadhi pendekezo",
    "Create a meeting for \"{date}\"? This will create a calendar event with all participants." : "Ungependa kuunda mkutano wa \"{date}\"? Hii itaunda tukio la kalenda na washiriki wote.",
    "Creating meeting for {date}" : "Inaunda mkutano wa {date}",
    "Successfully created meeting for {date}" : "Imefaulu kuunda mkutano wa {date}",
    "Failed to create a meeting for {date}" : "Imeshindwa kuunda mkutano wa {date}",
    "Please enter a valid duration in minutes." : "Tafadhali weka muda halali kwa dakika.",
    "Failed to fetch proposals" : "Imeshindwa kuleta mapendekezo",
    "Failed to fetch free/busy data" : "Imeshindwa kuleta data isiyolipishwa/inayoshughulika",
    "Selected" : "Iliyochaguliwa",
    "No Description" : "Hakuna maelezo",
    "No Location" : "Hakuna eneo",
    "Edit this meeting proposal" : "Hariri pendekezo hili la mkutano",
    "Delete this meeting proposal" : "Futa pendekezo hili la mkutano",
    "Title" : "Kichwa cha habari",
    "15 min" : "15 dakika",
    "30 min" : "30 dakika",
    "60 min" : "60 dakika",
    "90 min" : "90 dakika",
    "Participants" : "Washiriki",
    "Selected times" : "Nyakati zilizochaguliwa",
    "Previous span" : "Muda uliopita",
    "Next span" : "Muda unaofuata",
    "Less days" : "Siku pungufu",
    "More days" : "Siku zaidi",
    "Loading meeting proposal" : "Inapakia pendekezo la mkutano",
    "No meeting proposal found" : "Hakuna pendekezo la mkutano lililopatikana",
    "Please wait while we load the meeting proposal." : "Tafadhali subiri tunapopakia pendekezo la mkutano.",
    "The link you followed may be broken, or the meeting proposal may no longer exist." : "Kiungo ulichofuata kinaweza kuvunjwa, au huenda pendekezo la mkutano halipo tena.",
    "Thank you for your response!" : "Asante kwa jibu lako!",
    "Your vote has been recorded. Thank you for participating!" : "Kura yako imerekodiwa. Asante kwa kushiriki!",
    "Unknown User" : "Mtumiaji asiyejulikana",
    "No Title" : "Hakuna kichwa",
    "No Duration" : "Hakuna Muda",
    "Select a different time zone" : "Select a different time zone",
    "Submit" : "Wasilisha",
    "Subscribe to {name}" : "Jisajili kwa {name}",
    "Export {name}" : "Agiza {name}",
    "Show availability" : "Onesha upatikanaji",
    "Anniversary" : "Maadhimisho ya miaka",
    "Appointment" : "Muadi",
    "Business" : "Biashara",
    "Education" : "Elimu",
    "Holiday" : "Likizo",
    "Meeting" : "Mkutano",
    "Miscellaneous" : "Mbalimbali",
    "Non-working hours" : "Masaa yasiyo ya kazi",
    "Not in office" : "Nje ya ofisi",
    "Phone call" : "Mwito wa simu",
    "Sick day" : "Siku ya kuumwa",
    "Special occasion" : "Tukio maalum",
    "Travel" : "Safari",
    "Vacation" : "Likizo",
    "Midnight on the day the event starts" : "Usiku wa manane siku ambayo tukio linaanza",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n day before the event at {formattedHourMinute}","%n  siku kabla ya tukio katika {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n week before the event at {formattedHourMinute}","%n wiki kabla ya tukio katika {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "wakati wa siku ya tukio katika {formattedHourMinute}",
    "at the event's start" : "Katika mwanzo wa tukio",
    "at the event's end" : "Katika mwisho wa tukio",
    "{time} before the event starts" : "{time} kabla ya tukio kuanza",
    "{time} before the event ends" : "{time} kabla ya tukio kumalizika",
    "{time} after the event starts" : "{time} baada ya tukio kuanza",
    "{time} after the event ends" : "{time} baada ya tukio kumalizika",
    "on {time}" : "juu ya {time}",
    "on {time} ({timezoneId})" : "juu ya {time} ({timezoneId})",
    "Week {number} of {year}" : "Wiki {number} wa {year}",
    "Daily" : "Kwa kila siku",
    "Weekly" : "Kwa kila wiki",
    "Monthly" : "Kwa kila mwezi",
    "Yearly" : "Kwa kila mwaka",
    "_Every %n day_::_Every %n days_" : ["Every %n day","Kila %n siku"],
    "_Every %n week_::_Every %n weeks_" : ["Every %n week","Kila %n wiki"],
    "_Every %n month_::_Every %n months_" : ["Every %n month","Kila %n miezi"],
    "_Every %n year_::_Every %n years_" : ["Every %n year","Kila %n miaka"],
    "_on {weekday}_::_on {weekdays}_" : ["on {weekday}","kwenye {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["on day {dayOfMonthList}","katika siku {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "kwenye {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {dayOfMonthList}" : "katika {monthNames} juu ya {dayOfMonthList}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "katika {monthNames} juu ya {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "mpaka {untilDate}",
    "_%n time_::_%n times_" : ["%n time","%n mara"],
    "second" : "pili",
    "third" : "tatu",
    "fourth" : "nne",
    "fifth" : "tano",
    "second to last" : "pili kutoka mwisho",
    "last" : "mwisho",
    "Untitled task" : "Kazi zisizo na jina",
    "Please ask your administrator to enable the Tasks App." : "Tafadhali uliza msimamizi wako kuwezesha kazi za App",
    "You are not allowed to edit this event as an attendee." : "Huruhusiwi kuhariri tukio hili kama mhudhuriaji",
    "W" : "W",
    "%n more" : "%n zaidi",
    "No events to display" : "Hakuna tukio lililooneshwa",
    "All participants declined" : "Washiriki wote walikataa",
    "Please confirm your participation" : "Tafadhali thibitisha ushiriki wako",
    "You declined this event" : "Umekataa tukio hili",
    "Your participation is tentative" : "Ushiriki wako ni wa uvumilivu",
    "_+%n more_::_+%n more_" : ["+%n more","+%n zaidi"],
    "No events" : "Hakuna tukio",
    "Create a new event or change the visible time-range" : "Tengeneza tukio jipya au badili masafa ya wakati yanayoonekana",
    "Failed to save event" : "Imeshindikana kuhifadhi tukio",
    "It might have been deleted, or there was a typo in a link" : "Huenda ilifutwa au kulikuwa na makosa ya uandishi katika kiungio",
    "It might have been deleted, or there was a typo in the link" : "Huenda ilifutwa au kulikuwa na makosa ya uandishi katika kiungio",
    "Meeting room" : "Chumba cha mikutano",
    "Lecture hall" : "Bwalo la mihadhara",
    "Seminar room" : "Chumba cha semina",
    "Other" : "Mengine",
    "When shared show" : "Iliyoshirikishwa inapoonesha",
    "When shared show full event" : "Iliyoshirikishwa inapoonesha tukio zima",
    "When shared show only busy" : "Iliyoshirikishwa inapoonesha ubize tu",
    "When shared hide this event" : "Iliyoshirikishwa inapoficha tukio hili",
    "The visibility of this event in read-only shared calendars." : "Mwonekano wa tukio hili katika kalenda zinazoshirikiwa kusoma pekee.",
    "Add a location" : "Ongeza eneo",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Ongeza maelezo\n\nMkutano huu unahusu nini\nVipengele vya ajenda- kitu chochote mshiriki anahitaji kuandaa",
    "Status" : "Wadhifa",
    "Confirmed" : "Imethibitishwa",
    "Canceled" : "Imesitishwa",
    "Confirmation about the overall status of the event." : "Uthibitisho kuhusu hali ya jumla ya tukio.",
    "Show as" : "Onesha kama",
    "Take this event into account when calculating free-busy information." : "Zingatia tukio hili wakati wa kukokotoa maelezo yasiyo na shughuli nyingi.",
    "Categories" : "Vipengele",
    "Categories help you to structure and organize your events." : "Vipengele vinakusaidia kuunda na kupanga matukio yako",
    "Search or add categories" : "Tafuta au ongeza vipengele",
    "Add this as a new category" : "Ongeza hii kama kipengele kipya",
    "Custom color" : "Rangi maalum",
    "Special color of this event. Overrides the calendar-color." : "Rangi maalum ya tukio hili. Inabatilisha rangi ya kalenda.",
    "Error while sharing file" : "Hitilafu wakati wa kushirikisha faili",
    "Error while sharing file with user" : "Hitilafu ikishirikisha faili na mtumiaji",
    "Error creating a folder {folder}" : "Hitilafu wakati wa kutengeneza folda {folder}",
    "Attachment {fileName} already exists!" : "Kiambatanisho {fileName}kimeshajitokeza",
    "Attachment {fileName} added!" : "Kiambatanisho {fileName}kimeongezwa",
    "An error occurred during uploading file {fileName}" : "Hitilafu ilitokea wakati wa kupakia faili {fileName}",
    "An error occurred during getting file information" : "Hitilafu imetokea wakati wa kupata taarifa za faili",
    "Talk conversation for proposal" : "Mazungumzo ya Talk kwa pendekezo",
    "An error occurred, unable to delete the calendar." : "Hitilafu imetokea, haiwezi kufuta kalenda",
    "Imported {filename}" : "Imeagizwa {filename}",
    "This is an event reminder." : "Hiki ni kikumbishi cha tukio",
    "Error while parsing a PROPFIND error" : "Hitilafu wakati wa kuchanganua hitilafu ya PROPFIND",
    "Appointment not found" : "Muadi haupatikani",
    "User not found" : "Mtumiaji hapatikani",
    "Hidden" : "Iliyofichwa",
    "can edit" : "Inaweza kuhariri",
    "Calendar name …" : "Jina la kalenda",
    "Default attachments location" : "Chaguo msingi la eneo la viambatanisho.",
    "Automatic ({detected})" : "Kiotomatiki {detected}",
    "Shortcut overview" : "Muhtasari wa mkato",
    "CalDAV link copied to clipboard." : "Kiungio cha CalDAV kimenakiliwa kwenye clipboard ",
    "CalDAV link could not be copied to clipboard." : "Kiungo cha CalDAV hakikuweza kunakuliwa kwenye clipboard",
    "Enable birthday calendar" : "Wezesha kalenda ya siku ya kuzaliwa",
    "Show tasks in calendar" : "Onesha kazi katika kalenda",
    "Enable simplified editor" : "Wezesha mhariri aliyerahisishwa",
    "Limit the number of events displayed in the monthly view" : "Zuia namba za matukio yanayooneshwa katika mwonekano wa mwezi",
    "Show weekends" : "Onesha wikendi",
    "Show week numbers" : "Onesha namba za wiki",
    "Time increments" : "Uongezekaji wa muda",
    "Default calendar for incoming invitations" : "Kalenda ya chaguo msingi kwa mialiko inayoingia",
    "Copy primary CalDAV address" : "Nakili anwani msingi ya CalDAV",
    "Copy iOS/macOS CalDAV address" : "Nakili anwani ya iOS/macOS CalDAV",
    "Personal availability settings" : "Mipangilio ya Upatikanaji binafsi",
    "Show keyboard shortcuts" : "Onesha mikato ya keyboard",
    "Create a new public conversation" : "Unda mazungumzo mapya ya umma",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount}amealikwa,\n{confirmedCount}amethibitisha",
    "Successfully appended link to talk room to location." : "Kikmilifu kimeongezwa kiungo kwa chumba cha talk na eneo",
    "Successfully appended link to talk room to description." : "Kikmilifu kimeongezwa kiungo kwa chumba cha talk na kwa maelezo",
    "Error creating Talk room" : "Hitilafu kutengeneza chumba cha Talk",
    "_%n more guest_::_%n more guests_" : ["%n more guest","%n wageni zaidi"],
    "The visibility of this event in shared calendars." : "Mwonekano wa tukio hili katika kalenda zilizoshirikiwa."
},
"nplurals=2; plural=(n != 1);");
