/*!
 * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */
@import 'app-navigation';
@import 'app-full';
@import 'app-settings';
@import 'app-modal';
@import 'edit-simple';
@import 'freebusy';
@import 'fullcalendar';
@import 'global';
@import 'import';
@import 'print';
@import 'public';
@import 'props-linkify-links';
