OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Sisestatud e-postiaadress on liiga pikk",
    "User-Session unexpectedly expired" : "Kasutajasessioon aegus ootamatult",
    "Provided email-address is not valid" : "Sisestatud e-postiaadress pole korrektne",
    "%s has published the calendar »%s«" : "%s avaldas kalendri „%s“",
    "Unexpected error sending email. Please contact your administrator." : "Ootamatu viga e-kirja saatmisel. Palun võta ühendust oma peakasutajaga.",
    "Successfully sent email to %1$s" : "E-kiri on saadetud kasutajale %1$s",
    "Hello," : "Tere,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Tahtsime Sind informeerida, et %s on avaldanud „%s“ kalendri.",
    "Open »%s«" : "Ava „%s“",
    "Cheers!" : "Tervist!",
    "Upcoming events" : "Tulekul sündmused",
    "No more events today" : "Täna rohkem sündmuseid pole",
    "No upcoming events" : "Tulekul sündmuseid pole",
    "More events" : "Rohkem sündmuseid",
    "%1$s with %2$s" : "%1$s ja %2$s",
    "Calendar" : "Kalender",
    "New booking {booking}" : "Uus broneering „{booking}“",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) leppis kokku kohtumise „{config_display_name}“ algusega {date_time}.",
    "Appointments" : "Kohtumised",
    "Schedule appointment \"%s\"" : "Ajasta kokkulepitud kohtumine „%s“",
    "Schedule an appointment" : "Ajasta kokkulepitud kohtumine",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : "Valmistu „%s“ ürituseks",
    "Follow up for %s" : "„%s“ ürituse järelkaja",
    "Your appointment \"%s\" with %s needs confirmation" : "Sinu „%s“ osalejaga „%s“ vajab kinnitamist",
    "Dear %s, please confirm your booking" : "Lugupeetud %s, palun kinnita oma broneering",
    "Confirm" : "Kinnita",
    "Appointment with:" : "Kokkulepitud kohtumine kasutajaga:",
    "Description:" : "Kirjeldus:",
    "This confirmation link expires in %s hours." : "See kinnituslink aegub %s tunni möödudes.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Kui soovid kohtumise broneeringut tühistada, siis võta ühendust korraldajaga vastates sellele kirjale või külastades tema profiili.",
    "Your appointment \"%s\" with %s has been accepted" : "Sinu kohtumine „%s“ kasutajaga „%s“ on k innitatud",
    "Dear %s, your booking has been accepted." : "Lugupeetud %s, sinu broneering on kinnitatud.",
    "Appointment for:" : "Kohtumine:",
    "Date:" : "Kuupäev:",
    "You will receive a link with the confirmation email" : "Sa saad lingi kinnituskirjaga",
    "Where:" : "Kus:",
    "Comment:" : "Kommentaar:",
    "You have a new appointment booking \"%s\" from %s" : "Sul on uus kohtumise broneering „%s“ kasutajalt „%s“",
    "Dear %s, %s (%s) booked an appointment with you." : "Lugupeetud %s, %s (%s) broneeris sinuga kohtumise.",
    "%s has proposed a meeting" : "%s on teinud ettepaneku kohtumiseks",
    "%s has updated a proposed meeting" : "%s on uuendanud kohtumise ettepanekut",
    "%s has canceled a proposed meeting" : "%s on tühistanud kohtumise ettepaneku",
    "Dear %s, a new meeting has been proposed" : "Lugupeetud %s, ettepanek koosoleku korraldamiseks on loodud",
    "Dear %s, a proposed meeting has been updated" : "Lugupeetud %s, ettepanek koosoleku korraldamiseks on uuendatud",
    "Dear %s, a proposed meeting has been cancelled" : "Lugupeetud %s, ettepanek kohtumise korraldamiseks on tühistatud",
    "Location:" : "Asukoht:",
    "Duration:" : "Kestus",
    "%1$s from %2$s to %3$s" : "%1$s alates %2$s kuni %3$s",
    "Dates:" : "Kuupäevad:",
    "Respond" : "Vasta",
    "A Calendar app for Nextcloud" : "Nextcloudi kalendrirakendus",
    "A Calendar app for Nextcloud. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Like Contacts, Talk, Tasks, Deck and Circles\n* 🌐 **WebCal Support!** Want to see your favorite team's matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 **Search!** Find your events at ease\n* ☑️ **Tasks!** See tasks or Deck cards with a due date directly in the calendar\n* 🔈 **Talk rooms!** Create an associated Talk room when booking a meeting with just one click\n* 📆 **Appointment booking** Send people a link so they can book an appointment with you [using this app](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Attachments!** Add, upload and view event attachments\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Kalendrirakendus Nextcloudi jaoks. Sünkroniseeri sündmusi erinevatest seadmetest oma Nextcloudi serverisse ja muuda neid võrgus.\n\n* 🚀 **Lõiming muude Nextcloudi rakendustega!** Nagu näiteks Kontaktid, Kõned, Ülesanded, Kanban and Tiimid\n* 🌐 **WebCAL-i tugi!** Tahad näha oma lemmikklubide mängude aegu oma kalendris? Pole probleemi!\n* 🙋 **Osalejad!** Kutsu teisi oma sündmustele\n* ⌚ **Vaba/Hõivatud!** Vaata, millal osalejad saaksid tulla\n* ⏰ **Meeldetuletused!** Telli ürituste meeldetuletused brauseriteadetena või e-kirjadena\n* 🔍 **Otsing!** Leia oma sündmused kiiresti ja mugavalt\n* ☑️ **Ülesanded!** Näed ülesannete ja Kanbani kaartide tähtaegu otse kalendris\n* 🔈 **Jututoad!** Lisa kohtumise broneerimisel ühe klõpsuga asjakohane Kõnerakenduse jututuba\n* 📆 **Kohtumiste broneerimine** Saada teistele link, mis võimaldab neil broneerida kohtumist sinuga ning kasuta [selleks seda rakendust](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Manused!** Lisa, laadi üles ja vaata sündmuste manused\n* 🙈 **Me ei tegele ratta uuesti leiutamisega!** Selle rakenduse aluseks on suurepärased teegid: [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) ja [fullcalendar](https://github.com/fullcalendar/fullcalendar).",
    "Previous day" : "Eelmine päev",
    "Previous week" : "Eelmine nädal",
    "Previous year" : "Eelmine aasta",
    "Previous month" : "Eelmine kuu",
    "Next day" : "Järgmine päev",
    "Next week" : "Järgmine nädal",
    "Next year" : "Järgmine aasta",
    "Next month" : "Järgmine kuu",
    "Create new event" : "Lisa uus sündmus",
    "Event" : "Sündmus",
    "Today" : "Täna",
    "Day" : "Päev",
    "Week" : "Nädal",
    "Month" : "Kuu",
    "Year" : "Aasta",
    "List" : "Loend",
    "Appointment link was copied to clipboard" : "Kohtumise link on kopeeritud lõikelauale",
    "Appointment link could not be copied to clipboard" : "Kohtumise linki ei õnnestunud lõikelauale kopeerida",
    "Preview" : "Eelvaade",
    "Copy link" : "Kopeeri link",
    "Edit" : "Redigeeri",
    "Delete" : "Kustuta",
    "Appointment schedules" : "Kokkulepitud kohtumiste ajakava",
    "Create new" : "Loo uus",
    "Disable calendar \"{calendar}\"" : "Lülita välja „{calendar}“ kalender",
    "Disable untitled calendar" : "Lülita välja nimetu kalender",
    "Enable calendar \"{calendar}\"" : "Lülita sisse „{calendar}“ kalender",
    "Enable untitled calendar" : "Lülita sisse nimetu kalender",
    "An error occurred, unable to change visibility of the calendar." : "Tekkis viga ja kalendri nähtavust pole võimalik muuta.",
    "Untitled calendar" : "Nimetu kalender",
    "Shared with you by" : "Seda jagas sinuga",
    "Edit and share calendar" : "Muuda ja jaga kalendrit",
    "Edit calendar" : "Muuda kalendrit",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Lõpetan kalendri jagamise {countdown} sekundi möödumisel","Lõpetan kalendri jagamise {countdown} sekundi möödumisel"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Kustutan kalendri {countdown} sekundi möödumisel","Kustutan kalendri {countdown} sekundi möödumisel"],
    "An error occurred, unable to create the calendar." : "Tekkis viga ja kalendri loomine pole võimalik.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Palun sisesta korrektne link (alguses peab olema http://, https://, webcal:// või webcals://)",
    "Calendars" : "Kalendrid",
    "Add new" : "Lisa uus",
    "New calendar" : "Uus kalender",
    "Name for new calendar" : "Uue kalendri nimi",
    "Creating calendar …" : "Loon kalendrit…",
    "New calendar with task list" : "Uus kalender ülesannete loendiga",
    "New subscription from link (read-only)" : "Uus tellimus lingi põhjal (vaid lugemisõigustes)",
    "Creating subscription …" : "Loon tellimust…",
    "Add public holiday calendar" : "Lisa riigipühade kalender",
    "Add custom public calendar" : "Lisa kohandatud riigipühade kalender",
    "Calendar link copied to clipboard." : "Kalendri link on kopeeritud lõikelauale.",
    "Calendar link could not be copied to clipboard." : "Kalendri linki ei õnnestunud lõikelauale kopeerida.",
    "Copy subscription link" : "Kopeeri tellimuse link",
    "Copying link …" : "Kopeerin linki…",
    "Copied link" : "Link on kopeeritud",
    "Could not copy link" : "Linki ei õnnestunud kopeerida",
    "Export" : "Ekspordi",
    "Untitled item" : "Tundmatu kirje",
    "Unknown calendar" : "Tundmatu kalender",
    "Could not load deleted calendars and objects" : "Kustutatud kalendrite ja objektide laadimine ei õnnestunud",
    "Could not delete calendar or event" : "Kalendri või sündmuse kustutamine ei õnnestunud",
    "Could not restore calendar or event" : "Kalendri või sündmuse taastamine ei õnnestunud",
    "Do you really want to empty the trash bin?" : "Oled sa kindel, et soovid prügikasti tühjendada?",
    "Empty trash bin" : "Tühjenda prügikast",
    "Trash bin" : "Prügikast",
    "Loading deleted items." : "Laadin kustutatud kirjeid.",
    "You do not have any deleted items." : "Sul pole kustutatud kirjeid.",
    "Name" : "Nimi",
    "Deleted" : "Kustutatud",
    "Restore" : "Taasta",
    "Delete permanently" : "Kustuta jäädavalt",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Prügikastis olevad objektid kustutatakse {numDays} päeva pärast","Prügikastis olevad objektid kustutatakse {numDays} päeva pärast"],
    "Could not update calendar order." : "Kalendri järjekorda ei õnnestunud uuendada.",
    "Shared calendars" : "Jagatud kalendrid",
    "Deck" : "Deck",
    "Internal link" : "Sisemine link",
    "A private link that can be used with external clients" : "Privaatne link, mida saad kasutada väliste klientide jaoks",
    "Copy internal link" : "Kopeeri sisemine link",
    "An error occurred, unable to publish calendar." : "Tekkis viga ja kalendri avaldamine pole võimalik.",
    "An error occurred, unable to send email." : "Tekkis viga ja e-kirja saatmine pole võimalik.",
    "Embed code copied to clipboard." : "Lõimitav kood on kopeeritud lõikelauale.",
    "Embed code could not be copied to clipboard." : "Ei õnnestunud kopeerida lõimitavat koodi lõikelauale.",
    "Unpublishing calendar failed" : "Ei õnnestunud lõpetada kalendri avaldamist",
    "Share link" : "Jaga linki",
    "Copy public link" : "Kopeeri avalik link",
    "Send link to calendar via email" : "Saada link kalendrisse e-posti teel",
    "Enter one address" : "Sisesta üks aadress",
    "Sending email …" : "E-kiri on saatmisel…",
    "Copy embedding code" : "Kopeeri lõimitav kood",
    "Copying code …" : "Kopeerin koodi…",
    "Copied code" : "Kood on kopeeritud",
    "Could not copy code" : "Koodi ei õnnestunud kopeerida",
    "Delete share link" : "Kustuta jagamise link",
    "Deleting share link …" : "Kustutan jagamislinki…",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (tiim)",
    "An error occurred while unsharing the calendar." : "Kalendri jagamise lõpetamisel tekkis viga.",
    "An error occurred, unable to change the permission of the share." : "Tekkis viga ja jaosmeedia õigusi pole võimalik muuta.",
    "can edit and see confidential events" : "võib muuta ja näha konfidentsiaalseid sündmusi",
    "Unshare with {displayName}" : "Lõpeta jagamine kasutajaga: {displayName}",
    "Share with users or groups" : "Jaga kasutajate või gruppidega",
    "No users or groups" : "Ei ole kasutajaid või gruppe",
    "Failed to save calendar name and color" : "Kalendri värvi ja nime salvestamine ei õnnestunud",
    "Calendar name …" : "Kalendri nimi…",
    "Never show me as busy (set this calendar to transparent)" : "Ära iialgi näita, et ma olen hõivatud (muuda see kalender läbipaistvaks)",
    "Share calendar" : "Jaga kalendrit",
    "Unshare from me" : "Eemalda minult see jagamine",
    "Save" : "Salvesta",
    "No title" : "Pealkiri puudub",
    "Are you sure you want to delete \"{title}\"?" : "Kas oled kindel, et soovid „{title}“ kustutada?",
    "Deleting proposal \"{title}\"" : "Kustutan ettepanekut: „{title}“",
    "Successfully deleted proposal" : "Ettepaneku kustutamine õnnestus",
    "Failed to delete proposal" : "Ettepaneku kustutamine ei õnnestunud",
    "Failed to retrieve proposals" : "Ettepanekute laadimine ei õnnestunud",
    "Meeting proposals" : "Ettepanekud kohtumisteks",
    "A configured email address is required to use meeting proposals" : "Kohtumiste ettepanekute kasutamiseks on vajalik toimiv e-posti aadress",
    "No active meeting proposals" : "Pole aktiivseid ettepanekuid kohtumisteks",
    "View" : "Vaata",
    "Import calendars" : "Impordi kalendrid",
    "Please select a calendar to import into …" : "Palun vali kalender, kuhu soovid importida…",
    "Filename" : "Failinimi",
    "Calendar to import into" : "Imporditav kalender",
    "Cancel" : "Loobu",
    "_Import calendar_::_Import calendars_" : ["Impordi kalender","Impordi kalendrid"],
    "Select the default location for attachments" : "Vali manustele vaikimisi asukoht",
    "Pick" : "Vali",
    "Invalid location selected" : "Vigane asukoht valitud",
    "Attachments folder successfully saved." : "Manuste kausta salvestamine õnnestus.",
    "Error on saving attachments folder." : "Viga manuste kausta salvestamisel.",
    "Attachments folder" : "Manuste kaust",
    "{filename} could not be parsed" : "{filename} töötlemine ei õnnestunud",
    "No valid files found, aborting import" : "Ühtegi korrektset faili ei  leidu, katkestan impordi",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["%n sündmuse importimine õnnestus","%n sündmuse importimine õnnestus"],
    "Import partially failed. Imported {accepted} out of {total}." : "Importimine osaliselt ei õnnestunud. Importisin {accepted} kokku {total}-st kirjest.",
    "Automatic" : "Automaatne",
    "Automatic ({timezone})" : "Automaatne ({timezone})",
    "New setting was not saved successfully." : "Uue seadistuse salvestamine ei õnnestunud.",
    "Timezone" : "Ajavöönd",
    "Navigation" : "Liikumine",
    "Previous period" : "Eelmine periood",
    "Next period" : "Järgmine periood",
    "Views" : "Vaated",
    "Day view" : "Päeva vaade",
    "Week view" : "Nädala vaade",
    "Month view" : "Kuuvaade",
    "Year view" : "Aasta vaade",
    "List view" : "Nimekirjavaade",
    "Actions" : "Tegevused",
    "Create event" : "Lisa sündmus",
    "Show shortcuts" : "Näita kiirklahve",
    "Editor" : "Muutmisvaade",
    "Close editor" : "Sulge muutmisvaade",
    "Save edited event" : "Salvesta muudetud sündmus",
    "Delete edited event" : "Kustuta muudetud sündmus",
    "Duplicate event" : "Tee sündmusest koopia",
    "or" : "või",
    "Calendar settings" : "Kalendri seadistused",
    "At event start" : "Sündmuse algamisel",
    "No reminder" : "Meeldetuletust pole",
    "Failed to save default calendar" : "Vaikimisi kalendri salvestamine ei õnnestunud",
    "General" : "Üldine",
    "Availability settings" : "Kohaloleku seadistused",
    "CalDAV" : "CalDAV",
    "Access Nextcloud calendars from other apps and devices" : "Ligipääs Nextcloudi kalendrile muudest rakendustest ja seadmestest",
    "CalDAV URL" : "CalDAVi võrguaadress",
    "Server Address for iOS and macOS" : "Serveri aadress iOS-i ja macOS-i jaoks",
    "Appearance" : "Välimus",
    "Birthday calendar" : "Sünnipäevade kalender",
    "Tasks in calendar" : "Ülesanded kalendris ",
    "Weekends" : "Nädalavahetused",
    "Week numbers" : "Nädalanumbrid",
    "Limit number of events shown in Month view" : "Piira kuuvaates kuvatavate sündmuste arvu",
    "Density in Day and Week View" : "Päeva- ja nädalavaate tihedus",
    "Editing" : "Muutmisel",
    "Default reminder" : "Vaikimisi meeldetuletus",
    "Simple event editor" : "Lihtne muutmisvaade",
    "\"More details\" opens the detailed editor" : "„Täiendavad üksikasjad“ avab üksikasjaliku muutmisvaate",
    "Files" : "Failid",
    "Appointment schedule successfully created" : "Kokkulepitud kohtumiste ajakava loomine õnnestus",
    "Appointment schedule successfully updated" : "Kokkulepitud kohtumiste ajakava uuendamine õnnestus",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minut","{duration} minutit"],
    "0 minutes" : "0 minutit",
    "_{duration} hour_::_{duration} hours_" : ["{duration} tund","{duration} tundi"],
    "_{duration} day_::_{duration} days_" : ["{duration} päev","{duration} päeva"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} nädal","{duration} nädalat"],
    "_{duration} month_::_{duration} months_" : ["{duration} kuu","{duration} kuud"],
    "_{duration} year_::_{duration} years_" : ["{duration} aasta","{duration} aastat"],
    "To configure appointments, add your email address in personal settings." : "Kokkulepitud kohtumiste seadistamiseks palun lisa oma seadistustesse e-posti aadress.",
    "Public – shown on the profile page" : "Avalik - näidatud profiili lehel",
    "Private – only accessible via secret link" : "Privaatne - ligipääsetav vaid salajase lingi alusel",
    "Appointment schedule saved" : "Kokkulepitud kohtumiste ajakava on salvestatud",
    "Create appointment schedule" : "Loo kokkulepitud kohtumiste ajakava",
    "Edit appointment schedule" : "Muuda kokkulepitud kohtumiste ajakava",
    "Update" : "Uuenda",
    "Appointment name" : "Kohtumise nimi",
    "Location" : "Asukoht",
    "Create a Talk room" : "Loo Kõnerakenduse jututuba",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Rakendus koostab iga broneeritud kohtumise jaoks unikaalse lingi ja lisab selle kinnituskirja",
    "Description" : "Kirjeldus",
    "Visibility" : "Nähtavus",
    "Duration" : "Kestus",
    "Increments" : "Ajasammud",
    "Additional calendars to check for conflicts" : "Täiendavad kalendrid, kust peaksime ajastamise konflikte kontrollima",
    "Pick time ranges where appointments are allowed" : "Vali üldine ajavahemik, kuhu kohtumisi saaks broneerida",
    "to" : "saaja",
    "Delete slot" : "Kustuta ajavahemik",
    "No times set" : "Ajad on määramata",
    "Add" : "Lisa",
    "Monday" : "Esmaspäev",
    "Tuesday" : "Teisipäev",
    "Wednesday" : "Kolmapäev",
    "Thursday" : "Neljapäev",
    "Friday" : "Reede",
    "Saturday" : "Laupäev",
    "Sunday" : "Pühapäev",
    "Weekdays" : "Nädalapäevad",
    "Add time before and after the event" : "Lisa aeg enne ja pärast sündmust",
    "Before the event" : "Enne sündmust",
    "After the event" : "Pärast sündmust",
    "Planning restrictions" : "Piirangud kavandamsiel",
    "Minimum time before next available slot" : "Miinimumaeg enne järgmist ajavahemikku",
    "Max slots per day" : "Ajavahemikke päevas",
    "Limit how far in the future appointments can be booked" : "Piira kui kaugele tulevikku on võimalik kohtumisi broneerida",
    "It seems a rate limit has been reached. Please try again later." : "Tundub, et päringute arvu ülempiir on käes. Palun proovi hiljem uuesti.",
    "Please confirm your reservation" : "Palun kinnita oma broneering",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Me saatsime sulle e-kirja üksikasjadega. Klikates seal leiduvat linki, palun kinnita oma kohtumine. Sa võid selle lehe nüüd sulgeda.",
    "Your name" : "Sinu nimi",
    "Your email address" : "Sinu e-posti aadress",
    "Please share anything that will help prepare for our meeting" : "Palun jaga kõike, mis võiks aidata kohtumiseks valmistuda",
    "Could not book the appointment. Please try again later or contact the organizer." : "Kohtumist ei õnnestunud broneerida. Palun proovi hiljem uuesti või küsi korraldajalt nõu.",
    "Back" : "Tagasi",
    "Book appointment" : "Broneeri kohtumine",
    "Error fetching Talk conversations." : "Viga Kõnerakenduse vestluste laadimisel.",
    "Conversation does not have a valid URL." : "Vestlusel pole korrektset võrguaadressi",
    "Successfully added Talk conversation link to location." : "Kõnerakenduse vestluse lingi lisamine asukohale õnnestus.",
    "Successfully added Talk conversation link to description." : "Kõnerakenduse vestluse lingi lisamine kirjeldusele õnnestus.",
    "Failed to apply Talk room." : "Viga Kõnerakenduse jututoa kinnitamisel.",
    "Talk conversation for event" : "Kõnerakenduse vestlus ürituse jaoks",
    "Error creating Talk conversation" : "Viga Kõnerakenduse vestluse loomisel",
    "Select a Talk Room" : "Vali Kõnerakenduse jututuba",
    "Add Talk conversation" : "Lisa Kõnerakenduse vestlus",
    "Fetching Talk rooms…" : "Laadin Kõnerakenduse jututube…",
    "No Talk room available" : "Ühtegi Kõnerakenduse jututuba pole saadaval",
    "Create public conversation" : "Loo avalik vestlus",
    "Select conversation" : "Vali vestlus",
    "on" : "ajal",
    "at" : "asukohas",
    "before at" : "enne",
    "Notification" : "Teavitus",
    "Email" : "E-post",
    "Audio notification" : "Heliteavitus",
    "Other notification" : "Muu teavitus",
    "Relative to event" : "Suhteliselt sündmuse suhtes",
    "On date" : "Kuupäeval",
    "Edit time" : "Muuda aega",
    "Save time" : "Salvesta aeg",
    "Remove reminder" : "Eemalda meeldetuletus",
    "Add reminder" : "Lisa meeldetuletus",
    "seconds" : "sekundit",
    "minutes" : "minutit",
    "hours" : "tundi",
    "days" : "päeva",
    "weeks" : "nädalat",
    "Choose a file to add as attachment" : "Vali fail, mida manustada",
    "Choose a file to share as a link" : "Valilingiga jagatav fail",
    "Attachment {name} already exist!" : "Manus {name} on juba olemas!",
    "Could not upload attachment(s)" : "Manuse või manuste üleslaadimine ei õnenstunud",
    "You are about to navigate to {link}. Are you sure to proceed?" : "Sa oled avamas linki teenusesse „{link}“. Kas sa oled kindel, et soovid jätkata?",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Sa oled avamas linki teenusesse „{host}“. Kas sa oled kindel, et soovid jätkata? Link: {link}",
    "Proceed" : "Jätka",
    "No attachments" : "Manuseid pole",
    "Add from Files" : "Lisa failidest",
    "Upload from device" : "Laadi üles seadmest",
    "Delete file" : "Kustuta fail",
    "Confirmation" : "Kinnitus",
    "_{count} attachment_::_{count} attachments_" : ["{count} manus","{count} manust"],
    "Suggested" : "Soovitatud",
    "Available" : "Saadaval",
    "Invitation accepted" : "Kutse on vastu võetud",
    "Accepted {organizerName}'s invitation" : "Võtsid vastu kutse korraldajalt {organizerName}",
    "Participation marked as tentative" : "Osalemine on kinnitatud esialgsena",
    "Invitation is delegated" : "Kutse on suunatud edasi",
    "Not available" : "Pole saadaval",
    "Invitation declined" : "Kutse on tagasi lükatud",
    "Declined {organizerName}'s invitation" : "Keeldusid korraldajal {organizerName} kutsest",
    "Availability will be checked" : "Saadavus saab olema kontrollitud",
    "Invitation will be sent" : "Kutse saab olema saadetud",
    "Failed to check availability" : "Ei õnnestunud kontrollida saadavust",
    "Failed to deliver invitation" : "Ei õnnestunud kutset kohale toimetada",
    "Awaiting response" : "Ootan vastust",
    "Checking availability" : "Kontrollin saadavust",
    "Has not responded to {organizerName}'s invitation yet" : "Pole veel vastanud korraldaja „{organizerName}“ kutsele",
    "Suggested times" : "Soovitatud ajad",
    "chairperson" : "eesistuja",
    "required participant" : "nõutav osaleja",
    "non-participant" : "mitteosaleja",
    "optional participant" : "valikuline osaleja",
    "{organizer} (organizer)" : "{organizer} (korraldaja)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Selected slot" : "Valitud ajavahemik",
    "Availability of attendees, resources and rooms" : "Osalejate, vahendite ja ruumide saadavus",
    "Suggestion accepted" : "Soovitud on vastu võetud",
    "Previous date" : "Eelmine kuupäev",
    "Next date" : "Järgmine kuupäev",
    "Legend" : "Legend",
    "Out of office" : "Kontorist väljas",
    "Attendees:" : "Osalejad:",
    "local time" : "kohalik aeg",
    "Done" : "Valmis",
    "Search room" : "Otsi koosolekuruumi",
    "Room name" : "Koosolekuruumi nimi",
    "Check room availability" : "Kontrolli koosolekuruumi saadavust",
    "Free" : "Vaba",
    "Busy (tentative)" : "Hõivatud (esialgselt)",
    "Busy" : "Hõivatud",
    "Unknown" : "Teadmata",
    "Find a time" : "Otsi aega",
    "The invitation has been accepted successfully." : "Kutse on märgitud vastuvõetuks.",
    "Failed to accept the invitation." : "Ei õnnestunud märkida, et kutset nõustutuks.",
    "The invitation has been declined successfully." : "Kutse on märgitud keeldutuks.",
    "Failed to decline the invitation." : "Ei õnnestunud märkida, et kutset keeldutuks.",
    "Your participation has been marked as tentative." : "Sinu osalemine on märgitud esialgseks.",
    "Failed to set the participation status to tentative." : "Ei õnnestunud määrata osalemise olekut „Kinnitatud esialgselt“.",
    "Accept" : "Nõustu",
    "Decline" : "Keeldu",
    "Tentative" : "Esialgne",
    "No attendees yet" : "Osalejaid veel pole",
    "{confirmedCount} confirmed, {waitingCount} awaiting response" : "{confirmedCount} kinnitust, {waitingCount} vastuse ootel",
    "Please add at least one attendee to use the \"Find a time\" feature." : "Et „Otsi aega“ toimiks lisa palun vähemalt üks osaleja.",
    "Attendees" : "Osalejad",
    "_%n more attendee_::_%n more attendees_" : ["%n täiendav osaleja","%n täiendavat osalejat"],
    "Remove group" : "Eemalda grupp",
    "Remove attendee" : "Eemalda osaleja",
    "Request reply" : "Palun vastust",
    "Chairperson" : "Eesistuja",
    "Required participant" : "Vajalik osaleja",
    "Optional participant" : "Võimalik osaleja",
    "Non-participant" : "Mitteosaleja",
    "_%n member_::_%n members_" : ["%n liige","%n liiget"],
    "Search for emails, users, contacts, contact groups or teams" : "Otsi e-posti aadresse, kasutajaid, kontakte, gruppe või tiime",
    "No match found" : "Vastet ei leidu",
    "Note that members of circles get invited but are not synced yet." : "Palun arvesta, et tiimide liikmed saavad kutse, kuid pole veel sünkroniseeritud.",
    "Note that members of contact groups get invited but are not synced yet." : "Palun arvesta, et kontaktgruppide liikmed saavad kutse, kuid pole veel sünkroniseeritud.",
    "(organizer)" : "(korraldaja)",
    "Make {label} the organizer" : "Määra {label} korraldajaks",
    "Make {label} the organizer and attend" : "Määra {label} korraldajaks ja osalejaks",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Kutsete saatmiseks ja vastuste haldamiseks, [linkopen]palun lisa isiklikesse seadistustesse oma e-posti aadress[linkclose].",
    "Remove color" : "Eemalda värv",
    "Event title" : "Sündmuse peakiri",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Korduvate sündmuste komplektis oleva sündmusel ei sa valida „Kestab terve päeva“ valikut.",
    "From" : "Saatja",
    "To" : "Saaja",
    "Your Time" : "Sinu aeg",
    "Repeat" : "Korda",
    "Repeat event" : "Korda sündmust",
    "_time_::_times_" : ["kord","korda"],
    "never" : "mitte kunagi",
    "on date" : "kuupäeval",
    "after" : "pärast",
    "End repeat" : "Lõpeta kordamine",
    "Select to end repeat" : "Vali kordamise lõpetamiseks",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "See sündmus juba on erand korduvate sündmuste komplektis. Seega sa ei saa talle korduvust lisada.",
    "first" : "esimesel",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Korduvuse reegli muudatused kehtivad sellele ja tulevastele kordadele",
    "Repeat every" : "Korda iga",
    "By day of the month" : "Kuu päeva alusel",
    "On the" : "Päeval",
    "_day_::_days_" : ["päev","päeva"],
    "_week_::_weeks_" : ["nädal","nädalat"],
    "_month_::_months_" : ["kuu","kuud"],
    "_year_::_years_" : ["aasta","aastat"],
    "On specific day" : "Kindlal päeval",
    "weekday" : "nädalapäev",
    "weekend day" : "nädalalõpu päev",
    "Does not repeat" : "Ei kordu",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Selle sündmuse korduvuse määratlus pole Nextcloudis toetatud. Kui muudad korduvuse valikuid, siis mõned neist võivad kaotsi minna.",
    "No rooms or resources yet" : "Pole veel ruume ega ressursse",
    "Resources" : "Ressursid",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} koht","{seatingCapacity} kohta"],
    "Add resource" : "Lisa ressurss",
    "Has a projector" : "Olemas on projektor",
    "Has a whiteboard" : "Olemas on tahvel",
    "Wheelchair accessible" : "Ligipääsetav ratastooliga",
    "Remove resource" : "Eemalda ressurss",
    "Search for resources or rooms" : "Otsi ressurssi või ruume",
    "available" : "saadaval",
    "unavailable" : "pole saadaval",
    "Show all rooms" : "Näita kõiki koosolekuruume",
    "Projector" : "Projektor",
    "Whiteboard" : "Tahvel",
    "Room type" : "Koosolekuruumi tüüp",
    "Any" : "Kõik",
    "Minimum seating capacity" : "Väikseim kohtade arv",
    "More details" : "Täiendavad üksikasjad",
    "Update this and all future" : "Uuenda seda ja kõiki tulevasi",
    "Update this occurrence" : "Uuenda seda sündmust",
    "Public calendar does not exist" : "Avalikku kalendrit pole olemas",
    "Maybe the share was deleted or has expired?" : "Võib-olla on jaosmeedia kustutanud või aegunud?",
    "Remove date" : "Eemalda kuupäev",
    "Attendance required" : "Kohalolek on vajalik",
    "Attendance optional" : "Kohalolek on valikuline",
    "Remove participant" : "Eemalda osaleja",
    "Yes" : "Jah",
    "No" : "Ei",
    "Maybe" : "Võib-olla",
    "None" : "Pole kasutusel",
    "Select your meeting availability" : "Vali selle kohtumise jaoks saadavus",
    "Create a meeting for this date and time" : "Lisa kohtumine selleks kuupäevaks ja kellaajaks",
    "Create" : "Lisa",
    "No participants or dates available" : "Ei leidu osalejaid ega kuupäevi",
    "from {formattedDate}" : "{formattedDate} kuupäevast",
    "to {formattedDate}" : "{formattedDate} kuupäevani",
    "on {formattedDate}" : "{formattedDate}",
    "from {formattedDate} at {formattedTime}" : " {formattedDate}, {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "{formattedDate} kell {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "{formattedDate} kuupäeval, kell {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} kell {formattedTime}",
    "Please enter a valid date" : "Palun sisesta korrektne kuupäev",
    "Please enter a valid date and time" : "Palun sisesta korrektne kuupäev ja aeg",
    "Select a time zone" : "Vali ajavöönd",
    "Please select a time zone:" : "Palun vali ajavöönd:",
    "Pick a time" : "Vali aeg",
    "Pick a date" : "Vali kuupäev",
    "Type to search time zone" : "Ajavööndi otsimiseks alusta kirjutamist",
    "Global" : "Üldine",
    "Holidays in {region}" : "Riigipühad: {region}",
    "An error occurred, unable to read public calendars." : "Tekkis viga ja avaliku kalendri lugemine pole võimalik.",
    "An error occurred, unable to subscribe to calendar." : "Tekkis viga ja kalendri tellimine pole võimalik.",
    "Public holiday calendars" : "Avalikud riigipühade kalendrid",
    "Public calendars" : "Avalikud kalendrid",
    "No valid public calendars configured" : "Kehtivaid avalikke kalendreid pole seadistatud",
    "Speak to the server administrator to resolve this issue." : "Selle vea lahendamiseks palun suhtle oma serveri haldajaga.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Avalikud riigipühade kalendrid on koostanud Thunderbird. Kalendriandmed laaditakse alla siit: {website}",
    "These public calendars are suggested by the server administrator. Calendar data will be downloaded from the respective website." : "Serveri peakasutaja on soovitanud neid avalikke kalendreid. Kalendri tegelikud andmed laaditakse alla vastavast veebisaidist.",
    "By {authors}" : "Koostajalt {authors}",
    "Subscribed" : "Tellitud",
    "Subscribe" : "Telli",
    "Could not fetch slots" : "Ajavahemikke ei olnud võimalik laadida",
    "Select a date" : "Vali kuupäev",
    "Select slot" : "Vali ajavahemik",
    "No slots available" : "Sobilikke ajavahemikke ei leidu",
    "The slot for your appointment has been confirmed" : "Ajavahemik sinu kohtumise jaoks on kinnitatud",
    "Appointment Details:" : "Kohtumise üksikasjad:",
    "Time:" : "Aeg:",
    "Booked for:" : "Broneeritud:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Tänud. Sinu broneering on kinitatud: {startDate}-{endDate}.",
    "Book another appointment:" : "Broneeri mõni muu kokkulepitud kohtumise aeg:",
    "See all available slots" : "Vaata kõiki vabu ajavahemikke",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Ajavahemik {startDate}-{endDate} pole sinu kohtumise jaoks enam saadaval.",
    "Please book a different slot:" : "Palun broneeri teine ajavahemik:",
    "Book an appointment with {name}" : "Broneeri kohtumine: „{name}“",
    "No public appointments found for {name}" : "Ei leidu avalikku kohtumist: „{name}“",
    "Personal" : "Isiklik",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Automaatne ajavööndikontroll tuvastas, et kasutad UTC/GMT ajavööndit.\nSuure tõenäosusega on tegemist sinu veebibrauseri trurvameetmega.\nKui see pole nii, siis saad kalendri seadistustest määrata õige ajavööndi.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Sinu seadistatud ajavööndit ({timezoneId}) ei leidu. Kasutame varuvariandina UTC/GMT valikut.\nKalendri seadistustest määrata õige ajavööndi ning kui tegemist on veaga, siis palun anna meile sellest teada..",
    "Show unscheduled tasks" : "Näita ajastamata ülesandeid",
    "Unscheduled tasks" : "Ajastamata ülesanded",
    "Availability of {displayName}" : "{displayName} saadavus",
    "Discard event" : "Loobu sündmusest",
    "Edit event" : "Muuda sündmust",
    "Event does not exist" : "Sündmust pole olemas",
    "Duplicate" : "Tee koopia",
    "Delete this occurrence" : "Kustuta vaid see kord",
    "Delete this and all future" : "Kustuta see ja kõik tulevased",
    "All day" : "Kestab terve päeva",
    "Modifications wont get propagated to the organizer and other attendees" : "Muudatused ei jõua ei korraldaja ega muude osalejateni",
    "Managing shared access" : "Halda jagatud ligipääsu",
    "Deny access" : "Keela ligipääs",
    "Invite" : "Kutse",
    "Discard changes?" : "Kas loobud muudatustest?",
    "Are you sure you want to discard the changes made to this event?" : "Kas oled kindel, et tahad selle sündmuse muudatustest loobuda?",
    "_User requires access to your file_::_Users require access to your file_" : ["Kasutaja vajab jagatud ligipääsu","Kasutajad vajavad jagatud ligipääsu"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Manus eeldab jagatud ligipääsu","Manused eeldavad jagatud ligipääsu"],
    "Untitled event" : "Ilma nimeta sündmus",
    "Close" : "Sulge",
    "Modifications will not get propagated to the organizer and other attendees" : "Muudatused ei jõua ei korraldaja ega muude osalejateni",
    "Meeting proposals overview" : "Ülevaade kohtumiste ettepanekutest",
    "Edit meeting proposal" : "Muuda kohtumise ettepanekut",
    "Create meeting proposal" : "Lisa ettepanek kohtumiseks",
    "Update meeting proposal" : "Uuenda kohtumise ettepanekut",
    "Saving proposal \"{title}\"" : "Salvestan ettepanekut „{title}“",
    "Successfully saved proposal" : "Ettepaneku salvestamine õnnestus",
    "Failed to save proposal" : "Ettepaneku salvestamine ei õnnestunud",
    "Create a meeting for \"{date}\"? This will create a calendar event with all participants." : "Kas lisad kohtumise {date} kuupäevaks? Järgnevaga lisad kalendrisündmuse kõikide osalejatega.",
    "Creating meeting for {date}" : "Lisan kohtumise {date} kuupäevaks",
    "Successfully created meeting for {date}" : "Kohtumise lisamine {date} kuupäevaks õnnestus",
    "Failed to create a meeting for {date}" : "Kohtumise lisamine {date} kuupäevaks ei õnnestunud",
    "Please enter a valid duration in minutes." : "Palun sisesta korrektne kehtivus minutites",
    "Failed to fetch proposals" : "Ettepanekute laadimine ei õnnestunud",
    "Failed to fetch free/busy data" : "Vaba/hõivatud andmete laadimine ei õnnestunud",
    "Selected" : "Valitud",
    "No Description" : "Kirjeldust pole",
    "No Location" : "Asukohta pole",
    "Edit this meeting proposal" : "Muuda seda ettepanekut kohtumise korraldamiseks",
    "Delete this meeting proposal" : "Kustuta see ettepanek kohtumise korraldamiseks",
    "Title" : "Pealkiri",
    "15 min" : "15 minutit",
    "30 min" : "30 minutit",
    "60 min" : "60 minutit",
    "90 min" : "90 minutit",
    "Participants" : "Osalejad",
    "Selected times" : "Valitud ajad",
    "Previous span" : "Eelmine vahemik",
    "Next span" : "Järgmine vahemik",
    "Less days" : "Vähem päevi",
    "More days" : "Enam päevi",
    "Loading meeting proposal" : "Laadin kohtumise ettepanekut",
    "No meeting proposal found" : "Ühtegi ettepanekut kohtumiseks ei leidunud",
    "Please wait while we load the meeting proposal." : "Palun oota, kuni laadime ettepanekut kohtumiseks.",
    "The link you followed may be broken, or the meeting proposal may no longer exist." : "Link, mida kasutasid võib olla katki läinud või sellist ettepanekut kohtumiseks enam pole olemas.",
    "Thank you for your response!" : "Suur tänu vastamise eest!",
    "Your vote has been recorded. Thank you for participating!" : "Sinu hääl on salvestatud. Tänud osalemast!",
    "Unknown User" : "Tundmatu kasutaja",
    "No Title" : "Nime pole",
    "No Duration" : "Kestust pole",
    "Select a different time zone" : "Vali muu ajavöönd",
    "Submit" : "Saada",
    "Subscribe to {name}" : "Telli: „{name}“",
    "Export {name}" : "Ekspordi „{name}“",
    "Show availability" : "Näita saadavust",
    "Anniversary" : "Aastapäev",
    "Appointment" : "Kohtumine",
    "Business" : "Ärikohtumine",
    "Education" : "Koolitus",
    "Holiday" : "Riigipüha",
    "Meeting" : "Kohtumine",
    "Miscellaneous" : "Varia",
    "Non-working hours" : "Väljaspool tööaega",
    "Not in office" : "Pole kohal",
    "Phone call" : "Telefonikõne",
    "Sick day" : "Tervisepäev",
    "Special occasion" : "Oluline sündmus",
    "Travel" : "Reis",
    "Vacation" : "Puhkus",
    "Midnight on the day the event starts" : "Sündmuse alguspäeva kesköösel",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n päev enne sündmust kell {formattedHourMinute}","%n päeva enne sündmust kell {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n nädal enne sündmust kell {formattedHourMinute}","%n nädalat enne sündmust kell {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "sündmuse päeval kell {formattedHourMinute}",
    "at the event's start" : "sündmuse lõpus",
    "at the event's end" : "sündmuse alguses",
    "{time} before the event starts" : "{time} enne sündmuse algust",
    "{time} before the event ends" : "{time} enne sündmuse lõppu",
    "{time} after the event starts" : "{time} peale sündmuse algust",
    "{time} after the event ends" : "{time} peale sündmuse lõppu",
    "on {time}" : " {time}",
    "on {time} ({timezoneId})" : " {time} ({timezoneId})",
    "Week {number} of {year}" : "Nädal nr. {number} aastas {year}",
    "Daily" : "Iga päev",
    "Weekly" : "Iga nädal",
    "Monthly" : "Igakuine",
    "Yearly" : "Igaastane",
    "_Every %n day_::_Every %n days_" : ["Iga %n. päev","Iga %n. päev"],
    "_Every %n week_::_Every %n weeks_" : ["Iga %n. nädal","Iga %n. nädal"],
    "_Every %n month_::_Every %n months_" : ["Iga %n. kuu","Iga %n. kuu"],
    "_Every %n year_::_Every %n years_" : ["Iga %n. aasta","Iga %n. aasta"],
    "_on {weekday}_::_on {weekdays}_" : ["nädalapäeval „{weekday}“","nädalapäevdel „{weekdays}“"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["päeval „{dayOfMonthList}“","päevadel „{dayOfMonthList}“"],
    "on the {ordinalNumber} {byDaySet}" : "{ordinalNumber}. päeval {byDaySet}",
    "in {monthNames} on the {dayOfMonthList}" : "{monthNames} kuus {dayOfMonthList}. päeval",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "{monthNames} kuus {ordinalNumber}. päeval {byDaySet}",
    "until {untilDate}" : "kuni {untilDate}",
    "_%n time_::_%n times_" : ["%n kord","%n korda"],
    "second" : "teisel",
    "third" : "kolmandal",
    "fourth" : "nejandal",
    "fifth" : "viiendal",
    "second to last" : "tagant teisel",
    "last" : "viimasel",
    "Untitled task" : "Ilma nimeta pealkiri",
    "Please ask your administrator to enable the Tasks App." : "Palu oma serveri haldajal paigaldada Ülesannete rakendus.",
    "You are not allowed to edit this event as an attendee." : "Kutsutuna pole sul õigust selle sündmuse muutmiseks.",
    "W" : "Nd",
    "%n more" : "Veel %n",
    "No events to display" : "Pole sündmusi, mida kuvada",
    "All participants declined" : "Kõik  osalejad keeldusid",
    "Please confirm your participation" : "Palun kinnita oma osalemine",
    "You declined this event" : "Sa keeldusid sündmusel osalemast",
    "Your participation is tentative" : "Oled esialgselt kinnitanud oma osalemise",
    "_+%n more_::_+%n more_" : ["veel +%n","veel +%n"],
    "No events" : "Sündmusi pole",
    "Create a new event or change the visible time-range" : "Loo uus sündmus või muuda kuvatavat ajavahemikku",
    "Failed to save event" : "Sündmust ei õnnestu salvestada",
    "It might have been deleted, or there was a typo in a link" : "Ta kas on kustutatud või on lingis trükiviga",
    "It might have been deleted, or there was a typo in the link" : "Ta kas on kustutatud või on lingis trükiviga",
    "Meeting room" : "Koosolekuruum",
    "Lecture hall" : "Loengusaal",
    "Seminar room" : "Seminariruum",
    "Other" : "Muu",
    "When shared show" : "Jagamisel näita",
    "When shared show full event" : "Kui on jagatud, siis näita kogu sündmust",
    "When shared show only busy" : "Kui on jagatud, siis näita ainult, kas on hõivatud",
    "When shared hide this event" : "Kui on jagatud, siis peida see sündmus",
    "The visibility of this event in read-only shared calendars." : "Selle sündmuse nähtavus jagatud kalendrites, millel on vaid lugemisõigus.",
    "Add a location" : "Lisa asukoht",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Lisa kirjeldus\n\n- Mis on kohtumise teema\n- Päevakorrapunktid\n- Kõik, milleks osalejad peaks valmistuma",
    "Status" : "Staatus",
    "Confirmed" : "Kinnitatud",
    "Canceled" : "Tühistatud",
    "Confirmation about the overall status of the event." : "Kinnitus ürituse üldise oleku kohta.",
    "Show as" : "Näita kui",
    "Take this event into account when calculating free-busy information." : "Arvesta selle sündmusega Vaba/Hõivatud olekute tuvastamisel.",
    "Categories" : "Kategooriad",
    "Categories help you to structure and organize your events." : "Kategooriad aitavad sul oma sündmusi struktureerida ja korraldada.",
    "Search or add categories" : "Otsi või lisa kategooriaid",
    "Add this as a new category" : "Lisa see uue kategooriana",
    "Custom color" : "Sinu valitud värv",
    "Special color of this event. Overrides the calendar-color." : "Sellele sündmusele määratud värv, mis asendab kalendri standardvärvi.",
    "Error while sharing file" : "Viga faili jagamisel",
    "Error while sharing file with user" : "Viga kasutajale jagamisel",
    "Error creating a folder {folder}" : "Viga {folder} kausta loomisel",
    "Attachment {fileName} already exists!" : "Manus nimega „{fileName}“ on  juba olemas!",
    "Attachment {fileName} added!" : "{fileName} manus on lisatud!",
    "An error occurred during uploading file {fileName}" : "Viga {fileName} faili üleslaadimisel",
    "An error occurred during getting file information" : "Failiteabe kättesaamisel tekkis viga",
    "Talk conversation for proposal" : "Ettepanekuga seotud vestlus kõnerakenduses",
    "An error occurred, unable to delete the calendar." : "Tekkis viga ja kalendri kustutamine pole võimalik.",
    "Imported {filename}" : "Importisin „{filename}“ faili",
    "This is an event reminder." : "See on sündmuse meeldetuletus.",
    "Error while parsing a PROPFIND error" : "Viga PROPFIND-meetodi vea töötlemisel",
    "Appointment not found" : "Kokkulepitud kohtumist ei leidu",
    "User not found" : "Kasutajat ei leitud",
    "Hidden" : "Peidetud",
    "can edit" : "saab muuta",
    "Calendar name …" : "Kalendri nimi…",
    "Default attachments location" : "Manuste vaikimisi asukoht",
    "Automatic ({detected})" : "Automaatne ({detected})",
    "Shortcut overview" : "Kiirklahvide ülevaade",
    "CalDAV link copied to clipboard." : "CalDAV-i link on kopeeritud lõikelauale.",
    "CalDAV link could not be copied to clipboard." : "CalDAV-i linki ei õnnestunud lõikelauale kopeerida.",
    "Enable birthday calendar" : "Lülita sisse sünnipäevade kalender",
    "Show tasks in calendar" : "Näita kalendris ülesandeid",
    "Enable simplified editor" : "Kasuta lihtsat muutmisvaadet",
    "Limit the number of events displayed in the monthly view" : "Piira kuuvaates kuvatavate sündmuste arvu",
    "Show weekends" : "Näita nädalavahetusi",
    "Show week numbers" : "Näita nädalanumberid",
    "Time increments" : "Ajasammud",
    "Default calendar for incoming invitations" : "Vaikimisi kalender sulle saadetud kutsetele",
    "Copy primary CalDAV address" : "Kopeeri primaarne CalDAV-i aadress",
    "Copy iOS/macOS CalDAV address" : "Kopeeri CalDAV-i aadress iOS/macOS-i jaoks",
    "Personal availability settings" : "Isikliku kohaloleku seadistused",
    "Show keyboard shortcuts" : "Näita klaviatuuri kiirklahve",
    "Create a new public conversation" : "Loo uus avalik vestlus",
    "{invitedCount} invited, {confirmedCount} confirmed" : "Kutseid saadetud: {invitedCount}, kinnitusi on {confirmedCount}",
    "Successfully appended link to talk room to location." : "Kõnerakenduse jututoa lingi lisamine asukohale õnnestus.",
    "Successfully appended link to talk room to description." : "Kõnerakenduse jututoa lingi lisamine kirjeldusele õnnestus.",
    "Error creating Talk room" : "Viga Kõnerakenduse jututoa loomisel",
    "_%n more guest_::_%n more guests_" : ["veel %n külaline","veel %n külalist"],
    "The visibility of this event in shared calendars." : "Selle sündmuse nähtavus jagatud kalendrites."
},
"nplurals=2; plural=(n != 1);");
