OC.L10N.register(
    "calendar",
    {
    "Hello," : "Azul,",
    "Open »%s«" : "Ldi »%s«",
    "Calendar" : "Awitay",
    "Confirm" : "Sergeg",
    "Description:" : "Aglam:",
    "Comment:" : "Awennit:",
    "Location:" : "Adig:",
    "Previous day" : "Ass yezrin",
    "Previous week" : "Amalas yezrin",
    "Previous year" : "Ilindi",
    "Previous month" : "Ayyur yezrin",
    "Next year" : "Qabel",
    "Today" : "Ass-a",
    "Day" : "Ass",
    "Week" : "Amalas",
    "Month" : "Ayyur",
    "Year" : "Aseggas",
    "List" : "Tabdart",
    "Copy link" : "Nɣel aseɣwen",
    "Edit" : "Ẓreg",
    "Delete" : "Kkes",
    "Create new" : "Snulfu-d amaynut",
    "Calendars" : "Iwitayen",
    "Add new" : "Rnu amaynut",
    "New calendar" : "Awitay amaynut",
    "Name" : "Isem",
    "Deleted" : "Yettwakkes",
    "Delete permanently" : "Kkes-it i lebda",
    "Share link" : "Bḍu aseɣwen",
    "Save" : "Sekles",
    "Filename" : "Isem n ufaylu",
    "Cancel" : "Semmet",
    "Navigation" : "Tunigin",
    "List view" : "Timeẓri n tebdart",
    "Actions" : "Tigawin",
    "Editor" : "Amaẓrag",
    "Close editor" : "Mdel amaẓrag",
    "or" : "neɣ",
    "General" : "Amatu",
    "Appearance" : "Udem",
    "Location" : "Adig",
    "Description" : "Aglam",
    "Add" : "Rnu",
    "Monday" : "Arim",
    "Tuesday" : "Aram",
    "Wednesday" : "Ahad",
    "Thursday" : "Amhad",
    "Friday" : "Sem",
    "Saturday" : "Sed",
    "Sunday" : "Acer",
    "Your name" : "Isem-ik·im",
    "Back" : "Uɣal",
    "Notification" : "Alɣu",
    "Email" : "Imayl",
    "days" : "ussan",
    "Proceed" : "Kemmel",
    "Delete file" : "Kkes afaylu",
    "Done" : "Immed",
    "Busy" : "Ur yestuf ara",
    "Unknown" : "Arussin",
    "Yes" : "Ih",
    "No" : "Uhu",
    "None" : "Ula d yiwen",
    "Create" : "Snulfu-d",
    "Personal" : "Udmawan",
    "Close" : "Mdel",
    "Selected" : "Yettwafren",
    "Title" : "Azwel",
    "Participants" : "Imttekkiyen",
    "Daily" : "S wass",
    "Weekly" : "S umalas",
    "Other" : "Wayeḍ",
    "Status" : "Addad",
    "Categories" : "Taggayin"
},
"nplurals=2; plural=(n != 1);");
