OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "عنوان البريد طويل جداً",
    "User-Session unexpectedly expired" : "إنتهت صلاحية جلسة المستخدم بشكل غير متوقع",
    "Provided email-address is not valid" : "عنوان البريد الإلكتروني غير صالح",
    "%s has published the calendar »%s«" : "%s نشر التقويم »%s«",
    "Unexpected error sending email. Please contact your administrator." : "حدث خطأ اثناء إرسال البريد. تحقّق من إعدادات البريد او تواصل مع مسؤول النظام.",
    "Successfully sent email to %1$s" : "تم إرسال الإيميل إلى %1$s بنجاح.",
    "Hello," : "مرحباً،",
    "We wanted to inform you that %s has published the calendar »%s«." : "المستخدم %s قام بنشر تقويم »%s«.",
    "Open »%s«" : "فتح »%s«",
    "Cheers!" : "تحياتي!",
    "Upcoming events" : "الأحداث القادمة",
    "No more events today" : "لا يوجد المزيد من الفعاليات اليوم",
    "No upcoming events" : "ليست هناك أحداث قادمة",
    "More events" : "أحداث أخرى",
    "%1$s with %2$s" : "%1$s مع %2$s",
    "Calendar" : "التقويم",
    "New booking {booking}" : "حجز جديد {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) قام بحجز الموعد \"{config_display_name}\" في {date_time}.",
    "Appointments" : "المواعيد",
    "Schedule appointment \"%s\"" : "جدولة الموعد \"%s\"",
    "Schedule an appointment" : "جدولة موعد",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : "تحضير لـ %s",
    "Follow up for %s" : "متابعة لـ %s",
    "Your appointment \"%s\" with %s needs confirmation" : "موعدك \"%s\" مع %s يحتاج إلى توكيد.",
    "Dear %s, please confirm your booking" : "السيد/السيدة %s؛ رجاءً، قم بتأكيد حجز موعدك.",
    "Confirm" : "تأكيد",
    "Appointment with:" : "موعد مع: ",
    "Description:" : "الوصف:",
    "This confirmation link expires in %s hours." : "رابط التأكيد هذا تنتهي صلاحيته بعد%s ساعات..",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "إذا كنت ترغب في إلغاء الموعد، فيُرجى الاتصال بمُنظّم الحدث عن طريق الرّد على هذا البريد الإلكتروني أو عن طريق زيارة صفحة ملفه الشخصي.",
    "Your appointment \"%s\" with %s has been accepted" : "موعدك \"%s\" مع %s تمّ قبوله",
    "Dear %s, your booking has been accepted." : "السيد/السيدة %s, حجزك ثم قبوله.",
    "Appointment for:" : "موعد لـ :",
    "Date:" : "التاريخ:",
    "You will receive a link with the confirmation email" : "سوف تستلم رابطاً في رسالة التأكيد عبر البريد الإلكتروني",
    "Where:" : "المكان:",
    "Comment:" : "ملاحظات:",
    "You have a new appointment booking \"%s\" from %s" : "لديك حجز موعدٍ جديدٍ \"%s\" من %s",
    "Dear %s, %s (%s) booked an appointment with you." : "السيد/السيدة %s, %s (%s) حجز موعداً معك.",
    "Location:" : "المكان :",
    "Duration:" : "المدة الزمنية:",
    "A Calendar app for Nextcloud" : "تطبيق التقويم لـ نكست كلاود",
    "Previous day" : "أمس",
    "Previous week" : "الأسبوع الماضي",
    "Previous year" : "العام الماضى",
    "Previous month" : "الشهر الماضي",
    "Next day" : "غداً",
    "Next week" : "الأسبوع القادم",
    "Next year" : "العام القادم",
    "Next month" : "الشهر القادم",
    "Create new event" : "إنشاء حدث جديد",
    "Event" : "حدث",
    "Today" : "اليوم",
    "Day" : "يوم",
    "Week" : "أسبوع",
    "Month" : "شهر",
    "Year" : "السنة",
    "List" : "قائمة",
    "Appointment link was copied to clipboard" : "تمّ نسخ رابط الموعد في الحافظة",
    "Appointment link could not be copied to clipboard" : "تعذّر نسخ رابط الموعد في الحافظة",
    "Preview" : "معاينة",
    "Copy link" : "نسخ الرابط",
    "Edit" : "تعديل",
    "Delete" : "حذف ",
    "Appointment schedules" : "جداول المواعيد",
    "Create new" : "إنشاء جديد",
    "Disable calendar \"{calendar}\"" : "إيقاف التقويم \"{calendar}\"",
    "Disable untitled calendar" : "إيقاف تقويم بدون اسم",
    "Enable calendar \"{calendar}\"" : "تمكين التقويم \"{calendar}\"",
    "Enable untitled calendar" : "تمكين التقويم بدون اسم",
    "An error occurred, unable to change visibility of the calendar." : "حدث خطأ، لا يمكن تعديل وضعية ظهور التقويم.",
    "Untitled calendar" : "تقويم بدون اسم",
    "Shared with you by" : "مشاركة معك من قِبَل",
    "Edit and share calendar" : "تعديل ومشاركة التقويم",
    "Edit calendar" : "تعديل التقويم",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["إلغاء مشاركة التقويم في {countdown} ثواني","إلغاء مشاركة التقويم في {countdown} ثانية","إلغاء مشاركة التقويم في {countdown} ثواني","إلغاء مشاركة التقويم في {countdown} ثواني","إلغاء مشاركة التقويم في {countdown} ثواني","إلغاء مشاركة التقويم في {countdown} ثواني"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["حذف التقويم في {countdown} ثواني","حذف التقويم في {countdown} ثانية","حذف التقويم في {countdown} ثواني","حذف التقويم في {countdown} ثواني","حذف التقويم في {countdown} ثواني","حذف التقويم في {countdown} ثواني"],
    "An error occurred, unable to create the calendar." : "حدث خطأ، يتعذّر إنشاء التقويم.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "يرجى ادخال رابطٍ صحيحٍ (يبدأ بـ https://, http://, webcals://, webcal://)",
    "Calendars" : "التقاويم",
    "Add new" : "إضافة جديد",
    "New calendar" : "تقويم جديد",
    "Name for new calendar" : "اسم التقويم الجديد",
    "Creating calendar …" : "جارٍ إنشاء التقويم…",
    "New calendar with task list" : "تقويم جديد مع قائمة مهام",
    "New subscription from link (read-only)" : "إشتراك جديد عن طريق رابط (للقراءة فقط)",
    "Creating subscription …" : "جارٍ إنشاء اشتراك…",
    "Add public holiday calendar" : "أضف تقويم العطلات العامة",
    "Add custom public calendar" : "إضافة تقويم عام مخصّص",
    "Calendar link copied to clipboard." : "تم نسخ رابط التقويم إلى الحافظة.",
    "Calendar link could not be copied to clipboard." : "تعذّر نسخ رابط التقويم إلى الحافظة.",
    "Copy subscription link" : "نسخ رابط الاشتراك",
    "Copying link …" : "جارٍ نسخ رابط  …",
    "Copied link" : "تمّ نسخ الرابط",
    "Could not copy link" : "تعذّر نسخ الرابط",
    "Export" : "تصدير",
    "Untitled item" : "عنصر بلا اسم",
    "Unknown calendar" : "تقويم غير معروف",
    "Could not load deleted calendars and objects" : "تعذّر تحميل التقاويم و الأشياء المحذوفة ",
    "Could not delete calendar or event" : "تعذّر حذف التقويم أو الحدث",
    "Could not restore calendar or event" : "تعذرت استعادة تقويم أو حدث",
    "Do you really want to empty the trash bin?" : "هل ترغب بالفعل في تفريغ سلة المهملات؟",
    "Empty trash bin" : "تفريغ سلة المهملات",
    "Trash bin" : "سلة المهملات",
    "Loading deleted items." : "تحميل العناصر المحذوفة",
    "You do not have any deleted items." : "لا توجد أي عناصر محذوفة",
    "Name" : "الاسم",
    "Deleted" : "تمّ حذفه",
    "Restore" : "استعادة ",
    "Delete permanently" : "حذف نهائي",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["حذف العناصر الموجودة في سلة المهملات بعد {numDays} أيام","حذف العناصر الموجودة في سلة المهملات بعد {numDays} يوم","حذف العناصر الموجودة في سلة المهملات بعد {numDays} أيام","حذف العناصر الموجودة في سلة المهملات بعد {numDays} أيام","حذف العناصر الموجودة في سلة المهملات بعد {numDays} أيام","حذف العناصر الموجودة في سلة المهملات بعد {numDays} أيام"],
    "Could not update calendar order." : "لا يمكن تعديل ترتيب التقويم.",
    "Shared calendars" : "تقاويم مشتركة",
    "Deck" : "البطاقات",
    "Internal link" : "رابط داخلي",
    "A private link that can be used with external clients" : "رابط خاص يمكن استخدامه مع العملاء الخارجيين",
    "Copy internal link" : "إنسخ الرابط الداخلي",
    "An error occurred, unable to publish calendar." : "حدث خطأ، لا يمكن نشر التقويم",
    "An error occurred, unable to send email." : "حدث خطأ، لا يُمكن إرسال البريد.",
    "Embed code copied to clipboard." : "الكود المُضمّن تمّ نسخه إلى الحافظة",
    "Embed code could not be copied to clipboard." : "الكود المُضمّن تعذّر نسخه إلى الحافظة",
    "Unpublishing calendar failed" : "محاولة إلغاء نشر التقويم أخفقت",
    "Share link" : "رابط مشاركة",
    "Copy public link" : "نسخ الرابط العام",
    "Send link to calendar via email" : "إرسال رابط التقويم عبر الإيمل",
    "Enter one address" : "أدخِل عنواناً بريدياً واحداً",
    "Sending email …" : "جارٍ إرسال البريد  …",
    "Copy embedding code" : "نسخ كود التضمين",
    "Copying code …" : "نسخ الكود  …",
    "Copied code" : "تمّ نسخ الكود",
    "Could not copy code" : "تعذّر نسخ الكود",
    "Delete share link" : "حذف رابط المشاركة",
    "Deleting share link …" : "حذف رابط المشاركة  …",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (فريق)",
    "An error occurred while unsharing the calendar." : "حدث خطأ أثناء إلغاء مشاركة التقويم",
    "An error occurred, unable to change the permission of the share." : "حدث خطأ، لا يمكن تعديل صلاحيات نشر التقويم.",
    "Unshare with {displayName}" : "إلغاء المشاركة مع {displayName}",
    "Share with users or groups" : "شارك مع مستخدمين او مجموعات",
    "No users or groups" : "لا يوجد مستخدمين أو مجموعات",
    "Failed to save calendar name and color" : "تعذّر حفظ اسم و لون التقويم",
    "Never show me as busy (set this calendar to transparent)" : "لا تُظهرني مطلقًا مشغولاً (اضبط هذا التقويم على شفاف)",
    "Share calendar" : "مُشاركة التقويم",
    "Unshare from me" : "أنت ألغيت المشاركة",
    "Save" : "حفظ",
    "No title" : "بدون عنوان",
    "View" : "عرض",
    "Import calendars" : "استيراد التقويم",
    "Please select a calendar to import into …" : "يرجى اختيار تقويم للاستيراد اليه  …",
    "Filename" : "اسم الملف",
    "Calendar to import into" : "تقويم للاستيراد اليه",
    "Cancel" : "إلغاء",
    "_Import calendar_::_Import calendars_" : ["استيراد التقويم","استيراد التقويم","استيراد التقويم","استيراد التقويم","استيراد التقويم","استيراد التقويم"],
    "Select the default location for attachments" : "عيّن موقع المُرفقات التلقائي",
    "Pick" : "إختر",
    "Invalid location selected" : "الموقع المُختار غير صحيح",
    "Attachments folder successfully saved." : "تمّ بنجاح حفظ مُجلّد المُرفقات",
    "Error on saving attachments folder." : "خطأ في حفظ مُجلّد المُرفقات",
    "Attachments folder" : "مجلد المرفقات",
    "{filename} could not be parsed" : "{filename} لم يُمكن تحليله",
    "No valid files found, aborting import" : "لم يٌمكن إيجاد ملفّاتٍ صحيحة. إنهاءُ عملية الاستيراد",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["تم استيراد %n أحداث بنجاح","تم استيراد %n حدث بنجاح","تم استيراد %n أحداث بنجاح","تم استيراد %n أحداث بنجاح","تم استيراد %n أحداث بنجاح","تم استيراد %n أحداث بنجاح"],
    "Import partially failed. Imported {accepted} out of {total}." : "الاستيراد فشل جزئيّاً. تمّ استيراد {accepted} من مجموع {total}.",
    "Automatic" : "تلقائي",
    "Automatic ({timezone})" : "تلقائي ({timezone})",
    "New setting was not saved successfully." : "لم يتم حفظ الاعدادات الجديدة.",
    "Timezone" : "المنطقة الزمنية",
    "Navigation" : "التنقل",
    "Previous period" : "الفترة السابقة",
    "Next period" : "الفترة القادمة",
    "Views" : "مشاهدات",
    "Day view" : "مشاهدات يومية",
    "Week view" : "مشاهدات اسبوعية",
    "Month view" : "مشاهدات شهرية",
    "Year view" : "عرض السنة",
    "List view" : "عرض على شكل قائمة",
    "Actions" : "الإجراءات",
    "Create event" : "انشاء فعالية",
    "Show shortcuts" : "انشاء اختصارات",
    "Editor" : "المحرر",
    "Close editor" : "إغلاق المحرر",
    "Save edited event" : "حفظ تعديلات الأحداث",
    "Delete edited event" : "حذف الأحداث المحررة",
    "Duplicate event" : "تكرار الحدث",
    "or" : "او",
    "Calendar settings" : "إعدادات التقويم",
    "At event start" : "في بداية الحدث",
    "No reminder" : "لا يوجد تذكير ",
    "Failed to save default calendar" : "تعذّر حفظ التقويم التلقائي",
    "General" : "عامٌّ",
    "Appearance" : "المظهر",
    "Editing" : "جارِ التعديل",
    "Default reminder" : "التذكير الافتراضي",
    "Files" : "الملفّات",
    "Appointment schedule successfully created" : "تمّ إنشاء جدول المواعيد بنجاح",
    "Appointment schedule successfully updated" : "تمّ تحديث جدول المواعيد بنجاح",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} دقائق","{duration} دقيقة","{duration} دقائق","{duration} دقائق","{duration} دقائق","{duration} دقائق"],
    "0 minutes" : "0 دقيقة",
    "_{duration} hour_::_{duration} hours_" : ["{duration} ساعات","{duration} ساعة","{duration} ساعات","{duration} ساعات","{duration} ساعات","{duration} ساعات"],
    "_{duration} day_::_{duration} days_" : ["{duration} أيام","{duration} يوم","{duration} أيام","{duration} أيام","{duration} أيام","{duration} أيام"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} أسابيع","{duration} أسبوع","{duration} أسابيع","{duration} أسابيع","{duration} أسابيع","{duration} أسابيع"],
    "_{duration} month_::_{duration} months_" : ["{duration} شهور","{duration} شهر","{duration} شهور","{duration} شهور","{duration} شهور","{duration} شهور"],
    "_{duration} year_::_{duration} years_" : ["{duration} سنوات","{duration} سنة","{duration} سنوات","{duration} سنوات","{duration} سنوات","{duration} سنوات"],
    "To configure appointments, add your email address in personal settings." : "ليُمكنك إعداد المواعيد، يتوجب إضافة عنوان إيميلك الشخصي في إعداداتك الشخصية.",
    "Public – shown on the profile page" : "عمومي - أعرض في صفحة الملف الشخصي",
    "Private – only accessible via secret link" : "خصوصي - يُمكن فقط الوصول إليه عن طريق رابط سرّي",
    "Appointment schedule saved" : "تمّ حفظ جدول المواعيد",
    "Create appointment schedule" : "إنشاء جدول مواعيد",
    "Edit appointment schedule" : "تعديل جدول المواعيد",
    "Update" : "حدث",
    "Appointment name" : "اسم الموعد",
    "Location" : "الموقع",
    "Create a Talk room" : "إنشاء غرفة محادثة",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "سيتم إنشاء رابط خاص بكل موعد محجوز و سيتم إرساله عبر البريد الإلكتروني للتأكيد",
    "Description" : "الوصف",
    "Visibility" : "الرؤية",
    "Duration" : "المدة الزمنية",
    "Increments" : "الزيادات",
    "Additional calendars to check for conflicts" : "تقاويم إضافية للتحقّق من وجود تعارضات",
    "Pick time ranges where appointments are allowed" : "إختر النطاقات الزمنية التي يُسمح فيها بالمواعيد",
    "to" : "إلى",
    "Delete slot" : "حذف الخانة الزمنية",
    "No times set" : "لم يتم تحديد أي أوقات",
    "Add" : "إضافة",
    "Monday" : "الإثنين",
    "Tuesday" : "الثلاثاء",
    "Wednesday" : "الأربعاء",
    "Thursday" : "الخميس",
    "Friday" : "الجمعة",
    "Saturday" : "السبت",
    "Sunday" : "الأحد",
    "Weekdays" : "أيام الأسبوع",
    "Add time before and after the event" : "أضف مُهلة زمنية قبل وبعد الحدث",
    "Before the event" : "قبل الحدث",
    "After the event" : "بعد الحدث",
    "Planning restrictions" : "قيود التخطيط",
    "Minimum time before next available slot" : "أقل مدة قبل الخانة الزمنية التالية",
    "Max slots per day" : "أقصى عدد من الخانات الزمنية في اليوم",
    "Limit how far in the future appointments can be booked" : "تقييد أبعد تاريخ في المستقبل يمكن حجز مواعيد فيه ",
    "It seems a rate limit has been reached. Please try again later." : "يبدو أن معدل قبول الوصول للنظام قد وصل حدّه الأقصى. يُرجى إعادة المحاولة في وقت لاحقٍ.",
    "Please confirm your reservation" : "رجاء، قم بتأكيد حجزك",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "لقد أرسلنا لك بريدًا إلكترونيًا يحتوي على التفاصيل. يرجى تأكيد موعدك باستخدام الرابط الموجود في البريد الإلكتروني. يمكنك إغلاق هذه الصفحة الآن.",
    "Your name" : "اسمك",
    "Your email address" : "عنوان البريد الإلكتروني الخاص بك",
    "Please share anything that will help prepare for our meeting" : "رجاءً، شارك ما يمكن أن يساعد في التحضير لاجتماعنا",
    "Could not book the appointment. Please try again later or contact the organizer." : "تعذّر حجز الموعد. حاول مرة أخرى في وقتٍ لاحق من فضلك أو اتصل بالمُنظِّم.",
    "Back" : "عودة",
    "Book appointment" : "إحجِز موعداً",
    "Error fetching Talk conversations." : "خطأ في جلب محادثات Talk.",
    "Conversation does not have a valid URL." : "عنوان URL للمحادثة غير صحيح.",
    "Successfully added Talk conversation link to location." : "تمت إضافة رابط المحادثة إلى الموقع بنجاح.",
    "Successfully added Talk conversation link to description." : "تمت إضافة رابط المحادثة إلى الوصف بنجاح.",
    "Failed to apply Talk room." : "تعذّر تطبيق غرفة المحادثة.",
    "Talk conversation for event" : "محادثة الحدث ",
    "Error creating Talk conversation" : "خطأ في إنشاء رابط المحادثة",
    "Select a Talk Room" : "إختَر غرفة المحادثة",
    "Add Talk conversation" : "إضِف محادثة Talk",
    "Fetching Talk rooms…" : "جلب معلومات غرف المحادثة ...",
    "No Talk room available" : "لاتوجد غرف محادثة متاحة",
    "Select conversation" : "اختر محادثة",
    "on" : "في",
    "at" : "عند",
    "before at" : "قبل",
    "Notification" : "تنبيه",
    "Email" : "البريد الإلكتروني",
    "Audio notification" : "تنبيه صوتي",
    "Other notification" : "تنبيه اخر",
    "Relative to event" : "مرتبط بفعالية",
    "On date" : "في تاريخ",
    "Edit time" : "تعديل الوقت",
    "Save time" : "حفظ الوقت",
    "Remove reminder" : "حذف التذكير",
    "Add reminder" : "أضف تذكيراً",
    "seconds" : "ثوانٍ",
    "minutes" : "دقائق",
    "hours" : "ساعات",
    "days" : "أيام",
    "weeks" : "أسابيع",
    "Choose a file to add as attachment" : "إختر ملفّاً لإضافته كمرفق",
    "Choose a file to share as a link" : "إختر ملفاً لمشاركته كرابط",
    "Attachment {name} already exist!" : "المُرفَق {name} موجودٌ سلفاً!",
    "Could not upload attachment(s)" : "تعذر رفع المرفق/المرفقات",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "يمكنك الانتقال إلى {host}. هل أنت متأكد أنك ترغب في المتابعة؟ الرابط: {link}",
    "Proceed" : "مواصلة",
    "No attachments" : "لا توجد مرفقات",
    "Add from Files" : "إضافة من الملفات",
    "Upload from device" : "رفع من الجهاز",
    "Delete file" : "حذف الملف",
    "Confirmation" : "تأكيد",
    "_{count} attachment_::_{count} attachments_" : ["{count} مرفقات","{count} مرفق","{count} مرفقات","{count} مرفقات","{count} مرفقات","{count} مرفقات"],
    "Suggested" : "مُقترح",
    "Available" : "مُتوفر",
    "Invitation accepted" : "تمّ قبول الدعوة",
    "Accepted {organizerName}'s invitation" : "قَبِلَ دعوة {organizerName}",
    "Participation marked as tentative" : "المُشاركة مبدئية",
    "Invitation is delegated" : "الدعوة تمّ تفويضها",
    "Not available" : "غير متوفر",
    "Invitation declined" : "الدعوة لم تُقبل",
    "Declined {organizerName}'s invitation" : "رفض دعوة {organizerName}",
    "Availability will be checked" : "سوف يتم اختبار التوافر",
    "Invitation will be sent" : "سوف يتم إرسال الدعوة",
    "Failed to check availability" : "تعذّر اختبار التوافر",
    "Failed to deliver invitation" : "تعذّر تسليم الدعوة",
    "Awaiting response" : "في انتظار الرّد",
    "Checking availability" : "تحقّق من التواجد",
    "Has not responded to {organizerName}'s invitation yet" : "لم يَرُدَّ على دعوة {organizerName} بعدُ",
    "chairperson" : "الرئيس",
    "required participant" : "المُشارِك المطلوب",
    "non-participant" : "غير مُشارِك",
    "optional participant" : "مُشارِك اختياري",
    "{organizer} (organizer)" : "{organizer} (مُنظِّم)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Availability of attendees, resources and rooms" : "توافر الحضور والموارد والغرف",
    "Suggestion accepted" : "تمّ قبول الاقتراح",
    "Legend" : "مفتاح تفسيري",
    "Out of office" : "خارج المكتب",
    "Attendees:" : "الحُضُور:",
    "Done" : "تمّ",
    "Search room" : "البحث في الغرفة",
    "Room name" : "اسم الغرفة",
    "Check room availability" : "تحقَّق من توافر الغرفة",
    "Free" : "مُتاحٌ",
    "Busy (tentative)" : "مشغولٌ (حاليّاً)",
    "Busy" : "مشغول",
    "Unknown" : "غير معروف",
    "Find a time" : "إيجاد وقت",
    "The invitation has been accepted successfully." : "تمّ قبول الدعوة بنجاح.",
    "Failed to accept the invitation." : "فشل في قبول الدعوة.",
    "The invitation has been declined successfully." : "تمّ رفض الدعوة بنجاح.",
    "Failed to decline the invitation." : "فشل في رفض الدعوة.",
    "Your participation has been marked as tentative." : "تمّ وضع علامة \"مبدئية\" على مشاركتك.",
    "Failed to set the participation status to tentative." : "فشل في تعيين حالة المشاركة إلى مؤقتة.",
    "Accept" : "قبول",
    "Decline" : "رفض",
    "Tentative" : "مؤقت",
    "No attendees yet" : "لا يوجد حضور حتى الآن",
    "Attendees" : "المشاركون",
    "Remove group" : "حذف مجموعة",
    "Remove attendee" : "إلغاء شخص من قائمة الحضور",
    "Request reply" : "طلب الرّد",
    "Chairperson" : "الرئيس",
    "Required participant" : "مشارك مطلوب",
    "Optional participant" : "مشارك اختياري",
    "Non-participant" : "غير مشارك",
    "_%n member_::_%n members_" : ["%n عضواً","%n عضواً","%n عضواً","%n عضواً","%n عضواً","%n عضواً"],
    "Search for emails, users, contacts, contact groups or teams" : "البحث عن إيميلات، أو مستخدِمين، أو جهات اتصال، أو مجموعات، أو فِرَق",
    "No match found" : "لم يٌمكن إيجاد تطابق",
    "Note that members of circles get invited but are not synced yet." : "لاحظ أن أعضاء دوائر الاتصال تمّت دعوتهم لكن لم تتمّ مزامنتهم بعدُ.",
    "Note that members of contact groups get invited but are not synced yet." : "لاحظ أن أعضاء مجموعات الاتصال تتم تدعوتهم لكن لا تمكن مزامنهم بعدُ.",
    "(organizer)" : "(مُنظِّم)",
    "Make {label} the organizer" : "إجعَل {label} هو المُنظِّم",
    "Make {label} the organizer and attend" : "إجغعَل {label} هو المنظم و أحد الحضور",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "لإرسال الدعوات والتعامل مع الاستجابات [linkopen]، أضف بريدك الالكتروني في الإعدادات الشخصية [linkclose].",
    "Remove color" : "حذف لون",
    "Event title" : "عنوان الحدث",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "لم يُمكن تغيير إعداد \"كامل اليوم\" بالنسبة للأحداث التي هي جزء من مجموعة تكرارية. ",
    "From" : "مِن :",
    "To" : "إلى :",
    "Repeat" : "كرّر",
    "_time_::_times_" : ["مرات","مرة","مرات","مرات","مرات","مرات"],
    "never" : "أبداً",
    "on date" : "في تاريخ",
    "after" : "بعد",
    "End repeat" : "نهاية التكرار",
    "Select to end repeat" : "إختر نهاية التكرار",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "هذا الحدث هو استثناء من مجموعة التكرار. لا يمكنك إضافة شرط تكرار إليه.",
    "first" : "أول",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "التغيير في قاعدة التكرار سوف يُطبّق فقط على هذا التكرار و على التكرارات المستقبلية.",
    "Repeat every" : "تكرار كل",
    "By day of the month" : "بحسب اليوم من الشهر",
    "On the" : "في الـ",
    "_day_::_days_" : ["أيام","يوم","أيام","أيام","أيام","أيام"],
    "_week_::_weeks_" : ["أسابيع","أسبوع","أسابيع","أسابيع","أسابيع","أسابيع"],
    "_month_::_months_" : ["شهور","شهر","شهور","شهور","شهور","شهور"],
    "_year_::_years_" : ["سنه","سنه","سنه","سنوات","سنوات","سنوات"],
    "On specific day" : "في يومٍ مُحدَّد",
    "weekday" : "أيام الاسبوع",
    "weekend day" : "يوم نهاية الاسبوع",
    "Does not repeat" : "لا يتكرر",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "لا يدعم نكست كلاود تعريف التكرار لهذا الحدث بشكل كامل. إذا قمت بتحرير خيارات التكرار، فقد تفقد بعض التكرارات.",
    "No rooms or resources yet" : "لا توجد غرف يمكن حجزها حتى الآن",
    "Resources" : "الموارد",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatCapacity} مقاعد","{seatCapacity} مقعد","{seatCapacity} مقاعد","{seatCapacity} مقاعد","{seatCapacity} مقاعد","{seatCapacity} مقاعد"],
    "Add resource" : "إضافة مورِد",
    "Has a projector" : "لديه جهاز عرض",
    "Has a whiteboard" : "فيها لوحة whiteboard",
    "Wheelchair accessible" : "قابل للوصول بكراسي المعاقين",
    "Remove resource" : "حذف مورد",
    "Search for resources or rooms" : "البحث عن موارد  أو غُرَف",
    "available" : "متاح",
    "unavailable" : "غير متاح",
    "Show all rooms" : "إظهار كل الغرف",
    "Projector" : "عارض ضوئي projector",
    "Whiteboard" : "لوحة Whiteboard",
    "Room type" : "نوع الغرفة",
    "Any" : "أيّ",
    "Minimum seating capacity" : "الحد الأدنى لسعة الجلوس",
    "More details" : "تفاصيل أكثر",
    "Update this and all future" : "تغيير هذه و المستقبلية الأخرى",
    "Update this occurrence" : "تحديث هذا الحدوث",
    "Public calendar does not exist" : "التقويم العام غير موجود",
    "Maybe the share was deleted or has expired?" : "لربما كانت المشاركة محذوفة أو منتهية الصلاحية؟",
    "Yes" : "نعم",
    "No" : "لا",
    "Maybe" : "ربما",
    "None" : "لا شيء",
    "Create" : "إنشاء",
    "from {formattedDate}" : "من {formattedDate}",
    "to {formattedDate}" : "إلى {formattedDate}",
    "on {formattedDate}" : "في {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "من {formattedDate} عند {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "إلى {formattedDate} عند {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "في {formattedDate} عند {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} عند {formattedTime}",
    "Please enter a valid date" : "إختر تاريخاً صحيحاً",
    "Please enter a valid date and time" : "إختر تاريخاً و وقتاً صحيحاً",
    "Select a time zone" : "إختر المنطقة الزمنية",
    "Please select a time zone:" : "إختر المنطقة الزمنية من فضلك:",
    "Pick a time" : "إختر وقتاً",
    "Pick a date" : "إختر تاريخاً",
    "Type to search time zone" : "أكتب للبحث في المنطقة الزمنية ",
    "Global" : "عالمي",
    "Holidays in {region}" : "العطلات الرسمية في {region}",
    "An error occurred, unable to read public calendars." : "حدث خطأ؛ تعذّرت قراءة التقاويم العمومية.",
    "An error occurred, unable to subscribe to calendar." : "حدث خطأ؛ تعذّر الاشتراك في التقويم.",
    "Public holiday calendars" : "تقاويم العطلات العامة",
    "Public calendars" : "التقاويم العمومية",
    "No valid public calendars configured" : "لا توجد أيّ تقاويم عمومية مُهيّأة بالشكل الصحيح",
    "Speak to the server administrator to resolve this issue." : "تحدّث مع مسؤول النظام لحل هذا الإشكال.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "يتم توفير تقاويم العطلات العامة من موقع ثندربرد Thunderbird. سوف يتم تنزيل بيانات التقويم من {website}",
    "By {authors}" : "من قِبَل {authors}",
    "Subscribed" : "مشترك",
    "Subscribe" : "إشترك",
    "Could not fetch slots" : "تعذر تحميل الخانات الزمنية",
    "Select a date" : "إختر تاريخاً",
    "Select slot" : "إختر الخانة الزمنية",
    "No slots available" : "لا توجد خانة زمنية متاحة",
    "The slot for your appointment has been confirmed" : "تم تأكيد الموعد المحدد لك",
    "Appointment Details:" : "تفاصيل الموعد:",
    "Time:" : "الوقت:",
    "Booked for:" : "محجوز لـ :",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "شكراً. حجزك من {startDate} إلى {endDate} تمّ تأكيده.",
    "Book another appointment:" : "إحجز موعداً آخر:",
    "See all available slots" : "شاهد كل الخانات الزمنية المتاحة",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "موعدك من {startDate} إلى {endDate} غير متاح.",
    "Please book a different slot:" : "من فضلك، إختر خانة زمنية أخرى:",
    "Book an appointment with {name}" : "إحجز موعداً مع {name}",
    "No public appointments found for {name}" : "لم يُمكن إيجاد أي مواعيد عامة لـ {name}",
    "Personal" : "شخصي",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "الاكتشاف التلقائي للمنطقة الزمنية يُحدّد منطقتك الزمنية بالنسبة للتوقيت العالمي المُوحّد UTC. هذا على الأرجح نتيجة للتدابير الأمنية لمتصفح الويب الخاص بك. يُرجى ضبط المنطقة الزمنية يدويًا في إعدادات التقويم.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "لم يتم العثور على منطقتك الزمنية التي تمّت تهيئتها ({timezoneId}). تمّ الرجوع إلى التوقيت العالمي المُوحّد UTC. يرجى تغيير منطقتك الزمنية في الإعدادات، والإبلاغ عن هذه المشكلة.",
    "Availability of {displayName}" : "توافُر {displayName}",
    "Edit event" : "تعديل الحدث",
    "Event does not exist" : "الفعالية غير موجودة",
    "Duplicate" : "تكرار",
    "Delete this occurrence" : "حذف هذا الظهور",
    "Delete this and all future" : "حذف هذا الظهور والجميع في الستقبل",
    "All day" : "كامل اليوم",
    "Modifications wont get propagated to the organizer and other attendees" : "التعديلات لن يتم إذاعتها على المنظم والمشاركين الآخرين",
    "Managing shared access" : "إدارة الوصول المشترك",
    "Deny access" : "منع الوصول",
    "Invite" : "دعوة",
    "_User requires access to your file_::_Users require access to your file_" : ["يحتاج المستخدمون إلى الوصول إلى ملفك","يحتاج المستخدم إلى الوصول إلى ملفك","يحتاج المستخدمون إلى الوصول إلى ملفك","يحتاج المستخدمون إلى الوصول إلى ملفك","يحتاج المستخدمون إلى الوصول إلى ملفك","يحتاج المستخدمون إلى الوصول إلى ملفك"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["تتطلب المرفقات وصولاً مشتركًا","يتطلب المرفق وصولاً مشتركًا","تتطلب المرفقات وصولاً مشتركًا","تتطلب المرفقات وصولاً مشتركًا","تتطلب المرفقات وصولاً مشتركًا","تتطلب المرفقات وصولاً مشتركًا"],
    "Untitled event" : "حدث بدون اسم",
    "Close" : "إغلاق",
    "Modifications will not get propagated to the organizer and other attendees" : "التعديلات لن يتم إذاعتها على المنظم والمشاركين الآخرين",
    "Selected" : "مُحدّدة",
    "Title" : "العنوان",
    "30 min" : "30 دقيقة",
    "Participants" : "المشارِكون",
    "Submit" : "إرسال ",
    "Subscribe to {name}" : "اشتراك مع {name}",
    "Export {name}" : "تصدير {name}",
    "Show availability" : "أعرُض التوافر",
    "Anniversary" : "ذكرى سنوية",
    "Appointment" : "موعد",
    "Business" : "عمل",
    "Education" : "تعليم",
    "Holiday" : "عطلة",
    "Meeting" : "اجتماع",
    "Miscellaneous" : "متنوع",
    "Non-working hours" : "ساعات خارج العمل",
    "Not in office" : "خارج المكتب",
    "Phone call" : "مكالمة هاتفية",
    "Sick day" : "اجازة مرضية",
    "Special occasion" : "حدث خاص",
    "Travel" : "سفر",
    "Vacation" : "اجازة",
    "Midnight on the day the event starts" : "منتصف ليل اليوم الذي يبدأ فيه الحدث",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n أيام قبل الحدث في {formattedHourMinute}","%n يوم قبل الحدث في {formattedHourMinute}","%n أيام قبل الحدث في {formattedHourMinute}","%n أيام قبل الحدث في {formattedHourMinute}","%n أيام قبل الحدث في {formattedHourMinute}","%n أيام قبل الحدث في {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n أسابيع قبل الحدث في {formattedHourMinute}","%n أسبوع قبل الحدث في {formattedHourMinute}","%n أسابيع قبل الحدث في {formattedHourMinute}","%n أسابيع قبل الحدث في {formattedHourMinute}","%n أسابيع قبل الحدث في {formattedHourMinute}","%n أسابيع قبل الحدث في {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "في يوم الحدث عند {formattedHourMinute}",
    "at the event's start" : "في بداية الحدث",
    "at the event's end" : "في نهاية الحدث",
    "{time} before the event starts" : "{time} قبل بداية الحدث",
    "{time} before the event ends" : "{time} قبل نهاية الحدث",
    "{time} after the event starts" : "{time} بعد بداية الحدث",
    "{time} after the event ends" : "{time} بعد نهاية الحدث",
    "on {time}" : "في {time}",
    "on {time} ({timezoneId})" : "في {time} ({timezoneId})",
    "Week {number} of {year}" : "الأسبوع {number} من {year}",
    "Daily" : "يومي",
    "Weekly" : "أسبوعي",
    "Monthly" : "شهري",
    "Yearly" : "سنوي",
    "_Every %n day_::_Every %n days_" : ["كل %n أيام","كل %n يوم","كل %n أيام","كل %n أيام","كل  %nأيام","كل %n أيام"],
    "_Every %n week_::_Every %n weeks_" : ["كل%n أسابيع","كل%n أسبوع","كل %n أسابيع","كل %n أسابيع","كل %n أسابيع","كل %n أسابيع"],
    "_Every %n month_::_Every %n months_" : ["كل %n شهور","كل %nشهر","كل %n شهور","كل %n شهور","كل %n شهور","كل %n شهور"],
    "_Every %n year_::_Every %n years_" : ["كل %n سنوات","كل %n سنة","كل %n سنوات","كل %n سنوات","كل %n سنوات","كل %n سنوات"],
    "_on {weekday}_::_on {weekdays}_" : ["في {weekdays}","في {weekday}","في {weekdays}","في {weekdays}","في {weekdays}","في {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["في أيام {dayOfMonthList}","في يوم {dayOfMonthList}","في أيام {dayOfMonthList}","في أيام {dayOfMonthList}","في أيام {dayOfMonthList}","في أيام {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "في الـ {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {dayOfMonthList}" : "في شهر {monthNames} في {dayOfMonthList}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "في {monthNames} في الـ {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "حتى {untilDate}",
    "_%n time_::_%n times_" : ["%n مرات","%n مرة","%n مرات","%n مرات","%n مرات","%n مرات"],
    "second" : "ثاني",
    "third" : "ثالث",
    "fourth" : "رابع",
    "fifth" : "خامس",
    "second to last" : "الثاني إلى الاخير",
    "last" : "الأخير",
    "Untitled task" : "مهمة بدون اسم",
    "Please ask your administrator to enable the Tasks App." : "تواصل مع مسؤول النظام لاستخدام تطبيق المهام.",
    "You are not allowed to edit this event as an attendee." : "أنت غير مسموح لك بتعديل هذا الحدث كأحد الحضور.",
    "W" : "W",
    "%n more" : "%n المزيد",
    "No events to display" : "لا توجد أحداث",
    "All participants declined" : "رفض جميع المشاركين",
    "Please confirm your participation" : "رجاءً، قم بتأكيد مشاركتك",
    "You declined this event" : "أنت رفضت هذا الحدث",
    "Your participation is tentative" : "مشاركتك مبدئية غير نهائية",
    "_+%n more_::_+%n more_" : ["+ %n أكثر","+ %n أكثر","+ %n أكثر","+ %n أكثر","+ %n أكثر","+ %n أكثر"],
    "No events" : "لا توجد أحداث",
    "Create a new event or change the visible time-range" : "أنشيء حدثاً جديداً أو قم بتغيير المدى الزمني",
    "Failed to save event" : "تعذّر حفظ الحدث",
    "It might have been deleted, or there was a typo in a link" : "لربما تمّ حذفها، أو كان هناك خطأٌ هجائي في الرابط",
    "It might have been deleted, or there was a typo in the link" : "لربما تمّ حذفها، أو كان هناك خطأٌ هجائي في الرابط",
    "Meeting room" : "غرفة اجتماعات",
    "Lecture hall" : "قاعة محاضرات",
    "Seminar room" : "غرفة مناقشة",
    "Other" : "آخَر",
    "When shared show" : "عندما تظهر المشاركة",
    "When shared show full event" : "عرض الحدث كاملاً عند مشاركته",
    "When shared show only busy" : "عرض \"مشغول\" فقط عند مشاركته",
    "When shared hide this event" : "إخفاء هذا الحدث عند مشاركته",
    "Add a location" : "إضافة موقع",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "أضِف وصفاً:\n\n- ماهو موضوع الاجتماع\n- بنود الاجتماع\n- ما يحتاجه المشاركون إلى تحضيره للاجتماع",
    "Status" : "الحالة",
    "Confirmed" : "مؤكد",
    "Canceled" : "ملغي",
    "Confirmation about the overall status of the event." : "التأكيد بخصوص الحالة العامة للحدث.",
    "Show as" : "أظهر كـ",
    "Take this event into account when calculating free-busy information." : "ضع هذا الحدث في الاعتبار عند احتساب معلومة متوفر/ مشغول.",
    "Categories" : "التصنيفات",
    "Categories help you to structure and organize your events." : "التصنيفات تساعدك لهيكله وتنظيم أحداثك.",
    "Search or add categories" : "إبحث عن أو أضف تصنيفات",
    "Add this as a new category" : "أضفه كتصنيف جديد",
    "Custom color" : "لون مخصص",
    "Special color of this event. Overrides the calendar-color." : "اللون المخصص لهذا الحدث يغطي لون التقويم.",
    "Error while sharing file" : "خطأ اثناء مشاركة ملف",
    "Error while sharing file with user" : "حدث خطأ أثناء مُشاركة الملف مع مُستخدِم",
    "Attachment {fileName} already exists!" : "المُرفَق {fileName} موجودٌ سلفاً!",
    "An error occurred during getting file information" : "حدث خطأ أثناء جلب بيانات الملف",
    "An error occurred, unable to delete the calendar." : "حدث خطأ، لا يمكن حذف التقويم.",
    "Imported {filename}" : "إستيراد {filename}",
    "This is an event reminder." : "هذا تذكير بحدث",
    "Error while parsing a PROPFIND error" : "حدث خطأ أثناء تحليل PROFIND",
    "Appointment not found" : "الموعد غير موجود",
    "User not found" : "المستخدم غير موجود",
    "Hidden" : "مخفي",
    "can edit" : "يمكن التحرير",
    "Calendar name …" : "اسم التقويم ...",
    "Default attachments location" : "موقع المُرفقات التلقائي",
    "Automatic ({detected})" : "تلقائي ({detected})",
    "Shortcut overview" : "نظرة عامة للاختصارات",
    "CalDAV link copied to clipboard." : "تم نسخ CalDAV.",
    "CalDAV link could not be copied to clipboard." : "لا يمكن نسخ CalDAV.",
    "Enable birthday calendar" : "تفعيل تقويم عيد الميلاد",
    "Show tasks in calendar" : "إظهار المهام في التقويم",
    "Enable simplified editor" : "تفعيل المحرر البسيط",
    "Limit the number of events displayed in the monthly view" : "تقييد عدد الأحداث التي تُعرض في العرض الشهري",
    "Show weekends" : "إظهار أيام نهاية الاسبوع",
    "Show week numbers" : "إظهار أرقام الأسابيع",
    "Time increments" : "زيادات الوقت",
    "Default calendar for incoming invitations" : "التقويم التلقائي للدعوات الواردة",
    "Copy primary CalDAV address" : "نسخ عنوان CalDAV الرئيسي",
    "Copy iOS/macOS CalDAV address" : "نسخ عنوان CalDAV لأجهزة الماك/الأيفون",
    "Personal availability settings" : "إعدادات التواجد الشخصي",
    "Show keyboard shortcuts" : "إظهار اختصارات لوحة المفاتيح",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} مدعو, {confirmedCount} مؤكد",
    "Successfully appended link to talk room to location." : "تمّ إلحاق رابط غرفة المحادثة بالموقع بنجاح.",
    "Successfully appended link to talk room to description." : "تمّ إلحاق الرابط بوصف غرفة المحادثة بنجاح.",
    "Error creating Talk room" : "خطأ في انشاء غرفة محادثة",
    "_%n more guest_::_%n more guests_" : ["%n ضيفاً آخر","%n ضيفاً آخر","%n ضيفاً آخر","%n ضيوف آخرين","%n ضيفاً آخر","%n ضيفاً آخر"],
    "The visibility of this event in shared calendars." : "ظهور الحدث في التقاويم المشتركة."
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
