OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Provided email-address is too long",
    "User-Session unexpectedly expired" : "User-Session unexpectedly expired",
    "Provided email-address is not valid" : "Provided email address is not valid",
    "%s has published the calendar »%s«" : "%s has published the calendar »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Unexpected error sending email. Please contact your administrator.",
    "Successfully sent email to %1$s" : "Successfully sent email to %1$s",
    "Hello," : "Hello,",
    "We wanted to inform you that %s has published the calendar »%s«." : "We wanted to inform you that %s has published the calendar »%s«.",
    "Open »%s«" : "Open »%s«",
    "Cheers!" : "Cheers!",
    "Upcoming events" : "Upcoming events",
    "No more events today" : "No more events today",
    "No upcoming events" : "No upcoming events",
    "More events" : "More events",
    "%1$s with %2$s" : "%1$s with %2$s",
    "Calendar" : "Calendar",
    "New booking {booking}" : "New booking {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}.",
    "Appointments" : "Appointments",
    "Schedule appointment \"%s\"" : "Schedule appointment \"%s\"",
    "Schedule an appointment" : "Schedule an appointment",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : "Prepare for %s",
    "Follow up for %s" : "Follow up for %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Your appointment \"%s\" with %s needs confirmation",
    "Dear %s, please confirm your booking" : "Dear %s, please confirm your booking",
    "Confirm" : "Confirm",
    "Appointment with:" : "Appointment with:",
    "Description:" : "Description:",
    "This confirmation link expires in %s hours." : "This confirmation link expires in %s hours.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "If you wish to cancel the appointment after all, please contact your organiser by replying to this email or by visiting their profile page.",
    "Your appointment \"%s\" with %s has been accepted" : "Your appointment \"%s\" with %s has been accepted",
    "Dear %s, your booking has been accepted." : "Dear %s, your booking has been accepted.",
    "Appointment for:" : "Appointment for:",
    "Date:" : "Date:",
    "You will receive a link with the confirmation email" : "You will receive a link with the confirmation email",
    "Where:" : "Where:",
    "Comment:" : "Comment:",
    "You have a new appointment booking \"%s\" from %s" : "You have a new appointment booking \"%s\" from %s",
    "Dear %s, %s (%s) booked an appointment with you." : "Dear %s, %s (%s) booked an appointment with you.",
    "%s has proposed a meeting" : "%s has proposed a meeting",
    "%s has updated a proposed meeting" : "%s has updated a proposed meeting",
    "%s has canceled a proposed meeting" : "%s has canceled a proposed meeting",
    "Dear %s, a new meeting has been proposed" : "Dear %s, a new meeting has been proposed",
    "Dear %s, a proposed meeting has been updated" : "Dear %s, a proposed meeting has been updated",
    "Dear %s, a proposed meeting has been cancelled" : "Dear %s, a proposed meeting has been cancelled",
    "Location:" : "Location:",
    "Duration:" : "Duration:",
    "%1$s from %2$s to %3$s" : "%1$s from %2$s to %3$s",
    "Dates:" : "Dates:",
    "Respond" : "Respond",
    "A Calendar app for Nextcloud" : "A Calendar app for Nextcloud",
    "A Calendar app for Nextcloud. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Like Contacts, Talk, Tasks, Deck and Circles\n* 🌐 **WebCal Support!** Want to see your favorite team's matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 **Search!** Find your events at ease\n* ☑️ **Tasks!** See tasks or Deck cards with a due date directly in the calendar\n* 🔈 **Talk rooms!** Create an associated Talk room when booking a meeting with just one click\n* 📆 **Appointment booking** Send people a link so they can book an appointment with you [using this app](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Attachments!** Add, upload and view event attachments\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "A Calendar app for Nextcloud. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Like Contacts, Talk, Tasks, Deck and Circles\n* 🌐 **WebCal Support!** Want to see your favorite team's matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 **Search!** Find your events at ease\n* ☑️ **Tasks!** See tasks or Deck cards with a due date directly in the calendar\n* 🔈 **Talk rooms!** Create an associated Talk room when booking a meeting with just one click\n* 📆 **Appointment booking** Send people a link so they can book an appointment with you [using this app](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Attachments!** Add, upload and view event attachments\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries.",
    "Previous day" : "Previous day",
    "Previous week" : "Previous week",
    "Previous year" : "Previous year",
    "Previous month" : "Previous month",
    "Next day" : "Next day",
    "Next week" : "Next week",
    "Next year" : "Next year",
    "Next month" : "Next month",
    "Create new event" : "Create new event",
    "Event" : "Event",
    "Today" : "Today",
    "Day" : "Day",
    "Week" : "Week",
    "Month" : "Month",
    "Year" : "Year",
    "List" : "List",
    "Appointment link was copied to clipboard" : "Appointment link was copied to clipboard",
    "Appointment link could not be copied to clipboard" : "Appointment link could not be copied to clipboard",
    "Preview" : "Preview",
    "Copy link" : "Copy link",
    "Edit" : "Edit",
    "Delete" : "Delete",
    "Appointment schedules" : "Appointment schedules",
    "Create new" : "Create new",
    "Disable calendar \"{calendar}\"" : "Disable calendar \"{calendar}\"",
    "Disable untitled calendar" : "Disable untitled calendar",
    "Enable calendar \"{calendar}\"" : "Enable calendar \"{calendar}\"",
    "Enable untitled calendar" : "Enable untitled calendar",
    "An error occurred, unable to change visibility of the calendar." : "An error occurred, unable to change visibility of the calendar.",
    "Untitled calendar" : "Untitled calendar",
    "Shared with you by" : "Shared with you by",
    "Edit and share calendar" : "Edit and share calendar",
    "Edit calendar" : "Edit calendar",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Unsharing the calendar in {countdown} second","Unsharing the calendar in {countdown} seconds"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Deleting the calendar in {countdown} second","Deleting the calendar in {countdown} seconds"],
    "An error occurred, unable to create the calendar." : "An error occurred, unable to create the calendar.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)",
    "Calendars" : "Calendars",
    "Add new" : "Add new",
    "New calendar" : "New calendar",
    "Name for new calendar" : "Name for new calendar",
    "Creating calendar …" : "Creating calendar …",
    "New calendar with task list" : "New calendar with task list",
    "New subscription from link (read-only)" : "New subscription from link (read-only)",
    "Creating subscription …" : "Creating subscription …",
    "Add public holiday calendar" : "Add public holiday calendar",
    "Add custom public calendar" : "Add custom public calendar",
    "Calendar link copied to clipboard." : "Calendar link copied to clipboard.",
    "Calendar link could not be copied to clipboard." : "Calendar link could not be copied to clipboard.",
    "Copy subscription link" : "Copy subscription link",
    "Copying link …" : "Copying link …",
    "Copied link" : "Copied link",
    "Could not copy link" : "Could not copy link",
    "Export" : "Export",
    "Untitled item" : "Untitled item",
    "Unknown calendar" : "Unknown calendar",
    "Could not load deleted calendars and objects" : "Could not load deleted calendars and objects",
    "Could not delete calendar or event" : "Could not delete calendar or event",
    "Could not restore calendar or event" : "Could not restore calendar or event",
    "Do you really want to empty the trash bin?" : "Do you really want to empty the trash bin?",
    "Empty trash bin" : "Empty trash bin",
    "Trash bin" : "Trash bin",
    "Loading deleted items." : "Loading deleted items.",
    "You do not have any deleted items." : "You do not have any deleted items.",
    "Name" : "Surname",
    "Deleted" : "Deleted",
    "Restore" : "Restore",
    "Delete permanently" : "Delete permanently",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Items in the trash bin are deleted after {numDays} day","Items in the trash bin are deleted after {numDays} days"],
    "Could not update calendar order." : "Could not update calendar order.",
    "Shared calendars" : "Shared calendars",
    "Deck" : "Deck",
    "Internal link" : "Internal link",
    "A private link that can be used with external clients" : "A private link that can be used with external clients",
    "Copy internal link" : "Copy internal link",
    "An error occurred, unable to publish calendar." : "An error occurred, unable to publish calendar.",
    "An error occurred, unable to send email." : "An error occurred, unable to send email.",
    "Embed code copied to clipboard." : "Embed code copied to clipboard.",
    "Embed code could not be copied to clipboard." : "Embed code could not be copied to clipboard.",
    "Unpublishing calendar failed" : "Unpublishing calendar failed",
    "Share link" : "Share link",
    "Copy public link" : "Copy public link",
    "Send link to calendar via email" : "Send link to calendar via email",
    "Enter one address" : "Enter one address",
    "Sending email …" : "Sending email …",
    "Copy embedding code" : "Copy embedding code",
    "Copying code …" : "Copying code …",
    "Copied code" : "Copied code",
    "Could not copy code" : "Could not copy code",
    "Delete share link" : "Delete share link",
    "Deleting share link …" : "Deleting share link …",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Team)",
    "An error occurred while unsharing the calendar." : "An error occurred while unsharing the calendar.",
    "An error occurred, unable to change the permission of the share." : "An error occurred, unable to change the permission of the share.",
    "can edit and see confidential events" : "can edit and see confidential events",
    "Unshare with {displayName}" : "Unshare with {displayName}",
    "Share with users or groups" : "Share with users or groups",
    "No users or groups" : "No users or groups",
    "Failed to save calendar name and color" : "Failed to save calendar name and colour",
    "Calendar name …" : "Calendar name …",
    "Never show me as busy (set this calendar to transparent)" : "Never show me as busy (set this calendar to transparent)",
    "Share calendar" : "Share calendar",
    "Unshare from me" : "Unshare from me",
    "Save" : "Save",
    "No title" : "No title",
    "Are you sure you want to delete \"{title}\"?" : "Are you sure you want to delete \"{title}\"?",
    "Deleting proposal \"{title}\"" : "Deleting proposal \"{title}\"",
    "Successfully deleted proposal" : "Successfully deleted proposal",
    "Failed to delete proposal" : "Failed to delete proposal",
    "Failed to retrieve proposals" : "Failed to retrieve proposals",
    "Meeting proposals" : "Meeting proposals",
    "A configured email address is required to use meeting proposals" : "A configured email address is required to use meeting proposals",
    "No active meeting proposals" : "No active meeting proposals",
    "View" : "View",
    "Import calendars" : "Import calendars",
    "Please select a calendar to import into …" : "Please select a calendar to import into …",
    "Filename" : "Filename",
    "Calendar to import into" : "Calendar to import into",
    "Cancel" : "Cancel",
    "_Import calendar_::_Import calendars_" : ["Import calendar","Import calendars"],
    "Select the default location for attachments" : "Select the default location for attachments",
    "Pick" : "Pick",
    "Invalid location selected" : "Invalid location selected",
    "Attachments folder successfully saved." : "Attachments folder successfully saved.",
    "Error on saving attachments folder." : "Error on saving attachments folder.",
    "Attachments folder" : "Attachments folder",
    "{filename} could not be parsed" : "{filename} could not be parsed",
    "No valid files found, aborting import" : "No valid files found, aborting import",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Successfully imported %n event","Successfully imported %n events"],
    "Import partially failed. Imported {accepted} out of {total}." : "Import partially failed. Imported {accepted} out of {total}.",
    "Automatic" : "Automatic",
    "Automatic ({timezone})" : "Automatic ({timezone})",
    "New setting was not saved successfully." : "New setting was not saved successfully.",
    "Timezone" : "Timezone",
    "Navigation" : "Navigation",
    "Previous period" : "Previous period",
    "Next period" : "Next period",
    "Views" : "Views",
    "Day view" : "Day view",
    "Week view" : "Week view",
    "Month view" : "Month view",
    "Year view" : "Year view",
    "List view" : "List view",
    "Actions" : "Actions",
    "Create event" : "Create event",
    "Show shortcuts" : "Show shortcuts",
    "Editor" : "Editor",
    "Close editor" : "Close editor",
    "Save edited event" : "Save edited event",
    "Delete edited event" : "Delete edited event",
    "Duplicate event" : "Duplicate event",
    "or" : "or",
    "Calendar settings" : "Calendar settings",
    "At event start" : "At event start",
    "No reminder" : "No reminder",
    "Failed to save default calendar" : "Failed to save default calendar",
    "General" : "General",
    "Availability settings" : "Availability settings",
    "CalDAV" : "CalDAV",
    "Access Nextcloud calendars from other apps and devices" : "Access Nextcloud calendars from other apps and devices",
    "CalDAV URL" : "CalDAV URL",
    "Server Address for iOS and macOS" : "Server Address for iOS and macOS",
    "Appearance" : "Appearance",
    "Birthday calendar" : "Birthday calendar",
    "Tasks in calendar" : "Tasks in calendar",
    "Weekends" : "Weekends",
    "Week numbers" : "Week numbers",
    "Limit number of events shown in Month view" : "Limit number of events shown in Month view",
    "Density in Day and Week View" : "Density in Day and Week View",
    "Editing" : "Editing",
    "Default reminder" : "Default reminder",
    "Simple event editor" : "Simple event editor",
    "\"More details\" opens the detailed editor" : "\"More details\" opens the detailed editor",
    "Files" : "Files",
    "Appointment schedule successfully created" : "Appointment schedule successfully created",
    "Appointment schedule successfully updated" : "Appointment schedule successfully updated",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minute","{duration} minutes"],
    "0 minutes" : "0 minutes",
    "_{duration} hour_::_{duration} hours_" : ["{duration} hour","{duration} hours"],
    "_{duration} day_::_{duration} days_" : ["{duration} day","{duration} days"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} week","{duration} weeks"],
    "_{duration} month_::_{duration} months_" : ["{duration} month","{duration} months"],
    "_{duration} year_::_{duration} years_" : ["{duration} year","{duration} years"],
    "To configure appointments, add your email address in personal settings." : "To configure appointments, add your email address in personal settings.",
    "Public – shown on the profile page" : "Public – shown on the profile page",
    "Private – only accessible via secret link" : "Private – only accessible via secret link",
    "Appointment schedule saved" : "Appointment schedule saved",
    "Create appointment schedule" : "Create appointment schedule",
    "Edit appointment schedule" : "Edit appointment schedule",
    "Update" : "Update",
    "Appointment name" : "Appointment name",
    "Location" : "Location",
    "Create a Talk room" : "Create a Talk room",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "A unique link will be generated for every booked appointment and sent via the confirmation email",
    "Description" : "Description",
    "Visibility" : "Visibility",
    "Duration" : "Duration",
    "Increments" : "Increments",
    "Additional calendars to check for conflicts" : "Additional calendars to check for conflicts",
    "Pick time ranges where appointments are allowed" : "Pick time ranges where appointments are allowed",
    "to" : "to",
    "Delete slot" : "Delete slot",
    "No times set" : "No times set",
    "Add" : "Add",
    "Monday" : "Monday",
    "Tuesday" : "Tuesday",
    "Wednesday" : "Wednesday",
    "Thursday" : "Thursday",
    "Friday" : "Friday",
    "Saturday" : "Saturday",
    "Sunday" : "Sunday",
    "Weekdays" : "Weekdays",
    "Add time before and after the event" : "Add time before and after the event",
    "Before the event" : "Before the event",
    "After the event" : "After the event",
    "Planning restrictions" : "Planning restrictions",
    "Minimum time before next available slot" : "Minimum time before next available slot",
    "Max slots per day" : "Max slots per day",
    "Limit how far in the future appointments can be booked" : "Limit how far in the future appointments can be booked",
    "It seems a rate limit has been reached. Please try again later." : "It seems a rate limit has been reached. Please try again later.",
    "Please confirm your reservation" : "Please confirm your reservation",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now.",
    "Your name" : "Your name",
    "Your email address" : "Your email address",
    "Please share anything that will help prepare for our meeting" : "Please share anything that will help prepare for our meeting",
    "Could not book the appointment. Please try again later or contact the organizer." : "Could not book the appointment. Please try again later or contact the organiser.",
    "Back" : "Back",
    "Book appointment" : "Book appointment",
    "Error fetching Talk conversations." : "Error fetching Talk conversations.",
    "Conversation does not have a valid URL." : "Conversation does not have a valid URL.",
    "Successfully added Talk conversation link to location." : "Successfully added Talk conversation link to location.",
    "Successfully added Talk conversation link to description." : "Successfully added Talk conversation link to description.",
    "Failed to apply Talk room." : "Failed to apply Talk room.",
    "Talk conversation for event" : "Talk conversation for event",
    "Error creating Talk conversation" : "Error creating Talk conversation",
    "Select a Talk Room" : "Select a Talk Room",
    "Add Talk conversation" : "Add Talk conversation",
    "Fetching Talk rooms…" : "Fetching Talk rooms…",
    "No Talk room available" : "No Talk room available",
    "Create public conversation" : "Create public conversation",
    "Select conversation" : "Select conversation",
    "on" : "on",
    "at" : "at",
    "before at" : "before at",
    "Notification" : "Notification",
    "Email" : "Email",
    "Audio notification" : "Audio notification",
    "Other notification" : "Other notification",
    "Relative to event" : "Relative to event",
    "On date" : "On date",
    "Edit time" : "Edit time",
    "Save time" : "Save time",
    "Remove reminder" : "Remove reminder",
    "Add reminder" : "Add reminder",
    "seconds" : "seconds",
    "minutes" : "minutes",
    "hours" : "hours",
    "days" : "days",
    "weeks" : "weeks",
    "Choose a file to add as attachment" : "Choose a file to add as attachment",
    "Choose a file to share as a link" : "Choose a file to share as a link",
    "Attachment {name} already exist!" : "Attachment {name} already exist!",
    "Could not upload attachment(s)" : "Could not upload attachment(s)",
    "You are about to navigate to {link}. Are you sure to proceed?" : "You are about to navigate to {link}. Are you sure to proceed?",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "You are about to navigate to {host}. Are you sure to proceed? Link: {link}",
    "Proceed" : "Proceed",
    "No attachments" : "No attachments",
    "Add from Files" : "Add from Files",
    "Upload from device" : "Upload from device",
    "Delete file" : "Delete file",
    "Confirmation" : "Confirmation",
    "_{count} attachment_::_{count} attachments_" : ["{count} attachment","{count} attachments"],
    "Suggested" : "Suggested",
    "Available" : "Available",
    "Invitation accepted" : "Invitation accepted",
    "Accepted {organizerName}'s invitation" : "Accepted {organizerName}'s invitation",
    "Participation marked as tentative" : "Participation marked as tentative",
    "Invitation is delegated" : "Invitation is delegated",
    "Not available" : "Not available",
    "Invitation declined" : "Invitation declined",
    "Declined {organizerName}'s invitation" : "Declined {organizerName}'s invitation",
    "Availability will be checked" : "Availability will be checked",
    "Invitation will be sent" : "Invitation will be sent",
    "Failed to check availability" : "Failed to check availability",
    "Failed to deliver invitation" : "Failed to deliver invitation",
    "Awaiting response" : "Awaiting response",
    "Checking availability" : "Checking availability",
    "Has not responded to {organizerName}'s invitation yet" : "Has not responded to {organizerName}'s invitation yet",
    "Suggested times" : "Suggested times",
    "chairperson" : "chairperson",
    "required participant" : "required participant",
    "non-participant" : "non-participant",
    "optional participant" : "optional participant",
    "{organizer} (organizer)" : "{organizer} (organiser)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Selected slot" : "Selected slot",
    "Availability of attendees, resources and rooms" : "Availability of attendees, resources and rooms",
    "Suggestion accepted" : "Suggestion accepted",
    "Previous date" : "Previous date",
    "Next date" : "Next date",
    "Legend" : "Legend",
    "Out of office" : "Out of office",
    "Attendees:" : "Attendees:",
    "local time" : "local time",
    "Done" : "Done",
    "Search room" : "Search room",
    "Room name" : "Room name",
    "Check room availability" : "Check room availability",
    "Free" : "Free",
    "Busy (tentative)" : "Busy (tentative)",
    "Busy" : "Busy",
    "Unknown" : "Unknown",
    "Find a time" : "Find a time",
    "The invitation has been accepted successfully." : "The invitation has been accepted successfully.",
    "Failed to accept the invitation." : "Failed to accept the invitation.",
    "The invitation has been declined successfully." : "The invitation has been declined successfully.",
    "Failed to decline the invitation." : "Failed to decline the invitation.",
    "Your participation has been marked as tentative." : "Your participation has been marked as tentative.",
    "Failed to set the participation status to tentative." : "Failed to set the participation status to tentative.",
    "Accept" : "Accept",
    "Decline" : "Decline",
    "Tentative" : "Tentative",
    "No attendees yet" : "No attendees yet",
    "{confirmedCount} confirmed, {waitingCount} awaiting response" : "{confirmedCount} confirmed, {waitingCount} awaiting response",
    "Please add at least one attendee to use the \"Find a time\" feature." : "Please add at least one attendee to use the \"Find a time\" feature.",
    "Attendees" : "Attendees",
    "_%n more attendee_::_%n more attendees_" : ["%n more attendee","%n more attendees"],
    "Remove group" : "Remove group",
    "Remove attendee" : "Remove attendee",
    "Request reply" : "Request reply",
    "Chairperson" : "Chairperson",
    "Required participant" : "Required participant",
    "Optional participant" : "Optional participant",
    "Non-participant" : "Non-participant",
    "_%n member_::_%n members_" : ["%n member","%n members"],
    "Search for emails, users, contacts, contact groups or teams" : "Search for emails, users, contacts, contact groups or teams",
    "No match found" : "No match found",
    "Note that members of circles get invited but are not synced yet." : "Note that members of circles get invited but are not synced yet.",
    "Note that members of contact groups get invited but are not synced yet." : "Note that members of contact groups get invited but are not synced yet.",
    "(organizer)" : "(organiser)",
    "Make {label} the organizer" : "Make {label} the organiser",
    "Make {label} the organizer and attend" : "Make {label} the organiser and attend",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose].",
    "Remove color" : "Remove colour",
    "Event title" : "Event title",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Cannot modify all-day setting for events that are part of a recurrence-set.",
    "From" : "From",
    "To" : "To",
    "Your Time" : "Your Time",
    "Repeat" : "Repeat",
    "Repeat event" : "Repeat event",
    "_time_::_times_" : ["time","times"],
    "never" : "never",
    "on date" : "on date",
    "after" : "after",
    "End repeat" : "End repeat",
    "Select to end repeat" : "Select to end repeat",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it.",
    "first" : "first",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Changes to the recurrence-rule will only apply to this and all future occurrences.",
    "Repeat every" : "Repeat every",
    "By day of the month" : "By day of the month",
    "On the" : "On the",
    "_day_::_days_" : ["day","days"],
    "_week_::_weeks_" : ["week","weeks"],
    "_month_::_months_" : ["month","months"],
    "_year_::_years_" : ["year","years"],
    "On specific day" : "On specific day",
    "weekday" : "weekday",
    "weekend day" : "weekend day",
    "Does not repeat" : "Does not repeat",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost.",
    "No rooms or resources yet" : "No rooms or resources yet",
    "Resources" : "Resources",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} seat","{seatingCapacity} seats"],
    "Add resource" : "Add resource",
    "Has a projector" : "Has a projector",
    "Has a whiteboard" : "Has a whiteboard",
    "Wheelchair accessible" : "Wheelchair accessible",
    "Remove resource" : "Remove resource",
    "Search for resources or rooms" : "Search for resources or rooms",
    "available" : "available",
    "unavailable" : "unavailable",
    "Show all rooms" : "Show all rooms",
    "Projector" : "Projector",
    "Whiteboard" : "Whiteboard",
    "Room type" : "Room type",
    "Any" : "Any",
    "Minimum seating capacity" : "Minimum seating capacity",
    "More details" : "More details",
    "Update this and all future" : "Update this and all future",
    "Update this occurrence" : "Update this occurrence",
    "Public calendar does not exist" : "Public calendar does not exist",
    "Maybe the share was deleted or has expired?" : "Maybe the share was deleted or has expired?",
    "Remove date" : "Remove date",
    "Attendance required" : "Attendance required",
    "Attendance optional" : "Attendance optional",
    "Remove participant" : "Remove participant",
    "Yes" : "Yes",
    "No" : "No",
    "Maybe" : "Maybe",
    "None" : "None",
    "Select your meeting availability" : "Select your meeting availability",
    "Create a meeting for this date and time" : "Create a meeting for this date and time",
    "Create" : "Create",
    "No participants or dates available" : "No participants or dates available",
    "from {formattedDate}" : "from {formattedDate}",
    "to {formattedDate}" : "to {formattedDate}",
    "on {formattedDate}" : "on {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "from {formattedDate} at {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "to {formattedDate} at {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "on {formattedDate} at {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} at {formattedTime}",
    "Please enter a valid date" : "Please enter a valid date",
    "Please enter a valid date and time" : "Please enter a valid date and time",
    "Select a time zone" : "Select a time zone",
    "Please select a time zone:" : "Please select a time zone:",
    "Pick a time" : "Pick a time",
    "Pick a date" : "Pick a date",
    "Type to search time zone" : "Type to search time zone",
    "Global" : "Global",
    "Holidays in {region}" : "Holidays in {region}",
    "An error occurred, unable to read public calendars." : "An error occurred, unable to read public calendars.",
    "An error occurred, unable to subscribe to calendar." : "An error occurred, unable to subscribe to calendar.",
    "Public holiday calendars" : "Public holiday calendars",
    "Public calendars" : "Public calendars",
    "No valid public calendars configured" : "No valid public calendars configured",
    "Speak to the server administrator to resolve this issue." : "Speak to the server administrator to resolve this issue.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}",
    "These public calendars are suggested by the server administrator. Calendar data will be downloaded from the respective website." : "These public calendars are suggested by the server administrator. Calendar data will be downloaded from the respective website.",
    "By {authors}" : "By {authors}",
    "Subscribed" : "Subscribed",
    "Subscribe" : "Subscribe",
    "Could not fetch slots" : "Could not fetch slots",
    "Select a date" : "Select a date",
    "Select slot" : "Select slot",
    "No slots available" : "No slots available",
    "The slot for your appointment has been confirmed" : "The slot for your appointment has been confirmed",
    "Appointment Details:" : "Appointment Details:",
    "Time:" : "Time:",
    "Booked for:" : "Booked for:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Thank you. Your booking from {startDate} to {endDate} has been confirmed.",
    "Book another appointment:" : "Book another appointment:",
    "See all available slots" : "See all available slots",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "The slot for your appointment from {startDate} to {endDate} is not available any more.",
    "Please book a different slot:" : "Please book a different slot:",
    "Book an appointment with {name}" : "Book an appointment with {name}",
    "No public appointments found for {name}" : "No public appointments found for {name}",
    "Personal" : "Personal",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue.",
    "Show unscheduled tasks" : "Show unscheduled tasks",
    "Unscheduled tasks" : "Unscheduled tasks",
    "Availability of {displayName}" : "Availability of {displayName}",
    "Discard event" : "Discard event",
    "Edit event" : "Edit event",
    "Event does not exist" : "Event does not exist",
    "Duplicate" : "Duplicate",
    "Delete this occurrence" : "Delete this occurrence",
    "Delete this and all future" : "Delete this and all future",
    "All day" : "All day",
    "Modifications wont get propagated to the organizer and other attendees" : "Modifications won't get propagated to the organiser and other attendees",
    "Managing shared access" : "Managing shared access",
    "Deny access" : "Deny access",
    "Invite" : "Invite",
    "Discard changes?" : "Discard changes?",
    "Are you sure you want to discard the changes made to this event?" : "Are you sure you want to discard the changes made to this event?",
    "_User requires access to your file_::_Users require access to your file_" : ["User requires access to your file","Users require access to your file"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Attachment requires shared access","Attachments requiring shared access"],
    "Untitled event" : "Untitled event",
    "Close" : "Close",
    "Modifications will not get propagated to the organizer and other attendees" : "Modifications will not get propagated to the organiser and other attendees",
    "Meeting proposals overview" : "Meeting proposals overview",
    "Edit meeting proposal" : "Edit meeting proposal",
    "Create meeting proposal" : "Create meeting proposal",
    "Update meeting proposal" : "Update meeting proposal",
    "Saving proposal \"{title}\"" : "Saving proposal \"{title}\"",
    "Successfully saved proposal" : "Successfully saved proposal",
    "Failed to save proposal" : "Failed to save proposal",
    "Create a meeting for \"{date}\"? This will create a calendar event with all participants." : "Create a meeting for \"{date}\"? This will create a calendar event with all participants.",
    "Creating meeting for {date}" : "Creating meeting for {date}",
    "Successfully created meeting for {date}" : "Successfully created meeting for {date}",
    "Failed to create a meeting for {date}" : "Failed to create a meeting for {date}",
    "Please enter a valid duration in minutes." : "Please enter a valid duration in minutes.",
    "Failed to fetch proposals" : "Failed to fetch proposals",
    "Failed to fetch free/busy data" : "Failed to fetch free/busy data",
    "Selected" : "Selected",
    "No Description" : "No Description",
    "No Location" : "No Location",
    "Edit this meeting proposal" : "Edit this meeting proposal",
    "Delete this meeting proposal" : "Delete this meeting proposal",
    "Title" : "Title",
    "15 min" : "15 min",
    "30 min" : "30 min",
    "60 min" : "60 min",
    "90 min" : "90 min",
    "Participants" : "Participants",
    "Selected times" : "Selected times",
    "Previous span" : "Previous span",
    "Next span" : "Next span",
    "Less days" : "Less days",
    "More days" : "More days",
    "Loading meeting proposal" : "Loading meeting proposal",
    "No meeting proposal found" : "No meeting proposal found",
    "Please wait while we load the meeting proposal." : "Please wait while we load the meeting proposal.",
    "The link you followed may be broken, or the meeting proposal may no longer exist." : "The link you followed may be broken, or the meeting proposal may no longer exist.",
    "Thank you for your response!" : "Thank you for your response!",
    "Your vote has been recorded. Thank you for participating!" : "Your vote has been recorded. Thank you for participating!",
    "Unknown User" : "Unknown User",
    "No Title" : "No Title",
    "No Duration" : "No Duration",
    "Select a different time zone" : "Select a different time zone",
    "Submit" : "Submit",
    "Subscribe to {name}" : "Subscribe to {name}",
    "Export {name}" : "Export {name}",
    "Show availability" : "Show availability",
    "Anniversary" : "Anniversary",
    "Appointment" : "Appointment",
    "Business" : "Business",
    "Education" : "Education",
    "Holiday" : "Holiday",
    "Meeting" : "Meeting",
    "Miscellaneous" : "Miscellaneous",
    "Non-working hours" : "Non-working hours",
    "Not in office" : "Not in office",
    "Phone call" : "Phone call",
    "Sick day" : "Sick day",
    "Special occasion" : "Special occasion",
    "Travel" : "Travel",
    "Vacation" : "Vacation",
    "Midnight on the day the event starts" : "Midnight on the day the event starts",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n day before the event at {formattedHourMinute}","%n days before the event at {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n week before the event at {formattedHourMinute}","%n weeks before the event at {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "on the day of the event at {formattedHourMinute}",
    "at the event's start" : "at the event's start",
    "at the event's end" : "at the event's end",
    "{time} before the event starts" : "{time} before the event starts",
    "{time} before the event ends" : "{time} before the event ends",
    "{time} after the event starts" : "{time} after the event starts",
    "{time} after the event ends" : "{time} after the event ends",
    "on {time}" : "on {time}",
    "on {time} ({timezoneId})" : "on {time} ({timezoneId})",
    "Week {number} of {year}" : "Week {number} of {year}",
    "Daily" : "Daily",
    "Weekly" : "Weekly",
    "Monthly" : "Monthly",
    "Yearly" : "Yearly",
    "_Every %n day_::_Every %n days_" : ["Every %n day","Every %n days"],
    "_Every %n week_::_Every %n weeks_" : ["Every %n week","Every %n weeks"],
    "_Every %n month_::_Every %n months_" : ["Every %n month","Every %n months"],
    "_Every %n year_::_Every %n years_" : ["Every %n year","Every %n years"],
    "_on {weekday}_::_on {weekdays}_" : ["on {weekday}","on {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["on day {dayOfMonthList}","on days {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "on the {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {dayOfMonthList}" : "in {monthNames} on the {dayOfMonthList}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "in {monthNames} on the {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "until {untilDate}",
    "_%n time_::_%n times_" : ["%n time","%n times"],
    "second" : "second",
    "third" : "third",
    "fourth" : "fourth",
    "fifth" : "fifth",
    "second to last" : "second to last",
    "last" : "last",
    "Untitled task" : "Untitled task",
    "Please ask your administrator to enable the Tasks App." : "Please ask your administrator to enable the Tasks App.",
    "You are not allowed to edit this event as an attendee." : "You are not allowed to edit this event as an attendee.",
    "W" : "W",
    "%n more" : "%n more",
    "No events to display" : "No events to display",
    "All participants declined" : "All participants declined",
    "Please confirm your participation" : "Please confirm your participation",
    "You declined this event" : "You declined this event",
    "Your participation is tentative" : "Your participation is tentative",
    "_+%n more_::_+%n more_" : ["+%n more","+%n more"],
    "No events" : "No events",
    "Create a new event or change the visible time-range" : "Create a new event or change the visible time-range",
    "Failed to save event" : "Failed to save event",
    "It might have been deleted, or there was a typo in a link" : "It might have been deleted, or there was a typo in a link",
    "It might have been deleted, or there was a typo in the link" : "It might have been deleted, or there was a typo in the link",
    "Meeting room" : "Meeting room",
    "Lecture hall" : "Lecture hall",
    "Seminar room" : "Seminar room",
    "Other" : "Other",
    "When shared show" : "When shared show",
    "When shared show full event" : "When shared show full event",
    "When shared show only busy" : "When shared show only busy",
    "When shared hide this event" : "When shared hide this event",
    "The visibility of this event in read-only shared calendars." : "The visibility of this event in read-only shared calendars.",
    "Add a location" : "Add a location",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare",
    "Status" : "Status",
    "Confirmed" : "Confirmed",
    "Canceled" : "Canceled",
    "Confirmation about the overall status of the event." : "Confirmation about the overall status of the event.",
    "Show as" : "Show as",
    "Take this event into account when calculating free-busy information." : "Take this event into account when calculating free-busy information.",
    "Categories" : "Categories",
    "Categories help you to structure and organize your events." : "Categories help you to structure and organise your events.",
    "Search or add categories" : "Search or add categories",
    "Add this as a new category" : "Add this as a new category",
    "Custom color" : "Custom colour",
    "Special color of this event. Overrides the calendar-color." : "Special colour of this event. Overrides the calendar-colour.",
    "Error while sharing file" : "Error while sharing file",
    "Error while sharing file with user" : "Error while sharing file with user",
    "Error creating a folder {folder}" : "Error creating a folder {folder}",
    "Attachment {fileName} already exists!" : "Attachment {fileName} already exists!",
    "Attachment {fileName} added!" : "Attachment {fileName} added!",
    "An error occurred during uploading file {fileName}" : "An error occurred during uploading file {fileName}",
    "An error occurred during getting file information" : "An error occurred during getting file information",
    "Talk conversation for proposal" : "Talk conversation for proposal",
    "An error occurred, unable to delete the calendar." : "An error occurred, unable to delete the calendar.",
    "Imported {filename}" : "Imported {filename}",
    "This is an event reminder." : "This is an event reminder.",
    "Error while parsing a PROPFIND error" : "Error while parsing a PROPFIND error",
    "Appointment not found" : "Appointment not found",
    "User not found" : "User not found",
    "Hidden" : "Hidden",
    "can edit" : "can edit",
    "Calendar name …" : "Calendar name …",
    "Default attachments location" : "Default attachments location",
    "Automatic ({detected})" : "Automatic ({detected})",
    "Shortcut overview" : "Shortcut overview",
    "CalDAV link copied to clipboard." : "CalDAV link copied to clipboard.",
    "CalDAV link could not be copied to clipboard." : "CalDAV link could not be copied to clipboard.",
    "Enable birthday calendar" : "Enable birthday calendar",
    "Show tasks in calendar" : "Show tasks in calendar",
    "Enable simplified editor" : "Enable simplified editor",
    "Limit the number of events displayed in the monthly view" : "Limit the number of events displayed in the monthly view",
    "Show weekends" : "Show weekends",
    "Show week numbers" : "Show week numbers",
    "Time increments" : "Time increments",
    "Default calendar for incoming invitations" : "Default calendar for incoming invitations",
    "Copy primary CalDAV address" : "Copy primary CalDAV address",
    "Copy iOS/macOS CalDAV address" : "Copy iOS/macOS CalDAV address",
    "Personal availability settings" : "Personal availability settings",
    "Show keyboard shortcuts" : "Show keyboard shortcuts",
    "Create a new public conversation" : "Create a new public conversation",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} invited, {confirmedCount} confirmed",
    "Successfully appended link to talk room to location." : "Successfully appended link to talk room to location.",
    "Successfully appended link to talk room to description." : "Successfully appended link to talk room to description.",
    "Error creating Talk room" : "Error creating Talk room",
    "_%n more guest_::_%n more guests_" : ["%n more guest","%n more guests"],
    "The visibility of this event in shared calendars." : "The visibility of this event in shared calendars."
},
"nplurals=2; plural=(n != 1);");
