<?php

// autoload_classmap.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'Bamarni\\Composer\\Bin\\ApplicationFactory\\FreshInstanceApplicationFactory' => $vendorDir . '/bamarni/composer-bin-plugin/src/ApplicationFactory/FreshInstanceApplicationFactory.php',
    'Bamarni\\Composer\\Bin\\ApplicationFactory\\NamespaceApplicationFactory' => $vendorDir . '/bamarni/composer-bin-plugin/src/ApplicationFactory/NamespaceApplicationFactory.php',
    'Bamarni\\Composer\\Bin\\BamarniBinPlugin' => $vendorDir . '/bamarni/composer-bin-plugin/src/BamarniBinPlugin.php',
    'Bamarni\\Composer\\Bin\\CommandProvider' => $vendorDir . '/bamarni/composer-bin-plugin/src/CommandProvider.php',
    'Bamarni\\Composer\\Bin\\Command\\BinCommand' => $vendorDir . '/bamarni/composer-bin-plugin/src/Command/BinCommand.php',
    'Bamarni\\Composer\\Bin\\Command\\CouldNotCreateNamespaceDir' => $vendorDir . '/bamarni/composer-bin-plugin/src/Command/CouldNotCreateNamespaceDir.php',
    'Bamarni\\Composer\\Bin\\Config\\Config' => $vendorDir . '/bamarni/composer-bin-plugin/src/Config/Config.php',
    'Bamarni\\Composer\\Bin\\Config\\ConfigFactory' => $vendorDir . '/bamarni/composer-bin-plugin/src/Config/ConfigFactory.php',
    'Bamarni\\Composer\\Bin\\Config\\InvalidBamarniComposerExtraConfig' => $vendorDir . '/bamarni/composer-bin-plugin/src/Config/InvalidBamarniComposerExtraConfig.php',
    'Bamarni\\Composer\\Bin\\Input\\BinInputFactory' => $vendorDir . '/bamarni/composer-bin-plugin/src/Input/BinInputFactory.php',
    'Bamarni\\Composer\\Bin\\Input\\InvalidBinInput' => $vendorDir . '/bamarni/composer-bin-plugin/src/Input/InvalidBinInput.php',
    'Bamarni\\Composer\\Bin\\Logger' => $vendorDir . '/bamarni/composer-bin-plugin/src/Logger.php',
    'Bamarni\\Composer\\Bin\\PublicIO' => $vendorDir . '/bamarni/composer-bin-plugin/src/PublicIO.php',
    'Composer\\InstalledVersions' => $vendorDir . '/composer/InstalledVersions.php',
    'OCA\\Calendar\\AppInfo\\Application' => $baseDir . '/lib/AppInfo/Application.php',
    'OCA\\Calendar\\BackgroundJob\\CleanUpOutdatedBookingsJob' => $baseDir . '/lib/BackgroundJob/CleanUpOutdatedBookingsJob.php',
    'OCA\\Calendar\\Controller\\AppointmentConfigController' => $baseDir . '/lib/Controller/AppointmentConfigController.php',
    'OCA\\Calendar\\Controller\\AppointmentController' => $baseDir . '/lib/Controller/AppointmentController.php',
    'OCA\\Calendar\\Controller\\BookingController' => $baseDir . '/lib/Controller/BookingController.php',
    'OCA\\Calendar\\Controller\\ContactController' => $baseDir . '/lib/Controller/ContactController.php',
    'OCA\\Calendar\\Controller\\EmailController' => $baseDir . '/lib/Controller/EmailController.php',
    'OCA\\Calendar\\Controller\\ProposalController' => $baseDir . '/lib/Controller/ProposalController.php',
    'OCA\\Calendar\\Controller\\ProposalPublicController' => $baseDir . '/lib/Controller/ProposalPublicController.php',
    'OCA\\Calendar\\Controller\\PublicViewController' => $baseDir . '/lib/Controller/PublicViewController.php',
    'OCA\\Calendar\\Controller\\SettingsController' => $baseDir . '/lib/Controller/SettingsController.php',
    'OCA\\Calendar\\Controller\\ViewController' => $baseDir . '/lib/Controller/ViewController.php',
    'OCA\\Calendar\\Dashboard\\CalendarWidget' => $baseDir . '/lib/Dashboard/CalendarWidget.php',
    'OCA\\Calendar\\Db\\AppointmentConfig' => $baseDir . '/lib/Db/AppointmentConfig.php',
    'OCA\\Calendar\\Db\\AppointmentConfigMapper' => $baseDir . '/lib/Db/AppointmentConfigMapper.php',
    'OCA\\Calendar\\Db\\Booking' => $baseDir . '/lib/Db/Booking.php',
    'OCA\\Calendar\\Db\\BookingMapper' => $baseDir . '/lib/Db/BookingMapper.php',
    'OCA\\Calendar\\Db\\ProposalDateEntry' => $baseDir . '/lib/Db/ProposalDateEntry.php',
    'OCA\\Calendar\\Db\\ProposalDateMapper' => $baseDir . '/lib/Db/ProposalDateMapper.php',
    'OCA\\Calendar\\Db\\ProposalDetailsEntry' => $baseDir . '/lib/Db/ProposalDetailsEntry.php',
    'OCA\\Calendar\\Db\\ProposalMapper' => $baseDir . '/lib/Db/ProposalMapper.php',
    'OCA\\Calendar\\Db\\ProposalParticipantEntry' => $baseDir . '/lib/Db/ProposalParticipantEntry.php',
    'OCA\\Calendar\\Db\\ProposalParticipantMapper' => $baseDir . '/lib/Db/ProposalParticipantMapper.php',
    'OCA\\Calendar\\Db\\ProposalVoteEntry' => $baseDir . '/lib/Db/ProposalVoteEntry.php',
    'OCA\\Calendar\\Db\\ProposalVoteMapper' => $baseDir . '/lib/Db/ProposalVoteMapper.php',
    'OCA\\Calendar\\Events\\BeforeAppointmentBookedEvent' => $baseDir . '/lib/Events/BeforeAppointmentBookedEvent.php',
    'OCA\\Calendar\\Exception\\ClientException' => $baseDir . '/lib/Exception/ClientException.php',
    'OCA\\Calendar\\Exception\\NoSlotFoundException' => $baseDir . '/lib/Exception/NoSlotFoundException.php',
    'OCA\\Calendar\\Exception\\ServiceException' => $baseDir . '/lib/Exception/ServiceException.php',
    'OCA\\Calendar\\Http\\JsonResponse' => $baseDir . '/lib/Http/JsonResponse.php',
    'OCA\\Calendar\\Listener\\AppointmentBookedListener' => $baseDir . '/lib/Listener/AppointmentBookedListener.php',
    'OCA\\Calendar\\Listener\\CalendarReferenceListener' => $baseDir . '/lib/Listener/CalendarReferenceListener.php',
    'OCA\\Calendar\\Listener\\UserDeletedListener' => $baseDir . '/lib/Listener/UserDeletedListener.php',
    'OCA\\Calendar\\Migration\\Version2040Date20210908101001' => $baseDir . '/lib/Migration/Version2040Date20210908101001.php',
    'OCA\\Calendar\\Migration\\Version3000Date20211109132439' => $baseDir . '/lib/Migration/Version3000Date20211109132439.php',
    'OCA\\Calendar\\Migration\\Version3010Date20220111090252' => $baseDir . '/lib/Migration/Version3010Date20220111090252.php',
    'OCA\\Calendar\\Migration\\Version4050Date20230614163505' => $baseDir . '/lib/Migration/Version4050Date20230614163505.php',
    'OCA\\Calendar\\Migration\\Version5050Date20250701000001' => $baseDir . '/lib/Migration/Version5050Date20250701000001.php',
    'OCA\\Calendar\\Migration\\Version5050Date20250701000002' => $baseDir . '/lib/Migration/Version5050Date20250701000002.php',
    'OCA\\Calendar\\Migration\\Version5050Date20250701000003' => $baseDir . '/lib/Migration/Version5050Date20250701000003.php',
    'OCA\\Calendar\\Migration\\Version5050Date20250701000004' => $baseDir . '/lib/Migration/Version5050Date20250701000004.php',
    'OCA\\Calendar\\Notification\\Notifier' => $baseDir . '/lib/Notification/Notifier.php',
    'OCA\\Calendar\\Objects\\BaseCollection' => $baseDir . '/lib/Objects/BaseCollection.php',
    'OCA\\Calendar\\Objects\\Proposal\\ProposalDateCollection' => $baseDir . '/lib/Objects/Proposal/ProposalDateCollection.php',
    'OCA\\Calendar\\Objects\\Proposal\\ProposalDateObject' => $baseDir . '/lib/Objects/Proposal/ProposalDateObject.php',
    'OCA\\Calendar\\Objects\\Proposal\\ProposalDateVote' => $baseDir . '/lib/Objects/Proposal/ProposalDateVote.php',
    'OCA\\Calendar\\Objects\\Proposal\\ProposalObject' => $baseDir . '/lib/Objects/Proposal/ProposalObject.php',
    'OCA\\Calendar\\Objects\\Proposal\\ProposalParticipantAttendance' => $baseDir . '/lib/Objects/Proposal/ProposalParticipantAttendance.php',
    'OCA\\Calendar\\Objects\\Proposal\\ProposalParticipantCollection' => $baseDir . '/lib/Objects/Proposal/ProposalParticipantCollection.php',
    'OCA\\Calendar\\Objects\\Proposal\\ProposalParticipantObject' => $baseDir . '/lib/Objects/Proposal/ProposalParticipantObject.php',
    'OCA\\Calendar\\Objects\\Proposal\\ProposalParticipantRealm' => $baseDir . '/lib/Objects/Proposal/ProposalParticipantRealm.php',
    'OCA\\Calendar\\Objects\\Proposal\\ProposalParticipantStatus' => $baseDir . '/lib/Objects/Proposal/ProposalParticipantStatus.php',
    'OCA\\Calendar\\Objects\\Proposal\\ProposalResponseDateCollection' => $baseDir . '/lib/Objects/Proposal/ProposalResponseDateCollection.php',
    'OCA\\Calendar\\Objects\\Proposal\\ProposalResponseDateObject' => $baseDir . '/lib/Objects/Proposal/ProposalResponseDateObject.php',
    'OCA\\Calendar\\Objects\\Proposal\\ProposalResponseObject' => $baseDir . '/lib/Objects/Proposal/ProposalResponseObject.php',
    'OCA\\Calendar\\Objects\\Proposal\\ProposalVoteCollection' => $baseDir . '/lib/Objects/Proposal/ProposalVoteCollection.php',
    'OCA\\Calendar\\Objects\\Proposal\\ProposalVoteObject' => $baseDir . '/lib/Objects/Proposal/ProposalVoteObject.php',
    'OCA\\Calendar\\Profile\\AppointmentsAction' => $baseDir . '/lib/Profile/AppointmentsAction.php',
    'OCA\\Calendar\\Reference\\ReferenceProvider' => $baseDir . '/lib/Reference/ReferenceProvider.php',
    'OCA\\Calendar\\Service\\Appointments\\AppointmentConfigService' => $baseDir . '/lib/Service/Appointments/AppointmentConfigService.php',
    'OCA\\Calendar\\Service\\Appointments\\AvailabilityGenerator' => $baseDir . '/lib/Service/Appointments/AvailabilityGenerator.php',
    'OCA\\Calendar\\Service\\Appointments\\BookingCalendarWriter' => $baseDir . '/lib/Service/Appointments/BookingCalendarWriter.php',
    'OCA\\Calendar\\Service\\Appointments\\BookingService' => $baseDir . '/lib/Service/Appointments/BookingService.php',
    'OCA\\Calendar\\Service\\Appointments\\DailyLimitFilter' => $baseDir . '/lib/Service/Appointments/DailyLimitFilter.php',
    'OCA\\Calendar\\Service\\Appointments\\EventConflictFilter' => $baseDir . '/lib/Service/Appointments/EventConflictFilter.php',
    'OCA\\Calendar\\Service\\Appointments\\Interval' => $baseDir . '/lib/Service/Appointments/Interval.php',
    'OCA\\Calendar\\Service\\Appointments\\MailService' => $baseDir . '/lib/Service/Appointments/MailService.php',
    'OCA\\Calendar\\Service\\Appointments\\SlotExtrapolator' => $baseDir . '/lib/Service/Appointments/SlotExtrapolator.php',
    'OCA\\Calendar\\Service\\Appointments\\TimezoneGenerator' => $baseDir . '/lib/Service/Appointments/TimezoneGenerator.php',
    'OCA\\Calendar\\Service\\CalendarInitialStateService' => $baseDir . '/lib/Service/CalendarInitialStateService.php',
    'OCA\\Calendar\\Service\\ContactsService' => $baseDir . '/lib/Service/ContactsService.php',
    'OCA\\Calendar\\Service\\JSDataService' => $baseDir . '/lib/Service/JSDataService.php',
    'OCA\\Calendar\\Service\\Proposal\\ProposalService' => $baseDir . '/lib/Service/Proposal/ProposalService.php',
    'OCA\\Calendar\\Service\\ServiceException' => $baseDir . '/lib/Service/ServiceException.php',
);
