OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "提供的電郵地址太長",
    "User-Session unexpectedly expired" : "用戶時段意外地結束",
    "Provided email-address is not valid" : "提供的電郵地址無效",
    "%s has published the calendar »%s«" : "%s 發佈了日曆 »%s«",
    "Unexpected error sending email. Please contact your administrator." : "傳送電子郵件出現意外的錯誤。請聯絡系統管理員。",
    "Successfully sent email to %1$s" : "成功傳送電子郵件給%1$s",
    "Hello," : "嗨，",
    "We wanted to inform you that %s has published the calendar »%s«." : "通知您，%s 發佈了日曆 »%s«。",
    "Open »%s«" : "開啟 »%s«",
    "Cheers!" : "太棒了！",
    "Upcoming events" : "接下來的活動",
    "No more events today" : "今日沒有其他活動",
    "No upcoming events" : "沒有接下來的活動",
    "More events" : "更多活動",
    "%1$s with %2$s" : "與 %2$s 預定的對話 %1$s",
    "Calendar" : "日曆",
    "New booking {booking}" : "新預約 {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) 於 {date_time} 預約了“{config_display_name}”。",
    "Appointments" : "預約",
    "Schedule appointment \"%s\"" : "安排預約 \"%s\"",
    "Schedule an appointment" : "安排約會",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : "準備 %s",
    "Follow up for %s" : "跟進 %s",
    "Your appointment \"%s\" with %s needs confirmation" : "您與 %s 的預約 “%s” 需要確認",
    "Dear %s, please confirm your booking" : "%s，請確認您的預約",
    "Confirm" : "確認",
    "Appointment with:" : "預約：",
    "Description:" : "描述：",
    "This confirmation link expires in %s hours." : "此確認鏈接將在 %s 小時後過期。",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "如果您想取消預約，請通過以下方式聯絡籌辦者：回覆此電郵或訪問他們的個人資料頁面。",
    "Your appointment \"%s\" with %s has been accepted" : "您與 %s 的預約 “%s” 已被接受",
    "Dear %s, your booking has been accepted." : "親愛的 %s，您的預約已被接受。",
    "Appointment for:" : "預約：",
    "Date:" : "日期：",
    "You will receive a link with the confirmation email" : "您將在確認電郵中收到一個連結",
    "Where:" : "地點：",
    "Comment:" : "留言︰",
    "You have a new appointment booking \"%s\" from %s" : "您有一個來自 %s 的新預約 “%s”",
    "Dear %s, %s (%s) booked an appointment with you." : "親愛的 %s，%s (%s) 與您預約了。",
    "%s has proposed a meeting" : "%s 提出了會議建議",
    "%s has updated a proposed meeting" : "%s 已更新會議建議",
    "%s has canceled a proposed meeting" : "%s 已取消會議建議",
    "Dear %s, a new meeting has been proposed" : "親愛的 %s，有人提議召開新的會議",
    "Dear %s, a proposed meeting has been updated" : "親愛的 %s，提議的會議已更新",
    "Dear %s, a proposed meeting has been cancelled" : "親愛的 %s，提議的會議已取消",
    "Location:" : "位置：",
    "Duration:" : "歷時：",
    "%1$s from %2$s to %3$s" : "%1$s 從 %2$s 到 %3$s",
    "Dates:" : "日期：",
    "Respond" : "回應",
    "A Calendar app for Nextcloud" : "Nextcloud 的日曆應用程式",
    "A Calendar app for Nextcloud. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Like Contacts, Talk, Tasks, Deck and Circles\n* 🌐 **WebCal Support!** Want to see your favorite team's matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 **Search!** Find your events at ease\n* ☑️ **Tasks!** See tasks or Deck cards with a due date directly in the calendar\n* 🔈 **Talk rooms!** Create an associated Talk room when booking a meeting with just one click\n* 📆 **Appointment booking** Send people a link so they can book an appointment with you [using this app](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Attachments!** Add, upload and view event attachments\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "適用於 Nextcloud 的日曆應用程式。輕鬆從各種裝置與 Nextcloud 同步處理事件，並可線上編輯。\n\n* 🚀 **與其他 Nextcloud 應用程式整合！** 例如通訊錄、Talk、工作項目、Deck 與小圈圈\n* 🌐 **支援 WebCal！** 想要在您的日曆中看到您最喜愛的球隊的比賽日嗎？沒問題！\n* 🙋 **參與者！** 邀請夥伴參與您的活動\n* ⌚ **有空/忙碌！** 檢視您的與會者何時可以見面\n* ⏰ **提醒！** 透過您的瀏覽器與電子郵件取得活動提醒\n* 🔍 **搜尋！** 輕鬆找到您的活動\n* ☑️ **工作項目！** 直接在日曆中檢視有到期日的工作項目或 Deck 卡片\n* 🔈 **Talk 聊天室！** 預約會議時，只要按一下就能建立相關的 Talk 聊天室\n* 📆 **預約** 傳送連結給他人，讓他們可以[使用此應用程式](https://apps.nextcloud.com/apps/appointments)與您預約\n* 📎 **附件！** 新增、上傳與檢視活動附件\n* 🙈 **我們沒有重新發明輪子！** 以超棒的 [c-dav](https://github.com/nextcloud/cdav-library)、[ical.js](https://github.com/mozilla-comm/ical.js) 與 [fullcalendar](https://github.com/fullcalendar/fullcalendar) 函式庫為基礎開發。",
    "Previous day" : "前一日",
    "Previous week" : "上星期",
    "Previous year" : "上一年",
    "Previous month" : "上個月",
    "Next day" : "隔日",
    "Next week" : "下星期",
    "Next year" : "下一年",
    "Next month" : "下個月",
    "Create new event" : "創建新活動",
    "Event" : "活動",
    "Today" : "今日",
    "Day" : "日",
    "Week" : "星期",
    "Month" : "月",
    "Year" : "年",
    "List" : "清單",
    "Appointment link was copied to clipboard" : "約會連結已複製到剪貼板",
    "Appointment link could not be copied to clipboard" : "約會連結無法複製到剪貼板",
    "Preview" : "預覽",
    "Copy link" : "複製連結",
    "Edit" : "編輯",
    "Delete" : "刪除",
    "Appointment schedules" : "預約時間表",
    "Create new" : "建立新的",
    "Disable calendar \"{calendar}\"" : "停用日曆 \"{calendar}\"",
    "Disable untitled calendar" : "停用未命名日曆",
    "Enable calendar \"{calendar}\"" : "啟用日曆 \"{calendar}\"",
    "Enable untitled calendar" : "啟用未命名日曆",
    "An error occurred, unable to change visibility of the calendar." : "發生錯誤，無法改變日曆的能見度",
    "Untitled calendar" : "未命名日曆",
    "Shared with you by" : "分享給您藉由",
    "Edit and share calendar" : "編輯及分享日曆",
    "Edit calendar" : "編輯日曆",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["將在 {countdown} 秒後取消日曆分享"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["將在 {countdown} 秒後刪除日曆"],
    "An error occurred, unable to create the calendar." : "發生錯誤，無法建立日曆",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "請輸入有效的連結（以 http://，https://，webcal://，或 webcals:// 開頭）",
    "Calendars" : "日曆",
    "Add new" : "新增",
    "New calendar" : "新日曆",
    "Name for new calendar" : "新日曆名字",
    "Creating calendar …" : "正在建立日曆…",
    "New calendar with task list" : "新日曆及任務清單",
    "New subscription from link (read-only)" : "自連結建立新訂閱（唯讀）",
    "Creating subscription …" : "正在建立新訂閱…",
    "Add public holiday calendar" : "添加公眾假期日曆",
    "Add custom public calendar" : "新增自訂公共日曆",
    "Calendar link copied to clipboard." : "複製日曆連結到剪貼板",
    "Calendar link could not be copied to clipboard." : "日曆連結無法複製到剪貼板",
    "Copy subscription link" : "複製訂閱的連結",
    "Copying link …" : "正在複製連結…",
    "Copied link" : "連結已複製",
    "Could not copy link" : "無法複製連結",
    "Export" : "導出",
    "Untitled item" : "無題項目",
    "Unknown calendar" : "日曆不詳",
    "Could not load deleted calendars and objects" : "無法加載已刪除日曆或物體",
    "Could not delete calendar or event" : "無法刪除日曆或活動",
    "Could not restore calendar or event" : "無法復原日曆或活動",
    "Do you really want to empty the trash bin?" : "您真的想要清空回收桶嗎？",
    "Empty trash bin" : "清空回收桶",
    "Trash bin" : "回收桶",
    "Loading deleted items." : "正加載已删除的項目。",
    "You do not have any deleted items." : "你没有已删除的項目。",
    "Name" : "姓名",
    "Deleted" : "已刪除",
    "Restore" : "復原",
    "Delete permanently" : "永久刪除",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["回收桶中的項目會在 {numDays} 天後被刪除"],
    "Could not update calendar order." : "無法變更日曆順序",
    "Shared calendars" : "分享日曆",
    "Deck" : "Deck",
    "Internal link" : "內部連結",
    "A private link that can be used with external clients" : "可與外部客戶端一起使用的私人連結",
    "Copy internal link" : "複製內部連結",
    "An error occurred, unable to publish calendar." : "發生錯誤，無法發佈日曆",
    "An error occurred, unable to send email." : "發生錯誤，無法寄送電子郵件",
    "Embed code copied to clipboard." : "內嵌程式碼已複製到剪貼板",
    "Embed code could not be copied to clipboard." : "無法複製內嵌程式碼到剪貼板",
    "Unpublishing calendar failed" : "取消發佈日曆失敗",
    "Share link" : "分享連結",
    "Copy public link" : "複製公開連結",
    "Send link to calendar via email" : "透過電子郵件傳送日曆連結",
    "Enter one address" : "輸入一個地址",
    "Sending email …" : "正在傳送電子郵件…",
    "Copy embedding code" : "複製內嵌程式碼",
    "Copying code …" : "正在複製程式碼…",
    "Copied code" : "已複製程式碼",
    "Could not copy code" : "無法複製程式碼",
    "Delete share link" : "刪除分享連結",
    "Deleting share link …" : "正在刪除共享連結…",
    "{teamDisplayName} (Team)" : "{teamDisplayName}（團隊）",
    "An error occurred while unsharing the calendar." : "取消分享日曆時發生錯誤。",
    "An error occurred, unable to change the permission of the share." : "發生錯誤，無法變更分享權限",
    "can edit and see confidential events" : "可以編輯與檢視機密事件",
    "Unshare with {displayName}" : "取消與 {displayName} 的分享",
    "Share with users or groups" : "與用戶或群組分享",
    "No users or groups" : "沒有用戶或群組",
    "Failed to save calendar name and color" : "儲存日曆名稱或色彩失敗",
    "Calendar name …" : "日曆名稱 …",
    "Never show me as busy (set this calendar to transparent)" : "永遠不顯示我為忙碌狀態（將此日曆設置為透明）",
    "Share calendar" : "分享日曆",
    "Unshare from me" : "由我取消的分享",
    "Save" : "儲存",
    "No title" : "沒有標題",
    "Are you sure you want to delete \"{title}\"?" : "您確定您想要刪除「{title}」嗎？",
    "Deleting proposal \"{title}\"" : "正在刪除提案「{title}」",
    "Successfully deleted proposal" : "成功刪除提案",
    "Failed to delete proposal" : "刪除提案失敗",
    "Failed to retrieve proposals" : "擷取提案失敗",
    "Meeting proposals" : "會議提案",
    "A configured email address is required to use meeting proposals" : "使用會議提案功能需設定電子郵件地址",
    "No active meeting proposals" : "目前無有效的會議提案",
    "View" : "檢視",
    "Import calendars" : "匯入日曆",
    "Please select a calendar to import into …" : "請選擇將匯入的日曆",
    "Filename" : "檔案名稱",
    "Calendar to import into" : "將匯入的日曆",
    "Cancel" : "取消",
    "_Import calendar_::_Import calendars_" : ["匯入日曆"],
    "Select the default location for attachments" : "選擇附件的默認位置",
    "Pick" : "挑選",
    "Invalid location selected" : "所選的位置無效",
    "Attachments folder successfully saved." : "附件資料夾已成功保存。",
    "Error on saving attachments folder." : "儲存附件資料夾時發生錯誤。",
    "Attachments folder" : "附件資料夾",
    "{filename} could not be parsed" : "無法解析 {filename}",
    "No valid files found, aborting import" : "沒有找到有效的檔案，中斷匯入",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["成功匯入 %n 個活動"],
    "Import partially failed. Imported {accepted} out of {total}." : "匯入部分失敗，僅成功匯入 {total} 中的 {accepted} 項",
    "Automatic" : "自動",
    "Automatic ({timezone})" : "自動（{timezone}）",
    "New setting was not saved successfully." : "新設定未成功儲存",
    "Timezone" : "時區",
    "Navigation" : "導覽列",
    "Previous period" : "前一期間",
    "Next period" : "下一期間",
    "Views" : "視圖",
    "Day view" : "日視圖",
    "Week view" : "週視圖",
    "Month view" : "月視圖",
    "Year view" : "年度檢視",
    "List view" : "清單檢視",
    "Actions" : "操作",
    "Create event" : "建立活動",
    "Show shortcuts" : "顯示捷徑",
    "Editor" : "編輯器",
    "Close editor" : "關閉編輯器",
    "Save edited event" : "儲存已編輯的活動",
    "Delete edited event" : "刪除已編輯的活動",
    "Duplicate event" : "重複活動",
    "or" : "或者",
    "Calendar settings" : "日曆設定",
    "At event start" : "在活動開始時",
    "No reminder" : "無提醒",
    "Failed to save default calendar" : "無法保存默認日曆",
    "General" : "一般",
    "Availability settings" : "空閒時間設定",
    "CalDAV" : "CalDAV",
    "Access Nextcloud calendars from other apps and devices" : "從其他應用程式與裝置存取 Nextcloud 日曆",
    "CalDAV URL" : "CalDAV URL",
    "Server Address for iOS and macOS" : "iOS 與 macOS 的伺服器地址",
    "Appearance" : "外觀",
    "Birthday calendar" : "生日日曆",
    "Tasks in calendar" : "日曆中的待辦事項",
    "Weekends" : "週末",
    "Week numbers" : "週數",
    "Limit number of events shown in Month view" : "限制月份檢視中顯示的活動數量",
    "Density in Day and Week View" : "日檢視與週檢視中的密度",
    "Editing" : "编辑",
    "Default reminder" : "默認提醒",
    "Simple event editor" : "簡易活動編輯器",
    "\"More details\" opens the detailed editor" : "「更多詳細資訊」開啟詳細資訊編輯器",
    "Files" : "檔案",
    "Appointment schedule successfully created" : "已成功建立預約時間表",
    "Appointment schedule successfully updated" : "已成功更新預約時間表",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} 分鐘"],
    "0 minutes" : "0 分鐘",
    "_{duration} hour_::_{duration} hours_" : ["{duration} 小時"],
    "_{duration} day_::_{duration} days_" : ["{duration} 天"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} 星期"],
    "_{duration} month_::_{duration} months_" : ["{duration} 月"],
    "_{duration} year_::_{duration} years_" : ["{duration} 年"],
    "To configure appointments, add your email address in personal settings." : "要配置預約，請在個人設置中添加您的電郵地址。",
    "Public – shown on the profile page" : "公開 - 顯示在個人資料頁面上",
    "Private – only accessible via secret link" : "私人 - 只能通過秘密連結進入",
    "Appointment schedule saved" : "已儲存預約時間表",
    "Create appointment schedule" : "建立預約時間表",
    "Edit appointment schedule" : "編輯預約時間表",
    "Update" : "更新",
    "Appointment name" : "預約名稱",
    "Location" : "地點",
    "Create a Talk room" : "創建聊天室",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "將為每個預訂的預約生成一個獨一無二的連結，並將通過確認電郵發送",
    "Description" : "描述",
    "Visibility" : "可見性",
    "Duration" : "歷時",
    "Increments" : "增量",
    "Additional calendars to check for conflicts" : "其他要檢查衝突的日曆",
    "Pick time ranges where appointments are allowed" : "選擇允許預約時間的範圍",
    "to" : "至",
    "Delete slot" : "刪除時段",
    "No times set" : "尚未設置時間",
    "Add" : "添加",
    "Monday" : "星期一",
    "Tuesday" : "星期二",
    "Wednesday" : "星期三",
    "Thursday" : "星期四",
    "Friday" : "星期五",
    "Saturday" : "星期六",
    "Sunday" : "星期日",
    "Weekdays" : "平日",
    "Add time before and after the event" : "添加活動前後的時間",
    "Before the event" : "活動前",
    "After the event" : "活動後",
    "Planning restrictions" : "規劃限制",
    "Minimum time before next available slot" : "下一個可用時段之前的最短時間",
    "Max slots per day" : "每天最多的時段數",
    "Limit how far in the future appointments can be booked" : "限制可以提前多長時間預約",
    "It seems a rate limit has been reached. Please try again later." : "似乎已達速率限制。請稍後再試。",
    "Please confirm your reservation" : "請確認您的預約",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "我們向您發送了一封包含詳細信息的電子郵件。 請使用電子郵件中的連結確認您的預約。 您現在可以關閉此頁面。",
    "Your name" : "您的名字",
    "Your email address" : "您的電郵地址",
    "Please share anything that will help prepare for our meeting" : "請分享任何有助於為我們的會議做準備的信息",
    "Could not book the appointment. Please try again later or contact the organizer." : "無法預約。 請稍後再試或聯絡組織者。",
    "Back" : "上星期",
    "Book appointment" : "預約",
    "Error fetching Talk conversations." : "擷取 Talk 對話時發生錯誤",
    "Conversation does not have a valid URL." : "對話沒有有效的 URL。",
    "Successfully added Talk conversation link to location." : "成功在位置中新增 Talk 聊天室連結。",
    "Successfully added Talk conversation link to description." : "成功在描述中新增 Talk 聊天室連結。",
    "Failed to apply Talk room." : "使用 Talk 聊天室失敗。",
    "Talk conversation for event" : "活動 Talk 對話",
    "Error creating Talk conversation" : "創建 Talk 對話時發生錯誤",
    "Select a Talk Room" : "選取 Talk 聊天室",
    "Add Talk conversation" : "添加 Talk 對話",
    "Fetching Talk rooms…" : "正在擷取 Talk 聊天室 …",
    "No Talk room available" : "無可用的 Talk 聊天室",
    "Create public conversation" : "創建公開對話",
    "Select conversation" : "選擇對話",
    "on" : "在",
    "at" : "在",
    "before at" : "之前於",
    "Notification" : "通告",
    "Email" : "電子郵件",
    "Audio notification" : "音訊通知",
    "Other notification" : "其他通知",
    "Relative to event" : "相對於活動",
    "On date" : "在特定日期",
    "Edit time" : "編輯時間",
    "Save time" : "儲存時間",
    "Remove reminder" : "刪除提醒",
    "Add reminder" : "添加提醒",
    "seconds" : "秒",
    "minutes" : "分鐘",
    "hours" : "小時",
    "days" : "日",
    "weeks" : "星期",
    "Choose a file to add as attachment" : "選擇要作為附件的檔案",
    "Choose a file to share as a link" : "選擇要作為連結分享的檔案",
    "Attachment {name} already exist!" : "附件 {name} 已存在！",
    "Could not upload attachment(s)" : "無法上傳附件",
    "You are about to navigate to {link}. Are you sure to proceed?" : "您將要前往 {link}。您確定要繼續嗎？",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "您即將前往 {host}。您確定要繼續嗎？連結：{link}",
    "Proceed" : "進行",
    "No attachments" : "無附件",
    "Add from Files" : "從檔案添加",
    "Upload from device" : "從裝置上傳",
    "Delete file" : "刪除檔案",
    "Confirmation" : "確認",
    "_{count} attachment_::_{count} attachments_" : ["{count} 個附件"],
    "Suggested" : "建議",
    "Available" : "可用",
    "Invitation accepted" : "已接受邀請",
    "Accepted {organizerName}'s invitation" : "已接受 {organizerName} 的邀請",
    "Participation marked as tentative" : "參與標記為暫定",
    "Invitation is delegated" : "邀請已委派",
    "Not available" : "不可用",
    "Invitation declined" : "邀請被婉拒",
    "Declined {organizerName}'s invitation" : "已婉拒 {organizerName} 的邀請",
    "Availability will be checked" : "將檢查可用性",
    "Invitation will be sent" : "將會傳送邀請",
    "Failed to check availability" : "檢查可用性失敗",
    "Failed to deliver invitation" : "遞送邀請失敗",
    "Awaiting response" : "等待回應",
    "Checking availability" : "檢查空閒時間",
    "Has not responded to {organizerName}'s invitation yet" : "尚未回覆 {organizerName} 的邀請",
    "Suggested times" : "建議的時間",
    "chairperson" : "主席",
    "required participant" : "需出席的參與者",
    "non-participant" : "非參與者",
    "optional participant" : "可不出席的參與者",
    "{organizer} (organizer)" : "{organizer}（主辦人）",
    "{attendee} ({role})" : "{attendee}（{role}）",
    "Selected slot" : "選擇時段",
    "Availability of attendees, resources and rooms" : "參與者、資源和會議室的空閒時間",
    "Suggestion accepted" : "已接受建議",
    "Previous date" : "前一個日期",
    "Next date" : "下一個日期",
    "Legend" : "圖例",
    "Out of office" : "不在辦公室",
    "Attendees:" : "參加者：",
    "local time" : "本地時間",
    "Done" : "完成",
    "Search room" : "搜尋房間",
    "Room name" : "聊天室名稱",
    "Check room availability" : "檢查房間可得性",
    "Free" : "有空",
    "Busy (tentative)" : "忙碌（暫定）",
    "Busy" : "忙碌",
    "Unknown" : "不詳",
    "Find a time" : "找一個時間",
    "The invitation has been accepted successfully." : "已成功接受邀請。",
    "Failed to accept the invitation." : "無法接受邀請。",
    "The invitation has been declined successfully." : "已成功婉拒邀請。",
    "Failed to decline the invitation." : "無法婉拒邀請。",
    "Your participation has been marked as tentative." : "您的參與已標記為暫定。",
    "Failed to set the participation status to tentative." : "未能將參與狀態設置為暫定。",
    "Accept" : "接受",
    "Decline" : "婉拒",
    "Tentative" : "暫定",
    "No attendees yet" : "還沒有任何參與者",
    "{confirmedCount} confirmed, {waitingCount} awaiting response" : "{confirmedCount} 個已確認，{waitingCount} 個正在等待回應",
    "Please add at least one attendee to use the \"Find a time\" feature." : "請至少添加一位與會者以使用「尋找時間」功能。",
    "Attendees" : "參與者",
    "_%n more attendee_::_%n more attendees_" : ["還有 %n 位與會者"],
    "Remove group" : "移除群組",
    "Remove attendee" : "移除參與者",
    "Request reply" : "請求回覆",
    "Chairperson" : "主席",
    "Required participant" : "需出席的參與者",
    "Optional participant" : "可不出席的參與者",
    "Non-participant" : "非參與者",
    "_%n member_::_%n members_" : ["%n 個成員"],
    "Search for emails, users, contacts, contact groups or teams" : "搜尋電子郵件、用戶、聯絡人、聯絡人群組或團隊",
    "No match found" : "找不到符合的項目",
    "Note that members of circles get invited but are not synced yet." : "請注意，社交圈子成員已收到邀請，但尚未同步。",
    "Note that members of contact groups get invited but are not synced yet." : "請注意，聯絡人群組已收到邀請，但尚未同步。",
    "(organizer)" : "（主辦人）",
    "Make {label} the organizer" : "讓 {label} 成為籌辦者",
    "Make {label} the organizer and attend" : "讓 {label} 成為籌辦者並參與",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "若要送出邀請函並處理回覆，[linkopen] 請到個人設定頁加入您的電郵地址 [linkclose]",
    "Remove color" : "移除顏色",
    "Event title" : "活動標題",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "無法變更定期重複活動的全日設定",
    "From" : "從",
    "To" : "至",
    "Your Time" : "您的時間",
    "Repeat" : "重複",
    "Repeat event" : "重複活動",
    "_time_::_times_" : ["次"],
    "never" : "永不",
    "on date" : "在特定日期",
    "after" : "之後",
    "End repeat" : "停止重複",
    "Select to end repeat" : "選擇以結束重複",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "此活動是一系列重複活動的特例，您無法針對它設定重複規則",
    "first" : "第一",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "變更的重複規則只會套用至這項活動和重複的未來活動",
    "Repeat every" : "重複循環",
    "By day of the month" : "每月中特定日",
    "On the" : "在",
    "_day_::_days_" : ["天"],
    "_week_::_weeks_" : ["星期"],
    "_month_::_months_" : ["月"],
    "_year_::_years_" : ["年"],
    "On specific day" : "在指定的日子",
    "weekday" : "平日",
    "weekend day" : "週末",
    "Does not repeat" : "不要重複",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Nextcloud 不完全支援此活動的重複。如果您編輯了重複選項，某些重複可能會遺失。",
    "No rooms or resources yet" : "尚無可用會議室或資源",
    "Resources" : "資源",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} 個座位"],
    "Add resource" : "添加資源",
    "Has a projector" : "有投影機",
    "Has a whiteboard" : "有白板",
    "Wheelchair accessible" : "無障礙通道",
    "Remove resource" : "删除資源",
    "Search for resources or rooms" : "搜尋資源或會議室",
    "available" : "可用",
    "unavailable" : "不可用",
    "Show all rooms" : "顯示所有房間",
    "Projector" : "投影機",
    "Whiteboard" : "白板",
    "Room type" : "房間類型",
    "Any" : "任何",
    "Minimum seating capacity" : "最小座位數量",
    "More details" : "更多細節",
    "Update this and all future" : "更新此次和以後的活動",
    "Update this occurrence" : "更新此重複",
    "Public calendar does not exist" : "公開日曆不存在",
    "Maybe the share was deleted or has expired?" : "分享是否已刪除或過期？",
    "Remove date" : "移除日期",
    "Attendance required" : "必須出席",
    "Attendance optional" : "非強制出席",
    "Remove participant" : "移除參與者",
    "Yes" : "是",
    "No" : "否",
    "Maybe" : "也許",
    "None" : "無",
    "Select your meeting availability" : "選取您的會議可出席時間",
    "Create a meeting for this date and time" : "為此日期與時間建立會議",
    "Create" : "創建",
    "No participants or dates available" : "目前沒有可用的參與者或日期",
    "from {formattedDate}" : "從 {formattedDate}",
    "to {formattedDate}" : "至 {formattedDate}",
    "on {formattedDate}" : "於 {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "從 {formattedDate} {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "至 {formattedDate} {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "於 {formattedDate} {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime}",
    "Please enter a valid date" : "請輸入有效的日期",
    "Please enter a valid date and time" : "請輸入有效的日期和時間",
    "Select a time zone" : "選擇時區",
    "Please select a time zone:" : "請選擇時區：",
    "Pick a time" : "挑選時間",
    "Pick a date" : "挑選日期",
    "Type to search time zone" : "輸入以搜尋時區",
    "Global" : "全球",
    "Holidays in {region}" : "{region} 的假期",
    "An error occurred, unable to read public calendars." : "發生錯誤，無法讀取公共日曆。",
    "An error occurred, unable to subscribe to calendar." : "發生錯誤，無法訂閱日曆。",
    "Public holiday calendars" : "公眾假期日曆",
    "Public calendars" : "公共日曆",
    "No valid public calendars configured" : "未設定有效的公共日曆",
    "Speak to the server administrator to resolve this issue." : "請與伺服器管理員聯絡以解決此問題。",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "公眾假期日曆由 Thunderbird 提供。將從 {website} 下載日曆數據",
    "These public calendars are suggested by the server administrator. Calendar data will be downloaded from the respective website." : "這些公開日曆是伺服器管理員建議的。日曆資料將從對應的網站下載。",
    "By {authors}" : "作者 {authors}",
    "Subscribed" : "已訂閱",
    "Subscribe" : "訂閱",
    "Could not fetch slots" : "無法擷取時段",
    "Select a date" : "選擇日期",
    "Select slot" : "選擇時段",
    "No slots available" : "沒有可用的時段",
    "The slot for your appointment has been confirmed" : "您預約的時間已確認",
    "Appointment Details:" : "預約細節：",
    "Time:" : "時間：",
    "Booked for:" : "已訂：",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "謝謝。您 {startDate} 至 {endDate} 的預訂已確認。",
    "Book another appointment:" : "設置另一個預約：",
    "See all available slots" : "查看所有可用的時段",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "{startDate} 至 {endDate} 的時段不再可用。",
    "Please book a different slot:" : "請選擇另一個時段：",
    "Book an appointment with {name}" : "與 {name} 預約",
    "No public appointments found for {name}" : "找不到 {name} 的公開預約",
    "Personal" : "個人",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "自動時區檢測確定您的時區為 UTC。\n這很可能是您的網絡瀏覽器的安全措施的結果。\n請在日曆設置中手動設置您的時區。",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "找不到您選擇的時區 {timezoneId} ，先以 UTC 替代。\n請至設定改變您的時區並舉報此問題。",
    "Show unscheduled tasks" : "顯示未排程的任務",
    "Unscheduled tasks" : "未排程的任務",
    "Availability of {displayName}" : "{displayName} 的可得性",
    "Discard event" : "掉棄活動",
    "Edit event" : "編輯活動",
    "Event does not exist" : "活動不存在",
    "Duplicate" : "重複",
    "Delete this occurrence" : "刪除此次活動",
    "Delete this and all future" : "刪除此次和以後的活動",
    "All day" : "全日",
    "Modifications wont get propagated to the organizer and other attendees" : "修改將不會傳播給籌辦者和其他與會者",
    "Managing shared access" : "管理已分享的存取權限",
    "Deny access" : "拒絕存取",
    "Invite" : "邀請",
    "Discard changes?" : "掉棄更新?",
    "Are you sure you want to discard the changes made to this event?" : "您確定您想要掉棄對此活動的變更嗎？",
    "_User requires access to your file_::_Users require access to your file_" : ["用戶要求存取您的檔案"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["需要分享存取權限的附件"],
    "Untitled event" : "未命名活動",
    "Close" : " 關閉",
    "Modifications will not get propagated to the organizer and other attendees" : "修改將不會傳播給籌辦者和其他與會者",
    "Meeting proposals overview" : "會議提案概覽",
    "Edit meeting proposal" : "編輯會議提案",
    "Create meeting proposal" : "建立會議提案",
    "Update meeting proposal" : "更新會議提案",
    "Saving proposal \"{title}\"" : "正在儲存提案「{title}」",
    "Successfully saved proposal" : "成功儲存提案",
    "Failed to save proposal" : "儲存提案失敗",
    "Create a meeting for \"{date}\"? This will create a calendar event with all participants." : "建立「{date}」的會議？這將會建立包含所有與會者的日曆事件。",
    "Creating meeting for {date}" : "正在建立 {date} 的會議",
    "Successfully created meeting for {date}" : "成功建立 {date} 的會議",
    "Failed to create a meeting for {date}" : "建立 {date} 的會議失敗",
    "Please enter a valid duration in minutes." : "請輸入有效的分鐘數。",
    "Failed to fetch proposals" : "擷取提案失敗",
    "Failed to fetch free/busy data" : "擷取空閒/忙碌資料失敗",
    "Selected" : "已選擇",
    "No Description" : "沒有描述",
    "No Location" : "沒有位置",
    "Edit this meeting proposal" : "編輯此會議提案",
    "Delete this meeting proposal" : "刪除此會議提案",
    "Title" : "標題",
    "15 min" : "15 分鐘",
    "30 min" : "30 分鐘",
    "60 min" : "60 分鐘",
    "90 min" : "90 分鐘",
    "Participants" : "參與者",
    "Selected times" : "已選擇時間",
    "Previous span" : "上一個時段",
    "Next span" : "下一個時段",
    "Less days" : "較少天數",
    "More days" : "較多天數",
    "Loading meeting proposal" : "正在載入會議提案",
    "No meeting proposal found" : "找不到會議提案",
    "Please wait while we load the meeting proposal." : "正在載入會議提案，請稍候。",
    "The link you followed may be broken, or the meeting proposal may no longer exist." : "您點擊的連結可能已失效，或會議提案可能已不存在。",
    "Thank you for your response!" : "感謝您的回應！",
    "Your vote has been recorded. Thank you for participating!" : "已記錄您的投票。感謝您的參與！",
    "Unknown User" : "用戶不詳",
    "No Title" : "沒有標題",
    "No Duration" : "沒有持續時間",
    "Select a different time zone" : "選擇其他時區",
    "Submit" : "遞交",
    "Subscribe to {name}" : "訂閱 {name}",
    "Export {name}" : "導出 {name}",
    "Show availability" : "顯示可得性",
    "Anniversary" : "週年",
    "Appointment" : "約會",
    "Business" : "商業",
    "Education" : "教育",
    "Holiday" : "假日",
    "Meeting" : "會議",
    "Miscellaneous" : "其他",
    "Non-working hours" : "非工作時間",
    "Not in office" : "不在辦公室",
    "Phone call" : "通話",
    "Sick day" : "病假",
    "Special occasion" : "特殊場合",
    "Travel" : "旅行",
    "Vacation" : "度假",
    "Midnight on the day the event starts" : "活動開始日的午夜",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["於 {formattedHourMinute} 的活動 %n 日前"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["於 {formattedHourMinute} 的活動 %n 星期前"],
    "on the day of the event at {formattedHourMinute}" : "於 {formattedHourMinute} 的活動當日",
    "at the event's start" : "在活動開始時",
    "at the event's end" : "在活動結束時",
    "{time} before the event starts" : "活動開始前 {time}",
    "{time} before the event ends" : "活動結束前 {time}",
    "{time} after the event starts" : "活動開始後 {time}",
    "{time} after the event ends" : "活動結束後 {time}",
    "on {time}" : "於 {time}",
    "on {time} ({timezoneId})" : "於 {time}（{timezoneId}）",
    "Week {number} of {year}" : "{year} 的第 {number} 星期",
    "Daily" : "每日",
    "Weekly" : "每星期",
    "Monthly" : "每月",
    "Yearly" : "每年",
    "_Every %n day_::_Every %n days_" : ["每 %n 日"],
    "_Every %n week_::_Every %n weeks_" : ["每 %n 星期"],
    "_Every %n month_::_Every %n months_" : ["每 %n 月"],
    "_Every %n year_::_Every %n years_" : ["每 %n 年"],
    "_on {weekday}_::_on {weekdays}_" : ["於 {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["在 {dayOfMonthList} 天"],
    "on the {ordinalNumber} {byDaySet}" : "在 {ordinalNumber} {byDaySet} 上",
    "in {monthNames} on the {dayOfMonthList}" : "在 {monthNames} 的 {dayOfMonthList}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "在 {ordinalNumber} {byDaySet} 於 {monthNames}",
    "until {untilDate}" : "到 {untilDate}",
    "_%n time_::_%n times_" : ["%n 次"],
    "second" : "秒",
    "third" : "第三",
    "fourth" : "第四",
    "fifth" : "第五",
    "second to last" : "尾二",
    "last" : "最尾",
    "Untitled task" : "未命名任務",
    "Please ask your administrator to enable the Tasks App." : "請要求您的管理員啟用任務應用程式。",
    "You are not allowed to edit this event as an attendee." : "作為與會者，您無權編輯此活動。",
    "W" : "星期",
    "%n more" : "其餘 %n 項",
    "No events to display" : "無可顯示的活動",
    "All participants declined" : "所有參與者均被婉拒",
    "Please confirm your participation" : "請確認您的參與",
    "You declined this event" : "您婉拒了此活動",
    "Your participation is tentative" : "您的參與是暫時性的",
    "_+%n more_::_+%n more_" : ["* 和其他 %n 個"],
    "No events" : "無活動",
    "Create a new event or change the visible time-range" : "建立新活動或變更可見的時間範圍",
    "Failed to save event" : "無法保存活動",
    "It might have been deleted, or there was a typo in a link" : "其可能已經被刪除，或是連結中有錯字",
    "It might have been deleted, or there was a typo in the link" : "其可能已經被刪除，或是連結中有錯字",
    "Meeting room" : "會議室",
    "Lecture hall" : "講課廳",
    "Seminar room" : "研討室",
    "Other" : "其它",
    "When shared show" : "當分享顯示時",
    "When shared show full event" : "分享的時候顯示完整活動",
    "When shared show only busy" : "分享的時候顯示忙碌中",
    "When shared hide this event" : "分享的時候隱藏這個活動",
    "The visibility of this event in read-only shared calendars." : "此事件在唯讀共享行事曆中的能見度。",
    "Add a location" : "加入地點",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "添加描述\n\n- 此會議的主題是什麼\n- 議程項目\n- 參與者需要準備的事項",
    "Status" : "狀態",
    "Confirmed" : "已確認",
    "Canceled" : "已取消",
    "Confirmation about the overall status of the event." : "有關活動整體狀態的確認。",
    "Show as" : "顯示為",
    "Take this event into account when calculating free-busy information." : "計算有空與忙碌資訊時，請將此活動考慮在內。",
    "Categories" : "分類",
    "Categories help you to structure and organize your events." : "分類可以幫您整理您的活動",
    "Search or add categories" : "搜尋或加入分類",
    "Add this as a new category" : "將此加入為新分類",
    "Custom color" : "自訂顏色",
    "Special color of this event. Overrides the calendar-color." : "此活動的特殊顏色。覆寫日曆顏色。",
    "Error while sharing file" : "分享檔案時發生錯誤",
    "Error while sharing file with user" : "與用戶分享檔案時發生錯誤",
    "Error creating a folder {folder}" : "建立資料夾 {folder} 時發生錯誤",
    "Attachment {fileName} already exists!" : "附件 {fileName} 已存在！",
    "Attachment {fileName} added!" : "附件 {fileName} 已添加！",
    "An error occurred during uploading file {fileName}" : "上傳檔案 {fileName} 時發生錯誤",
    "An error occurred during getting file information" : "取得檔案資訊時發生錯誤",
    "Talk conversation for proposal" : "提案的 Talk 對話",
    "An error occurred, unable to delete the calendar." : "發生錯誤，無法刪除日曆",
    "Imported {filename}" : "匯入的 {filename}",
    "This is an event reminder." : "這是一個活動提醒。",
    "Error while parsing a PROPFIND error" : "解析 PROPFIND 錯誤時發生錯誤",
    "Appointment not found" : "找不到預約",
    "User not found" : "找不到用戶",
    "Hidden" : "隱藏",
    "can edit" : "可編輯",
    "Calendar name …" : "日曆名稱 ...",
    "Default attachments location" : "默認附件位置",
    "Automatic ({detected})" : "自動（{detected}）",
    "Shortcut overview" : "捷徑簡介",
    "CalDAV link copied to clipboard." : "已複製 CalDAV 連結至剪貼板",
    "CalDAV link could not be copied to clipboard." : "無法複製 CalDAV 連結至剪貼板",
    "Enable birthday calendar" : "啟用生日日曆",
    "Show tasks in calendar" : "在日曆上顯示待辦事項",
    "Enable simplified editor" : "啟用簡化的編輯器",
    "Limit the number of events displayed in the monthly view" : "限制日曆月視圖中顯示的活動次數",
    "Show weekends" : "顯示週末",
    "Show week numbers" : "顯示週數",
    "Time increments" : "時間增量",
    "Default calendar for incoming invitations" : "傳入邀請的默認日曆",
    "Copy primary CalDAV address" : "複製主要的 CalDAV 位址",
    "Copy iOS/macOS CalDAV address" : "複製 iOS/macOS 的 CalDAV 位址",
    "Personal availability settings" : "個人空閒時間設置",
    "Show keyboard shortcuts" : "顯示鍵盤快捷鍵",
    "Create a new public conversation" : "創建一個新的公開對話",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} 個已邀請，{confirmedCount} 個已確認",
    "Successfully appended link to talk room to location." : "成功將線上會議室的連結加至位置。",
    "Successfully appended link to talk room to description." : "成功將線上會議室的連結加至活動細節",
    "Error creating Talk room" : "建立線上會議室發生錯誤",
    "_%n more guest_::_%n more guests_" : ["還有 %n 位來賓"],
    "The visibility of this event in shared calendars." : "此活動在分享的日曆可見程度。"
},
"nplurals=1; plural=0;");
