OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Pateiktas el. pašto adresas yra per ilgas",
    "User-Session unexpectedly expired" : "Netikėtai pasibaigė naudotojo seanso galiojimas",
    "Provided email-address is not valid" : "Pateiktas el. pašto adresas nėra teisingas",
    "%s has published the calendar »%s«" : "%s paskelbė kalendorių „%s“",
    "Unexpected error sending email. Please contact your administrator." : "Netikėta klaida siunčiant el. laišką. Susisiekite su savo administratoriumi.",
    "Successfully sent email to %1$s" : "El. laiškas sėkmingai išsiųstas į %1$s",
    "Hello," : "Sveiki,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Norėtume informuoti, kad %s paskelbė kalendorių „%s“.",
    "Open »%s«" : "Atverti „%s“",
    "Cheers!" : "Sveikinimai!",
    "Upcoming events" : "Artėjantys įvykiai",
    "No more events today" : "Šiandien daugiau įvykių nėra",
    "No upcoming events" : "Artėjančių įvykių nėra",
    "More events" : "Daugiau įvykių",
    "%1$s with %2$s" : "%1$s su %2$s",
    "Calendar" : "Kalendorius",
    "Appointments" : "Susitikimai",
    "%1$s - %2$s" : "%1$s – %2$s",
    "Confirm" : "Patvirtinti",
    "Description:" : "Aprašas:",
    "This confirmation link expires in %s hours." : "Ši patvirtinimo nuoroda baigia galioti po %s val.",
    "Date:" : "Data:",
    "Where:" : "Kur:",
    "Comment:" : "Komentaras:",
    "Location:" : "Vieta:",
    "Duration:" : "Trukmė:",
    "A Calendar app for Nextcloud" : "Kalendoriaus programėlė, skirta Nextcloud",
    "Previous day" : "Ankstesnė diena",
    "Previous week" : "Ankstesnė savaitė",
    "Previous year" : "Ankstesni metai",
    "Previous month" : "Ankstesnis mėnuo",
    "Next day" : "Kita diena",
    "Next week" : "Kita savaitė",
    "Next year" : "Kiti metai",
    "Next month" : "Kitas mėnuo",
    "Create new event" : "Sukurti naują įvykį",
    "Event" : "Įvykis",
    "Today" : "Šiandiena",
    "Day" : "Diena",
    "Week" : "Savaitė",
    "Month" : "Mėnuo",
    "Year" : "Metai",
    "List" : "Sąrašas",
    "Appointment link was copied to clipboard" : "Susitikimo nuoroda buvo nukopijuota į iškarpinę",
    "Appointment link could not be copied to clipboard" : "Susitikimo nuorodos nepavyko nukopijuoti į iškarpinę",
    "Preview" : "Peržiūra",
    "Copy link" : "Kopijuoti nuorodą",
    "Edit" : "Taisyti",
    "Delete" : "Ištrinti",
    "Create new" : "Sukurti naują",
    "Disable calendar \"{calendar}\"" : "Išjungti kalendorių „{calendar}“",
    "Disable untitled calendar" : "Išjungti kalendorių be pavadinimo",
    "Enable calendar \"{calendar}\"" : "Įjungti kalendorių „{calendar}“",
    "Enable untitled calendar" : "Įjungti kalendorių be pavadinimo",
    "An error occurred, unable to change visibility of the calendar." : "Įvyko klaida, nepavyko pakeisti kalendoriaus matomumo.",
    "Untitled calendar" : "Kalendorius be pavadinimo",
    "Shared with you by" : "Su jumis bendrina",
    "Edit and share calendar" : "Taisyti ir bendrinti kalendorių",
    "Edit calendar" : "Taisyti kalendorių",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Kalendorius nustojamas bendrinti po {countdown} sekundės","Kalendorius nustojamas bendrinti po {countdown} sekundžių","Kalendorius nustojamas bendrinti po {countdown} sekundžių","Kalendorius nustojamas bendrinti po {countdown} sekundės"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Kalendorius ištrinamas po {countdown} sekundės","Kalendorius ištrinamas po {countdown} sekundžių","Kalendorius ištrinamas po {countdown} sekundžių","Kalendorius ištrinamas po {countdown} sekundės"],
    "An error occurred, unable to create the calendar." : "Įvyko klaida, nepavyko sukurti kalendoriaus.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Įveskite teisingą nuorodą (prasidedančią http://, https://, webcal:// ar webcals://)",
    "Calendars" : "Kalendoriai",
    "Add new" : "Pridėti naują",
    "New calendar" : "Naujas kalendorius",
    "Name for new calendar" : "Naujo kalendoriaus pavadinimas",
    "Creating calendar …" : "Kuriamas kalendorius…",
    "New calendar with task list" : "Naujas kalendorius su užduočių sąrašu",
    "New subscription from link (read-only)" : "Nauja prenumerata iš nuorodos (tik skaitymui)",
    "Creating subscription …" : "Kuriama prenumerata…",
    "Calendar link copied to clipboard." : "Kalendoriaus nuoroda nukopijuota į iškarpinę.",
    "Calendar link could not be copied to clipboard." : "Kalendoriaus nuorodos nepavyko nukopijuoti į iškarpinę.",
    "Copy subscription link" : "Kopijuoti prenumeratos nuorodą",
    "Copying link …" : "Kopijuojama nuoroda…",
    "Copied link" : "Nuoroda nukopijuota",
    "Could not copy link" : "Nepavyko nukopijuoti nuorodos",
    "Export" : "Eksportuoti",
    "Unknown calendar" : "Nežinomas kalendorius",
    "Could not load deleted calendars and objects" : "Nepavyko įkelti ištrintų kalendorių ir objektų",
    "Could not delete calendar or event" : "Nepavyko ištrinti kalendoriaus ar įvykio",
    "Could not restore calendar or event" : "Nepavyko atkurti kalendoriaus ar įvykio",
    "Do you really want to empty the trash bin?" : "Ar tikrai norite išvalyti šiukšlinę?",
    "Empty trash bin" : "Išvalyti šiukšlinę",
    "Trash bin" : "Šiukšlinė",
    "Loading deleted items." : "Įkeliami ištrinti elementai.",
    "You do not have any deleted items." : "Jūs neturite jokių ištrintų elementų.",
    "Name" : "Pavadinimas",
    "Deleted" : "Ištrintas",
    "Restore" : "Atkurti",
    "Delete permanently" : "Ištrinti negrįžtamai",
    "Could not update calendar order." : "Nepavyko atnaujinti kalendoriaus tvarkos.",
    "Deck" : "Darbai",
    "Internal link" : "Vidinė nuoroda",
    "Copy internal link" : "Kopijuoti vidinę nuorodą",
    "An error occurred, unable to publish calendar." : "Įvyko klaida, nepavyko paskelbti kalendoriaus.",
    "An error occurred, unable to send email." : "Įvyko klaida, nepavyko išsiųsti el. laiško.",
    "Embed code copied to clipboard." : "Įterpimo kodas nukopijuotas į iškarpinę.",
    "Embed code could not be copied to clipboard." : "Įterpimo kodo nepavyko nukopijuoti į iškarpinę.",
    "Unpublishing calendar failed" : "Nepavyko paskelbti kalendoriaus",
    "Share link" : "Viešinio nuoroda",
    "Copy public link" : "Kopijuoti viešąją nuorodą",
    "Send link to calendar via email" : "Siųsti el. paštu nuorodą į kalendorių",
    "Enter one address" : "Įveskite vieną adresą",
    "Sending email …" : "Siunčiamas el. laiškas…",
    "Copy embedding code" : "Kopijuoti įterpimo kodą",
    "Copying code …" : "Kopijuojamas kodas…",
    "Copied code" : "Kodas nukopijuotas",
    "Could not copy code" : "Nepavyko nukopijuoti kodo",
    "Delete share link" : "Ištrinti viešinio nuorodą",
    "Deleting share link …" : "Ištrinama viešinio nuoroda …",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Komanda)",
    "An error occurred, unable to change the permission of the share." : "Įvykio klaida, nepavyko pakeisti viešinio leidimo.",
    "Unshare with {displayName}" : "Nustoti bendrinti su {displayName}",
    "Share with users or groups" : "Bendrinti su naudotojais ar grupėmis",
    "No users or groups" : "Nėra jokių naudotojų ar grupių",
    "Failed to save calendar name and color" : "Nepavyko įrašyti kalendoriaus pavadinimo ir spalvos",
    "Share calendar" : "Bendrinti kalendorių",
    "Unshare from me" : "Nustoti bendrinti su manimi",
    "Save" : "Įrašyti",
    "View" : "Rodyti",
    "Import calendars" : "Importuoti kalendorius",
    "Please select a calendar to import into …" : "Pasirinkite kalendorių į kurį importuoti…",
    "Filename" : "Failo pavadinimas",
    "Calendar to import into" : "Kalendorius, į kurį importuoti",
    "Cancel" : "Atsisakyti",
    "_Import calendar_::_Import calendars_" : ["Importuoti kalendorių","Importuoti kalendorius","Importuoti kalendorius","Importuoti kalendorius"],
    "Invalid location selected" : "Pasirinkta neteisinga vieta",
    "Attachments folder successfully saved." : "Priedų aplankas sėkmingai įrašytas.",
    "Error on saving attachments folder." : "Klaida įrašant priedų aplanką.",
    "Attachments folder" : "Priedų aplankas",
    "{filename} could not be parsed" : "Nepavyko išnagrinėti {filename}",
    "No valid files found, aborting import" : "Nerasta jokių tinkamų failų, importavimas nutraukiamas",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Sėkmingai importuotas %n įvykis","Sėkmingai importuoti %n įvykiai","Sėkmingai importuota %n įvykių","Sėkmingai importuotas %n įvykis"],
    "Import partially failed. Imported {accepted} out of {total}." : "Importavimas dalinai nepavyko. Importuota {accepted} iš {total}.",
    "Automatic" : "Automatinė",
    "Automatic ({timezone})" : "Automatinė ({timezone})",
    "New setting was not saved successfully." : "Naujas nustatymas nebuvo sėkmingai įrašytas.",
    "Timezone" : "Laiko juosta",
    "Navigation" : "Navigacija",
    "Previous period" : "Ankstesnis laikotarpis",
    "Next period" : "Kitas laikotarpis",
    "Views" : "Rodiniai",
    "Day view" : "Dienos rodinys",
    "Week view" : "Savaitės rodinys",
    "Month view" : "Mėnesio rodinys",
    "Year view" : "Metų rodinys",
    "List view" : "Sąrašo rodinys",
    "Actions" : "Veiksmai",
    "Create event" : "Sukurti įvykį",
    "Show shortcuts" : "Rodyti nuorodas",
    "Editor" : "Redaktorius",
    "Close editor" : "Užverti redaktorių",
    "Save edited event" : "Įrašyti taisytą įvykį",
    "Delete edited event" : "Ištrinti taisytą įvykį",
    "Duplicate event" : "Dubliuoti įvykį",
    "or" : "ar",
    "Calendar settings" : "Kalendoriaus nustatymai",
    "No reminder" : "Jokio priminimo",
    "Failed to save default calendar" : "Nepavyko įrašyti numatytojo kalendoriaus",
    "General" : "Bendra",
    "Appearance" : "Išvaizda",
    "Editing" : "Taisymas",
    "Default reminder" : "Numatytasis priminimas",
    "Files" : "Failai",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minutė","{duration} minutės","{duration} minučių","{duration} minutė"],
    "0 minutes" : "0 minučių",
    "_{duration} hour_::_{duration} hours_" : ["{duration} valanda","{duration} valandos","{duration} valandų","{duration} valanda"],
    "_{duration} day_::_{duration} days_" : ["{duration} diena","{duration} dienos","{duration} dienų","{duration} diena"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} savaitė","{duration} savaitės","{duration} savaičių","{duration} savaitė"],
    "_{duration} month_::_{duration} months_" : ["{duration} mėnesis","{duration} mėnesiai","{duration} mėnesių","{duration} mėnesis"],
    "_{duration} year_::_{duration} years_" : ["{duration} metai","{duration} metai","{duration} metų","{duration} metai"],
    "To configure appointments, add your email address in personal settings." : "Norėdami konfigūruoti susitikimus, asmeniniuose nustatymuose pridėkite savo el. pašto adresą.",
    "Public – shown on the profile page" : "Viešas – rodomas profilio puslapyje",
    "Private – only accessible via secret link" : "Privatus – pasiekiamas tik per slaptą nuorodą",
    "Update" : "Atnaujinti",
    "Location" : "Vieta",
    "Description" : "Aprašas",
    "Visibility" : "Matomumas",
    "Duration" : "Trukmė",
    "Pick time ranges where appointments are allowed" : "Pasirinkite laiko rėžius, kuomet bus leidžiami susitikimai",
    "to" : "iki",
    "No times set" : "Nėra nustatytų laikų",
    "Add" : "Pridėti",
    "Monday" : "Pirmadienis",
    "Tuesday" : "Antradienis",
    "Wednesday" : "Trečiadienis",
    "Thursday" : "Ketvirtadienis",
    "Friday" : "Penktadienis",
    "Saturday" : "Šeštadienis",
    "Sunday" : "Sekmadienis",
    "Add time before and after the event" : "Pridėti laiką prieš ir po įvykio",
    "Before the event" : "Prieš įvykį",
    "After the event" : "Po įvykio",
    "Planning restrictions" : "Planavimo apribojimai",
    "Your name" : "Jūsų vardas",
    "Your email address" : "Jūsų el. pašto adresas",
    "Please share anything that will help prepare for our meeting" : "Pasidalinkite informacija, kuri padės mums pasiruošti šiam susitikimui",
    "Back" : "Atgal",
    "on" : "šiomis dienomis",
    "at" : ",",
    "before at" : "prieš įvykį, ties",
    "Notification" : "Pranešimas",
    "Email" : "Elektroninis laiškas",
    "Audio notification" : "Garsinis pranešimas",
    "Other notification" : "Kitas pranešimas",
    "Relative to event" : "Susieta su įvykiu",
    "On date" : "data",
    "Edit time" : "Taisyti laiką",
    "Save time" : "Įrašyti laiką",
    "Remove reminder" : "Šalinti priminimą",
    "Add reminder" : "Pridėti priminimą",
    "seconds" : "sekundes",
    "minutes" : "minučių",
    "hours" : "valandų",
    "days" : "dienų",
    "weeks" : "savaičių",
    "Choose a file to add as attachment" : "Pasirinkite failą, kurį prisegsite prie laiško",
    "Choose a file to share as a link" : "Pasirinkite failą, kurį bendrinsite kaip nuorodą",
    "Add from Files" : "Pridėti iš Failų",
    "Upload from device" : "Įkelti iš įrenginio",
    "Delete file" : "Ištrinti failą",
    "_{count} attachment_::_{count} attachments_" : ["{count} priedas","{count} priedai","{count} priedų","{count} priedas"],
    "Available" : "Prieinamas",
    "Invitation accepted" : "Pakvietimas priimtas",
    "Failed to deliver invitation" : "Nepavyko pristatyti pakvietimo",
    "Checking availability" : "Tikrinamas prieinamumas",
    "chairperson" : "pirmininkas",
    "{organizer} (organizer)" : "{organizer} (organizatorius)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Availability of attendees, resources and rooms" : "Kviestinių, išteklių ir kambarių prieinamumas",
    "Out of office" : "Ne darbo vietoje",
    "Attendees:" : "Kviestiniai:",
    "Done" : "Atlikta",
    "Room name" : "Kambario pavadinimas",
    "Free" : "Laisvas laikas",
    "Busy (tentative)" : "Užimtas laikas (preliminariai)",
    "Busy" : "Užimtas laikas",
    "Unknown" : "Nežinoma",
    "Accept" : "Priimti",
    "Decline" : "Atmesti",
    "Tentative" : "Preliminarus",
    "No attendees yet" : "Kol kas kviestinių nėra",
    "Attendees" : "Kviestiniai",
    "Remove group" : "Šalinti grupę",
    "Remove attendee" : "Šalinti kviestinį",
    "Chairperson" : "Pirmininkas",
    "Required participant" : "Būtinas dalyvis",
    "Optional participant" : "Nebūtinas dalyvis",
    "Non-participant" : "Ne dalyvis",
    "_%n member_::_%n members_" : ["%n narys","%n nariai","%n narių","%n narys"],
    "No match found" : "Nerasta jokio atitikmens",
    "(organizer)" : "(organizatorius)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Norėdami siųsti pakvietimus ir apdoroti atsakymus, [linkopen]pridėkite į asmeninius nustatymus savo el. pašto adresą[linkclose].",
    "Remove color" : "Šalinti spalvą",
    "Event title" : "Įvykio pavadinimas",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Negalima modifikuoti „Visos dienos“ nustatymą įvykiams, kurie yra pasikartojimo rinkinio dalis.",
    "From" : "Nuo",
    "To" : "Kam",
    "Repeat" : "Kartoti",
    "_time_::_times_" : ["karto","kartų","kartų","karto"],
    "never" : "niekada",
    "on date" : "tam tikrą datą",
    "after" : "po",
    "End repeat" : "Užbaigti kartojimą",
    "Select to end repeat" : "Pasirinkite norėdami užbaigti kartojimą",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Šis įvykis yra pasikartojimo rinkinio pasikartojimo išimtis. Negalite jam pridėti pasikartojimo taisyklės.",
    "first" : "pirmas",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Pakeitimai pasikartojimo taisyklėje bus taikomi tik šiam ir būsimiems pasikartojimams.",
    "Repeat every" : "Kartoti kas",
    "By day of the month" : "Pagal mėnesio dienas",
    "On the" : "Ties",
    "_day_::_days_" : ["diena","dienos","dienų","diena"],
    "_week_::_weeks_" : ["savaitė","savaitės","savaičių","savaitė"],
    "_month_::_months_" : ["mėnesis","mėnesiai","mėnesių","mėnesis"],
    "_year_::_years_" : ["metai","metai","metų","metai"],
    "weekday" : "savaitės darbo dienos",
    "weekend day" : "savaitgalio diena",
    "Does not repeat" : "Nekartojamas",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Nextcloud nepalaiko pilnai šio įvykio pasikartojimo apibrėžimo. Jei taisysite pasikartojimo parinktis, tam tikri pasikartojimai gali būti prarasti.",
    "No rooms or resources yet" : "Kol kas nėra kambarių ar išteklių",
    "Resources" : "Ištekliai",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} sėdima vieta","{seatingCapacity} sėdimos vietos","{seatingCapacity} sėdimų vietų","{seatingCapacity} sėdima vieta"],
    "Add resource" : "Pridėti išteklių",
    "Has a projector" : "Yra projektorius",
    "Has a whiteboard" : "Yra rašymo lenta",
    "Wheelchair accessible" : "Prieiga neįgaliųjų vežimėliu",
    "Remove resource" : "Šalinti išteklių",
    "Search for resources or rooms" : "Ieškoti išteklių ar kambarių",
    "available" : "prieinamas",
    "unavailable" : "neprieinamas",
    "Show all rooms" : "Rodyti visus kambarius",
    "Projector" : "Projektorius",
    "Whiteboard" : "Rašymo lenta",
    "Room type" : "Kambario tipas",
    "Any" : "Bet koks",
    "More details" : "Išsamiau",
    "Update this and all future" : "Atnaujinti šį ir visus būsimus",
    "Update this occurrence" : "Atnaujinti šį pasikartojimą",
    "Public calendar does not exist" : "Viešojo kalendoriaus nėra",
    "Maybe the share was deleted or has expired?" : "Galbūt, viešinys buvo ištrintas arba nebegalioja?",
    "Yes" : "Taip",
    "No" : "Ne",
    "Maybe" : "Galbūt",
    "None" : "Nėra",
    "Create" : "Sukurti",
    "from {formattedDate}" : "nuo {formattedDate}",
    "to {formattedDate}" : "iki {formattedDate}",
    "on {formattedDate}" : "{formattedDate}",
    "from {formattedDate} at {formattedTime}" : "nuo {formattedDate}, {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "iki {formattedDate}, {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "{formattedDate}, {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate}, {formattedTime}",
    "Please enter a valid date" : "Įveskite teisingą datą",
    "Please enter a valid date and time" : "Įveskite teisingą datą ir laiką",
    "Please select a time zone:" : "Pasirinkite laiko juostą:",
    "Pick a time" : "Pasirinkite laiką",
    "Pick a date" : "Pasirinkite datą",
    "Type to search time zone" : "Rašykite norėdami ieškoti laiko juostos",
    "Global" : "Visuotinis",
    "An error occurred, unable to subscribe to calendar." : "Įvyko klaida, nepavyko prenumeruoti kalendoriaus.",
    "Subscribed" : "Prenumeruotas",
    "Subscribe" : "Prenumeruoti",
    "Select a date" : "Pasirinkti datą",
    "Time:" : "Laikas:",
    "Personal" : "Asmeniniai",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Automatinis laiko juostos aptikimas nustatė, kad jūsų laiko juosta yra UTC.\nTaip, greičiausiai, yra dėl jūsų saityno naršyklės saugos priemonių.\nKalendoriaus nustatymuose prašome rankiniu būdu nusistatyti laiko juostą.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Jūsų konfigūruota laiko juosta ({timezoneId}) nerasta. Grįžtama į UTC.\nPrašome nustatymuose pakeisti savo laiko juostą ir pranešti apie šią problemą.",
    "Edit event" : "Taisyti įvykį",
    "Event does not exist" : "Įvykio nėra",
    "Delete this occurrence" : "Ištrinti šį pasikartojimą",
    "Delete this and all future" : "Ištrinti šį ir visus būsimus",
    "All day" : "Visą dieną",
    "Untitled event" : "Įvykis be pavadinimo",
    "Close" : "Užverti",
    "Selected" : "Pasirinkta",
    "Title" : "Pavadinimas",
    "Participants" : "Dalyviai",
    "Submit" : "Pateikti",
    "Subscribe to {name}" : "Prenumeruoti {name}",
    "Export {name}" : "Eksportuoti {name}",
    "Show availability" : "Rodyti prieinamumą",
    "Anniversary" : "Metinės",
    "Appointment" : "Paskyrimas",
    "Business" : "Verslas",
    "Education" : "Švietimas",
    "Holiday" : "Šventinė diena",
    "Meeting" : "Susitikimas",
    "Miscellaneous" : "Įvairūs",
    "Non-working hours" : "Ne darbo valandos",
    "Not in office" : "Ne darbo vietoje",
    "Phone call" : "Telefono skambutis",
    "Sick day" : "Nedarbingumo dėl ligos diena",
    "Special occasion" : "Ypatinga proga",
    "Travel" : "Kelionės",
    "Vacation" : "Atostogos",
    "Midnight on the day the event starts" : "Vidurnaktį, įvykio pradžios dieną",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n dieną prieš įvykį, ties {formattedHourMinute}","%n dienas prieš įvykį, ties {formattedHourMinute}","%n dienų prieš įvykį, ties {formattedHourMinute}","%n dieną prieš įvykį, ties {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n savaitę prieš įvykį, ties {formattedHourMinute}","%n savaites prieš įvykį, ties {formattedHourMinute}","%n savaičių prieš įvykį, ties {formattedHourMinute}","%n savaitę prieš įvykį, ties {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "įvykio dieną ties {formattedHourMinute}",
    "at the event's start" : "įvykio pradžioje",
    "at the event's end" : "įvykio pabaigoje",
    "{time} before the event starts" : "{time} prieš įvykio pradžią",
    "{time} before the event ends" : "{time} prieš įvykio pabaigą",
    "{time} after the event starts" : "{time} po įvykio pradžios",
    "{time} after the event ends" : "{time} po įvykio pabaigos",
    "on {time}" : "ties {time}",
    "on {time} ({timezoneId})" : "ties {time} ({timezoneId})",
    "Week {number} of {year}" : "{year}-ųjų metų {number} savaitė",
    "Daily" : "Kasdien",
    "Weekly" : "Kas savaitę",
    "Monthly" : "Kas mėnesį",
    "Yearly" : "Kas metus",
    "_Every %n day_::_Every %n days_" : ["Kas %n dieną","Kas %n dienas","Kas %n dienų","Kas %n dieną"],
    "_Every %n week_::_Every %n weeks_" : ["Kas %n savaitę","Kas %n savaites","Kas %n savaičių","Kas %n savaitę"],
    "_Every %n month_::_Every %n months_" : ["Kas %n mėnesį","Kas %n mėnesius","Kas %n mėnesių","Kas %n mėnesį"],
    "_Every %n year_::_Every %n years_" : ["Kas %n metus","Kas %n metus","Kas %n metų","Kas %n metus"],
    "_on {weekday}_::_on {weekdays}_" : ["ties {weekday}","ties {weekdays}","ties {weekdays}","ties {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["šiomis dienomis: {dayOfMonthList}","šiomis dienomis: {dayOfMonthList}","šiomis dienomis: {dayOfMonthList}","šiomis dienomis: {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "ties {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "ties {monthNames}, ties {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "iki {untilDate}",
    "_%n time_::_%n times_" : ["%n kartą","%n kartus","%n kartų","%n kartą"],
    "second" : "antras",
    "third" : "trečias",
    "fourth" : "ketvirtas",
    "fifth" : "penktas",
    "second to last" : "priešpaskutinis",
    "last" : "paskutinis",
    "Untitled task" : "Užduotis be pavadinimo",
    "Please ask your administrator to enable the Tasks App." : "Paprašykite administratoriaus įjungti Užduočių programą.",
    "W" : "Sav.",
    "%n more" : "dar %n",
    "No events to display" : "Nėra rodytinų įvykių",
    "_+%n more_::_+%n more_" : ["+ dar %n","+ dar %n","+ dar %n","+ dar %n"],
    "No events" : "Įvykių nėra",
    "Create a new event or change the visible time-range" : "Sukurti naują įvykį ar keisti matomą laiko rėžį",
    "Failed to save event" : "Nepavyko įrašyti įvykio",
    "Meeting room" : "Susitikimų kambarys",
    "Lecture hall" : "Paskaitų auditorija",
    "Seminar room" : "Seminarų salė",
    "Other" : "Kita",
    "When shared show" : "Bendrinant rodyti",
    "When shared show full event" : "Bendrinant, rodyti visą įvykio informaciją",
    "When shared show only busy" : "Bendrinant, rodyti tik kaip užimtą laiką",
    "When shared hide this event" : "Bendrinant, slėpti šį įvykį",
    "Add a location" : "Pridėti vietą",
    "Status" : "Būsena",
    "Confirmed" : "Patvirtintas",
    "Canceled" : "Atsisakytas",
    "Confirmation about the overall status of the event." : "Patvirtinimas apie bendrą įvykio būseną.",
    "Show as" : "Rodyti kaip",
    "Take this event into account when calculating free-busy information." : "Atsižvelgti į šį įvykį apskaičiuojant laisvo ir užimto laiko informaciją.",
    "Categories" : "Kategorijos",
    "Categories help you to structure and organize your events." : "Kategorijos padeda jums struktūrizuoti ir valdyti savo įvykius.",
    "Search or add categories" : "Ieškoti ar pridėti kategorijas",
    "Add this as a new category" : "Pridėti tai kaip naują kategoriją",
    "Custom color" : "Tinkinta spalva",
    "Special color of this event. Overrides the calendar-color." : "Speciali šio įvykio spalva. Nustelbia kalendoriaus spalvą.",
    "Error while sharing file" : "Klaida bendrinant failą",
    "Error while sharing file with user" : "Klaida bendrinant failą su naudotoju",
    "Attachment {fileName} already exists!" : "Priedas „{fileName}“ jau yra!",
    "An error occurred during getting file information" : "Gaunant informaciją apie failą įvyko klaida",
    "An error occurred, unable to delete the calendar." : "Įvyko klaida, nepavyko ištrinti kalendorių.",
    "Imported {filename}" : "Importuotas {filename}",
    "This is an event reminder." : "Tai priminimas apie įvykį.",
    "Appointment not found" : "Susitikimas nerastas",
    "User not found" : "Naudotojas nerastas",
    "Hidden" : "Paslėpta",
    "can edit" : "gali redaguoti",
    "Calendar name …" : "Kalendoriaus pavadinimas…",
    "Default attachments location" : "Numatytoji priedų vieta",
    "Automatic ({detected})" : "Automatinė ({detected})",
    "Shortcut overview" : "Nuorodų apžvalga",
    "CalDAV link copied to clipboard." : "CalDAV nuoroda nukopijuota į iškarpinę.",
    "CalDAV link could not be copied to clipboard." : "Nepavyko nukopijuoti CalDAV nuorodą į iškarpinę.",
    "Enable birthday calendar" : "Įjungti gimtadienių kalendorių",
    "Show tasks in calendar" : "Rodyti užduotis kalendoriuje",
    "Enable simplified editor" : "Įjungti supaprastintą redaktorių",
    "Limit the number of events displayed in the monthly view" : "Riboti mėnesio rodinyje rodomų įvykių skaičių",
    "Show weekends" : "Rodyti savaitgalius",
    "Show week numbers" : "Rodyti savaičių numerius",
    "Copy primary CalDAV address" : "Kopijuoti pirminį CalDAV adresą",
    "Copy iOS/macOS CalDAV address" : "Kopijuoti iOS/macOS CalDAV adresą",
    "Personal availability settings" : "Asmeninio pasiekiamumo nustatymai",
    "Show keyboard shortcuts" : "Rodyti sparčiuosius klavišus",
    "Successfully appended link to talk room to description." : "Pokalbių kambario nuoroda sėkmingai pridėta į aprašą.",
    "Error creating Talk room" : "Klaida sukuriant pokalbių kambarį",
    "The visibility of this event in shared calendars." : "Šio įvykio matomumas bendrinamuose kalendoriuose."
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
