OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Zadaná e-mailová adresa je příliš dlouhá",
    "User-Session unexpectedly expired" : "Sezení bylo neočekávaně přerušeno",
    "Provided email-address is not valid" : "Zadaná e-mailová adresa není platná",
    "%s has published the calendar »%s«" : "%s zveřejnil(a) kalendář „%s“",
    "Unexpected error sending email. Please contact your administrator." : "Neočekávaná chyba při odesílání e-mailu. Obraťte se správce.",
    "Successfully sent email to %1$s" : "E-mail úspěšně odeslán na %1$s",
    "Hello," : "Dobrý den,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Chceme vás informovat, že %s právě zveřejnil/a  kalendář „%s“.",
    "Open »%s«" : "Otevřít „%s“",
    "Cheers!" : "Mějte se!",
    "Upcoming events" : "Nadcházející události",
    "No more events today" : "Dnes už žádné další události",
    "No upcoming events" : "Žádné nadcházející události",
    "More events" : "Více událostí",
    "%1$s with %2$s" : "%1$s s %2$s",
    "Calendar" : "Kalendář",
    "New booking {booking}" : "Nová rezervace {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) si zarezervoval(a) schůzku „{config_display_name}“ v {date_time}.",
    "Appointments" : "Schůzky",
    "Schedule appointment \"%s\"" : "Naplánovat schůzku „%s“",
    "Schedule an appointment" : "Naplánovat schůzku",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : "Příprava na %s",
    "Follow up for %s" : "Následné kroky ohledně %s",
    "Your appointment \"%s\" with %s needs confirmation" : "K vaší schůzce „%s“ s %s je třeba potvrzení",
    "Dear %s, please confirm your booking" : "%s, prosíme potvrďte svou rezervaci",
    "Confirm" : "Potvrdit",
    "Appointment with:" : "Schůzka s:",
    "Description:" : "Popis:",
    "This confirmation link expires in %s hours." : "Platnost tohoto odkazu pro potvrzení skončí za %s hodin.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Pokud si přejete schůzku přece jen zrušit, obraťte se na organizátora odpovědí na tento e-mail nebo navštívením jeho profilové stránky.",
    "Your appointment \"%s\" with %s has been accepted" : "Vaše schůzka „%s“ s %s byla přijata",
    "Dear %s, your booking has been accepted." : "Vážená/ý %s, vaše rezervace byla přijata.",
    "Appointment for:" : "Schůzka pro:",
    "Date:" : "Datum:",
    "You will receive a link with the confirmation email" : "Obdržíte odkaz s potvrzovacím e-mailem",
    "Where:" : "Kde:",
    "Comment:" : "Komentář:",
    "You have a new appointment booking \"%s\" from %s" : "Máte novou rezervaci schůzky „%s“ od %s",
    "Dear %s, %s (%s) booked an appointment with you." : "Vážená/ý %s, %s (%s) si s vámi zarezervoval/a schůzku.",
    "%s has proposed a meeting" : "%s navrhl/a schůzku",
    "%s has updated a proposed meeting" : "%s zaktualizoval/a navrhovanou schůzku",
    "%s has canceled a proposed meeting" : "%s zrušil/a navrhovanou schůzku",
    "Dear %s, a new meeting has been proposed" : "Vážená/ý %s, byla navržena nová schůzka",
    "Dear %s, a proposed meeting has been updated" : "Vážená/ý %s, navrhovaná schůzka byla aktualizována",
    "Dear %s, a proposed meeting has been cancelled" : "Vážená/ý %s, navrhovaná schůzka byla zrušena",
    "Location:" : "Umístění:",
    "Duration:" : "Doba trvání:",
    "%1$s from %2$s to %3$s" : "%1$s od %2$s do %3$s",
    "Dates:" : "Datumy:",
    "Respond" : "Odpovědět",
    "A Calendar app for Nextcloud" : "Kalendář pro Nextcloud",
    "A Calendar app for Nextcloud. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Like Contacts, Talk, Tasks, Deck and Circles\n* 🌐 **WebCal Support!** Want to see your favorite team's matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 **Search!** Find your events at ease\n* ☑️ **Tasks!** See tasks or Deck cards with a due date directly in the calendar\n* 🔈 **Talk rooms!** Create an associated Talk room when booking a meeting with just one click\n* 📆 **Appointment booking** Send people a link so they can book an appointment with you [using this app](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Attachments!** Add, upload and view event attachments\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Aplikace kalendáře pro Nextcloud. Snadno synchronizujte události z různých zařízení s vaším Nextcloudem a upravujte je online.\n\n* 🚀 **Integrace s dalšími aplikacemi Nextcloud!** Jako Kontakty, Talk, Úkoly, Deck a Circles\n* 🌐 **Podpora WebCal!** Chcete vidět zápasy svého oblíbeného týmu ve svém kalendáři? Žádný problém!\n* 🙋 **Účastníci!** Pozvěte lidi na své události\n* ⌚ **Mám/nemám čas!** Zjistěte, kdy jsou vaši účastníci k dispozici na schůzku\n* ⏰ **Připomenutí!** Získejte upozornění na události přímo v prohlížeči a e-mailem\n* 🔍 **Vyhledávání!** Snadno najděte své události\n* ☑️ **Úkoly!** Zobrazte si úkoly nebo karty Deck s termínem přímo v kalendáři\n* 🔈 **Místnosti Talk!** Vytvořte přidruženou místnost Talk při rezervaci schůzky jedním kliknutím\n* 📆 **Rezervace schůzek** Pošlete lidem odkaz, aby si mohli s vámi rezervovat schůzku [pomocí této aplikace](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Přílohy!** Přidávejte, nahrávejte a prohlížejte přílohy událostí\n* 🙈 **Nevynalézáme kolo!** Aplikace je založena na skvělých knihovnách [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) a [fullcalendar](https://github.com/fullcalendar/fullcalendar).",
    "Previous day" : "Předchozí den",
    "Previous week" : "Předchozí týden",
    "Previous year" : "Předchozí rok",
    "Previous month" : "Předchozí měsíc",
    "Next day" : "Příští den",
    "Next week" : "Příští týden",
    "Next year" : "Následující rok",
    "Next month" : "Příští měsíc",
    "Create new event" : "Vytvořit novou událost",
    "Event" : "Událost",
    "Today" : "Dnes",
    "Day" : "Den",
    "Week" : "Týden",
    "Month" : "Měsíc",
    "Year" : "Rok",
    "List" : "Seznam",
    "Appointment link was copied to clipboard" : "Odkaz na schůzku byl zkopírován do schránky",
    "Appointment link could not be copied to clipboard" : "Odkaz na schůzku se nepodařilo zkopírovat do schránky",
    "Preview" : "Náhled",
    "Copy link" : "Zkopírovat odkaz",
    "Edit" : "Upravit",
    "Delete" : "Smazat",
    "Appointment schedules" : "Plány schůzek",
    "Create new" : "Vytvořit nové",
    "Disable calendar \"{calendar}\"" : "Vypnout kalendář „{calendar}“",
    "Disable untitled calendar" : "Vypnout nenazvaný kalendář",
    "Enable calendar \"{calendar}\"" : "Zapnout kalendář „{calendar}“",
    "Enable untitled calendar" : "Zapnout nenazvaný kalendář",
    "An error occurred, unable to change visibility of the calendar." : "Došlo k chybě, nedaří se změnit viditelnost kalendáře.",
    "Untitled calendar" : "Nepojmenovaný kalendář",
    "Shared with you by" : "Nasdílel(a) vám",
    "Edit and share calendar" : "Upravit a nasdílet kalendář",
    "Edit calendar" : "Upravit kalendář",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Kalendář přestane být sdílen za {countdown} sekundu","Kalendář přestane být sdílen za {countdown} sekundy","Kalendář přestane být sdílen za {countdown} sekund","Kalendář přestane být sdílen za {countdown} sekundy"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Smazání kalendáře za {countdown} sekundu","Smazání kalendáře za {countdown} sekundy","Smazání kalendáře za {countdown} sekund","Smazání kalendáře za {countdown} sekundy"],
    "An error occurred, unable to create the calendar." : "Došlo k chybě, kalendář se nepodařilo vytvořit.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Vložte platný odkaz (včetně http://, https://, webcal://, nebo webcals:// na začátku)",
    "Calendars" : "Kalendáře",
    "Add new" : "Přidat novou",
    "New calendar" : "Nový kalendář",
    "Name for new calendar" : "Název pro nový kalendář",
    "Creating calendar …" : "Vytváření kalendáře …",
    "New calendar with task list" : "Nový kalendář s úkolníkem",
    "New subscription from link (read-only)" : "Nové přihlášení se k odběru z odkazu (pouze pro čtení)",
    "Creating subscription …" : "Vytváření přihlášení se k odběru …",
    "Add public holiday calendar" : "Přidat kalendář veřejných svátků",
    "Add custom public calendar" : "Přidat uživatelsky určený veřejný kalendář",
    "Calendar link copied to clipboard." : "Odkaz kalendáře zkopírován do schránky.",
    "Calendar link could not be copied to clipboard." : "Odkaz na kalendář se nepodařilo zkopírovat do schránky.",
    "Copy subscription link" : "Zkopírovat odkaz pro přihlášení se k odběru",
    "Copying link …" : "Kopírování odkazu …",
    "Copied link" : "Odkaz zkopírován",
    "Could not copy link" : "Odkaz se nedaří zkopírovat",
    "Export" : "Exportovat",
    "Untitled item" : "Nepojmenovaná položka",
    "Unknown calendar" : "Neznámý kalendář",
    "Could not load deleted calendars and objects" : "Nedaří se načíst smazané kalendáře a objekty",
    "Could not delete calendar or event" : "Kalendář či událost se nepodařilo smazat",
    "Could not restore calendar or event" : "Kalendář nebo událost se nepodařilo obnovit",
    "Do you really want to empty the trash bin?" : "Opravdu chcete koš vyprázdnit?",
    "Empty trash bin" : "Vyprázdnit koš",
    "Trash bin" : "Koš",
    "Loading deleted items." : "Načítání smazaných položek.",
    "You do not have any deleted items." : "Nemáte žádné smazané položky.",
    "Name" : "Název",
    "Deleted" : "Smazáno",
    "Restore" : "Obnovit",
    "Delete permanently" : "Trvale odstranit",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Položky v koši jsou smazány po uplynutí {numDays} dne","Prvky v koši jsou smazány po uplynutí {numDays} dnů","Položky v koši jsou smazány po uplynutí {numDays} dnů","Položky v koši jsou smazány po uplynutí {numDays} dnů"],
    "Could not update calendar order." : "Pořadí kalendářů se nedaří aktualizovat.",
    "Shared calendars" : "Sdílené kalendáře",
    "Deck" : "Deck",
    "Internal link" : "Interní odkaz",
    "A private link that can be used with external clients" : "Soukromý odkaz, který je možné použít s externími klienty",
    "Copy internal link" : "Zkopírovat interní odkaz",
    "An error occurred, unable to publish calendar." : "Došlo k chybě, kalendář se nedaří zveřejnit.",
    "An error occurred, unable to send email." : "Došlo k chybě, e-mail se nedaří odeslat.",
    "Embed code copied to clipboard." : "HTML kód, který vložit do kódu stránky, zkopírován do schránky.",
    "Embed code could not be copied to clipboard." : "HTML kód, který vložit do kódu stránky, se nepodařilo zkopírovat do schránky",
    "Unpublishing calendar failed" : "Zrušení zveřejnění kalendáře se nezdařilo",
    "Share link" : "Odkaz na sdílení",
    "Copy public link" : "Zkopírovat veřejný odkaz",
    "Send link to calendar via email" : "Odeslat odkaz na kalendář prostřednictvím e-mailu",
    "Enter one address" : "Zadejte jednu adresu",
    "Sending email …" : "Posílání e-mailu …",
    "Copy embedding code" : "Zkopírovat kód pro vložení do HTML",
    "Copying code …" : "Kopírování kódu …",
    "Copied code" : "HTML kód zkopírován",
    "Could not copy code" : "HTML kód se nedaří zkopírovat",
    "Delete share link" : "Smazat sdílecí odkaz",
    "Deleting share link …" : "Mazání odkazu na sdílení …",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (tým)",
    "An error occurred while unsharing the calendar." : "Došlo k chybě při rušení sdílení kalendáře",
    "An error occurred, unable to change the permission of the share." : "Došlo k chybě, nepodařilo se změnit přístupová práva k sdílení.",
    "can edit and see confidential events" : "může upravovat a zobrazovat si důvěrné události",
    "Unshare with {displayName}" : "Přestat sdílet s {displayName}",
    "Share with users or groups" : "Sdílet s uživateli nebo skupinami",
    "No users or groups" : "Žádní uživatelé nebo skupiny",
    "Failed to save calendar name and color" : "Nepodařilo se uložit název a barvu kalendáře",
    "Calendar name …" : "Název kalendáře …",
    "Never show me as busy (set this calendar to transparent)" : "Nikdy mne nezobrazovat jako zaneprázdněného (nastavit tento kalendář jako transparentní)",
    "Share calendar" : "Nasdílet kalendář",
    "Unshare from me" : "Přestat sdílet",
    "Save" : "Uložit",
    "No title" : "Bez nadpisu",
    "Are you sure you want to delete \"{title}\"?" : "Opravdu chcete „{title}“ smazat?",
    "Deleting proposal \"{title}\"" : "Maže se návrh „{title}“",
    "Successfully deleted proposal" : "Návrh úspěšně smazán",
    "Failed to delete proposal" : "Nepodařilo se smazat návrh",
    "Failed to retrieve proposals" : "Nepodařilo se načíst návrhy",
    "Meeting proposals" : "Návrhy schůzek",
    "A configured email address is required to use meeting proposals" : "Pro používání návrhů schůzek je třeba mít nastavenou e-mailovou adresu",
    "No active meeting proposals" : "Žádné aktivní návrhy schůzek",
    "View" : "Zobrazit",
    "Import calendars" : "Importovat kalendáře",
    "Please select a calendar to import into …" : "Vyberte kalendář do kterého importovat …",
    "Filename" : "Soubor",
    "Calendar to import into" : "Kalendář do kterého importovat",
    "Cancel" : "Storno",
    "_Import calendar_::_Import calendars_" : ["Importovat kalendář","Importovat kalendáře","Importovat kalendářů","Importovat kalendáře"],
    "Select the default location for attachments" : "Vyberte výchozí umístění pro přílohy",
    "Pick" : "Vybrat",
    "Invalid location selected" : "Vybráno neplatné umístění",
    "Attachments folder successfully saved." : "Nastavení složky pro přílohy úspěšně uloženo.",
    "Error on saving attachments folder." : "Chyba při ukládání nastavení složky pro přílohy.",
    "Attachments folder" : "Složka s přílohami",
    "{filename} could not be parsed" : "{filename} není možné zpracovat",
    "No valid files found, aborting import" : "Nenalezeny žádné platné soubory, import proto bude ukončen",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Úspěšně naimportována %n událost","Úspěšně naimportovány %n události","Úspěšně naimportováno %n událostí","Úspěšně naimportovány %n události"],
    "Import partially failed. Imported {accepted} out of {total}." : "Import se z části nezdařil. Naimportováno {accepted} z {total}.",
    "Automatic" : "Automaticky",
    "Automatic ({timezone})" : "Automaticky ({timezone})",
    "New setting was not saved successfully." : "Nové nastavení se nepodařilo uložit.",
    "Timezone" : "Časová zóna",
    "Navigation" : "Pohyb",
    "Previous period" : "Předchozí období",
    "Next period" : "Následující období",
    "Views" : "Zobrazení",
    "Day view" : "Denní zobrazení",
    "Week view" : "Týdenní zobrazení",
    "Month view" : "Měsíční zobrazení",
    "Year view" : "Roční zobrazení",
    "List view" : "Zobrazení v seznamu",
    "Actions" : "Akce",
    "Create event" : "Vytvořit událost",
    "Show shortcuts" : "Zobrazit zkratky",
    "Editor" : "Editor",
    "Close editor" : "Zavřít editor",
    "Save edited event" : "Uložit upravenou událost",
    "Delete edited event" : "Smazat upravenou událost",
    "Duplicate event" : "Zduplikovat událost",
    "or" : "nebo",
    "Calendar settings" : "Nastavení kalendáře",
    "At event start" : "Na začátku události",
    "No reminder" : "Žádná upomínka",
    "Failed to save default calendar" : "Nepodařilo se uložit výchozí kalendář",
    "General" : "Obecné",
    "Availability settings" : "Nastavení dostupnosti",
    "CalDAV" : "CalDAV",
    "Access Nextcloud calendars from other apps and devices" : "Přistupujte ke kalendářům v Nextcloud z ostatních aplikací a zařízení",
    "CalDAV URL" : "CalDAV URL",
    "Server Address for iOS and macOS" : "Adresa serveru pro iOS a macOS",
    "Appearance" : "Vzhled",
    "Birthday calendar" : "Kalendář s narozeninami",
    "Tasks in calendar" : "Úkoly v kalendáři",
    "Weekends" : "Víkendy",
    "Week numbers" : "Čísla týdnů",
    "Limit number of events shown in Month view" : "Omezit počet zobrazovaných událostí v měsíčním pohledu",
    "Density in Day and Week View" : "Nahuštění v denních a týdenních zobrazeních",
    "Editing" : "Upravování",
    "Default reminder" : "Výchozí upomínka",
    "Simple event editor" : "Jednoduchý editor událostí",
    "\"More details\" opens the detailed editor" : "„Další podrobnosti“ otevře podrobný editor",
    "Files" : "Soubory",
    "Appointment schedule successfully created" : "Plán schůzky úspěšně vytvořen",
    "Appointment schedule successfully updated" : "Plán schůzky úspěšně zaktualizován",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minuta","{duration} minuty","{duration} minut","{duration} minuty"],
    "0 minutes" : "0 minut",
    "_{duration} hour_::_{duration} hours_" : ["{duration} hodina","{duration} hodiny","{duration} hodin","{duration} hodiny"],
    "_{duration} day_::_{duration} days_" : ["{duration} den","{duration} dny","{duration} dnů","{duration} dny"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} týden","{duration} týdny","{duration} týdnů","{duration} týdny"],
    "_{duration} month_::_{duration} months_" : ["{duration} měsíc","{duration} měsíce","{duration} měsíců","{duration} měsíce"],
    "_{duration} year_::_{duration} years_" : ["{duration} rok","{duration} roky","{duration} let","{duration} roky"],
    "To configure appointments, add your email address in personal settings." : "Pokud chcete nastavovat schůzky, je třeba v nastavení, v sekci osobní údaje, zadat svůj e-mail.",
    "Public – shown on the profile page" : "Veřejné – zobrazeno na profilové stránce",
    "Private – only accessible via secret link" : "Soukromé – přístupné pouze přes soukromý odkaz",
    "Appointment schedule saved" : "Naplánování schůzky uloženo",
    "Create appointment schedule" : "Vytvořit plán schůzky",
    "Edit appointment schedule" : "Upravit plán schůzky",
    "Update" : "Aktualizovat",
    "Appointment name" : "Název schůzky",
    "Location" : "Umístění",
    "Create a Talk room" : "Vytvořit místnost v Talk",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Bude vytvořen neopakující se odkaz pro každou ze zarezervovanou schůzku a odeslán prostřednictvím potvrzovacího e-mailu",
    "Description" : "Popis",
    "Visibility" : "Viditelnost",
    "Duration" : "Trvání",
    "Increments" : "Přírůstky",
    "Additional calendars to check for conflicts" : "Další kalendáře které kontrolovat ohledně konfliktů",
    "Pick time ranges where appointments are allowed" : "Zvolte časové rozsahy, ve kterých jsou povolené schůzky",
    "to" : "do",
    "Delete slot" : "Smazat slot",
    "No times set" : "Nenastaveny žádné časy",
    "Add" : "Přidat",
    "Monday" : "pondělí",
    "Tuesday" : "úterý",
    "Wednesday" : "středa",
    "Thursday" : "čtvrtek",
    "Friday" : "pátek",
    "Saturday" : "sobota",
    "Sunday" : "neděle",
    "Weekdays" : "Dny v týdnu",
    "Add time before and after the event" : "Přidat čas před a po události",
    "Before the event" : "Před událostí",
    "After the event" : "Po události",
    "Planning restrictions" : "Omezení plánování",
    "Minimum time before next available slot" : "Nejkratší umožněná doba před dalším slotem k dispozici",
    "Max slots per day" : "Nejvýše slotů za den",
    "Limit how far in the future appointments can be booked" : "Omezte jak daleko v budoucnosti bude možné si rezervovat schůzky",
    "It seems a rate limit has been reached. Please try again later." : "Zdá se, že byl překročen limit četnosti v čase. Zkuste to prosím později.",
    "Please confirm your reservation" : "Potvrďte svou rezervaci",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "V e-mailu vám pošleme podrobnosti. Prosíme, potvrďte schůzku kliknutím na odkaz v e-mailu. Tuto stránku nyní můžete zavřít.",
    "Your name" : "Vaše jméno",
    "Your email address" : "Vaše e-mailová adresa",
    "Please share anything that will help prepare for our meeting" : "Nasílejte vše co pomůže pro přípravu na naši schůzku",
    "Could not book the appointment. Please try again later or contact the organizer." : "Schůzka nemohla být rezervována. Zkuste to znovu později nebo se obraťte na organizátora.",
    "Back" : "Zpět",
    "Book appointment" : "Zarezervovat schůzku",
    "Error fetching Talk conversations." : "Chyba při získávání konverzací v Talk.",
    "Conversation does not have a valid URL." : "Konverzace nemá platný URL.",
    "Successfully added Talk conversation link to location." : "Do místa konání úspěšně přidán odkaz na konverzaci v Talk.",
    "Successfully added Talk conversation link to description." : "Do popisu úspěšně přidán odkaz na konverzaci v Talk.",
    "Failed to apply Talk room." : "Nepodařilo se uplatnit místnost v Talk.",
    "Talk conversation for event" : "Konverzace v Talk pro událost",
    "Error creating Talk conversation" : "Chyba při vytváření konverzace v Talk",
    "Select a Talk Room" : "Vyberte místnost v Talk",
    "Add Talk conversation" : "Přidat konverzaci v Talk",
    "Fetching Talk rooms…" : "Získávání místností v Talk …",
    "No Talk room available" : "Nejsou k dispozici žádné místnosti v Talk",
    "Create public conversation" : "Vytvořit veřejnou konverzaci",
    "Select conversation" : "Vybrat konverzaci",
    "on" : "v",
    "at" : "na",
    "before at" : "před v",
    "Notification" : "Upozornění",
    "Email" : "E-mail",
    "Audio notification" : "Zvuková upozornění",
    "Other notification" : "Ostatní upozornění",
    "Relative to event" : "Vztaženo k události",
    "On date" : "Dne",
    "Edit time" : "Upravit čas",
    "Save time" : "Uložit čas",
    "Remove reminder" : "Odebrat připomínku",
    "Add reminder" : "Přidat připomínku",
    "seconds" : "sekund",
    "minutes" : "minut",
    "hours" : "hodin",
    "days" : "dnů",
    "weeks" : "týdnů",
    "Choose a file to add as attachment" : "Vyberte soubor k přiložení",
    "Choose a file to share as a link" : "Zvolte soubor, který sdílet jako odkaz",
    "Attachment {name} already exist!" : "Příloha {name} už existuje!",
    "Could not upload attachment(s)" : "Nepodařilo se nahrát přílohy",
    "You are about to navigate to {link}. Are you sure to proceed?" : "Chystáte se navigovat na {link}. Opravdu chcete pokračovat?",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Chystáte se navigovat na {host}. Opravdu chcete pokračovat? Odkaz: {link}",
    "Proceed" : "Pokračovat",
    "No attachments" : "Žádné přílohy",
    "Add from Files" : "Přidat ze Souborů",
    "Upload from device" : "Nahrát ze zařízení",
    "Delete file" : "Smazat soubor",
    "Confirmation" : "Potvrzení",
    "_{count} attachment_::_{count} attachments_" : ["{count} příloha","{count} přílohy","{count} příloh","{count} přílohy"],
    "Suggested" : "Doporučeno",
    "Available" : "K dispozici",
    "Invitation accepted" : "Pozvání přijato",
    "Accepted {organizerName}'s invitation" : "Pozvánka od {organizerName} přijata",
    "Participation marked as tentative" : "Účast označena jako povinná",
    "Invitation is delegated" : "Pozvání postoupeno někomu dalšímu",
    "Not available" : "Není k dispozici",
    "Invitation declined" : "Pozvání odmítnuto",
    "Declined {organizerName}'s invitation" : "Odmítnuta pozvánka od {organizerName}",
    "Availability will be checked" : "Dostupnost bude zkontrolována",
    "Invitation will be sent" : "Pozvánka bude odeslána",
    "Failed to check availability" : "Dostupnost se nepodařilo zkontrolovat",
    "Failed to deliver invitation" : "Pozvánku se nepodařilo doručit",
    "Awaiting response" : "Čeká na odpověď",
    "Checking availability" : "Zjišťuje se, zda je k dispozici",
    "Has not responded to {organizerName}'s invitation yet" : "Doposud neodpovězeno na pozvánku od {organizerName}",
    "Suggested times" : "Doporučené časy",
    "chairperson" : "předsedající",
    "required participant" : "povinný účastník",
    "non-participant" : "neúčastník",
    "optional participant" : "volitelní účastník",
    "{organizer} (organizer)" : "{organizer} (organizátor/ka)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Selected slot" : "Vybraný slot",
    "Availability of attendees, resources and rooms" : "Dostupnost účastníků, prostředků a místností",
    "Suggestion accepted" : "Návrh přijat",
    "Previous date" : "Předchozí datum",
    "Next date" : "Následující datum",
    "Legend" : "Popisek",
    "Out of office" : "Mimo kancelář",
    "Attendees:" : "Účastníci:",
    "local time" : "místní čas",
    "Done" : "Dokončeno",
    "Search room" : "Hledat místnost",
    "Room name" : "Název místnosti",
    "Check room availability" : "Zkontrolovat, že je místnost k dispozici",
    "Free" : "Volné",
    "Busy (tentative)" : "Zaneprázdněno (nezávazně)",
    "Busy" : "Zaneprázdněno",
    "Unknown" : "Neznámé",
    "Find a time" : "Najít čas",
    "The invitation has been accepted successfully." : "Pozvánka byla úspěšně přijata.",
    "Failed to accept the invitation." : "Pozvánku se nepodařilo přijmout.",
    "The invitation has been declined successfully." : "Pozvánka byla úspěšně odmítnuta.",
    "Failed to decline the invitation." : "Pozvánku se nepodařilo odmítnout.",
    "Your participation has been marked as tentative." : "Vaše účast byla označena jako povinná.",
    "Failed to set the participation status to tentative." : "Nepodařilo se nastavit stav účasti na povinnou.",
    "Accept" : "Přijmout",
    "Decline" : "Odmítnout",
    "Tentative" : "Nezávazně",
    "No attendees yet" : "Zatím žádní účastníci",
    "{confirmedCount} confirmed, {waitingCount} awaiting response" : "{confirmedCount} potvrdili, u {waitingCount} se čeká na odezvu",
    "Please add at least one attendee to use the \"Find a time\" feature." : "Aby bylo možné použít funkci „Najít čas“, je třeba přidat alespoň jednoho účastníka.",
    "Attendees" : "Účastníci",
    "_%n more attendee_::_%n more attendees_" : ["%n další účastník","%n další účastníci","%n dalších účastníků","%n další účastníci"],
    "Remove group" : "Odebrat skupinu",
    "Remove attendee" : "Odebrat účastníka",
    "Request reply" : "Požadovat odpověď",
    "Chairperson" : "Předseda/kyně",
    "Required participant" : "Povinný účastník",
    "Optional participant" : "Nepovinní účastníci",
    "Non-participant" : "Neúčastník",
    "_%n member_::_%n members_" : ["%n člen","%n členové","%n členů","%n členové"],
    "Search for emails, users, contacts, contact groups or teams" : "Hledat e-maily, uživatele, kontakty, skupiny kontaktů či týmy",
    "No match found" : "Nenalezena žádná shoda",
    "Note that members of circles get invited but are not synced yet." : "Mějte na paměti, že členové okruhů budou pozváni, ale zatím ještě nejsou synchronizováni.",
    "Note that members of contact groups get invited but are not synced yet." : "Mějte na paměti, že členové skupin kontaktů budou pozváni, ale zatím ještě nejsou synchronizováni.",
    "(organizer)" : "(organizátor(ka))",
    "Make {label} the organizer" : "Udělat {label} organizátorem",
    "Make {label} the organizer and attend" : "Udělat {label}organizátorem a zúčastnit se",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Pro rozesílání pozvánek a práci s odpověďmi na ně [linkopen]přidejte svoji  e-mailovou adresu[linkclose] do osobních nastavení.",
    "Remove color" : "Odebrat barvu",
    "Event title" : "Název události",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "U opakovaných událostí nelze u jednotlivého výskytu zvlášť měnit, zda je událost celodenní či ne.",
    "From" : "Od",
    "To" : "Do",
    "Your Time" : "Váš čas",
    "Repeat" : "Opakovat",
    "Repeat event" : "Zopakovat událost",
    "_time_::_times_" : ["krát","krát","krát","krát"],
    "never" : "nikdy",
    "on date" : "dne",
    "after" : "po",
    "End repeat" : "Konec opakování",
    "Select to end repeat" : "Vyberte konec opakování",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Tato událost je výjimka v opakované události. Proto k ní nelze přidat pravidlo opakování.",
    "first" : "první",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Změny v opakované události budou mít vliv jen na tuto a budoucí události",
    "Repeat every" : "Opakovat každé",
    "By day of the month" : "Podle dne v měsíci",
    "On the" : "V",
    "_day_::_days_" : ["den","dny","dní","dny"],
    "_week_::_weeks_" : ["týden","týdny","týdnů","týdny"],
    "_month_::_months_" : ["měsíc","měsíce","měsíců","měsíce"],
    "_year_::_years_" : ["rok","roky","let","roky"],
    "On specific day" : "V konkrétní den",
    "weekday" : "den v týdnu",
    "weekend day" : "den o víkendu",
    "Does not repeat" : "Neopakuje se",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Definice opakování této události není v Nextcloud zcela podporována. Pokud upravíte volby opakování, některá opakování mohou být ztracena.",
    "No rooms or resources yet" : "Zatím žádné místnosti nebo prostředky",
    "Resources" : "Prostředky",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} židle","{seatingCapacity} židle","{seatingCapacity} židlí","{seatingCapacity} židle"],
    "Add resource" : "Přidat prostředek",
    "Has a projector" : "Má projektor",
    "Has a whiteboard" : "Má tabuli",
    "Wheelchair accessible" : "Kolečkové křeslo pro invalidy",
    "Remove resource" : "Odebrat prostředek",
    "Search for resources or rooms" : "Hledat prostředky nebo místnosti",
    "available" : "dostupné",
    "unavailable" : "není dostupné",
    "Show all rooms" : "Zobrazit všechny místnosti",
    "Projector" : "Projektor",
    "Whiteboard" : "Tabule",
    "Room type" : "Typ místnosti",
    "Any" : "Jakákoli",
    "Minimum seating capacity" : "Minimální kapacita k sezení",
    "More details" : "Další podrobnosti",
    "Update this and all future" : "Aktualizovat tento a všechny budoucí",
    "Update this occurrence" : "Aktualizovat tento výskyt",
    "Public calendar does not exist" : "Veřejný kalendář neexistuje",
    "Maybe the share was deleted or has expired?" : "Sdílení byl nejspíš smazáno nebo skončila jeho platnost?",
    "Remove date" : "Odebrat datum",
    "Attendance required" : "Přítomnost vyžadována",
    "Attendance optional" : "Přítomnost volitelná",
    "Remove participant" : "Odstranit účastníka",
    "Yes" : "Ano",
    "No" : "Ne",
    "Maybe" : "Možná",
    "None" : "Žádná",
    "Select your meeting availability" : "Vyberte vaši dostupnost pro schůzku",
    "Create a meeting for this date and time" : "Vytvořit schůzku pro toto datum a čas",
    "Create" : "Vytvářet",
    "No participants or dates available" : "Nejsou k dispozici žádní účastníci nebo datumy",
    "from {formattedDate}" : "od {formattedDate}",
    "to {formattedDate}" : "do {formattedDate}",
    "on {formattedDate}" : "{formattedDate}",
    "from {formattedDate} at {formattedTime}" : "od {formattedDate} v {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "do {formattedDate} v {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "{formattedDate} v {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} v {formattedTime}",
    "Please enter a valid date" : "Zadejte platné datum",
    "Please enter a valid date and time" : "Zadejte platný datum a čas",
    "Select a time zone" : "Vyberte časovou zónu",
    "Please select a time zone:" : "Vyberte časové pásmo:",
    "Pick a time" : "Vyberte čas",
    "Pick a date" : "Vyberte datum",
    "Type to search time zone" : "Psaním vyhledejte časové pásmo",
    "Global" : "Globální",
    "Holidays in {region}" : "Svátky v {region}",
    "An error occurred, unable to read public calendars." : "Došlo k chybě –nepodařilo se načíst veřejné kalendáře.",
    "An error occurred, unable to subscribe to calendar." : "Došlo k chybě – nepodařilo se přihlásit k odběru kalendáře.",
    "Public holiday calendars" : "Kalendář veřejných svátků",
    "Public calendars" : "Veřejné kalendáře",
    "No valid public calendars configured" : "Nenastaveny žádné platné veřejné kalendáře",
    "Speak to the server administrator to resolve this issue." : "O řešení tohoto problému požádejte správce serveru.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Kalendáře veřejných svátků jsou poskytovány projektem Thunderbird. Data kalendáře budou stažena z {website}",
    "These public calendars are suggested by the server administrator. Calendar data will be downloaded from the respective website." : "Tyto veřejné kalendáře jsou navrhovány správcem serveru. Data kalendáře budou stažena z příslušného webu.",
    "By {authors}" : "Od {authors}",
    "Subscribed" : "Přihlášeno se k odběru",
    "Subscribe" : "Přihlásit se k odběru",
    "Could not fetch slots" : "Nepodařilo se získat sloty",
    "Select a date" : "Vybrat datum",
    "Select slot" : "Vybrat slot",
    "No slots available" : "Nejsou k dispozici žádná časová okna",
    "The slot for your appointment has been confirmed" : "Slož pro vaši schůzku byl potvrzen",
    "Appointment Details:" : "Podrobnosti o schůzce:",
    "Time:" : "Čas:",
    "Booked for:" : "Zarezervováno pro:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Děkujeme. Vaše rezervace od {startDate} do {endDate} byla potvrzena.",
    "Book another appointment:" : "Zarezervovat si jinou schůzku:",
    "See all available slots" : "Zobrazit všechny dostupné sloty",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Časové okno pro vaši schůzku od {startDate} do {endDate} už není k dispozici.",
    "Please book a different slot:" : "Prosím zarezervujte si jiné časové okno:",
    "Book an appointment with {name}" : "Zarezervovat si schůzku s {name}",
    "No public appointments found for {name}" : "Pro {name} nebyla nalezena žádná veřejná schůzka",
    "Personal" : "Osobní",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Automatickým zjištěním časové zóny bylo určeno, že vaše zóna je UTC.\nTo je nejspíš kvůli bezpečnostním opatřením vámi používaného webového prohlížeče.\nV nastavení kalendáře zadejte časovou zónu ručně.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Vámi nastavené časové pásmo ({timezoneId}) nenalezeno. Náhradou bude použit UTC čas.\nZměňte své časové pásmo v nastaveních a nahlaste tento problém vývojářům, děkujeme.",
    "Show unscheduled tasks" : "Zobrazit nenaplánované úkoly",
    "Unscheduled tasks" : "Nenaplánované úkoly",
    "Availability of {displayName}" : "Dostupnost {displayName}",
    "Discard event" : "Zahodit událost",
    "Edit event" : "Upravit událost",
    "Event does not exist" : "Událost neexistuje",
    "Duplicate" : "Zduplikovat",
    "Delete this occurrence" : "Smazat tento výskyt",
    "Delete this and all future" : "Smazat toto a všechny budoucí",
    "All day" : "Celý den",
    "Modifications wont get propagated to the organizer and other attendees" : "Změny nebudou propagovány organizátorovi a ostatním účastníkům",
    "Managing shared access" : "Správa sdíleného přístupu",
    "Deny access" : "Odepřít přístup",
    "Invite" : "Pozvat",
    "Discard changes?" : "Zahodit změny?",
    "Are you sure you want to discard the changes made to this event?" : "Opravdu chcete změny provedené v této události zahodit?",
    "_User requires access to your file_::_Users require access to your file_" : ["Uživatel potřebuje přístup k vašemu souboru","Uživatelé potřebují přístup k vašemu souboru","Uživatelé potřebují přístup k vašemu souboru","Uživatelé potřebují přístup k vašemu souboru"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Příloha vyžadující sdílení přístup","Přílohy vyžadující sdílení přístup","Přílohy vyžadující sdílení přístup","Přílohy vyžadující sdílení přístup"],
    "Untitled event" : "Nepojmenovaná událost",
    "Close" : "Zavřít",
    "Modifications will not get propagated to the organizer and other attendees" : "Změny nebudou propagovány organizátorovi a ostatním účastníkům",
    "Meeting proposals overview" : "Přehled návrhů schůzky",
    "Edit meeting proposal" : "Upravit návrh schůzky",
    "Create meeting proposal" : "Vytvořit návrh schůzky",
    "Update meeting proposal" : "Zaktualizovat návrh schůzky",
    "Saving proposal \"{title}\"" : "Ukládání návrhu „{title}“",
    "Successfully saved proposal" : "Návrh úspěšně uložen",
    "Failed to save proposal" : "Návrh se nepodařilo uložit",
    "Create a meeting for \"{date}\"? This will create a calendar event with all participants." : "Vytvořit schůzku pro „{date}“? Toto vytvoří událost v kalendáři se všemi účastníky.",
    "Creating meeting for {date}" : "Vytváření schůzky pro {date}",
    "Successfully created meeting for {date}" : "Úspěšně vytvořena schůzka v {date}",
    "Failed to create a meeting for {date}" : "Nepodařilo se vytvořit schůzku pro {date}",
    "Please enter a valid duration in minutes." : "Zadejte platnou dobu trvání (v minutách).",
    "Failed to fetch proposals" : "Nepodařilo se získat návrhy",
    "Failed to fetch free/busy data" : "Nepodařilo se získat data o volný/zaneprázdněný",
    "Selected" : "Vybráno",
    "No Description" : "Bez popisu",
    "No Location" : "Žádné místo",
    "Edit this meeting proposal" : "Upravit návrh na tuto schůzku",
    "Delete this meeting proposal" : "Smazat návrh na tuto schůzku",
    "Title" : "Titul",
    "15 min" : "15 min",
    "30 min" : "30 min",
    "60 min" : "60 min",
    "90 min" : "90 min",
    "Participants" : "Účastníci",
    "Selected times" : "Vybrané časy",
    "Previous span" : "Předchozí rozpětí",
    "Next span" : "Následujíc rozpětí",
    "Less days" : "Méně dnů",
    "More days" : "Více dnů",
    "Loading meeting proposal" : "Načítání návrhu schůzky",
    "No meeting proposal found" : "Nenalezen žádný návrh na schůzku",
    "Please wait while we load the meeting proposal." : "Vyčkejte než bude návrh schůzky načten.",
    "The link you followed may be broken, or the meeting proposal may no longer exist." : "Zdá se, že odkaz, který jste následovali, je rozbitý, nebo návrh na schůzku už neexistuje.",
    "Thank you for your response!" : "Děkujem za vaši odezvu!",
    "Your vote has been recorded. Thank you for participating!" : "Váš hlas byl zaznamenán. Děkujeme za účast!",
    "Unknown User" : "Neznámý uživatel",
    "No Title" : "Bez nadpisu",
    "No Duration" : "Žádná délka trvání",
    "Select a different time zone" : "Vybrat jiné časové pásmo",
    "Submit" : "Odeslat",
    "Subscribe to {name}" : "Přihlásit se k odběru {name}",
    "Export {name}" : "Exportovat {name}",
    "Show availability" : "Zobrazit dostupnost",
    "Anniversary" : "Výročí",
    "Appointment" : "Schůzka",
    "Business" : "Práce",
    "Education" : "Výuka",
    "Holiday" : "Svátek",
    "Meeting" : "Schůze",
    "Miscellaneous" : "Různé",
    "Non-working hours" : "Mimopracovní hodiny",
    "Not in office" : "Není v kanceláři",
    "Phone call" : "Telefonní hovor",
    "Sick day" : "Zdravotní volno",
    "Special occasion" : "Zvláštní příležitost",
    "Travel" : "Cesta",
    "Vacation" : "Dovolená",
    "Midnight on the day the event starts" : "Nejbližší půlnoc před začátkem události",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n den před událostí v {formattedHourMinute}","%n dny před událostí v {formattedHourMinute}","%n dnů před událostí v {formattedHourMinute}","%n dny před událostí v {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n týden před událostí v {formattedHourMinute}","%n týdny před událostí v {formattedHourMinute}","%n týdnů před událostí v {formattedHourMinute}","%n týdny před událostí v {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "v den události v {formattedHourMinute}",
    "at the event's start" : "na začátku události",
    "at the event's end" : "na konci události",
    "{time} before the event starts" : "{time} před začátkem události",
    "{time} before the event ends" : "{time} před skončením události",
    "{time} after the event starts" : "{time} po začátku události",
    "{time} after the event ends" : "{time} po skončení události",
    "on {time}" : "v {time}",
    "on {time} ({timezoneId})" : "v {time} ({timezoneId})",
    "Week {number} of {year}" : "{number}. týden {year}",
    "Daily" : "Každodenně",
    "Weekly" : "Týdně",
    "Monthly" : "Měsíčně",
    "Yearly" : "Každoročně",
    "_Every %n day_::_Every %n days_" : ["Každý den","Každé %n dny","Každých %n dnů","Každé %n dny"],
    "_Every %n week_::_Every %n weeks_" : ["Každý týden","Každé %n týdny","Každých %n týdnů","Každé %n týdny"],
    "_Every %n month_::_Every %n months_" : ["Každý měsíc","Každé %n měsíce","Každých %n měsíců","Každé %n měsíce"],
    "_Every %n year_::_Every %n years_" : ["Každý rok","Každé %n roky","Každých %n let","Každé %n roky"],
    "_on {weekday}_::_on {weekdays}_" : ["v {weekdays}","v {weekdays}","v {weekdays}","v {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["dne {dayOfMonthList}","ve dnech {dayOfMonthList}","ve dnech {dayOfMonthList}","ve dnech {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "každý měsíc {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {dayOfMonthList}" : "V {monthNames} v {dayOfMonthList}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "v {monthNames} v {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "do {untilDate}",
    "_%n time_::_%n times_" : ["%n kát","%n krát","%n krát","%n krát"],
    "second" : "sekunda",
    "third" : "třetí",
    "fourth" : "čtvrté",
    "fifth" : "páté",
    "second to last" : "po kolik sekund",
    "last" : "poslední",
    "Untitled task" : "Nepojmenovaný úkol",
    "Please ask your administrator to enable the Tasks App." : "Požádejte správce aby zapnul aplikaci Úkoly.",
    "You are not allowed to edit this event as an attendee." : "Nemáte oprávnění upravovat tuto událost coby účastník.",
    "W" : "T",
    "%n more" : "%n další",
    "No events to display" : "Žádné události k zobrazení",
    "All participants declined" : "Všichni účastníci odmítli",
    "Please confirm your participation" : "Potvrďte svou účast",
    "You declined this event" : "Odmítli jste účast na této události",
    "Your participation is tentative" : "Vaše účast je povinná",
    "_+%n more_::_+%n more_" : ["+%n další","+%n další","+%n dalších","+%n další"],
    "No events" : "Žádné události",
    "Create a new event or change the visible time-range" : "Vytvořit novou událost nebo změňte viditelný časový rozsah",
    "Failed to save event" : "Nepodařilo se uložit událost",
    "It might have been deleted, or there was a typo in a link" : "Mohla být smazána, nebo byl v odkazu překlep",
    "It might have been deleted, or there was a typo in the link" : "Mohla být smazána, nebo byl v odkazu překlep",
    "Meeting room" : "Zasedací místnost",
    "Lecture hall" : "Posluchárna",
    "Seminar room" : "Místnost pro semináře",
    "Other" : "Jiná",
    "When shared show" : "Při sdílení neskrývat",
    "When shared show full event" : "Když sdíleno zobrazit úplnou událost",
    "When shared show only busy" : "Když sdíleno zobrazit pouze zaneprázdněno",
    "When shared hide this event" : "Pří sdílení tuto událost skrýt",
    "The visibility of this event in read-only shared calendars." : "Viditelnost této události ve sdílených kalendářích, které jsou pouze pro čtení.",
    "Add a location" : "Přidat umístění",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Přidejte popis\n\n- O čem tato schůzka je\n- Body programu\n- Cokoli co je třeba, aby si účastnici připravili",
    "Status" : "Stav",
    "Confirmed" : "Potvrzeno",
    "Canceled" : "Zrušeno",
    "Confirmation about the overall status of the event." : "Potvrzení o celkovém stavu události.",
    "Show as" : "Zobrazit jako",
    "Take this event into account when calculating free-busy information." : "Zohlednit tuto událost při určování zaneprázdněných/volných hodin.",
    "Categories" : "Kategorie",
    "Categories help you to structure and organize your events." : "Kategorie pomáhají udržovat přehled v událostech a strukturovat je.",
    "Search or add categories" : "Hledat nebo přidat kategorie",
    "Add this as a new category" : "Přidat toto jako novou kategorii",
    "Custom color" : "Uživatelsky určená barva",
    "Special color of this event. Overrides the calendar-color." : "Speciální barva této události. Přebíjí barvu kalendáře.",
    "Error while sharing file" : "Chyba při sdílení souboru",
    "Error while sharing file with user" : "Chyba při sdílení souboru uživateli",
    "Error creating a folder {folder}" : "Chyba při vytváření složky {folder}",
    "Attachment {fileName} already exists!" : "Příloha {fileName} už existuje!",
    "Attachment {fileName} added!" : "Příloha {fileName} přidána!",
    "An error occurred during uploading file {fileName}" : "Při nahrávání souboru {fileName} došlo k chybě",
    "An error occurred during getting file information" : "Při získávání informací o souboru došlo k chybě",
    "Talk conversation for proposal" : "Konverzace v Talk ohledně návrhu",
    "An error occurred, unable to delete the calendar." : "Došlo k chybě, kalendář se nepodařilo smazat.",
    "Imported {filename}" : "Importováno {filename}",
    "This is an event reminder." : "Toto je připomínka události.",
    "Error while parsing a PROPFIND error" : "Chyba při zpracovávání PROPFIND chyby",
    "Appointment not found" : "Schůzka nenalezena",
    "User not found" : "Uživatel nenalezen",
    "Hidden" : "Skrytý",
    "can edit" : "může upravovat",
    "Calendar name …" : "Název kalendáře",
    "Default attachments location" : "Výchozí umístění příloh",
    "Automatic ({detected})" : "Automaticky ({detected})",
    "Shortcut overview" : "Přehled zkratek",
    "CalDAV link copied to clipboard." : "CalDAV odkaz zkopírován do schránky.",
    "CalDAV link could not be copied to clipboard." : "CalDAV odkaz se nepodařilo zkopírovat do schránky.",
    "Enable birthday calendar" : "Zobrazovat kalendář s narozeninami",
    "Show tasks in calendar" : "Zobrazovat úkoly v kalendáři",
    "Enable simplified editor" : "Používat zjednodušený editor",
    "Limit the number of events displayed in the monthly view" : "Omezit počet zobrazovaných událostí v měsíčním pohledu",
    "Show weekends" : "Zobrazit víkendy",
    "Show week numbers" : "Zobrazovat čísla týdnů",
    "Time increments" : "Přírůstky času",
    "Default calendar for incoming invitations" : "Výchozí kalendář pro příchozí pozvánky",
    "Copy primary CalDAV address" : "Zkopírovat hlavní CalDAV adresu",
    "Copy iOS/macOS CalDAV address" : "Zkopírovat CalDAV adresu pro iOS/macOS",
    "Personal availability settings" : "Nastavení osobní dostupnosti",
    "Show keyboard shortcuts" : "Zobrazit klávesové zkratky",
    "Create a new public conversation" : "Vytvořit novou veřejnou konverzaci",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} pozváno, od {confirmedCount} potvrzeno",
    "Successfully appended link to talk room to location." : "Do popisu úspěšně přidán odkaz na umístění v Talk",
    "Successfully appended link to talk room to description." : "Do popisu úspěšně přidán odkaz na místnost v Talk",
    "Error creating Talk room" : "Chyba při vytváření místnosti v Talk",
    "_%n more guest_::_%n more guests_" : ["%n další host","%n další hosté","%n dalších hostů","%n další hosté"],
    "The visibility of this event in shared calendars." : "Viditelnost této události ve sdílených kalendářích."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
