OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "כתובת הדוא\"ל שהוזנה ארוכה מידי",
    "User-Session unexpectedly expired" : "החיבור של המשתמש הסתיימה באופן בלתי צפוי",
    "Provided email-address is not valid" : "כתובת הדוא\"ל שהוזנה אינה חוקית",
    "%s has published the calendar »%s«" : "%sפרסם את לוח השנה»%s«",
    "Unexpected error sending email. Please contact your administrator." : "שגיאה לא צפויה בשליחת דוא\"ל. אנא פנה למנהל המערכת שלך.",
    "Successfully sent email to %1$s" : "דוא\"ל נשלח בהצלחה ל%1$s",
    "Hello," : "שלום,",
    "We wanted to inform you that %s has published the calendar »%s«." : "רצינו להודיע לך ש-%s פירסם את לוח השנה. »%s«.",
    "Open »%s«" : "פתח את „%s”",
    "Cheers!" : "ברכותינו!",
    "Upcoming events" : "אירועים קרובים",
    "No more events today" : "אין אירועים נוספים היום",
    "No upcoming events" : "אין אירועים בזמן הקרוב",
    "More events" : "אירועים נוספים",
    "Calendar" : "יומן",
    "New booking {booking}" : "יצירת אירוע חדש {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) תיזמן את הפגישה \"{config_display_name}\" ב{date_time}.",
    "Appointments" : "פגישות",
    "Schedule appointment \"%s\"" : "קבע את הפגישה \"%s\"",
    "Schedule an appointment" : "קבע פגישה",
    "Prepare for %s" : "התכונן ל%s",
    "Your appointment \"%s\" with %s needs confirmation" : "הפגישה שלך \"%s\" עם %s דרושה אישור",
    "Dear %s, please confirm your booking" : "היי %s, אשר/י בבקשה את תזמון הפגישה שלך",
    "Confirm" : "אישור",
    "Description:" : "תיאור:",
    "This confirmation link expires in %s hours." : "קישור האישור יפוג בעוד %s שעות.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "אם ברצונך לבטל את הפגישה למרות הכל, בבקשה צור קשר עם המארגן ע\"י תגובה למייל זה או באמצעות עמוד הפרופיל שלו.",
    "Your appointment \"%s\" with %s has been accepted" : "פגישתך \"%s\" עם %s אושרה",
    "Dear %s, your booking has been accepted." : "היי %s, תזמון הפגישה שלך התקבל.",
    "Appointment for:" : "פגישה עבור:",
    "Date:" : "בתאריך:",
    "You will receive a link with the confirmation email" : "יישלח אליך קישור יחד עם מייל האישור",
    "Where:" : "איפה:",
    "Comment:" : "הערה:",
    "You have a new appointment booking \"%s\" from %s" : "קיבלת זימון חדש לפגישה \"%s\" מ%s",
    "Dear %s, %s (%s) booked an appointment with you." : "היי %s, %s (%s) זימן פגישה איתך.",
    "Location:" : "מיקום:",
    "A Calendar app for Nextcloud" : "יישומון לוח שנה ל־Nextcloud",
    "Previous day" : "יום לאחור",
    "Previous week" : "שבוע לאחור",
    "Previous year" : "שנה אחורה",
    "Previous month" : "חודש לאחור",
    "Next day" : "היום הבא",
    "Next week" : "שבוע קדימה",
    "Next year" : "שנה קדימה",
    "Next month" : "חודש קדימה",
    "Create new event" : "צור אירוע חדש",
    "Event" : "אירוע",
    "Today" : "היום",
    "Day" : "יום",
    "Week" : "שבוע",
    "Month" : "חודש",
    "Year" : "שנה",
    "List" : "רשימה",
    "Appointment link was copied to clipboard" : "קישור לפגישה הועתק ללוח",
    "Appointment link could not be copied to clipboard" : "לא ניתן להעתיק את הקישור",
    "Preview" : "תצוגה מקדימה",
    "Copy link" : "העתקת קישור",
    "Edit" : "עריכה",
    "Delete" : "מחיקה",
    "Create new" : "יצירת חדש",
    "Disable calendar \"{calendar}\"" : "השבת את לוח השנה \"{calendar}\"",
    "Disable untitled calendar" : "השבת לוח שנה ללא כותרת זה",
    "Enable calendar \"{calendar}\"" : "החל את לוח השנה \"{calendar}\"",
    "Enable untitled calendar" : "החל לוח שנה ללא כותרת זה",
    "An error occurred, unable to change visibility of the calendar." : "אירעה שגיאה, לא ניתן לשנות את אופן ההצגה של לוח השנה.",
    "Untitled calendar" : "לוח שנה ללא כותרת",
    "Shared with you by" : "שותף איתך ע\"י",
    "Edit and share calendar" : "ערוך ושתף לוח שנה זה",
    "Edit calendar" : "ערוך לוח שנה זה",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["ביטול שיתוף לוח השנה בתוך {countdown} שניות","ביטול שיתוף לוח השנה בתוך {countdown} שניות","ביטול שיתוף לוח השנה בתוך {countdown} שניות","ביטול שיתוף לוח השנה בתוך {countdown} שניות"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["מחיקת לוח השנה בתוך {countdown} שניות","מחיקת לוח השנה בתוך {countdown} שניות","מחיקת לוח השנה בתוך {countdown} שניות","מחיקת לוח השנה בתוך {countdown} שניות"],
    "An error occurred, unable to create the calendar." : "אירעה שגיאה--לא ניתן ליצור את לוח השנה.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "נא למלא קישור תקני (מתחיל ב־‎http://‎,‏ https://‎,‏ webcal://‎, או webcals://‎)",
    "Calendars" : "לוחות שנה",
    "Add new" : "הוסף חדש",
    "New calendar" : "לוח שנה חדש",
    "Name for new calendar" : "שם עבור לוח השנה החדש",
    "Creating calendar …" : "יוצר לוח שנה  ...",
    "New calendar with task list" : "לוח שנה חדש עם רשימת משימות",
    "New subscription from link (read-only)" : "מינוי חדש מקישור (קריאה בלבד)",
    "Creating subscription …" : "יוצר מנוי …",
    "Add public holiday calendar" : "הוסף לוח מועדים ציבורי חדש",
    "Add custom public calendar" : "הוסף לוח מותאם אישית ציבורי חדש",
    "Calendar link copied to clipboard." : "הקישור ללוח השנה הועתק ללוח הגזירים.",
    "Calendar link could not be copied to clipboard." : "לא ניתן להעתיק את הקישור ללוח השנה אל לוח הגזירים.",
    "Copy subscription link" : "העתק את קישור המנוי",
    "Copying link …" : "מעתיק את הקישור  ...",
    "Copied link" : "הועתק קישור",
    "Could not copy link" : "לא ניתן להעתיק קישור",
    "Export" : "ייצוא",
    "Untitled item" : "פריט ללא כותרת",
    "Unknown calendar" : "לוח שנה לא ידוע",
    "Could not load deleted calendars and objects" : "לא ניתן היה לטעון לוחות שנה ופריטים מחוקים",
    "Could not restore calendar or event" : "לא ניתן היה לשחזר לוח שנה או אירוע",
    "Do you really want to empty the trash bin?" : "האם אמת בכוונתך לרוקן את סל האשפה?",
    "Empty trash bin" : "פינוי סל האשפה",
    "Trash bin" : "סל האשפה",
    "Loading deleted items." : "טוען פריטים שנמחקו.",
    "You do not have any deleted items." : "אין לך פריטים מחוקים",
    "Name" : "שם",
    "Deleted" : "נמחק",
    "Restore" : "שחזור",
    "Delete permanently" : "מחיקה לצמיתות",
    "Could not update calendar order." : "לא היה ניתן לעדכן את סדר לוח השנה.",
    "Deck" : "חפיסה",
    "Internal link" : "קישור פנימי",
    "A private link that can be used with external clients" : "קישור פרטי שיכול לשמש עבור משתמשים חיצוניים",
    "Copy internal link" : "העתקת קישור פנימי",
    "An error occurred, unable to publish calendar." : "אירעה שגיאה, לא ניתן לפרסם יומן.",
    "An error occurred, unable to send email." : "אירעה שגיאה, לא ניתן לשלוח הודעת דוא״ל.",
    "Embed code copied to clipboard." : "קוד ההטמעה הועתק ללוח הגזירים.",
    "Embed code could not be copied to clipboard." : "לא ניתן להעתיק את קוד ההטמעה ללוח הגזירים.",
    "Unpublishing calendar failed" : "ביטול פרסום לוח השנה נכשל",
    "Share link" : "שיתוף קישור",
    "Copy public link" : "העתקת הקישור הציבורי",
    "Send link to calendar via email" : "שלח קישור ללוח השנה באמצעות דוא\"ל",
    "Enter one address" : "הזן כתובת אחת",
    "Sending email …" : "שולח דוא\"ל ...",
    "Copy embedding code" : "העתקת קוד הטמעה",
    "Copying code …" : "הקוד מועתק …",
    "Copied code" : "הקוד הועתק",
    "Could not copy code" : "לא ניתן להעתיק את הקוד",
    "Delete share link" : "מחיקת קישור שיתוף",
    "Deleting share link …" : "מחיקת קישור השיתוף…",
    "An error occurred while unsharing the calendar." : "אירעה שגיאה במהלך ביטול שיתוף לוח השנה",
    "An error occurred, unable to change the permission of the share." : "אירעה שגיאה, לא ניתן לשנות את הרשאות השיתוף.",
    "Unshare with {displayName}" : "ביטול שיתוף עם {displayName}",
    "Share with users or groups" : "שיתוף עם משתמשים או קבוצות",
    "No users or groups" : "אין משתמשים או קבוצות",
    "Failed to save calendar name and color" : "נכשל בשמירת שם וצבע לוח השנה",
    "Share calendar" : "שיתוף לוח השנה",
    "Unshare from me" : "ביטול השיתוף איתי",
    "Save" : "שמור",
    "View" : "צפייה",
    "Import calendars" : "יבוא לוחות שנה",
    "Please select a calendar to import into …" : "בחר לוח שנה לייבוא אליו …",
    "Filename" : "שם קובץ",
    "Calendar to import into" : "לוח שנה לייבוא אליו",
    "Cancel" : "ביטול",
    "_Import calendar_::_Import calendars_" : ["יבוא לוחות שנה","יבוא לוחות שנה","יבוא לוחות שנה"],
    "Attachments folder" : "תיקיית הקבצים המצורפים",
    "{filename} could not be parsed" : "לא ניתן לפענח את {filename}",
    "No valid files found, aborting import" : "לא נמצאו קבצים תקפים, הייבוא מבוטל",
    "Import partially failed. Imported {accepted} out of {total}." : "הייבוא נכשל חלקית. מיובא {accepted} מתוך {total}.",
    "Automatic" : "אוטומטי",
    "Automatic ({timezone})" : "אוטומטי ({timezone})",
    "New setting was not saved successfully." : "ההגדרה החדשה לא נשמרה בהצלחה.",
    "Timezone" : "אזור זמן",
    "Navigation" : "ניווט",
    "Previous period" : "התקופה הקודמת",
    "Next period" : "התקופה הבאה",
    "Views" : "תצוגות",
    "Day view" : "תצוגת יום",
    "Week view" : "תצוגת שבוע",
    "Month view" : "תצוגת חודש",
    "List view" : "תצוגת רשימה",
    "Actions" : "פעולות",
    "Create event" : "יצירת אירוע",
    "Show shortcuts" : "הצגת קיצורי דרך",
    "or" : "או",
    "No reminder" : "אין תזכורת",
    "General" : "כללי",
    "Appearance" : "מראה",
    "Files" : "קבצים",
    "Update" : "עדכון",
    "Location" : "מיקום",
    "Description" : "תיאור",
    "Duration" : "משך",
    "to" : "אל",
    "Add" : "הוספה",
    "Monday" : "יום שני",
    "Tuesday" : "יום שלישי",
    "Wednesday" : "יום רביעי",
    "Thursday" : "יום חמישי",
    "Friday" : "יום שישי",
    "Saturday" : "יום שבת",
    "Sunday" : "יום ראשון",
    "Your email address" : "כתובת הדוא״ל שלך",
    "Back" : "אחורה",
    "Select conversation" : "בחירת דיון",
    "on" : "על",
    "at" : "ב-",
    "before at" : "לפני",
    "Notification" : "הוֹדָעָה",
    "Email" : "דוא״ל",
    "Audio notification" : "הודעת שמע",
    "Other notification" : "הודעה אחרת",
    "Relative to event" : "יחסית לאירוע",
    "On date" : "בתאריך",
    "Edit time" : "עריכת שעה",
    "Save time" : "שמירת שעה",
    "Remove reminder" : "הסרת תזכורת",
    "seconds" : "שניות",
    "minutes" : "דקות",
    "hours" : "שעות",
    "days" : "ימים",
    "weeks" : "שבועיים",
    "Choose a file to add as attachment" : "בחירת קובץ להוספה כקובץ מצורף",
    "Choose a file to share as a link" : "נא לבחור קובץ לשיתוף כקישור",
    "Proceed" : "להמשיך",
    "Delete file" : "מחיקת קבצים",
    "Available" : "זמינות",
    "Availability of attendees, resources and rooms" : "זמינות של משתתפים, משאבים וחדרים",
    "Out of office" : "מחוץ למשרד",
    "Attendees:" : "משתתפים:",
    "Done" : "הסתיים",
    "Room name" : "שם החדר",
    "Free" : "פנוי",
    "Busy (tentative)" : "תפוס (טנטטיבי)",
    "Busy" : "עסוק",
    "Unknown" : "לא ידוע",
    "Accept" : "אשר",
    "Decline" : "דחייה",
    "Tentative" : "טנטטיבית",
    "No attendees yet" : "עדיין אין משתתפים",
    "Attendees" : "משתתפים",
    "Remove group" : "הסרת קבוצה",
    "Remove attendee" : "הסר את המשתתף",
    "Chairperson" : "יושב ראש",
    "Required participant" : "משתתף חובה",
    "Optional participant" : "משתתף אופציונלי",
    "Non-participant" : "לא משתתף",
    "No match found" : "לא נמצאה התאמה",
    "(organizer)" : "(מארגן)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "כדי לשלוח הזמנות ולטפל בתגובות, [linkopen] הוסף את כתובת הדוא\"ל שלך בהגדרות האישיות [linkclose].",
    "Remove color" : "הסר צבע",
    "Event title" : "כותרת האירוע",
    "From" : "מאת",
    "To" : "אל",
    "Repeat" : "חזרה",
    "_time_::_times_" : ["בשעה","בשעה","בשעות"],
    "never" : "לעולם לא",
    "on date" : "בתאריך",
    "after" : "לאחר",
    "End repeat" : "סיום חזרה",
    "Select to end repeat" : "בחר כדי לסיים את החזרה",
    "first" : "ראשון",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "שינויים ב-recurrence-rule יחולו רק על האירוע הזה ועל כל אירועים עתידיים.",
    "Repeat every" : "חזור על כל",
    "By day of the month" : "לפי היום בחודש",
    "On the" : "על",
    "_day_::_days_" : ["יום","יומיים","ימים"],
    "_week_::_weeks_" : ["שבוע","שבועיים","שבועות","שבועות"],
    "_month_::_months_" : ["חודש","חודשיים","חודשים","חודשים"],
    "_year_::_years_" : ["שנה","שנתיים","שנים","שנים"],
    "weekday" : "יום בשבוע",
    "weekend day" : "יום בסופ״ש",
    "Does not repeat" : "אינו חוזר",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "הגדרת ה-recurrence (=הישנות) של אירוע זה אינה נתמכת במלואה על ידי Nextcloud. אם אתה עורך את ה-recurrence-options, הישנות מסוימות עשויות לאבד.",
    "Resources" : "משאבים",
    "Update this and all future" : "עדכון של זה והעתידיים",
    "Update this occurrence" : "עדכון המופע הזה",
    "Public calendar does not exist" : "לוח השנה הציבורי אינו קיים",
    "Maybe the share was deleted or has expired?" : "אולי השיתוף נמחק או פג תוקפו?",
    "None" : "ללא",
    "Create" : "יצירה",
    "from {formattedDate}" : "מ- {formattedDate}",
    "to {formattedDate}" : "אל {formattedDate}",
    "on {formattedDate}" : "בתאריך {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "מ-{formattedDate} בשעה {formattedTime} ",
    "to {formattedDate} at {formattedTime}" : "אל {formattedDate} בשעה {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "בתאריך {formattedDate} בשעה {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} בשעה {formattedTime}",
    "Please enter a valid date" : "נא להקליד תאריך תקני",
    "Please enter a valid date and time" : "נא להקליד שעה ותאריך תקניים",
    "Pick a time" : "בחר זמן",
    "Pick a date" : "תבחר תאריך",
    "Global" : "גלובלי",
    "Subscribe" : "הרשמה",
    "Time:" : "שעה:",
    "Personal" : "אישי",
    "Edit event" : "עריכת אירוע",
    "Event does not exist" : "האירוע לא קיים",
    "Delete this occurrence" : "מחיקת המופע הזה",
    "Delete this and all future" : "מחיקת זה והבאים",
    "All day" : "כל היום",
    "Invite" : "הזמנה",
    "Untitled event" : "אירוע ללא כותרת",
    "Close" : "סגירה",
    "Participants" : "משתתפים",
    "Submit" : "שליחה",
    "Subscribe to {name}" : "הרשמה אל {name}",
    "Anniversary" : "יום השנה",
    "Appointment" : "פגישה",
    "Business" : "עסקי",
    "Education" : "חינוך",
    "Holiday" : "חג",
    "Meeting" : "מפגש",
    "Miscellaneous" : "שונות",
    "Non-working hours" : "מחוץ לשעות העבודה",
    "Not in office" : "מחוץ למשרד",
    "Phone call" : "שיחת טלפון",
    "Sick day" : "יום מחלה",
    "Special occasion" : "אירוע מיוחד",
    "Travel" : "טיול",
    "Vacation" : "חופשה",
    "Midnight on the day the event starts" : "חצות ביום שלפני שמתחיל האירוע",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["יום לפני האירוע בשעה {formattedHourMinute}","יומיים לפני האירוע בשעה {formattedHourMinute}","%n ימים לפני האירוע בשעה {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["שבוע לפני האירוע בשעה {formattedHourMinute}","שבועיים לפני האירוע בשעה {formattedHourMinute}","%n שבועות לפני האירוע בשעה {formattedHourMinute}","%n שבועות לפני האירוע בשעה {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "ביום האירוע בשעה {formattedHourMinute}",
    "at the event's start" : "עם תחילת האירוע",
    "at the event's end" : "עם סיום האירוע",
    "{time} before the event starts" : "{time} לפני תחילת האירוע",
    "{time} before the event ends" : "{time} לפני סיום האירוע",
    "{time} after the event starts" : "{time} לאחר תחילת האירוע",
    "{time} after the event ends" : "{time} לאחר סיום האירוע",
    "on {time}" : "בשעה {time}",
    "on {time} ({timezoneId})" : "בשעה {time} ({timezoneId})",
    "Week {number} of {year}" : "שבוע {number} ב־{year}",
    "Daily" : "יומי",
    "Weekly" : "שבועי",
    "Monthly" : "חודשי",
    "Yearly" : "שנתי",
    "_Every %n day_::_Every %n days_" : ["כל יום","כל יומיים","כל %n ימים"],
    "_Every %n week_::_Every %n weeks_" : ["כל שבוע","כל שבועיים","כל %n שבועות","כל %n שבועות"],
    "_Every %n month_::_Every %n months_" : ["כל חודש","כל חודשיים","כל %n חודשים"],
    "_Every %n year_::_Every %n years_" : ["כל שנה","כל שנתיים","כל %n שנים"],
    "_on {weekday}_::_on {weekdays}_" : ["ב-{weekday}","ב-{weekday}","ב-{weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["בימים {dayOfMonthList}","בימים {dayOfMonthList}","בימים {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "ב- {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "ב- {monthNames} ב- {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "עד {untilDate}",
    "_%n time_::_%n times_" : ["פעם אחת","פעמיים","%n פעמים"],
    "second" : "שנייה",
    "third" : "שלישי",
    "fourth" : "רביעי",
    "fifth" : "חמישי",
    "second to last" : "אחד לפני האחרון",
    "last" : "אחרון",
    "Untitled task" : "משימה ללא כותרת",
    "Please ask your administrator to enable the Tasks App." : "אנא בקש ממנהל המערכת להפעיל את אפליקציית ה-Tasks.",
    "W" : "W",
    "%n more" : "%n עוד",
    "No events to display" : "אין אירועים להצגה",
    "_+%n more_::_+%n more_" : ["+ עוד פעם","+ עוד פעמיים","+ עוד %n פעמים"],
    "No events" : "אין אירועים",
    "Create a new event or change the visible time-range" : "צור אירוע חדש, או שנה את טווח הזמן הגלוי",
    "It might have been deleted, or there was a typo in a link" : "יתכן שהוא נמחק, או שהיה שגיאת הקלדה בקישור",
    "It might have been deleted, or there was a typo in the link" : "יתכן שהוא נמחק, או שהיה שגיאת הקלדה בקישור",
    "Other" : "אחר",
    "When shared show" : "כאשר משותף, הצג",
    "When shared show full event" : "כאשר משותף מציג אירוע מלא",
    "When shared show only busy" : "כאשר משותף מציג עסוק בלבד",
    "When shared hide this event" : "כאשר משותף מסתיר אירוע זה",
    "Add a location" : "הוסף מיקום",
    "Status" : "מצב",
    "Confirmed" : "מאושר",
    "Canceled" : "מבוטלת",
    "Confirmation about the overall status of the event." : "אישור לגבי הסטטוס הכללי של האירוע.",
    "Show as" : "הצג כ-",
    "Take this event into account when calculating free-busy information." : "קחו בחשבון אירוע זה בעת חישוב מידע free/busy.",
    "Categories" : "קטגוריות",
    "Categories help you to structure and organize your events." : "קטגוריות עוזרות לך לסדר ולארגן את האירועים שלך.",
    "Search or add categories" : "חפש או הוסף קטגוריות",
    "Add this as a new category" : "הוספת הקטגוריה הזאת כחדשה",
    "Custom color" : "צבע בהתאמה אישית",
    "Special color of this event. Overrides the calendar-color." : "צבע מיוחד עבור אירוע זה. דורס את הצבע של לוח השנה.",
    "Error while sharing file" : "שגיאה בשיתוף הקובץ",
    "An error occurred, unable to delete the calendar." : "אירעה שגיאה, לא ניתן למחוק את היומן.",
    "Imported {filename}" : "יובא {filename} ",
    "User not found" : "המשתמש לא נמצא",
    "Hidden" : "מוסתר",
    "can edit" : "ניתן לערוך",
    "Calendar name …" : "שם לוח השנה ...",
    "Automatic ({detected})" : "אוטומטי ({detected})",
    "Shortcut overview" : "סקירת קיצור דרך",
    "CalDAV link copied to clipboard." : "קישור ה־CalDAV הועתק ללוח הגזירים.",
    "CalDAV link could not be copied to clipboard." : "לא ניתן להעתיק את קישור ה־CalDAV ללוח הגזירים.",
    "Enable birthday calendar" : "אפשר לוח שנה ליום הולדת ",
    "Show tasks in calendar" : "הצג משימות בלוח השנה",
    "Enable simplified editor" : "אפשר עורך פשוט",
    "Show weekends" : "הצגת סופי שבוע",
    "Show week numbers" : "הצגת מספרי שבועות",
    "Copy primary CalDAV address" : "העתקת כתובת CalDAV עיקרית",
    "Copy iOS/macOS CalDAV address" : "העתקת כתובת CalDAV ל־iOS/macOS",
    "Show keyboard shortcuts" : "הצגת קיצורי מקלדת",
    "Successfully appended link to talk room to description." : "הקישור צורף ל\"חדר השיחות\" לתיאור בהצלחה.",
    "Error creating Talk room" : "שגיאה ביצירת \"חדר השיחות\"",
    "The visibility of this event in shared calendars." : "הנראות של אירוע זה בלוחות שנה משותפים."
},
"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
