OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "所提供的电子邮件地址太长",
    "User-Session unexpectedly expired" : "用户会话意外过期",
    "Provided email-address is not valid" : "提供的电子邮件地址无效",
    "%s has published the calendar »%s«" : "%s 已经发布了日历 »%s«",
    "Unexpected error sending email. Please contact your administrator." : "发送电子邮件时出现意外错误，请联系您的管理员。",
    "Successfully sent email to %1$s" : "成功将电子邮件发送到 %1$s",
    "Hello," : "你好，",
    "We wanted to inform you that %s has published the calendar »%s«." : "我们想通知您，%s 已发布日历 »%s«。",
    "Open »%s«" : "打开 »%s«",
    "Cheers!" : "干杯！",
    "Upcoming events" : "即将到来的事件",
    "No more events today" : "今天没有更多事件",
    "No upcoming events" : "没有即将到来的事件",
    "More events" : "更多事件",
    "%1$s with %2$s" : "与%2$s预定的对话%1$s",
    "Calendar" : "日历",
    "New booking {booking}" : "新预约 {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email})在{date_time}预约了“{config_display_name}”。",
    "Appointments" : "预约",
    "Schedule appointment \"%s\"" : "安排预约“%s”",
    "Schedule an appointment" : "安排预约",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : "准备 %s",
    "Follow up for %s" : "跟进 %s",
    "Your appointment \"%s\" with %s needs confirmation" : "您与 %s 的预约“%s”需要确认",
    "Dear %s, please confirm your booking" : "尊敬的 %s，请确认您的预约",
    "Confirm" : "确认",
    "Appointment with:" : "预约：",
    "Description:" : "描述：",
    "This confirmation link expires in %s hours." : "此确认链接将在 %s 小时内过期。",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "如果您想取消预约，请通过回复这封邮件或访问他们的个人资料页面与您的组织者联系。",
    "Your appointment \"%s\" with %s has been accepted" : "您与 %s 的预约“%s”已被接受",
    "Dear %s, your booking has been accepted." : "尊敬的 %s，您的预约已被接受。",
    "Appointment for:" : "预约：",
    "Date:" : "日期：",
    "You will receive a link with the confirmation email" : "您将在确认电子邮件中收到链接",
    "Where:" : "地点：",
    "Comment:" : "留言：",
    "You have a new appointment booking \"%s\" from %s" : "您有来自 %s 的新预约“%s”",
    "Dear %s, %s (%s) booked an appointment with you." : "尊敬的 %s，%s（%s）已与您预约。",
    "%s has proposed a meeting" : "%s 已提议开会",
    "%s has updated a proposed meeting" : "%s 已更新提议的会议",
    "%s has canceled a proposed meeting" : "%s 已取消提议的会议",
    "Dear %s, a new meeting has been proposed" : "尊敬的 %s，新会议已提议",
    "Dear %s, a proposed meeting has been updated" : "尊敬的 %s，提议的会议已更新",
    "Dear %s, a proposed meeting has been cancelled" : "尊敬的 %s，提议的会议已取消",
    "Location:" : "地区：",
    "Duration:" : "时长：",
    "%1$s from %2$s to %3$s" : "%1$s 从 %2$s 到 %3$s",
    "Dates:" : "日期：",
    "Respond" : "回复",
    "A Calendar app for Nextcloud" : "适用于 Nextcloud 的日历应用",
    "A Calendar app for Nextcloud. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Like Contacts, Talk, Tasks, Deck and Circles\n* 🌐 **WebCal Support!** Want to see your favorite team's matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 **Search!** Find your events at ease\n* ☑️ **Tasks!** See tasks or Deck cards with a due date directly in the calendar\n* 🔈 **Talk rooms!** Create an associated Talk room when booking a meeting with just one click\n* 📆 **Appointment booking** Send people a link so they can book an appointment with you [using this app](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Attachments!** Add, upload and view event attachments\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Nextcloud 的日历应用。轻松将各种设备上的事件同步到 Nextcloud，并在线编辑。\n\n* 🚀 **与其他 Nextcloud 应用集成！** 例如 Contacts、Talk、Tasks、Deck 和 Circles\n* 🌐 **WebCal 支持！** 想在您的日历中查看您最喜欢的球队的比赛日吗？没问题！\n* 🙋 **参加者！** 邀请他人参加您的活动\n* ⌚ **空闲/忙碌！** 查看您的参加者何时有空参加会议\n* ⏰ **提醒！** 在浏览器中或通过电子邮件接收活动提醒\n* 🔍 **搜索！** 轻松查找您的活动\n* ☑️ **任务！** 直接在日历中查看带有截止日期的任务或 Deck 卡片\n* 🔈 **Talk 会议室！** 只需点击一下即可在预订会议时创建一个关联的 Talk 会议室\n* 📆 **预约** 向人们发送链接，以便他们[使用此应用](https://apps.nextcloud.com/apps/appointments)与您预约\n* 📎 **附件！** 添加、上传和查看活动附件\n* 🙈 **我们不会重复造轮子！** 基于强大的 [c-dav 库](https://github.com/nextcloud/cdav-library)、[ical.js](https://github.com/mozilla-comm/ical.js) 和 [fullcalendar](https://github.com/fullcalendar/fullcalendar) 库。",
    "Previous day" : "前一天",
    "Previous week" : "上周",
    "Previous year" : "前一年",
    "Previous month" : "上个月",
    "Next day" : "后一天",
    "Next week" : "下周",
    "Next year" : "下一年",
    "Next month" : "下个月",
    "Create new event" : "创建新事件",
    "Event" : "事件",
    "Today" : "今天",
    "Day" : "日",
    "Week" : "星期",
    "Month" : "月",
    "Year" : "年",
    "List" : "列表",
    "Appointment link was copied to clipboard" : "预约链接已复制到剪贴板",
    "Appointment link could not be copied to clipboard" : "无法将预约链接复制到剪贴板",
    "Preview" : "预览",
    "Copy link" : "复制链接",
    "Edit" : "编辑",
    "Delete" : "删除",
    "Appointment schedules" : "预约时间表",
    "Create new" : "新建",
    "Disable calendar \"{calendar}\"" : "禁用日历“{calendar}”",
    "Disable untitled calendar" : "禁用未命名日历",
    "Enable calendar \"{calendar}\"" : "启用日历“{calendar}”",
    "Enable untitled calendar" : "启用未命名日历",
    "An error occurred, unable to change visibility of the calendar." : "发生错误，无法修改日历的可见性。",
    "Untitled calendar" : "未命名的日历",
    "Shared with you by" : "与您共享，由",
    "Edit and share calendar" : "编辑并分享日历",
    "Edit calendar" : "编辑日历",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["将在{countdown}秒后取消共享日历"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["将在{countdown}秒后删除日历"],
    "An error occurred, unable to create the calendar." : "发生了错误，无法创建日历。",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "请输入合法的链接（以http://、https://、webcal://、或者webcals://开头）",
    "Calendars" : "日历",
    "Add new" : "新增",
    "New calendar" : "新日历",
    "Name for new calendar" : "新日历名称",
    "Creating calendar …" : "正在创建日历 ...",
    "New calendar with task list" : "带任务列表的新日历",
    "New subscription from link (read-only)" : "来自链接的新订阅（只读）",
    "Creating subscription …" : "正在创建订阅 ...",
    "Add public holiday calendar" : "添加公众节假期日历",
    "Add custom public calendar" : "添加自定义公开日历",
    "Calendar link copied to clipboard." : "日历链接已复制到剪贴板。",
    "Calendar link could not be copied to clipboard." : "日历链接无法复制到剪贴板。",
    "Copy subscription link" : "复制订阅链接",
    "Copying link …" : "正在复制链接 ...",
    "Copied link" : "已复制链接",
    "Could not copy link" : "无法复制链接",
    "Export" : "导出",
    "Untitled item" : "未命名项",
    "Unknown calendar" : "未知日历",
    "Could not load deleted calendars and objects" : "无法加载已删除的日历和对象",
    "Could not delete calendar or event" : "无法删除日历或事件",
    "Could not restore calendar or event" : "无法还原日历或事件",
    "Do you really want to empty the trash bin?" : "您真的想要清空回收站吗？",
    "Empty trash bin" : "清空回收站",
    "Trash bin" : "回收站",
    "Loading deleted items." : "正在加载已删除的项目。",
    "You do not have any deleted items." : "您没有任何已删除的项目。",
    "Name" : "名称",
    "Deleted" : "已删除",
    "Restore" : "还原",
    "Delete permanently" : "永久删除",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["回收站中的项目会在 {numDays} 天后删除"],
    "Could not update calendar order." : "无法更改日历顺序。",
    "Shared calendars" : "共享日历",
    "Deck" : "看板",
    "Internal link" : "内部链接",
    "A private link that can be used with external clients" : "可以与外部客户端一起使用的私人链接",
    "Copy internal link" : "复制内部链接",
    "An error occurred, unable to publish calendar." : "发生了错误，无法发布日历。",
    "An error occurred, unable to send email." : "发生了错误，无法发送电子邮件。",
    "Embed code copied to clipboard." : "嵌入代码已复制到剪贴板。",
    "Embed code could not be copied to clipboard." : "嵌入代码无法复制到剪贴板。",
    "Unpublishing calendar failed" : "取消发布日历失败",
    "Share link" : "共享链接",
    "Copy public link" : "复制公开链接",
    "Send link to calendar via email" : "通过电子邮件发送链接到日历",
    "Enter one address" : "输入一个地址",
    "Sending email …" : "正在发送电子邮件 ...",
    "Copy embedding code" : "复制嵌入代码",
    "Copying code …" : "正在复制代码 ...",
    "Copied code" : "已复制代码",
    "Could not copy code" : "无法复制代码",
    "Delete share link" : "删除共享链接",
    "Deleting share link …" : "正在删除共享链接 ...",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Team)",
    "An error occurred while unsharing the calendar." : "取消共享日历时发生错误。",
    "An error occurred, unable to change the permission of the share." : "发生了错误，无法更改共享权限。",
    "can edit and see confidential events" : "可以编辑和查看机密事件",
    "Unshare with {displayName}" : "取消与 {displayName} 的共享",
    "Share with users or groups" : "与用户或分组共享",
    "No users or groups" : "无用户或分组",
    "Failed to save calendar name and color" : "保存日历名称和颜色失败",
    "Calendar name …" : "日历名称 …",
    "Never show me as busy (set this calendar to transparent)" : "从不显示我为忙碌状态（将此日历设置为透明）",
    "Share calendar" : "共享日历",
    "Unshare from me" : "我取消的共享",
    "Save" : "保存",
    "No title" : "无标题",
    "Are you sure you want to delete \"{title}\"?" : "是否确定要删除“{title}”？",
    "Deleting proposal \"{title}\"" : "正在删除提议“{title}”",
    "Successfully deleted proposal" : "已成功删除提议",
    "Failed to delete proposal" : "无法删除提议",
    "Failed to retrieve proposals" : "无法检索提议",
    "Meeting proposals" : "会议提议",
    "A configured email address is required to use meeting proposals" : "使用会议提议需要配置的电子邮件地址",
    "No active meeting proposals" : "没有活动的会议提议",
    "View" : "查看",
    "Import calendars" : "导入日历",
    "Please select a calendar to import into …" : "请选择一个要导入的日历 ……",
    "Filename" : "文件名",
    "Calendar to import into" : "要导入的日历",
    "Cancel" : "取消",
    "_Import calendar_::_Import calendars_" : ["导入日历"],
    "Select the default location for attachments" : "选择附件的默认位置",
    "Pick" : "选择",
    "Invalid location selected" : "所选位置无效",
    "Attachments folder successfully saved." : "附件文件夹已成功保存。",
    "Error on saving attachments folder." : "保存附件文件夹时发生错误。",
    "Attachments folder" : "附件文件夹",
    "{filename} could not be parsed" : "无法解析{filename}",
    "No valid files found, aborting import" : "未找到有效文件，中止导入",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["成功导入%n个事件"],
    "Import partially failed. Imported {accepted} out of {total}." : "部分导入失败，已导入 {total} 个中的 {accepted} 个。",
    "Automatic" : "自动",
    "Automatic ({timezone})" : "自动（{timezone}）",
    "New setting was not saved successfully." : "新的设置没有成功保存。",
    "Timezone" : "时区",
    "Navigation" : "导航",
    "Previous period" : "上一时段",
    "Next period" : "下一时段",
    "Views" : "视图",
    "Day view" : "日视图",
    "Week view" : "周视图",
    "Month view" : "月视图",
    "Year view" : "年视图",
    "List view" : "列表视图",
    "Actions" : "操作",
    "Create event" : "创建事件",
    "Show shortcuts" : "显示快捷方式",
    "Editor" : "编辑器",
    "Close editor" : "关闭编辑器",
    "Save edited event" : "保存已编辑的事件",
    "Delete edited event" : "删除已编辑的事件",
    "Duplicate event" : "重复的事件",
    "or" : "或",
    "Calendar settings" : "日历设置",
    "At event start" : "在事件开始时",
    "No reminder" : "无提醒",
    "Failed to save default calendar" : "无法保存默认日历",
    "General" : "常规",
    "Availability settings" : "可用性设置",
    "CalDAV" : "CalDAV",
    "Access Nextcloud calendars from other apps and devices" : "从其他应用和设备访问 Nextcloud 日历",
    "CalDAV URL" : "CalDAV URL",
    "Appearance" : "外观",
    "Birthday calendar" : "生日日历",
    "Tasks in calendar" : "日历中的任务",
    "Weekends" : "周末",
    "Week numbers" : "周数",
    "Limit number of events shown in Month view" : "限制月视图中显示的事件数",
    "Density in Day and Week View" : "日视图和周视图中的密度",
    "Editing" : "编辑",
    "Default reminder" : "默认提醒",
    "Simple event editor" : "简单事件编辑器",
    "\"More details\" opens the detailed editor" : "“更多详情”打开详细编辑器",
    "Files" : "文件",
    "Appointment schedule successfully created" : "预约时间表已成功创建",
    "Appointment schedule successfully updated" : "预约时间表已成功更新",
    "_{duration} minute_::_{duration} minutes_" : ["{duration}分钟"],
    "0 minutes" : "0 分钟",
    "_{duration} hour_::_{duration} hours_" : ["{duration} 小时"],
    "_{duration} day_::_{duration} days_" : ["{duration} 天"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} 周"],
    "_{duration} month_::_{duration} months_" : ["{duration} 月"],
    "_{duration} year_::_{duration} years_" : ["{duration} 年"],
    "To configure appointments, add your email address in personal settings." : "要配置预约，请在个人设置中添加您的电子邮件地址。",
    "Public – shown on the profile page" : "公开 - 显示在个人资料页上",
    "Private – only accessible via secret link" : "私密 - 只能通过秘密链接访问",
    "Appointment schedule saved" : "预约时间表已保存",
    "Create appointment schedule" : "创建预约时间表",
    "Edit appointment schedule" : "编辑预约时间表",
    "Update" : "更新",
    "Appointment name" : "预约名称",
    "Location" : "地点",
    "Create a Talk room" : "创建聊天室",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "将为每个预订的预约生成一个唯一的链接，并通过确认电子邮件发送",
    "Description" : "描述",
    "Visibility" : "可见性",
    "Duration" : "时长",
    "Increments" : "增量",
    "Additional calendars to check for conflicts" : "其他要检查冲突的日历",
    "Pick time ranges where appointments are allowed" : "选择允许预约的时间范围",
    "to" : "到",
    "Delete slot" : "删除时段",
    "No times set" : "未设置时间",
    "Add" : "添加",
    "Monday" : "周一",
    "Tuesday" : "周二",
    "Wednesday" : "周三",
    "Thursday" : "周四",
    "Friday" : "周五",
    "Saturday" : "周六",
    "Sunday" : "周日",
    "Weekdays" : "工作日",
    "Add time before and after the event" : "添加事件前后时间",
    "Before the event" : "事件前",
    "After the event" : "事件后",
    "Planning restrictions" : "规划限制",
    "Minimum time before next available slot" : "下一可用时段前的最短时间",
    "Max slots per day" : "每日最多时段数",
    "Limit how far in the future appointments can be booked" : "限制可以预定未来多久的预约",
    "It seems a rate limit has been reached. Please try again later." : "似乎已达到速度限制。请稍后重试。",
    "Please confirm your reservation" : "请确认您的预约",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "我们给您发了一封详细的邮件，请使用邮件中的链接确认您的预约。您现在可以关闭此页面。",
    "Your name" : "名字",
    "Your email address" : "你的邮箱地址",
    "Please share anything that will help prepare for our meeting" : "请分享任何能帮助我们准备会议的东西",
    "Could not book the appointment. Please try again later or contact the organizer." : "无法登记预约，请稍后再试或联系组织者。",
    "Back" : "返回",
    "Book appointment" : "登记预约",
    "Error fetching Talk conversations." : "获取 Talk 对话时出错。",
    "Conversation does not have a valid URL." : "对话没有有效的 URL。",
    "Successfully added Talk conversation link to location." : "已成功将 Talk 对话链接添加到位置。",
    "Successfully added Talk conversation link to description." : "已成功将 Talk 对话链接添加到描述。",
    "Failed to apply Talk room." : "无法应用 Talk 聊天室。",
    "Talk conversation for event" : "事件的 Talk 对话",
    "Error creating Talk conversation" : "创建 Talk 对话时出错",
    "Select a Talk Room" : "选择 Talk 聊天室",
    "Add Talk conversation" : "添加 Talk 对话",
    "Fetching Talk rooms…" : "正在获取 Talk 聊天室…",
    "No Talk room available" : "没有可用的 Talk 聊天室",
    "Select conversation" : "选择对话",
    "on" : "于",
    "at" : "在",
    "before at" : "在此之前：",
    "Notification" : "通知",
    "Email" : "电子邮件",
    "Audio notification" : "语音通知",
    "Other notification" : "其他通知",
    "Relative to event" : "相对于事件",
    "On date" : "在特定日期",
    "Edit time" : "编辑时间",
    "Save time" : "保存时间",
    "Remove reminder" : "移除提醒",
    "Add reminder" : "添加提醒",
    "seconds" : "秒",
    "minutes" : "分钟",
    "hours" : "小时",
    "days" : "天",
    "weeks" : "周",
    "Choose a file to add as attachment" : "选择文件添加为附件",
    "Choose a file to share as a link" : "选择要共享的文件作为链接",
    "Attachment {name} already exist!" : "附件{name}已存在！",
    "Could not upload attachment(s)" : "无法上传附件",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "您将要导航到 {host}。是否确定要继续？链接：{link}",
    "Proceed" : "前进",
    "No attachments" : "无附件",
    "Add from Files" : "添加文件",
    "Upload from device" : "从设备上传",
    "Delete file" : "删除文件",
    "Confirmation" : "确认",
    "_{count} attachment_::_{count} attachments_" : ["{count} 附件"],
    "Suggested" : "建议",
    "Available" : "可用",
    "Invitation accepted" : "已接受邀请",
    "Accepted {organizerName}'s invitation" : "已接受 {organizerName} 的邀请",
    "Participation marked as tentative" : "参与被标记为暂定",
    "Invitation is delegated" : "邀请已委派",
    "Not available" : "不可用",
    "Invitation declined" : "邀请被拒绝",
    "Declined {organizerName}'s invitation" : "已拒绝 {organizerName} 的邀请",
    "Availability will be checked" : "将检查可用性",
    "Invitation will be sent" : "将发送邀请",
    "Failed to check availability" : "无法检查可用性",
    "Failed to deliver invitation" : "发送邀请失败",
    "Awaiting response" : "正在等在回应",
    "Checking availability" : "正在检查工作时间",
    "Has not responded to {organizerName}'s invitation yet" : "尚未回复 {organizerName} 的邀请",
    "Suggested times" : "建议时间",
    "chairperson" : "主席",
    "required participant" : "参与人员",
    "non-participant" : "非参加人员",
    "optional participant" : "可不出席的参加人员",
    "{organizer} (organizer)" : "{organizer}（组织者）",
    "{attendee} ({role})" : "{attendee}（{role}）",
    "Selected slot" : "所选时段",
    "Availability of attendees, resources and rooms" : "参加者、资源和会议室的可用性",
    "Suggestion accepted" : "建议已接受",
    "Previous date" : "上个日期",
    "Next date" : "下个日期",
    "Legend" : "图例",
    "Out of office" : "不在办公室",
    "Attendees:" : "参加者：",
    "local time" : "本地时间",
    "Done" : "完成",
    "Search room" : "搜索聊天室",
    "Room name" : "聊天室名称",
    "Check room availability" : "检查聊天室是否可用",
    "Free" : "空闲",
    "Busy (tentative)" : "忙碌（暂定）",
    "Busy" : "忙碌",
    "Unknown" : "未知",
    "Find a time" : "查找时间",
    "The invitation has been accepted successfully." : "已成功接受邀请。",
    "Failed to accept the invitation." : "接受邀请失败。",
    "The invitation has been declined successfully." : "已成功拒绝邀请。",
    "Failed to decline the invitation." : "拒绝邀请失败。",
    "Your participation has been marked as tentative." : "您的参与被标记为暂定。",
    "Failed to set the participation status to tentative." : "未能将参与状态设置为暂定。",
    "Accept" : "接受",
    "Decline" : "拒绝",
    "Tentative" : "暂定",
    "No attendees yet" : "暂无参加者",
    "Please add at least one attendee to use the \"Find a time\" feature." : "请至少添加一位参加者以使用“查找时间”功能。",
    "Attendees" : "参加者",
    "Remove group" : "删除分组",
    "Remove attendee" : "移除参加者",
    "Request reply" : "请求回复",
    "Chairperson" : "主席",
    "Required participant" : "必要的参与者",
    "Optional participant" : "可选的参与者",
    "Non-participant" : "非参与者",
    "_%n member_::_%n members_" : ["%n 位成员"],
    "Search for emails, users, contacts, contact groups or teams" : "搜索电子邮件、用户、联系人、联系人群组或团队",
    "No match found" : "未找到匹配项",
    "Note that members of circles get invited but are not synced yet." : "请注意，圈内成员已收到邀请但尚未同步。",
    "Note that members of contact groups get invited but are not synced yet." : "请注意，联系人群组的成员已邀请，但尚未同步。",
    "(organizer)" : "（组织者）",
    "Make {label} the organizer" : "将 {label} 设为组织者",
    "Make {label} the organizer and attend" : "将 {label} 设为组织者并参加",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "为发送邀请和处理回应，[linkopen] 将您的电子邮件地址添加到个人设置中 [linkclose] 。",
    "Remove color" : "移除颜色",
    "Event title" : "事件标题",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "无法修改属于重复活动事件的全天设置。 ",
    "From" : "来自",
    "To" : "给",
    "Your Time" : "您的时间",
    "Repeat" : "重复",
    "Repeat event" : "重复事件",
    "_time_::_times_" : ["次数"],
    "never" : "从不",
    "on date" : "在特定日期",
    "after" : "之后",
    "End repeat" : "结束重复",
    "Select to end repeat" : "选择以中止重复",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "此事件是重复事件的例外项，无法为其添加重复规则。",
    "first" : "第一个",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "对重复规则的更改将只应用于本次和所有未来事件。",
    "Repeat every" : "重复每",
    "By day of the month" : "每月特定日",
    "On the" : "在",
    "_day_::_days_" : ["天"],
    "_week_::_weeks_" : ["周"],
    "_month_::_months_" : ["月"],
    "_year_::_years_" : ["年"],
    "On specific day" : "在特定日子",
    "weekday" : "工作日",
    "weekend day" : "周末",
    "Does not repeat" : "不重复",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Nextcloud 不能完全支持此事件的重复定义。如果您编辑重复选项，某些重复可能会丢失。",
    "No rooms or resources yet" : "尚无房间或资源",
    "Resources" : "资源",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} 个座位"],
    "Add resource" : "添加资源",
    "Has a projector" : "有投影仪",
    "Has a whiteboard" : "有白板",
    "Wheelchair accessible" : "无障碍设施",
    "Remove resource" : "删除资源",
    "Search for resources or rooms" : "搜索资源或房间",
    "available" : "可用",
    "unavailable" : "不可用",
    "Show all rooms" : "显示所有房间",
    "Projector" : "投影仪",
    "Whiteboard" : "白板",
    "Room type" : "房间类型",
    "Any" : "任意",
    "Minimum seating capacity" : "最少座位数",
    "More details" : "更多细节",
    "Update this and all future" : "更新此项及以后的项目",
    "Update this occurrence" : "更新此重复事件",
    "Public calendar does not exist" : "公开日历不存在",
    "Maybe the share was deleted or has expired?" : "共享可能已删除或过期？",
    "Remove date" : "移除日期",
    "Attendance required" : "必须参加",
    "Attendance optional" : "可选参加",
    "Remove participant" : "移除参与者",
    "Yes" : "是",
    "No" : "否",
    "Maybe" : "可能",
    "None" : "无",
    "Select your meeting availability" : "选择您的会议可用性",
    "Create a meeting for this date and time" : "为此日期和时间创建会议",
    "Create" : "创建",
    "No participants or dates available" : "没有可用的参与者或日期",
    "from {formattedDate}" : "从 {formattedDate}",
    "to {formattedDate}" : "到 {formattedDate}",
    "on {formattedDate}" : "于 {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "从 {formattedDate} {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "到 {formattedDate} {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "于 {formattedDate} {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime}",
    "Please enter a valid date" : "请输入一个有效的日期",
    "Please enter a valid date and time" : "请输入有效的日期和时间",
    "Select a time zone" : "选择一个时区",
    "Please select a time zone:" : "请选择一个时区：",
    "Pick a time" : "选择一个时间",
    "Pick a date" : "选择一个日期",
    "Type to search time zone" : "输入以搜索时区 ",
    "Global" : "全球",
    "Holidays in {region}" : "{region}的节假日",
    "An error occurred, unable to read public calendars." : "发生错误，无法读取公开日历。",
    "An error occurred, unable to subscribe to calendar." : "发生错误，无法订阅日历。",
    "Public holiday calendars" : "公众节假日日历",
    "Public calendars" : "公开日历",
    "No valid public calendars configured" : "没有设置有效的日历",
    "Speak to the server administrator to resolve this issue." : "请联系服务器管理人员以解决该问题。",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "公众节假日日历由Thunderbird提供。将从{website}下载日历数据。",
    "These public calendars are suggested by the server administrator. Calendar data will be downloaded from the respective website." : "这些公开日历由服务器管理员建议。日历数据将从相应的网站下载。",
    "By {authors}" : "作者为{authors}",
    "Subscribed" : "已订阅",
    "Subscribe" : "订阅",
    "Could not fetch slots" : "无法获取空闲时段",
    "Select a date" : "选择一个日期",
    "Select slot" : "选择时段",
    "No slots available" : "无可用时段",
    "The slot for your appointment has been confirmed" : "您的预约时段已确认",
    "Appointment Details:" : "预约详情：",
    "Time:" : "时间：",
    "Booked for:" : "已预约：",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "谢谢，已确认了你从 {startDate} 到 {endDate} 的预约。",
    "Book another appointment:" : "登记另一个预约：",
    "See all available slots" : "查看所有可用时段",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "您从 {startDate} 到 {endDate} 没有可用的预约时段。",
    "Please book a different slot:" : "请预约其他时段：",
    "Book an appointment with {name}" : "登记与 {name} 的预约",
    "No public appointments found for {name}" : "未找到 {name} 的公开预约",
    "Personal" : "个人",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "自动时区检测确定您的时区为世界标准时间（UTC）。\n这很可能是由于您 Web 浏览器的安全措施的结果。\n请在日历设置中手动设置时区。",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "找不到您配置的时区 ({timezoneId})。将退回到世界标准时间（UTC）。\n请在设置中更改您的时区并报告此问题。",
    "Show unscheduled tasks" : "显示未计划的任务",
    "Unscheduled tasks" : "未计划的任务",
    "Availability of {displayName}" : "{displayName} 的可用性",
    "Discard event" : "舍弃事件",
    "Edit event" : "编辑事件",
    "Event does not exist" : "事件不存在",
    "Duplicate" : "重复",
    "Delete this occurrence" : "删除此重复事件",
    "Delete this and all future" : "删除此项及以后的项目",
    "All day" : "全天",
    "Modifications wont get propagated to the organizer and other attendees" : "修改不会传播给组织者和其他参加者",
    "Managing shared access" : "管理已分享的访问权限",
    "Deny access" : "拒绝访问",
    "Invite" : "邀请",
    "Discard changes?" : "舍弃更改？",
    "Are you sure you want to discard the changes made to this event?" : "是否确定要舍弃对此事件所做的更改？",
    "_User requires access to your file_::_Users require access to your file_" : ["用户要求访问您的文件"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["需要分享访问权限的附件"],
    "Untitled event" : "未命名事件",
    "Close" : "关闭",
    "Modifications will not get propagated to the organizer and other attendees" : "修改不会传播给组织者和其他参加者",
    "Meeting proposals overview" : "会议提议概览",
    "Edit meeting proposal" : "编辑会议提议",
    "Create meeting proposal" : "创建会议提议",
    "Update meeting proposal" : "更新会议提议",
    "Saving proposal \"{title}\"" : "正在保存提议“{title}”",
    "Successfully saved proposal" : "已成功保存提议",
    "Failed to save proposal" : "无法保存提议",
    "Create a meeting for \"{date}\"? This will create a calendar event with all participants." : "是否创建“{date}”的会议？这将创建一个包含所有参与者的日历事件。",
    "Creating meeting for {date}" : "正在创建 {date} 的会议",
    "Successfully created meeting for {date}" : "已成功创建 {date} 的会议",
    "Failed to create a meeting for {date}" : "无法创建 {date} 的会议",
    "Please enter a valid duration in minutes." : "请输入有效的时长（分钟）。",
    "Failed to fetch proposals" : "无法获取提议",
    "Failed to fetch free/busy data" : "无法获取空闲/忙碌数据",
    "Selected" : "已选择",
    "No Description" : "无描述",
    "No Location" : "无位置",
    "Edit this meeting proposal" : "编辑此会议提议",
    "Delete this meeting proposal" : "删除此会议提议",
    "Title" : "标题",
    "15 min" : "15 分钟",
    "30 min" : "30 分钟",
    "60 min" : "60 分钟",
    "90 min" : "90 分钟",
    "Participants" : "参与者",
    "Selected times" : "已选择时间",
    "Previous span" : "上一时段",
    "Next span" : "下一时段",
    "Less days" : "较少天数",
    "More days" : "更多天数",
    "Loading meeting proposal" : "正在加载会议提议",
    "No meeting proposal found" : "未找到会议提议",
    "Please wait while we load the meeting proposal." : "正在加载会议提议，请稍候。",
    "The link you followed may be broken, or the meeting proposal may no longer exist." : "您访问的链接可能已失效，或者会议提议可能不再存在。",
    "Thank you for your response!" : "感谢您的回复！",
    "Your vote has been recorded. Thank you for participating!" : "您的投票已被记录。感谢您的参与！",
    "Unknown User" : "未知用户",
    "No Title" : "无标题",
    "No Duration" : "无时长",
    "Select a different time zone" : "选择其他时区",
    "Submit" : "提交",
    "Subscribe to {name}" : "订阅 {name}",
    "Export {name}" : "导出 {name}",
    "Show availability" : "显示可用性",
    "Anniversary" : "周年",
    "Appointment" : "预约",
    "Business" : "商业",
    "Education" : "教育",
    "Holiday" : "节假日",
    "Meeting" : "会议",
    "Miscellaneous" : "杂项",
    "Non-working hours" : "非工作时间",
    "Not in office" : "不在办公室",
    "Phone call" : "电话通话",
    "Sick day" : "病假",
    "Special occasion" : "特殊场合",
    "Travel" : "旅行",
    "Vacation" : "假期",
    "Midnight on the day the event starts" : "事件开始时当天午夜",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["事件前%n天的 {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["事件发生前%n周的 {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "事件当天的 {formattedHourMinute}",
    "at the event's start" : "事件开始时",
    "at the event's end" : "事件结束时",
    "{time} before the event starts" : "事件开始前 {time}",
    "{time} before the event ends" : "事件结束前 {time}",
    "{time} after the event starts" : "在事件开始后 {time}",
    "{time} after the event ends" : "事件结束后 {time}",
    "on {time}" : "在 {time}",
    "on {time} ({timezoneId})" : "在 {time} （{timezoneId}）",
    "Week {number} of {year}" : "{year} 年的第 {number} 周",
    "Daily" : "每天",
    "Weekly" : "每周",
    "Monthly" : "每月",
    "Yearly" : "每年",
    "_Every %n day_::_Every %n days_" : ["每 %n 天"],
    "_Every %n week_::_Every %n weeks_" : ["每 %n 周"],
    "_Every %n month_::_Every %n months_" : ["每 %n 月"],
    "_Every %n year_::_Every %n years_" : ["每 %n 年"],
    "_on {weekday}_::_on {weekdays}_" : ["在 {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["在 {dayOfMonthList} 日"],
    "on the {ordinalNumber} {byDaySet}" : "在 {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {dayOfMonthList}" : "在 {monthNames} 的 {dayOfMonthList}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "在 {monthNames} 的 {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "直到 {untilDate}",
    "_%n time_::_%n times_" : ["%n次"],
    "second" : "第二",
    "third" : "第三",
    "fourth" : "第四",
    "fifth" : "第五",
    "second to last" : "倒数第二",
    "last" : "最后",
    "Untitled task" : "无标题任务",
    "Please ask your administrator to enable the Tasks App." : "请让您的管理员启用此应用。",
    "You are not allowed to edit this event as an attendee." : "不允许您以参加者身份编辑此事件。",
    "W" : "周",
    "%n more" : "%n更多",
    "No events to display" : "没有事件可显示",
    "All participants declined" : "所有参与者均拒绝",
    "Please confirm your participation" : "请确认您的参与",
    "You declined this event" : "您拒绝了此事件",
    "Your participation is tentative" : "您的参与是暂定的",
    "_+%n more_::_+%n more_" : ["再 +%n 项"],
    "No events" : "无事件",
    "Create a new event or change the visible time-range" : "创建一个新事件或更改可见的时间范围",
    "Failed to save event" : "无法保存事件",
    "It might have been deleted, or there was a typo in a link" : "它可能已被删除，或者链接有误",
    "It might have been deleted, or there was a typo in the link" : "它可能已被删除，或者链接有误",
    "Meeting room" : "会议室",
    "Lecture hall" : "演讲厅",
    "Seminar room" : "研讨室",
    "Other" : "其他",
    "When shared show" : "共享时显示",
    "When shared show full event" : "共享时显示完整事件",
    "When shared show only busy" : "共享时仅显示忙碌",
    "When shared hide this event" : "共享时隐藏此事项",
    "The visibility of this event in read-only shared calendars." : "此事件在只读共享日历中的可见性。",
    "Add a location" : "添加地点",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "添加描述\n\n- 这次会议是关于什么的\n- 议程项目\n- 参与者需要准备的内容",
    "Status" : "状态",
    "Confirmed" : "已确认",
    "Canceled" : "已取消",
    "Confirmation about the overall status of the event." : "对事件总体状态的确认。",
    "Show as" : "显示为",
    "Take this event into account when calculating free-busy information." : "在计算闲忙信息时将此事件考虑在内。",
    "Categories" : "分类",
    "Categories help you to structure and organize your events." : "分类帮助您归类和组织您的事件。",
    "Search or add categories" : "搜索或添加分类",
    "Add this as a new category" : "添加此项作为新的分类",
    "Custom color" : "自定义颜色",
    "Special color of this event. Overrides the calendar-color." : "此事件的特殊颜色。 覆盖日历颜色。",
    "Error while sharing file" : "共享文件时出错",
    "Error while sharing file with user" : "与用户共享文件时出错",
    "Error creating a folder {folder}" : "创建文件夹 {folder} 时出错",
    "Attachment {fileName} already exists!" : "附件 {fileName} 已存在！",
    "Attachment {fileName} added!" : "附件 {fileName} 已添加！",
    "An error occurred during uploading file {fileName}" : "上传文件 {fileName} 时出错",
    "An error occurred during getting file information" : "获取文件信息时发生错误",
    "Talk conversation for proposal" : "提议的 Talk 对话",
    "An error occurred, unable to delete the calendar." : "发生错误，无法删除日历。",
    "Imported {filename}" : "已导入 {filename}",
    "This is an event reminder." : "这是一个事件提醒。",
    "Error while parsing a PROPFIND error" : "解析 PROPFIND 错误时出错",
    "Appointment not found" : "未找到预约",
    "User not found" : "未找到用户",
    "Hidden" : "隐藏的",
    "can edit" : "可编辑",
    "Calendar name …" : "日历名称 ...",
    "Default attachments location" : "默认附件位置",
    "Automatic ({detected})" : "自动（{detected}）",
    "Shortcut overview" : "快捷方式概览",
    "CalDAV link copied to clipboard." : "CalDAV 链接已复制到剪贴板。",
    "CalDAV link could not be copied to clipboard." : "CalDAV 链接无法复制到剪贴板。",
    "Enable birthday calendar" : "启用生日日历",
    "Show tasks in calendar" : "在日历中显示任务",
    "Enable simplified editor" : "启用简单编辑器",
    "Limit the number of events displayed in the monthly view" : "限制月视图中显示的事件数量",
    "Show weekends" : "显示周末",
    "Show week numbers" : "显示周数",
    "Time increments" : "时间增量",
    "Default calendar for incoming invitations" : "传入邀请的默认日历",
    "Copy primary CalDAV address" : "复制主要的 CalDAV 地址",
    "Copy iOS/macOS CalDAV address" : "复制 iOS/macOS CalDAV 地址",
    "Personal availability settings" : "个人工作时间设置",
    "Show keyboard shortcuts" : "显示键盘快捷方式",
    "Create a new public conversation" : "创建新的公开对话",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} 已邀请， {confirmedCount} 已确认",
    "Successfully appended link to talk room to location." : "已成功将线上谈话室的链接附加了位置。",
    "Successfully appended link to talk room to description." : "成功将链接添加到聊天室的描述。",
    "Error creating Talk room" : "建立聊天室时发生错误",
    "_%n more guest_::_%n more guests_" : ["还有 %n 位访客"],
    "The visibility of this event in shared calendars." : "在共享日历中此事项的可见性。"
},
"nplurals=1; plural=0;");
