OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Uppgefið tölvupóstfang er of langt",
    "User-Session unexpectedly expired" : "Setu notanda lauk óvænt",
    "Provided email-address is not valid" : "Uppgefið tölvupóstfang er ekki gilt",
    "%s has published the calendar »%s«" : "%s gaf út dagatalið »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Óvænt vandamál kom upp við að senda tölvupóst. Hafðu samband við kerfisstjóra.",
    "Successfully sent email to %1$s" : "Tókst að senda tölvupóst til %1$s",
    "Hello," : "Halló,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Við vildum láta þig vita að %s gaf út dagatalið »%s«.",
    "Open »%s«" : "Opna »%s«",
    "Cheers!" : "Til hamingju!",
    "Upcoming events" : "Atburðir á næstunni",
    "No more events today" : "Ekki fleiri atburðir í dag",
    "No upcoming events" : "Engir atburðir á næstunni",
    "More events" : "Fleiri atburðir",
    "%1$s with %2$s" : "%1$s með %2$s",
    "Calendar" : "Dagatal",
    "New booking {booking}" : "Ný bókun {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) bókaði stefnumótið \"{config_display_name}\" þann {date_time}.",
    "Appointments" : "Stefnumót",
    "Schedule appointment \"%s\"" : "Setja stefnumótið \"%s\" á dagskrá",
    "Schedule an appointment" : "Setja stefnumót á dagskrá",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : "Undirbúa fyrir %s",
    "Follow up for %s" : "Fylgja eftir %s",
    "Your appointment \"%s\" with %s needs confirmation" : "\"%s\" stefnumótið þitt við %s krefst staðfestingar",
    "Dear %s, please confirm your booking" : "Kæri/Kæra %s, staðfestu bókunina þína",
    "Confirm" : "Staðfesta",
    "Appointment with:" : "Stefnumót með:",
    "Description:" : "Lýsing:",
    "This confirmation link expires in %s hours." : "Þessi tengill til staðfestingar rennur út eftir %s klukkustundir.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Ef þú vilt aflýsa stefnumótinu eftir allt saman, skaltu hafa samband við skipuleggjendurna með því að svara þessum tölvupósti eða fara á síðuna með persónusniðinu þeirra.",
    "Your appointment \"%s\" with %s has been accepted" : "\"%s\" stefnumótið þitt við %s hefur verið samþykkt",
    "Dear %s, your booking has been accepted." : "Kæri/Kæra %s, bókunin þín hefur verið samþykkt.",
    "Appointment for:" : "Stefnumót vegna:",
    "Date:" : "Dagsetning:",
    "You will receive a link with the confirmation email" : "Þú munt fá tengil í staðfestingarpósti",
    "Where:" : "Hvar:",
    "Comment:" : "Athugasemd:",
    "You have a new appointment booking \"%s\" from %s" : "Þú ert með nýja bókun um \"%s\" stefnumót frá %s",
    "Dear %s, %s (%s) booked an appointment with you." : "Kæri/Kæra %s, %s (%s) bókaði fund með þér.",
    "Location:" : "Staðsetning:",
    "A Calendar app for Nextcloud" : "Dagatalsforrit fyrir Nextcloud",
    "Previous day" : "Fyrri dagur",
    "Previous week" : "Fyrri vika",
    "Previous year" : "Fyrra ár",
    "Previous month" : "Fyrri mánuður",
    "Next day" : "Næsta dag",
    "Next week" : "Næsta viku",
    "Next year" : "Næsta ár",
    "Next month" : "Næsti mánuður",
    "Create new event" : "Búa til nýjan atburð",
    "Event" : "Atburður",
    "Today" : "Í dag",
    "Day" : "Dagur",
    "Week" : "Vika",
    "Month" : "Mánuður",
    "Year" : "Ár",
    "List" : "Listi",
    "Appointment link was copied to clipboard" : "Stefnumótstengill var afritaður á klippispjald",
    "Appointment link could not be copied to clipboard" : "Ekki var hægt að afrita stefnumótstengil á klippispjald",
    "Preview" : "Forskoðun",
    "Copy link" : "Afrita tengil",
    "Edit" : "Breyta",
    "Delete" : "Eyða",
    "Appointment schedules" : "Dagskrá stefnumóta",
    "Create new" : "Búa til nýjan",
    "Disable calendar \"{calendar}\"" : "Gera dagatalið \"{calendar}\" óvirkt",
    "Disable untitled calendar" : "Gera ónefnt dagatal óvirkt",
    "Enable calendar \"{calendar}\"" : "Gera dagatalið \"{calendar}\" virkt",
    "Enable untitled calendar" : "Gera ónefnt dagatal virkt",
    "An error occurred, unable to change visibility of the calendar." : "Villa kom upp, gat ekki breytt sýnileika dagatalsins.",
    "Untitled calendar" : "Ónefnt dagatal",
    "Shared with you by" : "Deilt með þér af",
    "Edit and share calendar" : "Breyta og deila dagatali",
    "Edit calendar" : "Breyta dagatali",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Hætti að deila dagatalinu eftir {countdown} sekúndu","Hætti að deila dagatalinu eftir {countdown} sekúndur"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Eyði dagatalinu eftir {countdown} sekúndu","Eyði dagatalinu eftir {countdown} sekúndur"],
    "An error occurred, unable to create the calendar." : "Villa kom upp, gat ekki búið til dagatalið.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Skráðu inn gilda slóð (starting with http://, https://, webcal://, or webcals://)",
    "Calendars" : "Dagatöl",
    "Add new" : "Bæta við nýju",
    "New calendar" : "Nýtt dagatal",
    "Name for new calendar" : "Nafn á nýju dagatali",
    "Creating calendar …" : "Útbý dagatal …",
    "New calendar with task list" : "Nýtt dagatal með verkefnalista",
    "New subscription from link (read-only)" : "Ný áskrift úr tengli (skrifvarið)",
    "Creating subscription …" : "Útbý áskrift …",
    "Add public holiday calendar" : "Bæta við opinberu frídagatali",
    "Add custom public calendar" : "Bæta við sérsniðnu opinberu dagatali",
    "Calendar link copied to clipboard." : "Dagatalstengill afritaður á klippispjald.",
    "Calendar link could not be copied to clipboard." : "Ekki var hægt að afrita dagatalstengil á klippispjald.",
    "Copy subscription link" : "Afrita áskriftartengil",
    "Copying link …" : "Afrita tengil …",
    "Copied link" : "Afritaði tengil",
    "Could not copy link" : "Gat ekki afritað tengil",
    "Export" : "Flytja út",
    "Untitled item" : "Ónefnt atriði",
    "Unknown calendar" : "Óþekkt dagatal",
    "Could not load deleted calendars and objects" : "Gat ekki hlaðið inn eyddum dagatölum og hlutum",
    "Could not delete calendar or event" : "Gat ekki eytt dagatali eða atburði",
    "Could not restore calendar or event" : "Gat ekki endurheimt dagatal eða atburð",
    "Do you really want to empty the trash bin?" : "Viltu örugglega tæma ruslið?",
    "Empty trash bin" : "Tæma ruslið",
    "Trash bin" : "Rusl",
    "Loading deleted items." : "Hleð inn eyddum atriðum.",
    "You do not have any deleted items." : "Þú ert ekki með nein eydd atriði.",
    "Name" : "Heiti",
    "Deleted" : "Eytt",
    "Restore" : "Endurheimta",
    "Delete permanently" : "Eyða varanlega",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Atriðum í ruslinu er eytt eftir {numDays} dag","Atriðum í ruslinu er eytt eftir {numDays} daga"],
    "Could not update calendar order." : "Gat ekki uppfært röð dagatalanna.",
    "Shared calendars" : "Sameiginleg dagatöl",
    "Deck" : "Deck-spjaldaforrit",
    "Internal link" : "Innri tengill",
    "A private link that can be used with external clients" : "Einkatengill sem hægt er að nota með öðrum forritum",
    "Copy internal link" : "Afrita innri tengil",
    "An error occurred, unable to publish calendar." : "Villa kom upp, gat ekki gefið út dagatalið.",
    "An error occurred, unable to send email." : "Villa kom upp, gat ekki sent tölvupóst.",
    "Embed code copied to clipboard." : "Ívafningarkóði afritaður á klippispjald.",
    "Embed code could not be copied to clipboard." : "Ekki var hægt að afrita ívafningarkóða á klippispjald.",
    "Unpublishing calendar failed" : "Mistókst að hætta birtingu dagatals",
    "Share link" : "Deila tengli",
    "Copy public link" : "Afrita opinberan tengil",
    "Send link to calendar via email" : "Senda tengil á dgatal með tölvupósti",
    "Enter one address" : "Settu inn eitt netfang",
    "Sending email …" : "Sendi tölvupóst ...",
    "Copy embedding code" : "Afrita ívafningarkóða",
    "Copying code …" : "Afrita kóða …",
    "Copied code" : "Afritaði kóða",
    "Could not copy code" : "Gat ekki afritað kóða",
    "Delete share link" : "Eyða tengli á sameign",
    "Deleting share link …" : "Eyði tengli á sameign …",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Teymi)",
    "An error occurred while unsharing the calendar." : "Villa kom upp við að taka dagatalið úr samnýtingu.",
    "An error occurred, unable to change the permission of the share." : "Villa kom upp, gat ekki breytt heimildum á sameigninni.",
    "Unshare with {displayName}" : "Hætta deilingu með {displayName}",
    "Share with users or groups" : "Deila með notendum eða hópum",
    "No users or groups" : "Engir notendur eða hópar",
    "Failed to save calendar name and color" : "Mistókst að vista heiti og lit dagatals",
    "Never show me as busy (set this calendar to transparent)" : "Aldrei sýna mig sem upptekinn/upptekna (stilla þetta dagatal á að vera gegnsætt)",
    "Share calendar" : "Deila dagatali",
    "Unshare from me" : "Hætta deilingu frá mér",
    "Save" : "Vista",
    "View" : "Skoða",
    "Import calendars" : "Flytja inn dagatöl",
    "Please select a calendar to import into …" : "Veldu dagatal til að flytja inn í …",
    "Filename" : "Skráarheiti",
    "Calendar to import into" : "Dagatal til að flytja inn í",
    "Cancel" : "Hætta við",
    "_Import calendar_::_Import calendars_" : ["Flytja inn dagatal","Flytja inn dagatöl"],
    "Select the default location for attachments" : "Veldu sjálfgefna geymslustaðsetningu viðhengja",
    "Pick" : "Veldu",
    "Invalid location selected" : "Ógild staðsetning valin",
    "Attachments folder successfully saved." : "Tókst að vista viðhengjamöppu.",
    "Error on saving attachments folder." : "Villa við að vista viðhengjamöppu.",
    "{filename} could not be parsed" : "Ekki var hægt að þátta {filename}",
    "No valid files found, aborting import" : "Engar gildar skrár fundust, hætti innflutningi",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Það tókst að flytja inn %n atburð","Það tókst að flytja inn %n atburði"],
    "Import partially failed. Imported {accepted} out of {total}." : "Innflutningur mistókst að hluta. Flutti inn {accepted} af {total}.",
    "Automatic" : "Sjálfvirkt",
    "Automatic ({timezone})" : "Sjálfvirkt ({timezone})",
    "New setting was not saved successfully." : "Ekki tókst að vista nýju stillinguna.",
    "Timezone" : "Tímabelti",
    "Navigation" : "Yfirsýn",
    "Previous period" : "Fyrra tímabil",
    "Next period" : "Næsta tímabil",
    "Views" : "Skoðun",
    "Day view" : "Dagsyfirlit",
    "Week view" : "Vikuyfirlit",
    "Month view" : "Mánaðaryfirlit",
    "Year view" : "Ársyfirlit",
    "List view" : "Listayfirlit",
    "Actions" : "Aðgerðir",
    "Create event" : "Búa til atburð",
    "Show shortcuts" : "Birta flýtileiðir",
    "Editor" : "Ritill",
    "Close editor" : "Loka ritli",
    "Save edited event" : "Vista breyttan atburð",
    "Delete edited event" : "Eyða breyttum atburði",
    "Duplicate event" : "Tvítaka atburð",
    "or" : "eða",
    "Calendar settings" : "Stillingar dagatals",
    "At event start" : "Við upphaf atburðar",
    "No reminder" : "Engin áminning",
    "Failed to save default calendar" : "Mistókst að vista sjálfgefið dagatal",
    "General" : "Almennt",
    "Appearance" : "Útlit",
    "Editing" : "Breytingar",
    "Default reminder" : "Sjálfgefin áminning",
    "Files" : "Skráaforrit",
    "Appointment schedule successfully created" : "Tókst að útbúa dagskrá stefnumóta",
    "Appointment schedule successfully updated" : "Tókst að uppfæra dagskrá stefnumóta",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} mínúta","{duration} mínútur"],
    "0 minutes" : "0 mínútur",
    "_{duration} hour_::_{duration} hours_" : ["{duration} klukkustund","{duration} klukkustundir"],
    "_{duration} day_::_{duration} days_" : ["{duration} dagur","{duration} dagar"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} vika","{duration} vikur"],
    "_{duration} month_::_{duration} months_" : ["{duration} mánuður","{duration} mánuðir"],
    "_{duration} year_::_{duration} years_" : ["{duration} ár","{duration} ár"],
    "To configure appointments, add your email address in personal settings." : "Til að setja upp stefnumót, skaltu setja inn tölvupóstfangið þitt í einkastillingum þínum.",
    "Public – shown on the profile page" : "Opinbert - birt á notandasíðunni",
    "Private – only accessible via secret link" : "Einka - eingöngu aðgengilegt í gegnum einkatengil",
    "Appointment schedule saved" : "Dagskrá stefnumóta vistuð",
    "Create appointment schedule" : "Útbúa dagskrá stefnumóta",
    "Edit appointment schedule" : "Breyta dagskrá stefnumóta",
    "Update" : "Uppfæra",
    "Appointment name" : "Heiti stefnumóts",
    "Location" : "Staðsetning",
    "Create a Talk room" : "Búa til spjallrás",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Einstakur tengill verður útbúinn fyrir hvert stefnumót og sendur í staðfestingarpóstinum",
    "Description" : "Lýsing",
    "Visibility" : "Sýnileiki",
    "Duration" : "Duration",
    "Increments" : "Þrep",
    "Additional calendars to check for conflicts" : "Viðbótardagatöl sem á að athuga með árekstra",
    "Pick time ranges where appointments are allowed" : "Veldu tímabil þar sem stefnumót eru leyfð",
    "to" : "til",
    "Delete slot" : "Eyða tímahólfi",
    "No times set" : "Engar tímasetningar stilltar",
    "Add" : "Bæta við",
    "Monday" : "Mánudagur",
    "Tuesday" : "Þriðjudagur",
    "Wednesday" : "Miðvikudagur",
    "Thursday" : "Fimmtudagur",
    "Friday" : "Föstudagur",
    "Saturday" : "Laugardagur",
    "Sunday" : "Sunnudagur",
    "Weekdays" : "Virkir dagar",
    "Add time before and after the event" : "Bættu við tíma fyrir og eftir atburðinn",
    "Before the event" : "Fyrir atburðinn",
    "After the event" : "Eftir atburðinn",
    "Planning restrictions" : "Takmarkanir við áætlunargerð",
    "Minimum time before next available slot" : "Lágmarkstími á undan næsta tímahólfi",
    "Max slots per day" : "Hámarksfjöldi tímahólfa á dag",
    "Limit how far in the future appointments can be booked" : "Takmarka hve langt fram í tíma hægt er að bóka stefnumót",
    "It seems a rate limit has been reached. Please try again later." : "Það lítur út fyrir að takmörkum á bókunum hafi verið náð. Reyndu aftur síðar.",
    "Please confirm your reservation" : "Staðfestu pöntunina þína",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Við höfum sent þér tölvupóst með nánari upplýsingum. Staðfestu stefnumótið þitt með því að fylgja tenglinum í póstinum. Þú mátt núna loka þessari síðu.",
    "Your name" : "Nafnið þitt",
    "Your email address" : "Netfangið þitt",
    "Please share anything that will help prepare for our meeting" : "Deildu með okkur hverju því sem getur hjálpað við að undirbúa fundinn",
    "Could not book the appointment. Please try again later or contact the organizer." : "Gat ekki bókað stefnumótið. Reyndu aftur seinna eða hafðu samband við skipuleggjendurna.",
    "Back" : "Til baka",
    "Book appointment" : "Bóka stefnumót",
    "Error fetching Talk conversations." : "Villa við að sækja samtöl af spjallsvæði.",
    "Conversation does not have a valid URL." : "Samtalið er ekki með gilda vefslóð.",
    "Successfully added Talk conversation link to location." : "Tókst að bæta tengli á samtal á staðsetningu.",
    "Successfully added Talk conversation link to description." : "Tókst að bæta tengli á samtal á lýsingu.",
    "Failed to apply Talk room." : "Mistókst að virkja spjallrás.",
    "Talk conversation for event" : "Samtal fyrir atburð",
    "Error creating Talk conversation" : "Mistókst að útbúa samtal",
    "Select a Talk Room" : "Veldu spjallrás",
    "Add Talk conversation" : "Bæta við samtali á spjallrás",
    "Fetching Talk rooms…" : "Sæki spjallrásir…",
    "No Talk room available" : "Engin spjallrás tiltæk",
    "Select conversation" : "Veldu samtal",
    "on" : "þann",
    "at" : "klukkan",
    "before at" : "á undan klukkan",
    "Notification" : "Tilkynning",
    "Email" : "Tölvupóstur",
    "Audio notification" : "Hljóðáminning",
    "Other notification" : "Önnur áminning",
    "Relative to event" : "Miðað við atburð",
    "On date" : "Þann",
    "Edit time" : "Breyta tíma",
    "Save time" : "Vista tíma",
    "Remove reminder" : "Fjarlægja áminningu",
    "Add reminder" : "Bæta við áminningu",
    "seconds" : "sekúndum",
    "minutes" : "mínútur",
    "hours" : "klukkustundir",
    "days" : "daga",
    "weeks" : "vikur",
    "Choose a file to add as attachment" : "Veldu skrá til að setja sem viðhengi",
    "Choose a file to share as a link" : "Veldu skrá til að deila sem tengli",
    "Attachment {name} already exist!" : "Viðhengið {name} er þegar til staðar!",
    "Could not upload attachment(s)" : "Gat ekki sent inn viðhengi",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Þú ert í þann mund að fara yfir á {host}. Ertu viss um að þú viljir halda áfram? Tengill: {link}",
    "Proceed" : "Halda áfram",
    "No attachments" : "Engin viðhengi",
    "Add from Files" : "Bæta við úr skrám",
    "Upload from device" : "Senda inn frá tæki",
    "Delete file" : "Eyða skrá",
    "Confirmation" : "Staðfesting",
    "_{count} attachment_::_{count} attachments_" : ["{count} viðhengi","{count} viðhengi"],
    "Suggested" : "Stungið upp á",
    "Available" : "Tiltækt",
    "Invitation accepted" : "Boð samþykkt",
    "Accepted {organizerName}'s invitation" : "Samþykkti boð frá {organizerName}",
    "Participation marked as tentative" : "Þátttaka merkt með fyrirvara",
    "Invitation is delegated" : "Boðinu er framvísað",
    "Not available" : "Not available",
    "Invitation declined" : "Boði hafnað",
    "Declined {organizerName}'s invitation" : "Hafnaði boði frá {organizerName}",
    "Availability will be checked" : "Framboð verður athugað",
    "Invitation will be sent" : "Boð verður sent",
    "Failed to check availability" : "Mistókst að skoða lausa tíma",
    "Failed to deliver invitation" : "Mistókst að afhenda boð",
    "Awaiting response" : "Bíður eftir svari",
    "Checking availability" : "Athuga hvað sé á lausu",
    "Has not responded to {organizerName}'s invitation yet" : "Hefur ekki svarað boðinu frá {organizerName} ennþá",
    "chairperson" : "fundarstjóri",
    "required participant" : "nauðsynlegur þátttakandi",
    "non-participant" : "ekki þátttakandi",
    "optional participant" : "aukaþátttakandi",
    "{organizer} (organizer)" : "{organizer} (organizer)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Availability of attendees, resources and rooms" : "Framboð á þátttakendum, tilföngum og herbergjum",
    "Suggestion accepted" : "Tillaga samþykkt",
    "Out of office" : "Ekki á staðnum",
    "Attendees:" : "Þáttakendur:",
    "Done" : "Lokið",
    "Search room" : "Leita að aðstöðu",
    "Room name" : "Heiti fundarsalar",
    "Check room availability" : "Athuga framboð",
    "Free" : "Laus",
    "Busy (tentative)" : "Upptekinn (með fyrirvara)",
    "Busy" : "Upptekinn",
    "Unknown" : "Óþekkt",
    "Find a time" : "Finna tíma",
    "The invitation has been accepted successfully." : "Boðið hefur verið samþykkt.",
    "Failed to accept the invitation." : "Mistókst að samþykkja boðið.",
    "The invitation has been declined successfully." : "Boðinu hefur verið hafnað.",
    "Failed to decline the invitation." : "Mistókst að hafna boðinu.",
    "Your participation has been marked as tentative." : "Þátttaka þín hefur verið merkt með fyrirvara.",
    "Failed to set the participation status to tentative." : "Mistókst að merkja stöðu þátttakanda með fyrirvara.",
    "Accept" : "Samþykkja",
    "Decline" : "Hafna",
    "Tentative" : "Með fyrirvara",
    "No attendees yet" : "Engir þátttakendur ennþá",
    "Attendees" : "Þátttakendur",
    "Remove group" : "Fjarlægja hóp",
    "Remove attendee" : "Fjarlægja þátttakanda",
    "Request reply" : "Biðja um svar",
    "Chairperson" : "Fundarstjóri",
    "Required participant" : "Nauðsynlegur þátttakandi",
    "Optional participant" : "Aukaþátttakandi",
    "Non-participant" : "Ekki þátttakandi",
    "_%n member_::_%n members_" : ["%n þátttakandi","%n þátttakendur"],
    "No match found" : "Fann engar samsvaranir",
    "Note that members of circles get invited but are not synced yet." : "Athugaðu að meðlimum hringja verður boðið en er enn ekki búnir að samstillast.",
    "Note that members of contact groups get invited but are not synced yet." : "Athugaðu að meðlimum tengiliðahópa verður boðið en er enn ekki búnir að samstillast.",
    "(organizer)" : "(skipuleggjandi)",
    "Make {label} the organizer" : "Gera {label} að skipuleggjanda",
    "Make {label} the organizer and attend" : "Gera {label} að skipuleggjanda og taka þátt",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Til að senda út boð og meðhöndla svör, [linkopen]skaltu setja inn tölvupóstfangið þitt í einkastillingum þínum[linkclose].",
    "Remove color" : "Fjarlægja lit",
    "Event title" : "Titill atburðar",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Get ekki breytt heils-dags-stillingu viðburða sem eru hluti af endurtekningasetti.",
    "From" : "Frá",
    "To" : "Til",
    "Repeat" : "Endurtaka",
    "_time_::_times_" : ["sinni","sinnum"],
    "never" : "aldrei",
    "on date" : "þann",
    "after" : "eftir",
    "End repeat" : "Hætta endurtekningu",
    "Select to end repeat" : "Veldu til að hætta endurtekningu",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Þessi viðburður er endurtekninga-frávik í endurtekningasetti. Þú getur ekki bætt endurtekninga-reglu við hann.",
    "first" : "fyrsta",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Breytingar á endurtekninga-reglunni mun aðeins eiga við þetta tilvik og framtíðartilvik.",
    "Repeat every" : "Endurtaka",
    "By day of the month" : "Eftir degi mánaðarins",
    "On the" : "Þann",
    "_day_::_days_" : ["dagur","dagar"],
    "_week_::_weeks_" : ["vika","vikur"],
    "_month_::_months_" : ["mánuður","mánuðir"],
    "_year_::_years_" : ["ár","ár"],
    "weekday" : "vinnudagur",
    "weekend day" : "helgardagur",
    "Does not repeat" : "Endurtekst ekki",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Endurtekninga-skilgreining þessa viðburðar er ekki að fullu studd í Nextcloud. Ef þú breytir endurtekninga-valkostunum, gætu sumar endurtekningar tapast.",
    "No rooms or resources yet" : "Ennþá ekki neinir salir eða tilföng",
    "Resources" : "Tilföng",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} sæti","{seatingCapacity} sæti"],
    "Add resource" : "Bæta við tilfangi",
    "Has a projector" : "Er með skjávarpa",
    "Has a whiteboard" : "Er með töflu",
    "Wheelchair accessible" : "Aðgengilegt í hjólastól",
    "Remove resource" : "Fjarlægja tilfang",
    "Search for resources or rooms" : "Leita að tilföngum eða fundarsölum",
    "available" : "tiltækt",
    "unavailable" : "ekki tiltækt",
    "Show all rooms" : "Sýna alla fundarsali",
    "Projector" : "Skjávarpi",
    "Whiteboard" : "Teiknitafla",
    "Room type" : "Tegund salar",
    "Any" : "Hvað sem er",
    "Minimum seating capacity" : "Lágmarks-sætafjöldi",
    "More details" : "Nánari upplýsingar",
    "Update this and all future" : "Uppfæra þetta og öll síðari",
    "Update this occurrence" : "Uppfæra þetta tilviki",
    "Public calendar does not exist" : "Opinbert dagatal er ekki til",
    "Maybe the share was deleted or has expired?" : "Hugsanlega hefur sameigninni verið eytt eða hún sé útrunnin?",
    "None" : "Ekkert",
    "Create" : "Búa til",
    "from {formattedDate}" : "frá {formattedDate}",
    "to {formattedDate}" : "til {formattedDate}",
    "on {formattedDate}" : "þann {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "frá {formattedDate} kl. {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "til {formattedDate} kl. {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "þann {formattedDate} kl. {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} kl. {formattedTime}",
    "Please enter a valid date" : "Settu inn gilda dagsetningu",
    "Please enter a valid date and time" : "Settu inn gilda dags- og tímasetningu",
    "Select a time zone" : "Veldu tímabelti",
    "Please select a time zone:" : "Veldu tímabelti:",
    "Pick a time" : "Veldu tíma",
    "Pick a date" : "Veldu dagsetningu",
    "Type to search time zone" : "Skrifaðu til að leita að tímabelti...",
    "Global" : "Víðvært",
    "Holidays in {region}" : "Frídagar á {region}",
    "An error occurred, unable to read public calendars." : "Villa kom upp, gat ekki lesið opinber dagatöl.",
    "An error occurred, unable to subscribe to calendar." : "Villa kom upp, gat ekki gerst áskrifandi að dagatali.",
    "Public holiday calendars" : "Dagatöl með opinberum frídögum",
    "Public calendars" : "Opinber dagatöl",
    "No valid public calendars configured" : "Engin gild opinber dagatöl stillt",
    "Speak to the server administrator to resolve this issue." : "Hafðu samband við kerfisstjóra netþjónsins til að leysa þetta.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Dagatöl með opinberum frídögum koma frá Thunderbird. Dagatalsgögnin eru sótt frá {website}",
    "By {authors}" : "Frá {authors}",
    "Subscribed" : "Í áskrift",
    "Subscribe" : "Gerast áskrifandi",
    "Could not fetch slots" : "Gat ekki sótt tímahólf",
    "Select a date" : "Veldu dagsetningu",
    "Select slot" : "Veldu tímahólf",
    "No slots available" : "Engin tímahólf tiltæk",
    "The slot for your appointment has been confirmed" : "Tímahólfið fyrir stefnumótið þtt er staðfestur",
    "Appointment Details:" : "Nánar um stefnumót:",
    "Time:" : "Tími:",
    "Booked for:" : "Bókað fyrir:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Takk fyrir. Bókun þín frá {startDate} til {endDate} hefur verið staðfest.",
    "Book another appointment:" : "Bóka annað stefnumót:",
    "See all available slots" : "Sjá öll tiltæk tímahólf",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Tímahólfið fyrir stefnumótið þtt frá {startDate} til {endDate} er ekki lengur tiltækt.",
    "Please book a different slot:" : "Bókaðu eitthvað annað tímahólf:",
    "Book an appointment with {name}" : "Bóka stefnumót með {name}",
    "No public appointments found for {name}" : "Engin opinber stefnumót fundust fyrir {name}",
    "Personal" : "Persónulegt",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Sjálfvirka tímabeltisgreiningin ákvarðaði tímabeltið þitt sem UTC.\nLíklega er það vegna öryggisstillinga í vafranum þínum.\nStilltu tímabeltið þitt í stillingum dagatalsins.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Stillta tímabeltið þitt ({timezoneId}) fannst ekki. Nota UTC til vara.\nStilltu tímabeltið þitt í stillingum dagatalsins og tilkynntu þetta vandamál.",
    "Availability of {displayName}" : "Lausir tímar hjá {displayName}",
    "Edit event" : "Breyta atburði",
    "Event does not exist" : "Atburður er ekki til",
    "Duplicate" : "Tvítaka",
    "Delete this occurrence" : "Eyða þessu tilviki",
    "Delete this and all future" : "Eyða þessu og framtíðar tilvikum",
    "All day" : "Heilsdagsviðburður",
    "Managing shared access" : "Sýsla með sameiginlegan aðgang",
    "Deny access" : "Hafna aðgangi",
    "Invite" : "Bjóða",
    "_User requires access to your file_::_Users require access to your file_" : ["Notandi þarf aðgang að skránni þinni","Notendur þurfa aðgang að skránni þinni"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Viðhengi krefst sameiginlegs aðgangs","Viðhengi krefjast sameiginlegs aðgangs"],
    "Untitled event" : "Ónefndur atburður",
    "Close" : "Loka",
    "Participants" : "Þátttakendur",
    "Submit" : "Senda inn",
    "Subscribe to {name}" : "Panta áskrift að {name}",
    "Export {name}" : "Flytja út {name}",
    "Show availability" : "Sýna lausa tíma",
    "Anniversary" : "Afmæli",
    "Appointment" : "Stefnumót",
    "Business" : "Viðskipti",
    "Education" : "Menntun",
    "Holiday" : "Frí",
    "Meeting" : "Fundur",
    "Miscellaneous" : "Ýmislegt",
    "Non-working hours" : "Utan vinnutíma",
    "Not in office" : "Ekki á skrifstofunni",
    "Phone call" : "Símtal",
    "Sick day" : "Veikindadagur",
    "Special occasion" : "Sérstakt tilefni",
    "Travel" : "Ferðalög",
    "Vacation" : "Í fríi",
    "Midnight on the day the event starts" : "Miðnætti dagsins sem atburður hefst",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n degi fyrir atburðinn kl. {formattedHourMinute}","%n dögum fyrir atburðinn kl. {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n viku fyrir atburðinn kl. {formattedHourMinute}","%n vikum fyrir atburðinn kl. {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "dagsins sem atburður hefst kl. {formattedHourMinute}",
    "at the event's start" : "{type} við upphaf atburðar",
    "at the event's end" : "{type} við lok atburðar",
    "{time} before the event starts" : "{time} áður en atburður hefst",
    "{time} before the event ends" : "{time} áður en atburður endar",
    "{time} after the event starts" : "{time} eftir að atburður hefst",
    "{time} after the event ends" : "{time} eftir að atburður endar",
    "on {time}" : "á slaginu {time}",
    "on {time} ({timezoneId})" : "klukkan {time} ({timezoneId})",
    "Week {number} of {year}" : "Vika {number}, ársins {year}",
    "Daily" : "Daglega",
    "Weekly" : "Vikulega",
    "Monthly" : "Mánaðarlega",
    "Yearly" : "Árlega",
    "_Every %n day_::_Every %n days_" : ["Á %n dags fresti","Á %n daga fresti"],
    "_Every %n week_::_Every %n weeks_" : ["Á %n viku fresti","Á %n vikna fresti"],
    "_Every %n month_::_Every %n months_" : ["Á %n mánaðar fresti","Á %n mánaða fresti"],
    "_Every %n year_::_Every %n years_" : ["Á %n árs fresti","Á %n ára fresti"],
    "_on {weekday}_::_on {weekdays}_" : ["á {weekday}","á {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["daginn {dayOfMonthList}","dagana {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "þann {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "í {monthNames} þann {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "þangað til {untilDate}",
    "_%n time_::_%n times_" : ["%n sinni","%n sinnum"],
    "second" : "sekúnda",
    "third" : "þriðja",
    "fourth" : "fjórða",
    "fifth" : "fimmta",
    "second to last" : "næstsíðasta",
    "last" : "síðasta",
    "Untitled task" : "Ónefnt verkefni",
    "Please ask your administrator to enable the Tasks App." : "Biddu kerfisstjórann þinn um að virkja verkefnasorritið (Tasks).",
    "W" : "V",
    "%n more" : "%n til viðbótar",
    "No events to display" : "Engir atburðir til að birta",
    "_+%n more_::_+%n more_" : ["+%n til viðbótar","+%n til viðbótar"],
    "No events" : "Engir atburðir",
    "Create a new event or change the visible time-range" : "Búa til nýjan atburð eða breyta sýnilegu tímabili",
    "Failed to save event" : "Mistókst að vista atburð",
    "It might have been deleted, or there was a typo in a link" : "Því gæti hafa verið eytt, eða að stafsetningarvilla hafi verið í tengli",
    "It might have been deleted, or there was a typo in the link" : "Því gæti hafa verið eytt, eða að stafsetningarvilla hafi verið í tenglinum",
    "Meeting room" : "Fundarherbergi",
    "Lecture hall" : "Fyrirlestrarsalur",
    "Seminar room" : "Námskeiðssalur",
    "Other" : "Annað",
    "When shared show" : "Þegar er deilt, birta ",
    "When shared show full event" : "Þegar er deilt, birta allan atburð",
    "When shared show only busy" : "Þegar er deilt, birta eingöngu upptekið",
    "When shared hide this event" : "Þegar er deilt, fela þennan atburð",
    "Add a location" : "Bæta við staðsetningu",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Bættu við lýsingu\n\n- Um hvað snýst þessi fundur\n- Atriði á dagskrá\n- Hvaðeina sem þátttakendur þurfa að undirbúa",
    "Status" : "Staða",
    "Confirmed" : "Staðfest",
    "Canceled" : "Hætt við",
    "Confirmation about the overall status of the event." : "Staðfesting á almennri stöðu atburðarins.",
    "Show as" : "Birta sem",
    "Take this event into account when calculating free-busy information." : "Taka þennan atburð með í reikninga á laus/upptekinn upplýsingum.",
    "Categories" : "Flokkar",
    "Categories help you to structure and organize your events." : "Flokkar hjálpa þér við að greina og skipuleggja atburði.",
    "Search or add categories" : "Leita eða bæta við flokkum",
    "Add this as a new category" : "Bæta þessu við sem nýjum flokki",
    "Custom color" : "Sérsniðinn litur",
    "Special color of this event. Overrides the calendar-color." : "Sértækur litur þessa atburðar. Er rétthærri en litur dagatalsins.",
    "Error while sharing file" : "Villa við deilingu skráar",
    "Error while sharing file with user" : "Villa við deilingu skráar með notanda",
    "Attachment {fileName} already exists!" : "Viðhengið {fileName} er þegar til staðar!",
    "An error occurred during getting file information" : "Villa kom upp við að sækja upplýsingar um skrá",
    "An error occurred, unable to delete the calendar." : "Villa kom upp, gat ekki eytt dagatalinu.",
    "Imported {filename}" : "Flutti inn {filename}",
    "This is an event reminder." : "Þetta er áminning vegna atburðar.",
    "Error while parsing a PROPFIND error" : "Villa við þáttun á PROPFIND-villu",
    "Appointment not found" : "Stefnumót fannst ekki",
    "User not found" : "Notandi fannst ekki",
    "Hidden" : "Falinn",
    "can edit" : "getur breytt",
    "Calendar name …" : "Heiti dagatals …",
    "Default attachments location" : "Sjálfgefin staðsetning viðhengja",
    "Automatic ({detected})" : "Sjálfvirkt ({detected})",
    "Shortcut overview" : "Yfirlit flýtilykla",
    "CalDAV link copied to clipboard." : "CalDAV-tengill afritaður á klippispjald.",
    "CalDAV link could not be copied to clipboard." : "Ekki var hægt að afrita CalDAV-tengil á klippispjald.",
    "Enable birthday calendar" : "Virkja fæðingardagatal",
    "Show tasks in calendar" : "Sýna verkefni í dagatali",
    "Enable simplified editor" : "Virkja einfaldaðan ritil",
    "Limit the number of events displayed in the monthly view" : "Takmarka fjölda atburða sem birtast í mánaðaryfirlitinu",
    "Show weekends" : "Sýna helgar",
    "Show week numbers" : "Sýna vikunúmer",
    "Time increments" : "Tímaþrep",
    "Default calendar for incoming invitations" : "Sjálfgefið dagatal fyrir boð sem berast",
    "Copy primary CalDAV address" : "Afrita aðal-CalDAV-vistfang",
    "Copy iOS/macOS CalDAV address" : "Afrita iOS/macOS CalDAV-vistfang ",
    "Personal availability settings" : "Persónulegar stillingar varðandi hvenær til taks",
    "Show keyboard shortcuts" : "Birta flýtivísanir á lyklaborði",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} boðið, {confirmedCount} staðfestir",
    "Successfully appended link to talk room to location." : "Tókst að bæta tengli á spjallsvæði við staðsetningu.",
    "Successfully appended link to talk room to description." : "Tókst að bæta tengli á spjallsvæði við lýsingu.",
    "Error creating Talk room" : "Villa við að búa til spjallsvæði.",
    "_%n more guest_::_%n more guests_" : ["%n gestur til viðbótar","%n gestir til viðbótar"],
    "The visibility of this event in shared calendars." : "Sýnileiki þessa atburðar í sameiginlegum dagatölum"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
