OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "L'adresse e-mail fournie est trop longue",
    "User-Session unexpectedly expired" : "La session utilisateur a expiré",
    "Provided email-address is not valid" : "L'adresse e-mail fournie n'est pas valide",
    "%s has published the calendar »%s«" : "%s a publié l'agenda «%s»",
    "Unexpected error sending email. Please contact your administrator." : "Erreur inattendue pendant l'envoi de l'e-mail. Veuillez contacter votre administrateur.",
    "Successfully sent email to %1$s" : "Envoi d'e-mail vers %1$s réussi",
    "Hello," : "Bonjour,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Nous voulions vous informer que %s a publié l'agenda « %s ».",
    "Open »%s«" : "Ouvrir «%s»",
    "Cheers!" : "À bientôt !",
    "Upcoming events" : "Événements à venir",
    "No more events today" : "Aucun autre événement aujourd'hui",
    "No upcoming events" : "Aucun événement à venir",
    "More events" : "Plus d'événements",
    "%1$s with %2$s" : "%1$s avec %2$s",
    "Calendar" : "Agenda",
    "New booking {booking}" : "Nouvelle prise de rendez-vous {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) a pris le rendez-vous \"{config_display_name}\" le {date_time}.",
    "Appointments" : "Rendez-vous",
    "Schedule appointment \"%s\"" : "Planifier le rendez-vous \"%s\"",
    "Schedule an appointment" : "Planifier un rendez-vous",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : "Préparez-vous pour %s",
    "Follow up for %s" : "Suivi pour %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Votre rendez-vous \"%s\" avec %s nécessite une confirmation",
    "Dear %s, please confirm your booking" : "Cher %s, merci de confirmer votre réservation",
    "Confirm" : "Confirmer",
    "Appointment with:" : "Rendez-vous avec :",
    "Description:" : "Description :",
    "This confirmation link expires in %s hours." : "Ce lien de confirmation expire dans %s heures.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Si vous souhaitez finalement annuler le rendez-vous, merci de contacter l'organisateur en répondant à cet e-mail ou en visitant la page de son profil.",
    "Your appointment \"%s\" with %s has been accepted" : "Votre rendez-vous \"%s\" avec %s a été accepté",
    "Dear %s, your booking has been accepted." : "Cher %s, votre réservation a été acceptée.",
    "Appointment for:" : "Rendez-vous pour :",
    "Date:" : "Date :",
    "You will receive a link with the confirmation email" : "Vous allez recevoir un lien avec l'e-mail de confirmation",
    "Where:" : "Lieu :",
    "Comment:" : "Commentaire :",
    "You have a new appointment booking \"%s\" from %s" : "Vous avez un nouveau rendez-vous \"%s\" avec %s",
    "Dear %s, %s (%s) booked an appointment with you." : "Cher·ère %s, %s (%s) a pris rendez-vous avec vous.",
    "%s has proposed a meeting" : "%s a proposé une réunion",
    "%s has updated a proposed meeting" : "%s a mis à jour une réunion proposée",
    "%s has canceled a proposed meeting" : "%s a annulé une réunion proposée",
    "Dear %s, a new meeting has been proposed" : "Cher %s, une nouvelle réunion a été proposée",
    "Dear %s, a proposed meeting has been updated" : "Cher %s, une réunion proposée a été mise à jour",
    "Dear %s, a proposed meeting has been cancelled" : "Cher %s, une réunion proposée a été annulée",
    "Location:" : "Lieu :",
    "Duration:" : "Durée :",
    "%1$s from %2$s to %3$s" : "%1$s de %2$s à %3$s",
    "Dates:" : "Dates:",
    "Respond" : "Répondre",
    "A Calendar app for Nextcloud" : "Application Agenda pour Nextcloud",
    "A Calendar app for Nextcloud. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Like Contacts, Talk, Tasks, Deck and Circles\n* 🌐 **WebCal Support!** Want to see your favorite team's matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 **Search!** Find your events at ease\n* ☑️ **Tasks!** See tasks or Deck cards with a due date directly in the calendar\n* 🔈 **Talk rooms!** Create an associated Talk room when booking a meeting with just one click\n* 📆 **Appointment booking** Send people a link so they can book an appointment with you [using this app](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Attachments!** Add, upload and view event attachments\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Une application de calendrier pour Nextcloud. Synchronisez facilement les événements de vos différents appareils avec votre Nextcloud et modifiez-les en ligne.\n\n* 🚀 **Intégration avec d'autres applications Nextcloud !** Comme Contacts, Discussion, Tâches, Deck et Cercles\n* 🌐 **Prise en charge de WebCal !** Vous souhaitez consulter les jours de match de votre équipe préférée dans votre calendrier ? Aucun problème ! * \n🙋 **Participants !** Invitez des personnes à vos événements\n* ⌚ **Libre/Occupé !** Voyez quand vos participants sont disponibles pour une réunion\n* ⏰ **Rappels !** Recevez des alarmes pour les événements directement dans votre navigateur et par e-mail\n* 🔍 **Recherche !** Trouvez facilement vos événements\n* ☑️ **Tâches !** Consultez les tâches ou les cartes Deck avec une date d'échéance directement dans le calendrier\n* 🔈 **Salles de discussion !** Créez une salle de discussion associée lors de la réservation d'une réunion en un seul clic\n* 📆 **Prise de rendez-vous** Envoyez un lien aux personnes pour qu'elles puissent prendre rendez-vous avec vous [via cette application](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Pièces jointes !** Ajoutez, téléchargez et consultez les pièces jointes des événements\n* 🙈 **On ne réinvente pas la roue !** Basé sur le célèbre [c-dav] bibliothèque](https://github.com/nextcloud/cdav-library), bibliothèques [ical.js](https://github.com/mozilla-comm/ical.js) et [fullcalendar](https://github.com/fullcalendar/fullcalendar).",
    "Previous day" : "Jour précédent",
    "Previous week" : "Semaine précédente",
    "Previous year" : "Année préc.",
    "Previous month" : "Mois précédent",
    "Next day" : "Jour suivant",
    "Next week" : "Semaine prochaine",
    "Next year" : "Année suiv.",
    "Next month" : "Mois prochain",
    "Create new event" : "Créer un nouvel événement",
    "Event" : "Événement",
    "Today" : "Auj.",
    "Day" : "Jour",
    "Week" : "Semaine",
    "Month" : "Mois",
    "Year" : "Année",
    "List" : "Liste",
    "Appointment link was copied to clipboard" : "Le lien vers l'événement a été copié dans le presse-papiers",
    "Appointment link could not be copied to clipboard" : "Le lien vers l'événement n'a pas pu être copié dans le presse-papiers",
    "Preview" : "Prévisualiser",
    "Copy link" : "Copier le lien",
    "Edit" : "Modifier",
    "Delete" : "Supprimer",
    "Appointment schedules" : "Calendriers de rendez-vous",
    "Create new" : "Créer un nouveau",
    "Disable calendar \"{calendar}\"" : "Désactiver l'agenda \"{calendar}\"",
    "Disable untitled calendar" : "Désactiver agenda sans titre",
    "Enable calendar \"{calendar}\"" : "Activer l'agenda \"{calendar}\"",
    "Enable untitled calendar" : "Activer agenda sans titre",
    "An error occurred, unable to change visibility of the calendar." : "Une erreur est survenue, impossible de modifier la visibilité de l'agenda.",
    "Untitled calendar" : "Agenda sans titre",
    "Shared with you by" : "Partagé avec vous par",
    "Edit and share calendar" : "Éditer et partager l'agenda",
    "Edit calendar" : "Éditer l'agenda",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Suppression du partage de l'agenda dans {countdown} seconde","Suppression du partage de l'agenda dans {countdown} secondes","Suppression du partage de l'agenda dans {countdown} secondes"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Suppression de l'agenda dans {countdown} seconde","Suppression de l'agenda dans {countdown} secondes","Suppression de l'agenda dans {countdown} secondes"],
    "An error occurred, unable to create the calendar." : "Une erreur est survenue, impossible de créer l'agenda.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Veuillez saisir un lien valide (débutant par http://, https://, webcal:// ou webcals://)",
    "Calendars" : "Agendas",
    "Add new" : "Ajouter un nouveau",
    "New calendar" : "Nouvel agenda",
    "Name for new calendar" : "Nom du nouvel agenda",
    "Creating calendar …" : "Création de l'agenda …",
    "New calendar with task list" : "Nouvel agenda avec liste de tâches",
    "New subscription from link (read-only)" : "Nouvel abonnement par lien (lecture seule)",
    "Creating subscription …" : "Création de l'abonnement en cours ...",
    "Add public holiday calendar" : "Ajouter un calendrier des jours fériés",
    "Add custom public calendar" : "Ajouter un agenda public personnalisé",
    "Calendar link copied to clipboard." : "Lien de l'agenda copié dans le presse-papier.",
    "Calendar link could not be copied to clipboard." : "Impossible de copier le lien de l'agenda dans le presse-papier.",
    "Copy subscription link" : "Copier le lien d'inscription",
    "Copying link …" : "Copie du lien …",
    "Copied link" : "Lien copié",
    "Could not copy link" : "Impossible de copier le lien",
    "Export" : "Exporter",
    "Untitled item" : "Élément sans titre",
    "Unknown calendar" : "Agenda inconnu",
    "Could not load deleted calendars and objects" : "Impossible de charger les agendas et objets supprimés",
    "Could not delete calendar or event" : "Impossible de supprimer le calendrier ou l'événement",
    "Could not restore calendar or event" : "Impossible de restaurer l'agenda ou l'événement",
    "Do you really want to empty the trash bin?" : "Voulez-vous vraiment vider la corbeille ?",
    "Empty trash bin" : "Vider la corbeille",
    "Trash bin" : "Corbeille",
    "Loading deleted items." : "Chargement des éléments supprimés.",
    "You do not have any deleted items." : "Vous n'avez aucun élément supprimé.",
    "Name" : "Nom",
    "Deleted" : "Supprimé",
    "Restore" : "Restaurer",
    "Delete permanently" : "Supprimer définitivement",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Les éléments dans la corbeille sont supprimés après {numDays} jour","Les éléments dans la corbeille sont supprimés après {numDays} jours","Les éléments dans la corbeille sont supprimés après {numDays} jours"],
    "Could not update calendar order." : "Impossible de mettre à jour l'ordre des agendas.",
    "Shared calendars" : "Agendas partagés",
    "Deck" : "Deck",
    "Internal link" : "Lien interne",
    "A private link that can be used with external clients" : "Un lien privé qui peut être utilisé avec des clients externes",
    "Copy internal link" : "Copier le lien interne",
    "An error occurred, unable to publish calendar." : "Une erreur est survenue, impossible de publier l'agenda.",
    "An error occurred, unable to send email." : "Une erreur est survenue, impossible d’envoyer l'e-mail.",
    "Embed code copied to clipboard." : "Code d'intégration copié dans le presse-papier.",
    "Embed code could not be copied to clipboard." : "Le code d'intégration n'a pas pu être copié dans le presse-papier.",
    "Unpublishing calendar failed" : "Impossible de dé-publier l'agenda",
    "Share link" : "Lien de partage",
    "Copy public link" : "Copier le lien public",
    "Send link to calendar via email" : "Envoyer le lien vers l'agenda par e-mail",
    "Enter one address" : "Saisissez une adresse",
    "Sending email …" : "Envoi de l'e-mail...",
    "Copy embedding code" : "Copier le code d'intégration",
    "Copying code …" : "Copie du code …",
    "Copied code" : "Code copié",
    "Could not copy code" : "Impossible de copier le code",
    "Delete share link" : "Supprimer le lien de partage",
    "Deleting share link …" : "Suppression du lien partagé …",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Équipe)",
    "An error occurred while unsharing the calendar." : "Une erreur est survenue lors de l'annulation du partage de l'agenda.",
    "An error occurred, unable to change the permission of the share." : "Une erreur est survenue, impossible de changer la permission du partage.",
    "can edit and see confidential events" : "peut éditer et voir les événements confidentiels",
    "Unshare with {displayName}" : "Ne plus partager avec {displayName}",
    "Share with users or groups" : "Partager avec des utilisateurs ou des groupes",
    "No users or groups" : "Aucun utilisateur ni groupe",
    "Failed to save calendar name and color" : "Échec d'enregistrement du nom et de la couleur de l'agenda",
    "Calendar name …" : "Nom de l'agenda …",
    "Never show me as busy (set this calendar to transparent)" : "Ne jamais me considérer occupé (définir ce calendrier comme transparent)",
    "Share calendar" : "Partager l'agenda",
    "Unshare from me" : "Quitter ce partage",
    "Save" : "Enregistrer",
    "No title" : "Pas de titre",
    "Are you sure you want to delete \"{title}\"?" : "Êtes-vous sûr de vouloir supprimer \"{title}\"?",
    "Deleting proposal \"{title}\"" : "Suppression de la proposition \"{title}\"",
    "Successfully deleted proposal" : "Proposition supprimée avec succès",
    "Failed to delete proposal" : "Impossible de supprimer la proposition",
    "Failed to retrieve proposals" : "Impossible de récupérer les propositions",
    "Meeting proposals" : "Propositions de réunion",
    "A configured email address is required to use meeting proposals" : "Une adresse e-mail configurée est nécessaire pour utiliser les propositions de réunion",
    "No active meeting proposals" : "Aucune proposition de réunion active",
    "View" : "Voir",
    "Import calendars" : "Importer des agendas",
    "Please select a calendar to import into …" : "Veuillez sélectionner un agenda dans lequel importer  …",
    "Filename" : "Nom du fichier",
    "Calendar to import into" : "Agenda dans lequel importer",
    "Cancel" : "Annuler",
    "_Import calendar_::_Import calendars_" : ["Importer un agenda","Importer des agendas","Importer des agendas"],
    "Select the default location for attachments" : "Sélectionner l'emplacement par défaut pour les pièces jointes",
    "Pick" : "Choisir",
    "Invalid location selected" : "Emplacement sélectionné non valide",
    "Attachments folder successfully saved." : "Dossier par défaut des pièces jointes enregistré.",
    "Error on saving attachments folder." : "Erreur lors de l'enregistrement du dossier des pièces jointes.",
    "Attachments folder" : "Dossier des pièces jointes",
    "{filename} could not be parsed" : "{filename} n'a pas pu être analysé",
    "No valid files found, aborting import" : "Aucun fichier valide trouvé, annulation de l’importation",
    "_Successfully imported %n event_::_Successfully imported %n events_" : [" %n évènement importé avec succès","%n évènements importés avec succès","%n évènements importés avec succès"],
    "Import partially failed. Imported {accepted} out of {total}." : "Échec partiel de l’importation. Import de {accepted} sur {total}.",
    "Automatic" : "Automatique",
    "Automatic ({timezone})" : "Automatique ({timezone})",
    "New setting was not saved successfully." : "Le nouveau paramètre n'a pas pu être enregistré.",
    "Timezone" : "Fuseau horaire",
    "Navigation" : "Navigation",
    "Previous period" : "Période précédente",
    "Next period" : "Période suivante",
    "Views" : "Affichages",
    "Day view" : "Affichage jour",
    "Week view" : "Affichage semaine",
    "Month view" : "Affichage mois",
    "Year view" : "Affichage année",
    "List view" : "Vue en liste",
    "Actions" : "Actions",
    "Create event" : "Créer un événement",
    "Show shortcuts" : "Afficher les raccourcis",
    "Editor" : "Éditeur",
    "Close editor" : "Fermer l'éditeur",
    "Save edited event" : "Sauvegarder l'événement édité",
    "Delete edited event" : "Supprimer l'événement édité",
    "Duplicate event" : "Dupliquer l'événement",
    "or" : "ou",
    "Calendar settings" : "Paramètres de Agenda",
    "At event start" : "Au début de l'événement",
    "No reminder" : "Aucun rappel",
    "Failed to save default calendar" : "Échec d'enregistrement de l'agenda par défaut",
    "General" : "Général",
    "Availability settings" : "Paramètres de disponibilité",
    "CalDAV" : "CalDAV",
    "Access Nextcloud calendars from other apps and devices" : "Accéder aux calendriers Nextcloud depuis d'autres applications et appareils",
    "CalDAV URL" : "Adresse CalDAV",
    "Server Address for iOS and macOS" : "Adresse du serveur pour iOS et macOS",
    "Appearance" : "Apparence",
    "Birthday calendar" : "Calendrier des anniversaires",
    "Tasks in calendar" : "Tâches dans le calendrier",
    "Weekends" : "Fins de semaines",
    "Week numbers" : "Numéros de semaines",
    "Limit number of events shown in Month view" : "Limiter le nombre d'événements affichés dans la vue Mois",
    "Density in Day and Week View" : "Densité dans les vues Jour et Semaine",
    "Editing" : "Éditer",
    "Default reminder" : "Rappel par défaut",
    "Simple event editor" : "Éditeur d'événement simple",
    "\"More details\" opens the detailed editor" : "\"Plus de détails\" ouvre l'éditeur détaillé",
    "Files" : "Fichiers",
    "Appointment schedule successfully created" : "Création du calendrier de rendez-vous réussie",
    "Appointment schedule successfully updated" : "Mise à jour du calendrier de rendez-vous réussie",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minute","{duration} minutes","{duration} minutes"],
    "0 minutes" : "0 minutes",
    "_{duration} hour_::_{duration} hours_" : ["{duration} heure","{duration} heures","{duration} heures"],
    "_{duration} day_::_{duration} days_" : ["{duration} jour","{duration} jours","{duration} jours"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} semaine","{duration} semaines","{duration} semaines"],
    "_{duration} month_::_{duration} months_" : ["{duration} mois","{duration} mois","{duration} mois"],
    "_{duration} year_::_{duration} years_" : ["{duration} année","{duration} années","{duration} années"],
    "To configure appointments, add your email address in personal settings." : "Pour configurer les rendez-vous, ajouter votre adresse e-mail dans les paramètres personnels.",
    "Public – shown on the profile page" : "Public - affiché sur la page du profil",
    "Private – only accessible via secret link" : "Privé - uniquement accessible via un lien secret",
    "Appointment schedule saved" : "Calendrier de rendez-vous sauvegardé",
    "Create appointment schedule" : "Création d'un calendrier de rendez-vous",
    "Edit appointment schedule" : "Édition du calendrier de rendez-vous",
    "Update" : "Mettre à jour",
    "Appointment name" : "Nom du rendez-vous",
    "Location" : "Lieu",
    "Create a Talk room" : "Créer une salle de conversation",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Un lien unique sera généré pour chaque rendez-vous réservé et envoyé via l'e-mail de confirmation",
    "Description" : "Description",
    "Visibility" : "Visibilité",
    "Duration" : "Durée",
    "Increments" : "Incréments",
    "Additional calendars to check for conflicts" : "Agendas supplémentaires à vérifier pour les conflits",
    "Pick time ranges where appointments are allowed" : "Sélectionnez les plages de temps pendant lesquelles les rendez-vous sont autorisés",
    "to" : "à",
    "Delete slot" : "Supprimer le créneau",
    "No times set" : "Aucun horaire défini",
    "Add" : "Ajouter",
    "Monday" : "Lundi",
    "Tuesday" : "Mardi",
    "Wednesday" : "Mercredi",
    "Thursday" : "Jeudi",
    "Friday" : "Vendredi",
    "Saturday" : "Samedi",
    "Sunday" : "Dimanche",
    "Weekdays" : "Jours de la semaine",
    "Add time before and after the event" : "Ajouter du temps avant et après l'évènement",
    "Before the event" : "Avant l'évènement",
    "After the event" : "Après l'évènement",
    "Planning restrictions" : "Restrictions de planning",
    "Minimum time before next available slot" : "Intervalle minimum avant le prochain créneau disponible",
    "Max slots per day" : "Nombre maximum de créneaux par jour",
    "Limit how far in the future appointments can be booked" : "Limiter le délai dans lequel les rendez-vous futurs peuvent être pris.",
    "It seems a rate limit has been reached. Please try again later." : "Il semblerait qu'une limite de vitesse ait été atteinte. Veuillez réessayer plus tard.",
    "Please confirm your reservation" : "Veuillez confirmer votre réservation",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Nous vous avons envoyé un e-mail avec les détails. Veuillez confirmer votre rendez-vous en utilisant le lien dans l'e-mail. Vous pouvez maintenant fermer cette page.",
    "Your name" : "Votre nom",
    "Your email address" : "Votre e-mail",
    "Please share anything that will help prepare for our meeting" : "Merci de partager tout ce qui peut être utile à la préparation de notre réunion",
    "Could not book the appointment. Please try again later or contact the organizer." : "Impossible de réserver le rendez-vous. Veuillez réessayer plus tard ou contacter l'organisateur.",
    "Back" : "Retour",
    "Book appointment" : "Prendre rendez-vous",
    "Error fetching Talk conversations." : "Erreur lors du listage des salons de discussion Talk.",
    "Conversation does not have a valid URL." : "L'URL de la conversation n'est pas valide",
    "Successfully added Talk conversation link to location." : "Le lien de conversation Talk a été ajouté avec succès au lieu.",
    "Successfully added Talk conversation link to description." : "Le lien de conversation Talk a été ajouté avec succès à la description.",
    "Failed to apply Talk room." : "Impossible de modifier le salon de discussion Talk.",
    "Talk conversation for event" : "Conversation Talk pour l'événement",
    "Error creating Talk conversation" : "Erreur lors de la création de la conversation Talk",
    "Select a Talk Room" : "Choisissez un salon de discussion Talk",
    "Add Talk conversation" : "Ajouter une conversation Talk",
    "Fetching Talk rooms…" : "Chargement des salons de discussion Talk...",
    "No Talk room available" : "Aucun salon de discussion Talk disponible",
    "Create public conversation" : "Créer une conversation publique",
    "Select conversation" : "Sélectionnez une conversation",
    "on" : "le",
    "at" : "le",
    "before at" : "avant",
    "Notification" : "Notification",
    "Email" : "E-mail",
    "Audio notification" : "Notification sonore",
    "Other notification" : "Autre notification",
    "Relative to event" : "Par rapport à l’événement",
    "On date" : "À une date précise",
    "Edit time" : "Modifier le rappel",
    "Save time" : "Enregistrer le rappel",
    "Remove reminder" : "Retirer le rappel",
    "Add reminder" : "Ajouter un rappel",
    "seconds" : "secondes",
    "minutes" : "minutes",
    "hours" : "heures",
    "days" : "jours",
    "weeks" : "semaines",
    "Choose a file to add as attachment" : "Choisissez un fichier à ajouter en pièce jointe",
    "Choose a file to share as a link" : "Sélectionnez un fichier à partager par lien",
    "Attachment {name} already exist!" : "La pièce jointe {name} existe déjà !",
    "Could not upload attachment(s)" : "Impossible de téléverser la/les pièce(s) jointe(s)",
    "You are about to navigate to {link}. Are you sure to proceed?" : "Vous êtes sur le point de visiter le site {link}. Êtes vous sûr de le vouloir ?",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Vous êtes sur le point de naviguer vers {host}. Êtes-vous sûr de vouloir continuer ? Lien : {link}",
    "Proceed" : "Continuer",
    "No attachments" : "Pas de pièce jointe",
    "Add from Files" : "Ajouter depuis Fichiers",
    "Upload from device" : "Téléverser depuis l'appareil",
    "Delete file" : "Supprimer le fichier",
    "Confirmation" : "Confirmation",
    "_{count} attachment_::_{count} attachments_" : ["{count} pièce jointe","{count} pièces jointes","{count}  pièces jointes"],
    "Suggested" : "Suggéré",
    "Available" : "Disponible",
    "Invitation accepted" : "Invitation acceptée",
    "Accepted {organizerName}'s invitation" : "Invitation de {organizerName} acceptée",
    "Participation marked as tentative" : "Participation marquée comme provisoire",
    "Invitation is delegated" : "L'invitation est déléguée",
    "Not available" : "Non disponible",
    "Invitation declined" : "Invitation déclinée",
    "Declined {organizerName}'s invitation" : "Invitation de {organizerName} déclinée",
    "Availability will be checked" : "La disponibilité sera vérifiée",
    "Invitation will be sent" : "Les invitations seront envoyées",
    "Failed to check availability" : "Échec de vérification de disponiblité",
    "Failed to deliver invitation" : "Échec de l'envoi de l'invitation",
    "Awaiting response" : "En attente de la réponse",
    "Checking availability" : "Vérification de la disponiblité",
    "Has not responded to {organizerName}'s invitation yet" : "N'a pas encore répondu à l'invitation de {organizerName}",
    "Suggested times" : "Horaires suggérés",
    "chairperson" : "président",
    "required participant" : "participant obligatoire",
    "non-participant" : "ne participe pas",
    "optional participant" : "participant facultatif",
    "{organizer} (organizer)" : "{organizer} (organizer)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Selected slot" : "Créneau sélectionné",
    "Availability of attendees, resources and rooms" : "Disponibilités des participants, ressources et salles.",
    "Suggestion accepted" : "Suggestion acceptée",
    "Previous date" : "Date précédente",
    "Next date" : "Date suivante",
    "Legend" : "Légende",
    "Out of office" : "Absent du bureau",
    "Attendees:" : "Participants :",
    "local time" : "heure locale",
    "Done" : "Terminé",
    "Search room" : "Chercher une salle",
    "Room name" : "Nom de la salle",
    "Check room availability" : "Vérifier la disponibilité de la salle",
    "Free" : "Libre",
    "Busy (tentative)" : "Occupé (provisoire)",
    "Busy" : "Occupé",
    "Unknown" : "Inconnu",
    "Find a time" : "Trouver un horaire",
    "The invitation has been accepted successfully." : "L'invitation a été acceptée.",
    "Failed to accept the invitation." : "Échec lors de l'acceptation de l'invitation.",
    "The invitation has been declined successfully." : "L'invitation a été déclinée.",
    "Failed to decline the invitation." : "Impossible de décliner l'invitation.",
    "Your participation has been marked as tentative." : "Votre participation a été marquée comme provisoire",
    "Failed to set the participation status to tentative." : "Erreur en voulant mettre votre participation comme provisoire.",
    "Accept" : "Accepter",
    "Decline" : "Décliner",
    "Tentative" : "Provisoire",
    "No attendees yet" : "Aucun participant pour l'instant",
    "{confirmedCount} confirmed, {waitingCount} awaiting response" : "{confirmedCount} confirmé(s), {waitingCount} en attente de réponse",
    "Please add at least one attendee to use the \"Find a time\" feature." : "Veuillez ajouter au moins un participant pour utiliser la fonction « Trouver un horaire ».",
    "Attendees" : "Participants",
    "_%n more attendee_::_%n more attendees_" : ["%n autre participant","%n autres participants","%n autres participants"],
    "Remove group" : "Retirer le groupe",
    "Remove attendee" : "Retirer le participant",
    "Request reply" : "Demander une réponse",
    "Chairperson" : "Président",
    "Required participant" : "Participant obligatoire",
    "Optional participant" : "Participant facultatif",
    "Non-participant" : "Ne participe pas",
    "_%n member_::_%n members_" : ["%n membre","%n membres","%n membres"],
    "Search for emails, users, contacts, contact groups or teams" : "Rechercher des e-mails, des utilisateurs, des contacts, des groupes de contacts ou des équipes",
    "No match found" : "Aucun résultat trouvé",
    "Note that members of circles get invited but are not synced yet." : "Notez que les membres des cercles sont invités mais ne sont pas encore synchronisés.",
    "Note that members of contact groups get invited but are not synced yet." : "Notez que les membres des groupes de contact sont invités mais ne sont pas encore synchronisés.",
    "(organizer)" : "(organisateur)",
    "Make {label} the organizer" : "Faire de {label} l'organisateur",
    "Make {label} the organizer and attend" : "Faire de {label} l'organisateur et le participant",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Pour envoyer des invitations et en gérer les réponses, [linkopen]ajoutez votre adresse e-mail dans vos paramètres personnels[linkclose].",
    "Remove color" : "Retirer la couleur",
    "Event title" : "Titre de l'événement",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Impossible de modifier le paramètre de la journée entière pour les événements qui font partie d'un ensemble de récurrences.",
    "From" : "De",
    "To" : "À",
    "Your Time" : "Heure locale",
    "Repeat" : "Répéter",
    "Repeat event" : "Répéter l'événement",
    "_time_::_times_" : ["fois","fois","fois"],
    "never" : "jamais",
    "on date" : "à une date précise",
    "after" : "après ",
    "End repeat" : "Arrêter la répétition",
    "Select to end repeat" : "Sélectionner pour terminer la répétition",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Cet événement est une exception dans un ensemble de récurrences. Vous ne pouvez pas y ajouter une règle de récurrence.",
    "first" : "premier",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Les modifications apportées à la règle de récurrence ne s’appliqueront qu’à cet événement et à tous les événements futurs.",
    "Repeat every" : "Répéter chaque",
    "By day of the month" : "Par jour du mois",
    "On the" : "Le",
    "_day_::_days_" : ["jour","jours","jours"],
    "_week_::_weeks_" : ["semaine","semaines","semaines"],
    "_month_::_months_" : ["mois","mois","mois"],
    "_year_::_years_" : ["année","années","années"],
    "On specific day" : "Un jour précis",
    "weekday" : "jour de la semaine",
    "weekend day" : "jour de weekend",
    "Does not repeat" : "Ne se répète pas.",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "La définition de la récurrence de cet événement n’est pas entièrement prise en charge par Nextcloud. Si vous modifiez les options de récurrence, certaines récurrences peuvent être perdues.",
    "No rooms or resources yet" : "Aucun lieu ou ressource pour le moment",
    "Resources" : "Ressources",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} place assise","{seatingCapacity} places assises","{seatingCapacity} places assises"],
    "Add resource" : "Ajouter une ressource",
    "Has a projector" : "Dispose d'un vidéoprojecteur",
    "Has a whiteboard" : "Dispose d'un tableau blanc",
    "Wheelchair accessible" : "Accessible en fauteuil roulant",
    "Remove resource" : "Retirer la ressource",
    "Search for resources or rooms" : "Rechercher une ressource ou un lieu",
    "available" : "disponible",
    "unavailable" : "indisponible",
    "Show all rooms" : "Montrer toutes les salles",
    "Projector" : "Vidéoprojecteur",
    "Whiteboard" : "Tableau blanc",
    "Room type" : "Type de salle",
    "Any" : "Toutes",
    "Minimum seating capacity" : "Nombre minimum de places assises",
    "More details" : "Plus de détails",
    "Update this and all future" : "Mettre à jour cette occurrence et toutes les prochaines",
    "Update this occurrence" : "Mettre à jour cette occurrence",
    "Public calendar does not exist" : "L'agenda public n'existe pas",
    "Maybe the share was deleted or has expired?" : "Le partage a expiré ou a été supprimé ?",
    "Remove date" : "Supprimer la date",
    "Attendance required" : "Présence obligatoire",
    "Attendance optional" : "Présence facultative",
    "Remove participant" : "Retirer le participant",
    "Yes" : "Oui",
    "No" : "Non",
    "Maybe" : "Peut-être",
    "None" : "Aucun",
    "Select your meeting availability" : "Sélectionnez vos disponibilités pour les réunions",
    "Create a meeting for this date and time" : "Créer une réunion pour cette date et heure",
    "Create" : "Créer",
    "No participants or dates available" : "Aucun participant ou date disponible",
    "from {formattedDate}" : "du {formattedDate}",
    "to {formattedDate}" : "au {formattedDate}",
    "on {formattedDate}" : "le {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "du {formattedDate} à {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "au {formattedDate} à {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "le {formattedDate} à {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} à {formattedTime}",
    "Please enter a valid date" : "Veuillez saisir une date valide",
    "Please enter a valid date and time" : "Veuillez saisir une date et une heure valides",
    "Select a time zone" : "Sélectionner un fuseau horaire",
    "Please select a time zone:" : "Veuillez sélectionner un fuseau horaire : ",
    "Pick a time" : "Indiquer une heure",
    "Pick a date" : "Indiquer une date",
    "Type to search time zone" : "Commencer la saisie pour rechercher le fuseau horaire",
    "Global" : "Général",
    "Holidays in {region}" : "Jours fériés {region}",
    "An error occurred, unable to read public calendars." : "Une erreur est survenue, impossible de lire les agendas publics.",
    "An error occurred, unable to subscribe to calendar." : "Une erreur est survenue, impossible de s'abonner à l'agenda.",
    "Public holiday calendars" : "Calendriers des jours fériés",
    "Public calendars" : "Agendas publics",
    "No valid public calendars configured" : "Aucun agenda public valide configuré",
    "Speak to the server administrator to resolve this issue." : "Discutez avec l'administrateur du serveur pour résoudre ce problème.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Les calendriers des jours fériés sont fournis par Thunderbird. Les données du calendrier seront téléchargées depuis {website}",
    "These public calendars are suggested by the server administrator. Calendar data will be downloaded from the respective website." : "Ces calendriers publics sont proposés par l'administrateur du serveur. Les données du calendrier seront téléchargées à partir du site web correspondant.",
    "By {authors}" : "Par {authors}",
    "Subscribed" : "Abonné",
    "Subscribe" : "S'abonner",
    "Could not fetch slots" : "Impossible de récupérer les créneaux",
    "Select a date" : "Sélectionner une date",
    "Select slot" : "Sélectionnez le créneau",
    "No slots available" : "Aucun créneau disponible",
    "The slot for your appointment has been confirmed" : "Le créneau pour votre rendez-vous a été confirmé",
    "Appointment Details:" : "Détails du rendez-vous :",
    "Time:" : "Horaire :",
    "Booked for:" : "Réservé pour :",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Merci. Votre réservation de {startDate} à {endDate} a été confirmée.",
    "Book another appointment:" : "Réserver un autre rendez-vous :",
    "See all available slots" : "Voir tous les créneaux disponibles",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Le créneau pour votre rendez-vous du {startDate} au {endDate} n'est plus disponible.",
    "Please book a different slot:" : "Merci de réserver un autre créneau :",
    "Book an appointment with {name}" : "Réserver un rendez-vous avec {name}",
    "No public appointments found for {name}" : "Aucun rendez-vous public trouvé pour {name}",
    "Personal" : "Personnel",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "La détection automatique a déterminé que votre fuseau horaire était UTC.\nIl s'agit très probablement du résultat des mesures de sécurité de votre navigateur Web.\nVeuillez régler votre fuseau horaire manuellement dans les paramètres de Agenda.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Le fuseau horaire configuré ({timezoneId}) n'a pas été trouvé. Retour à l'UTC.\nVeuillez modifier votre fuseau horaire dans les paramètres et signaler ce problème.",
    "Show unscheduled tasks" : "Afficher les tâches non planifiées",
    "Unscheduled tasks" : "Tâches non planifiées",
    "Availability of {displayName}" : "Disponibilité de {displayName}",
    "Discard event" : "Annuler l'évènement",
    "Edit event" : "Modifier l'événement",
    "Event does not exist" : "L'événement n'existe pas",
    "Duplicate" : "Dupliquer",
    "Delete this occurrence" : "Supprimer cette occurrence",
    "Delete this and all future" : "Supprimer cette occurrence et toutes les prochaines",
    "All day" : "Journée entière",
    "Modifications wont get propagated to the organizer and other attendees" : "Les modifications ne sont pas transmises à l'organisateur et aux autres participants",
    "Managing shared access" : "Gestion des accès partagés",
    "Deny access" : "Refuser l'accès",
    "Invite" : "Inviter",
    "Discard changes?" : "Abandonner les modifications ?",
    "Are you sure you want to discard the changes made to this event?" : "Êtes-vous sûr de vouloir ignorer les modifications apportées à cet événement ?",
    "_User requires access to your file_::_Users require access to your file_" : ["Un utilisateur requiert un accès à votre fichier","Des utilisateurs requièrent un accès à votre fichier","Des utilisateurs requièrent un accès à votre fichier"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Pièce jointe nécessitant un accès partagé","Pièces jointes nécessitant un accès partagé","Pièces jointes nécessitant un accès partagé"],
    "Untitled event" : "Événement sans titre",
    "Close" : "Fermer",
    "Modifications will not get propagated to the organizer and other attendees" : "Les modifications ne seront pas transmises à l'organisateur et aux autres participants",
    "Meeting proposals overview" : "Aperçu des propositions de réunion",
    "Edit meeting proposal" : "Modifier la proposition de réunion",
    "Create meeting proposal" : "Créer une proposition de réunion",
    "Update meeting proposal" : "Mettre à jour la proposition de réunion",
    "Saving proposal \"{title}\"" : "Enregistrement de la proposition \"{title}\"",
    "Successfully saved proposal" : "Proposition enregistrée avec succès",
    "Failed to save proposal" : "Impossible d'enregistrer la proposition",
    "Create a meeting for \"{date}\"? This will create a calendar event with all participants." : "Créer une réunion pour le {date} ? Cela créera un événement dans le calendrier avec tous les participants.",
    "Creating meeting for {date}" : "Création d'une réunion le {date}",
    "Successfully created meeting for {date}" : "Réunion créée avec succès le {date}",
    "Failed to create a meeting for {date}" : "Impossible de créer une réunion le {date}",
    "Please enter a valid duration in minutes." : "Veuillez saisir une durée valide en minutes.",
    "Failed to fetch proposals" : "Impossible de récupérer les propositions",
    "Failed to fetch free/busy data" : "Impossible de récupérer les informations de disponibilité",
    "Selected" : "Sélectionné",
    "No Description" : "Pas de description",
    "No Location" : "Pas de lieu",
    "Edit this meeting proposal" : "Modifier cette proposition de réunion",
    "Delete this meeting proposal" : "Supprimer cette proposition de réunion",
    "Title" : "Titre",
    "15 min" : "15 min",
    "30 min" : "30 min",
    "60 min" : "60 min",
    "90 min" : "90 min",
    "Participants" : "Participants",
    "Selected times" : "Horaires sélectionnés",
    "Previous span" : "Intervalle précédent",
    "Next span" : "Intervalle suivant",
    "Less days" : "Moins de jours",
    "More days" : "Plus de jours",
    "Loading meeting proposal" : "Chargement des propositions de réunions",
    "No meeting proposal found" : "Aucune proposition de réunion",
    "Please wait while we load the meeting proposal." : "Veuillez patienter pendant le chargement de la proposition de réunion.",
    "The link you followed may be broken, or the meeting proposal may no longer exist." : "Le lien est peut-être rompu, ou la proposition de réunion n'existe plus.",
    "Thank you for your response!" : "Merci pour votre réponse !",
    "Your vote has been recorded. Thank you for participating!" : "Votre vote a été enregistré. Merci d'avoir participé !",
    "Unknown User" : "Utilisateur inconnu",
    "No Title" : "Aucun titre",
    "No Duration" : "Aucune durée",
    "Select a different time zone" : "Sélectionner un autre fuseau horaire",
    "Submit" : "Envoyer",
    "Subscribe to {name}" : "S'abonner à {name}",
    "Export {name}" : "Exporter {name}",
    "Show availability" : "Afficher les disponibilités",
    "Anniversary" : "Anniversaire",
    "Appointment" : "Rendez-vous",
    "Business" : "Entreprise",
    "Education" : "Éducation",
    "Holiday" : "Vacances",
    "Meeting" : "Réunion",
    "Miscellaneous" : "Divers",
    "Non-working hours" : "Heures non travaillées",
    "Not in office" : "Absent du bureau",
    "Phone call" : "Appel téléphonique",
    "Sick day" : "Maladie",
    "Special occasion" : "Occasion spéciale",
    "Travel" : "Voyage",
    "Vacation" : "Congé",
    "Midnight on the day the event starts" : "Dès minuit, le jour de l'évènement",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n jour avant l'évènement, à {formattedHourMinute}","%n jours avant l'évènement, à {formattedHourMinute}","%n jours avant l'évènement, à {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n semaine avant l'évènement, à {formattedHourMinute}","%n semaines avant l'évènement, à {formattedHourMinute}","%n semaines avant l'évènement, à {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "le jour de l'évènement, à {formattedHourMinute}",
    "at the event's start" : "au début de l'évènement",
    "at the event's end" : "à la fin de l'évènement",
    "{time} before the event starts" : "{time} avant le début de l'évènement",
    "{time} before the event ends" : "{time} avant la fin de l'évènement",
    "{time} after the event starts" : "{time} après le début de l'évènement",
    "{time} after the event ends" : "{time} après la fin de l'évènement",
    "on {time}" : "le {time}",
    "on {time} ({timezoneId})" : "le {time} ({timezoneId})",
    "Week {number} of {year}" : "Semaine {number} de {year}",
    "Daily" : "Journalier",
    "Weekly" : "Hebdomadaire",
    "Monthly" : "Mensuel",
    "Yearly" : "Annuel",
    "_Every %n day_::_Every %n days_" : ["Tout les %n jour","Tous les %n jours","Tous les %n jours"],
    "_Every %n week_::_Every %n weeks_" : ["Toute les %n semaine","Toutes les %n semaines","Toutes les %n semaines"],
    "_Every %n month_::_Every %n months_" : ["Tous les %n mois","Tous les %n mois","Tous les %n mois"],
    "_Every %n year_::_Every %n years_" : ["Tous les %n ans","Tous les %n ans","Tous les %n ans"],
    "_on {weekday}_::_on {weekdays}_" : ["le {weekday}","les {weekdays}","les {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["le {dayOfMonthList}","les {dayOfMonthList}","les {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "le {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {dayOfMonthList}" : "en {monthNames} le {dayOfMonthList}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "en {monthNames}, le {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "jusqu'au {untilDate}",
    "_%n time_::_%n times_" : ["%n fois","%n fois","%n fois"],
    "second" : "seconde",
    "third" : "troisième",
    "fourth" : "quatrième",
    "fifth" : "cinquième",
    "second to last" : "avant-dernier",
    "last" : "dernier",
    "Untitled task" : "Tâche sans titre",
    "Please ask your administrator to enable the Tasks App." : "Veuillez demander à votre administrateur d’activer l'application Tasks.",
    "You are not allowed to edit this event as an attendee." : "Vous n'êtes pas autorisé à modifier cet événement en tant que participant.",
    "W" : "S",
    "%n more" : "%n de plus",
    "No events to display" : "Aucun événement à afficher",
    "All participants declined" : "Tous les participants ont décliné",
    "Please confirm your participation" : "Veuillez confirmer votre participation",
    "You declined this event" : "Vous avez décliné cet événement",
    "Your participation is tentative" : "Votre participation est provisoire",
    "_+%n more_::_+%n more_" : ["+%n de plus","+%n de plus","+%n de plus"],
    "No events" : "Pas d'évènements",
    "Create a new event or change the visible time-range" : "Créer un nouvel évènement ou modifier la période visible",
    "Failed to save event" : "Échec de la sauvegarde de l'événement",
    "It might have been deleted, or there was a typo in a link" : "Il a peut-être été supprimé, ou il y a une erreur dans le lien",
    "It might have been deleted, or there was a typo in the link" : "Il a peut-être été supprimé, ou il y a une erreur dans le lien",
    "Meeting room" : "Salle de réunion",
    "Lecture hall" : "Salle de lecture",
    "Seminar room" : "Salle de séminaire",
    "Other" : "Autre",
    "When shared show" : "Si partagé, afficher",
    "When shared show full event" : "Si partagé, afficher l'évènement entier",
    "When shared show only busy" : "Si partagé, afficher seulement comme occupé",
    "When shared hide this event" : "Si partagé, masquer l'évènement",
    "The visibility of this event in read-only shared calendars." : "La visibilité de cet événement dans les calendriers partagés en lecture seule.",
    "Add a location" : "Ajouter un lieu",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Ajouter une description\n\n- Sur quoi porte cette réunion\n- Points à l'ordre du jour\n- Tout ce que les participants doivent préparer",
    "Status" : "Statut",
    "Confirmed" : "Confirmé",
    "Canceled" : "Annulé",
    "Confirmation about the overall status of the event." : "Confirmation du statut de l'évènement.",
    "Show as" : "Afficher comme",
    "Take this event into account when calculating free-busy information." : "Prendre en compte cet évènement dans le calcul du temps de disponibilité.",
    "Categories" : "Catégories",
    "Categories help you to structure and organize your events." : "Les catégories vous aident à structurer vos évènements.",
    "Search or add categories" : "Rechercher ou ajouter des catégories",
    "Add this as a new category" : "Ajouter comme nouvelle catégorie",
    "Custom color" : "Couleur personnalisée",
    "Special color of this event. Overrides the calendar-color." : "Couleur de l'évènement. Remplace la couleur de l'agenda.",
    "Error while sharing file" : "Erreur lors du partage du fichier",
    "Error while sharing file with user" : "Erreur lors du partage du fichier avec un utilisateur",
    "Error creating a folder {folder}" : "Erreur lors de la création d'un dossier {folder}",
    "Attachment {fileName} already exists!" : "La pièce jointe {fileName} existe déjà !",
    "Attachment {fileName} added!" : "Pièce jointe {fileName} ajoutée !",
    "An error occurred during uploading file {fileName}" : "Une erreur est survenue lors de l'envoi du fichier {fileName}",
    "An error occurred during getting file information" : "Une erreur est survenue lors de la récupération des informations du fichier",
    "An error occurred, unable to delete the calendar." : "Une erreur est survenue, impossible de supprimer l'agenda.",
    "Imported {filename}" : "{filename} importé",
    "This is an event reminder." : "Ceci est un rappel d'événement.",
    "Error while parsing a PROPFIND error" : "Erreur lors de l'analyse d'une erreur PROPFIND",
    "Appointment not found" : "Rendez-vous non trouvé",
    "User not found" : "Utilisateur non trouvé",
    "Hidden" : "Cachés",
    "can edit" : "peut modifier",
    "Calendar name …" : "Nom de l'agenda ...",
    "Default attachments location" : "Emplacement par défaut des pièces jointes",
    "Automatic ({detected})" : "Automatique ({detected})",
    "Shortcut overview" : "Aperçu des raccourcis",
    "CalDAV link copied to clipboard." : "Lien CalDAV copié dans le presse-papier.",
    "CalDAV link could not be copied to clipboard." : "Impossible de copier le lien CalDAV dans le presse-papier.",
    "Enable birthday calendar" : "Activer l'agenda des anniversaires",
    "Show tasks in calendar" : "Afficher les tâches dans l'agenda",
    "Enable simplified editor" : "Activer l'éditeur simplifié",
    "Limit the number of events displayed in the monthly view" : "Limiter le nombre d'évènements affichés dans la vue mensuelle",
    "Show weekends" : "Afficher les week-ends",
    "Show week numbers" : "Afficher les numéros de semaine",
    "Time increments" : "Incréments de temps",
    "Default calendar for incoming invitations" : "Agenda par défaut pour les invitations entrantes",
    "Copy primary CalDAV address" : "Copier l'adresse CalDAV principale",
    "Copy iOS/macOS CalDAV address" : "Copier l'adresse CalDAV pour iOS/macOS",
    "Personal availability settings" : "Paramètres de disponibilités personnelles",
    "Show keyboard shortcuts" : "Afficher les raccourcis clavier",
    "Create a new public conversation" : "Créer une nouvelle conversation publique",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} invité(s), {confirmedCount} confirmé(s)",
    "Successfully appended link to talk room to location." : "Le lien vers la salle de réunion a été ajouté avec succès au lieu.",
    "Successfully appended link to talk room to description." : "Le lien vers la discussion a été ajouté à la description",
    "Error creating Talk room" : "Erreur lors de la création de la salle de discussion",
    "_%n more guest_::_%n more guests_" : ["%n invité de plus","%n invités de plus  ","%n invités en plus"],
    "The visibility of this event in shared calendars." : "Visibilité de cet évènement dans les agendas partagés."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
