OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Annettu sähköpostiosoite on liian pitkä",
    "User-Session unexpectedly expired" : "Käyttäjäistunto vanheni odottamatta",
    "Provided email-address is not valid" : "Sähköpostiosoite on virheellinen",
    "%s has published the calendar »%s«" : "%s on julkaissut kalenterin  »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Odottamaton virhe sähköpostia lähettäessä. Ole yhteydessä ylläpitoon.",
    "Successfully sent email to %1$s" : "Sähköposti lähetetty taholle %1$s",
    "Hello," : "Hei",
    "We wanted to inform you that %s has published the calendar »%s«." : "Halusimme ilmoittaa, että %s on julkaissut kalenterin »%s«.",
    "Open »%s«" : "Avaa »%s«",
    "Cheers!" : "Kiitos!",
    "Upcoming events" : "Tulevat tapahtumat",
    "No more events today" : "Ei enempää tapahtumia tänään",
    "No upcoming events" : "Ei tulevia tapahtumia",
    "More events" : "Lisää tapahtumia",
    "Calendar" : "Kalenteri",
    "New booking {booking}" : "Uusi varaus {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) varasi tapaamisen \"{config_display_name}\" {date_time}.",
    "Appointments" : "Tapaamiset",
    "Schedule appointment \"%s\"" : "Ajoita tapaaminen \"%s\"",
    "Schedule an appointment" : "Ajoita tapaaminen",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : "Valmistaudu tapahtumaan \"%s\"",
    "Your appointment \"%s\" with %s needs confirmation" : "Tapaaminen \"%s\"  henkilön %s kanssa vaatii vahvistamisen",
    "Dear %s, please confirm your booking" : "%s, ole hyvä ja vahvista varauksesi",
    "Confirm" : "Vahvista",
    "Description:" : "Kuvaus:",
    "This confirmation link expires in %s hours." : "Tämä vahvistuslinkki umpeutuu %s tunnin kuluttua.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Jos kaikesta huolimatta haluat perua tapaamiseen, ota yhteys järjestäjään vastaamalla tähän viestiin tai käymällä hänen profiilisivullaan.",
    "Your appointment \"%s\" with %s has been accepted" : "Tapaaminen \"%s\" henkilön %s kanssa on hyväksytty",
    "Dear %s, your booking has been accepted." : "%s, varauksesi on hyväksytty.",
    "Date:" : "Päivämäärä:",
    "You will receive a link with the confirmation email" : "Saat linkin vahvistussähköpostissa",
    "Where:" : "Paikka:",
    "Comment:" : "Kommentti:",
    "You have a new appointment booking \"%s\" from %s" : "Sinulla on uusi tapaamisvaraus \"%s\" henkilöltä %s",
    "Dear %s, %s (%s) booked an appointment with you." : "%s, %s (%s) varasi tapaamisen kanssasi.",
    "%s has proposed a meeting" : "%s ehdotti tapaamista",
    "%s has updated a proposed meeting" : "%s päivitti kokousehdotuksen",
    "%s has canceled a proposed meeting" : "%s perui kokousehdotuksen",
    "Dear %s, a new meeting has been proposed" : "%s, uutta kokousta on ehdotettu",
    "Dear %s, a proposed meeting has been updated" : "%s, ehdotettu kokous on päivitetty",
    "Dear %s, a proposed meeting has been cancelled" : "%s, ehdotettu kokous on peruttu",
    "Location:" : "Sijainti:",
    "Duration:" : "Kesto:",
    "Dates:" : "Päivät:",
    "Respond" : "Vastaa",
    "A Calendar app for Nextcloud" : "Kalenterisovellus Nextcloudille",
    "Previous day" : "Edellinen päivä",
    "Previous week" : "Edellinen viikko",
    "Previous year" : "Edellinen vuosi",
    "Previous month" : "Edellinen kuukausi",
    "Next day" : "Seuraava päivä",
    "Next week" : "Seuraava viikko",
    "Next year" : "Seuraava vuosi",
    "Next month" : "Seuraava kuukausi",
    "Create new event" : "Luo uusi tapahtuma",
    "Event" : "Tapahtuma",
    "Today" : "Tänään",
    "Day" : "Päivä",
    "Week" : "Viikko",
    "Month" : "Kuukausi",
    "Year" : "Vuosi",
    "List" : "Lista",
    "Appointment link was copied to clipboard" : "Linkki tapaamiseen kopioitiin leikepöydälle",
    "Appointment link could not be copied to clipboard" : "Linkkiä tapaamiseen ei voitu kopioida leikepöydälle",
    "Preview" : "Esikatselu",
    "Copy link" : "Kopioi linkki",
    "Edit" : "Muokkaa",
    "Delete" : "Poista",
    "Appointment schedules" : "Tapaamisaikataulut",
    "Create new" : "Luo uusi",
    "Disable calendar \"{calendar}\"" : "Poista käytöstä kalenteri \"{calendar}\"",
    "Disable untitled calendar" : "Poista nimetön kalenteri käytöstä",
    "Enable calendar \"{calendar}\"" : "Ota käyttöön kalenteri \"{calendar}\"",
    "Enable untitled calendar" : "Ota nimetön kalenteri käyttöön",
    "An error occurred, unable to change visibility of the calendar." : "Tapahtui virhe. Kalenterin näkyvyyttä ei voitu muuttaa.",
    "Untitled calendar" : "Nimetön kalenteri",
    "Shared with you by" : "Jaettu sinulle käyttäjältä",
    "Edit and share calendar" : "Muokkaa/jaa kalenteri",
    "Edit calendar" : "Muokkaa kalenteria",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Poistetaan kalenterin jako {countdown} sekunnin kuluttua","Poistetaan kalenterin jako {countdown} sekunnin kuluttua"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Poistetaan kalenteri {countdown} sekunnin kuluttua","Poistetaan kalenteri {countdown} sekunnin kuluttua"],
    "An error occurred, unable to create the calendar." : "Tapahtui virhe, kalenteria ei voitu luoda.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Anna kelvollinen linkki (alkaen http://, https://, webcal:// tai webcals://)",
    "Calendars" : "Kalenterit",
    "Add new" : "Lisää uusi",
    "New calendar" : "Uusi kalenteri",
    "Name for new calendar" : "Uuden kalenterin nimi",
    "Creating calendar …" : "Luodaan kalenteri …",
    "New calendar with task list" : "Uusi kalenteri tehtävälistan kera",
    "New subscription from link (read-only)" : "Uusi tilaus linkistä (vain luku)",
    "Creating subscription …" : "Luodaan tilaus …",
    "Add public holiday calendar" : "Lisää juhlapäiväkalenteri",
    "Add custom public calendar" : "Lisää mukautettu julkinen kalenteri",
    "Calendar link copied to clipboard." : "Kalenterilinkki kopioitu leikepöydälle.",
    "Calendar link could not be copied to clipboard." : "Kalenterilinkkiä ei voitu kopioida leikepöydälle.",
    "Copy subscription link" : "Kopioi tilauslinkki",
    "Copying link …" : "Kopioidaan linkki …",
    "Copied link" : "Linkki kopioitu",
    "Could not copy link" : "Linkkiä ei voitu kopioida",
    "Export" : "Vie",
    "Untitled item" : "Nimetön kohde",
    "Unknown calendar" : "Tuntematon kalenteri",
    "Could not load deleted calendars and objects" : "Poistettuja kalentereita tai objekteja ei voitu ladata",
    "Could not delete calendar or event" : "Kalenteria tai tapahtumaa ei voitu poistaa",
    "Could not restore calendar or event" : "Kalenteria tai tapahtumaa ei voitu palauttaa",
    "Do you really want to empty the trash bin?" : "Haluatko varmasti tyhjentää roskakorin?",
    "Empty trash bin" : "Tyhjennä roskakori",
    "Trash bin" : "Roskakori",
    "Loading deleted items." : "Ladataan poistettuja kohteita.",
    "You do not have any deleted items." : "Sinulla ei ole poistettuja kohteita.",
    "Name" : "Nimi",
    "Deleted" : "Poistettu",
    "Restore" : "Palauta",
    "Delete permanently" : "Poista pysyvästi",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Roskakorissa olevat kohteet poistetaan {numDays} päivän jälkeen","Roskakorissa olevat kohteet poistetaan {numDays} päivän jälkeen"],
    "Could not update calendar order." : "Kalenterin järjestystä ei voitu päivittää.",
    "Shared calendars" : "Jaetut kalenterit",
    "Deck" : "Pakka",
    "Internal link" : "Sisäinen linkki",
    "A private link that can be used with external clients" : "Yksityinen linkki, jota voi käyttää ulkoisten asiakkaiden kanssa",
    "Copy internal link" : "Kopioi sisäinen linkki",
    "An error occurred, unable to publish calendar." : "Tapahtui virhe, kalenterin julkaiseminen ei onnistu.",
    "An error occurred, unable to send email." : "Tapahtui virhe. Sähköpostia ei voitu lähettää.",
    "Embed code copied to clipboard." : "Upotuskoodi kopioitu leikepöydälle.",
    "Embed code could not be copied to clipboard." : "Upotuskoodia ei voitu kopioida leikepöydälle.",
    "Unpublishing calendar failed" : "Kalenterin julkaisun peruminen epäonnistui",
    "Share link" : "Jaa linkki",
    "Copy public link" : "Kopioi julkinen linkki",
    "Send link to calendar via email" : "Lähetä kalenteriin johtava linkki sähköpostitse",
    "Enter one address" : "Kirjoita yksi osoite",
    "Sending email …" : "Lähetetään sähköpostia …",
    "Copy embedding code" : "Kopioi upotuskoodi",
    "Copying code …" : "Kopioidaan koodi …",
    "Copied code" : "Koodi kopioitu",
    "Could not copy code" : "Koodia ei voitu kopioida",
    "Delete share link" : "Poista jakolinkki",
    "Deleting share link …" : "Poistetaan jakolinkki …",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (tiimi)",
    "An error occurred while unsharing the calendar." : "Kalenterin jaon poistamisessa tapahtui virhe.",
    "An error occurred, unable to change the permission of the share." : "Tapahtui virhe, jaon käyttöoikeuksia ei pysty muokkaamaan.",
    "Unshare with {displayName}" : "Poista jako kohteesta {displayName}",
    "Share with users or groups" : "Jaa käyttäjien tai ryhmien kanssa",
    "No users or groups" : "Ei käyttäjiä tai ryhmiä",
    "Failed to save calendar name and color" : "Kalenterin nimen ja värin tallentaminen epäonnistui",
    "Share calendar" : "Jaa kalenteri",
    "Unshare from me" : "Lopeta jako minulle",
    "Save" : "Tallenna",
    "No title" : "Ei otsikkoa",
    "Are you sure you want to delete \"{title}\"?" : "Haluatko varmasti poistaa \"{title}\"?",
    "Deleting proposal \"{title}\"" : "Poistetaan ehdotus \"{title}\"",
    "Successfully deleted proposal" : "Ehdotus poistettu",
    "Failed to delete proposal" : "Ehdotuksen poistaminen epäonnistui",
    "Failed to retrieve proposals" : "Ehdotusten noutaminen epäonnistui",
    "Meeting proposals" : "Kokousehdotukset",
    "No active meeting proposals" : "Ei aktiivisia kokousehdotuksia",
    "View" : "Näkymä",
    "Import calendars" : "Tuo kalenterit",
    "Please select a calendar to import into …" : "Valitse kalenteri, johon tuodaan …",
    "Filename" : "Tiedostonimi",
    "Calendar to import into" : "Kalenteri johon tuodaan",
    "Cancel" : "Peruuta",
    "_Import calendar_::_Import calendars_" : ["Tuo kalenteri","Tuo kalenterit"],
    "Select the default location for attachments" : "Valitse oletussijainti liitteille",
    "Pick" : "Valitse",
    "Invalid location selected" : "Virheellinen sijainti valittu",
    "Attachments folder successfully saved." : "Liitteiden kansio tallennettu.",
    "Error on saving attachments folder." : "Virhe liitetiedostokansiota tallennettaessa.",
    "Attachments folder" : "Liitteiden kansio",
    "{filename} could not be parsed" : "Tiedostoa {filename} ei voitu jäsentää",
    "No valid files found, aborting import" : "Kelvollisia tiedostoja ei löytynyt, lopetetaan tuonti",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Tuotiin onnistuneesti %n tapahtuma","Tuotiin onnistuneesti %n tapahtumaa"],
    "Import partially failed. Imported {accepted} out of {total}." : "Tuonti epäonnistui osittain. Tuotiin {accepted}/{total}.",
    "Automatic" : "Automaattinen",
    "Automatic ({timezone})" : "Automaattinen ({timezone})",
    "New setting was not saved successfully." : "Uutta asetusta ei tallennettu onnistuneesti.",
    "Timezone" : "Aikavyöhyke",
    "Navigation" : "Navigointi",
    "Previous period" : "Edellinen jakso",
    "Next period" : "Seuraava jakso",
    "Views" : "Näkymät",
    "Day view" : "Päivänäkymä",
    "Week view" : "Viikkonäkymä",
    "Month view" : "Kuukausinäkymä",
    "Year view" : "Vuosinäkymä",
    "List view" : "Listanäkymä",
    "Actions" : "Toiminnot",
    "Create event" : "Luo tapahtuma",
    "Show shortcuts" : "Näytä pikanäppäimet",
    "Editor" : "Muokkain",
    "Close editor" : "Sulje muokkain",
    "Save edited event" : "Tallenna muokattu tapahtuma",
    "Delete edited event" : "Poista muokattu tapahtuma",
    "Duplicate event" : "Tee kaksoiskappale tapahtumasta",
    "or" : "tai",
    "Calendar settings" : "Kalenteriasetukset",
    "At event start" : "Tapahtuman alkaessa",
    "No reminder" : "Ei muistutusta",
    "Failed to save default calendar" : "Oletuskalenterin tallentaminen epäonnistui",
    "General" : "Yleiset",
    "Appearance" : "Ulkoasu",
    "Default reminder" : "Oletusmuistutus",
    "Files" : "Tiedostot",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minuutti","{duration} minuuttia"],
    "0 minutes" : "0 minuuttia",
    "_{duration} hour_::_{duration} hours_" : ["{duration} tunti","{duration} tuntia"],
    "_{duration} day_::_{duration} days_" : ["{duration} päivä","{duration} päivää"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} viikko","{duration} viikkoa"],
    "_{duration} month_::_{duration} months_" : ["{duration} kuukausi","{duration} kuukautta"],
    "_{duration} year_::_{duration} years_" : ["{duration} vuosi","{duration} vuotta"],
    "To configure appointments, add your email address in personal settings." : "Lisää sähköpostiosoitteesi henkilökohtaisissa asetuksissa hallitaksesi tapaamisia.",
    "Public – shown on the profile page" : "Julkinen – näytetään profiilisivulla",
    "Private – only accessible via secret link" : "Yksityinen – nähtävissä vain salaisella linkillä",
    "Appointment schedule saved" : "Tapaamisaikataulu tallennettu",
    "Create appointment schedule" : "Luo tapaamisaikataulu",
    "Edit appointment schedule" : "Muokkaa tapaamisaikataulua",
    "Update" : "Päivitä",
    "Appointment name" : "Tapaamisen nimi",
    "Location" : "Sijainti",
    "Create a Talk room" : "Luo Talk-huone",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Jokaisesta varatusta tapaamisesta muodostetaan yksilöllinen linkki, ja se lähetetään vahvistussähköpostin yhteydessä",
    "Description" : "Kuvaus",
    "Visibility" : "Näkyvyys",
    "Duration" : "Kesto",
    "Increments" : "Aikaväli",
    "Additional calendars to check for conflicts" : "Lisäkalenterit, jotka tarkistetaan ristiriitojen varalta",
    "Pick time ranges where appointments are allowed" : "Valitse aikavälit joihin sallitaan tapaamisia",
    "to" : "päättyen",
    "Delete slot" : "Poista aikarako",
    "No times set" : "Ei asetettuja aikoja",
    "Add" : "Lisää",
    "Monday" : "Maanantai",
    "Tuesday" : "Tiistai",
    "Wednesday" : "Keskiviikko",
    "Thursday" : "Torstai",
    "Friday" : "Perjantai",
    "Saturday" : "Lauantai",
    "Sunday" : "Sunnuntai",
    "Weekdays" : "Viikonpäivät",
    "Add time before and after the event" : "Lisää aikaa ennen tapahtuman alkua ja tapahtuman jälkeen",
    "Before the event" : "Ennen tapahtumaa",
    "After the event" : "Tapahtuman jälkeen",
    "Planning restrictions" : "Suunnittelurajoitukset",
    "Minimum time before next available slot" : "Vähimmäisaika ennen seuraavaa saatavilla olevaa aikarakoa",
    "Max slots per day" : "Aikarakoja enintään päivää kohden",
    "Limit how far in the future appointments can be booked" : "Rajoita kuinka pitkälle tulevaisuuteen tapaamisia on mahdollista varata",
    "Please confirm your reservation" : "Vahvista varauksesi",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Lähetimme sinulle sähköpostin yksityiskohtien kera. Ole hyvä ja hyväksy tapaamisesi käyttäen linkkiä sähköpostissa. Voit sulkea tämän sivun.",
    "Your name" : "Nimesi",
    "Your email address" : "Sähköpostiosoitteesi",
    "Please share anything that will help prepare for our meeting" : "Jaa mitä tahansa, mikä auttaa valmistautumaan kokoukseen",
    "Could not book the appointment. Please try again later or contact the organizer." : "Tapaamista ei voitu kirjata. Ole hyvä ja yritä myöhemmin uudelleen tai ota yhteyttä järjestäjään.",
    "Back" : "Takaisin",
    "Book appointment" : "Varaa tapaaminen",
    "Error fetching Talk conversations." : "Virhe noudettaessa Talk-keskusteluja.",
    "Conversation does not have a valid URL." : "Keskustelulla ei ole kelvollista URL-osoitetta.",
    "Successfully added Talk conversation link to location." : "Talk-keskustelulinkki lisätty sijaintiin.",
    "Successfully added Talk conversation link to description." : "Talk-keskustelulinkki lisätty kuvaukseen.",
    "Talk conversation for event" : "Tapahtuman Talk-keskustelu",
    "Error creating Talk conversation" : "Virhe luotaessa Talk-keskustelua",
    "Select a Talk Room" : "Valitse Talk-huone",
    "Add Talk conversation" : "Lisää Talk-keskustelu",
    "Fetching Talk rooms…" : "Noudetaan Talk-huoneita…",
    "No Talk room available" : "Talk-huonetta ei ole käytettävissä",
    "Select conversation" : "Valitse keskustelu",
    "on" : "päivä",
    "at" : "kellonaika",
    "before at" : "ennen",
    "Notification" : "Ilmoitus",
    "Email" : "Sähköposti",
    "Audio notification" : "Ääni-ilmoitus",
    "Other notification" : "Muu ilmoitus",
    "Relative to event" : "Liittyy tapahtumaan",
    "On date" : "Päivänä",
    "Edit time" : "Muokkaa aikaa",
    "Save time" : "Tallenna aika",
    "Remove reminder" : "Poista muistutus",
    "Add reminder" : "Lisää muistutus",
    "seconds" : "sekuntia",
    "minutes" : "minuuttia",
    "hours" : "tuntia",
    "days" : "päivän jälkeen",
    "weeks" : "viikkoa",
    "Choose a file to add as attachment" : "Valitse liitteeksi lisättävä tiedosto",
    "Choose a file to share as a link" : "Valitse tiedosto, joka jaetaan linkkinä",
    "Attachment {name} already exist!" : "Liite {name} on jo olemassa!",
    "Could not upload attachment(s)" : "Liitteiden lähetys epäonnistui",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Olet aikeissa siirtyä kohteeseen {host}. Haluatko varmasti jatkaa? Linkki: {link}",
    "Proceed" : "Jatka",
    "No attachments" : "Ei liitteitä",
    "Add from Files" : "Lisää tiedostosovelluksesta",
    "Upload from device" : "Lähetä laitteelta",
    "Delete file" : "Poista tiedosto",
    "Confirmation" : "Vahvistus",
    "_{count} attachment_::_{count} attachments_" : ["{count} liite","{count} liitettä"],
    "Suggested" : "Ehdotettu",
    "Available" : "Saatavilla",
    "Invitation accepted" : "Kutsu hyväksytty",
    "Accepted {organizerName}'s invitation" : "Hyväksytty järjestäjän {organizerName} kutsu",
    "Participation marked as tentative" : "Osallistuminen merkitty alustavaksi",
    "Invitation is delegated" : "Kutsu on delegoitu",
    "Not available" : "Ei saatavilla",
    "Invitation declined" : "Kieltäydytty kutsusta",
    "Declined {organizerName}'s invitation" : "Kieltäytyi järjestäjän {organizerName} kutsusta",
    "Availability will be checked" : "Saatavuus tarkistetaan",
    "Invitation will be sent" : "Kutsu lähetetään",
    "Failed to check availability" : "Saatavuuden tarkistus epäonnistui",
    "Failed to deliver invitation" : "Kutsun toimittaminen epäonnistui",
    "Awaiting response" : "Odottaa vastausta",
    "Checking availability" : "Tarkistetaan saatavuutta",
    "Has not responded to {organizerName}'s invitation yet" : "Ei ole vielä vastanut järjestäjän {organizerName} kutsuun",
    "Suggested times" : "Ehdotetut ajat",
    "chairperson" : "puheenjohtaja",
    "required participant" : "vaadittu osallistuja",
    "optional participant" : "valinnainen osallistuja",
    "{organizer} (organizer)" : "{organizer} (järjestäjä)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Availability of attendees, resources and rooms" : "Osallistujien, resurssien ja huoneiden saatavuus",
    "Suggestion accepted" : "Ehdotus hyväksytty",
    "Previous date" : "Edellinen päivä",
    "Next date" : "Seuraava päivä",
    "Legend" : "Selite",
    "Out of office" : "Ulkona toimistolta",
    "Attendees:" : "Osallistujat:",
    "Done" : "Valmis",
    "Search room" : "Etsi huonetta",
    "Room name" : "Huoneen nimi",
    "Check room availability" : "Tarkista huoneen saatavuus",
    "Free" : "Vapaa",
    "Busy (tentative)" : "Varattu (alustava)",
    "Busy" : "Varattu",
    "Unknown" : "Tuntematon",
    "Find a time" : "Löydä aika",
    "The invitation has been accepted successfully." : "Kutsu on hyväksytty.",
    "Failed to accept the invitation." : "Kutsun hyväksyminen epäonnistui.",
    "The invitation has been declined successfully." : "Kieltäydytty kutsusta onnistuneesti.",
    "Failed to decline the invitation." : "Kutsusta kieltäytyminen epäonnistui.",
    "Your participation has been marked as tentative." : "Osallistumisesi on merkitty alustavaksi.",
    "Failed to set the participation status to tentative." : "Osallistumisen tilan asettaminen alustavaksi epäonnistui.",
    "Accept" : "Hyväksy",
    "Decline" : "Kieltäydy",
    "Tentative" : "Alustava",
    "No attendees yet" : "Ei vielä osallistujia",
    "Attendees" : "Osallistujat",
    "Remove group" : "Poista ryhmä",
    "Remove attendee" : "Poista osallistuja",
    "Request reply" : "Pyydä vastaus",
    "Chairperson" : "Puheenjohtaja",
    "Required participant" : "Vaadittu osallistuja",
    "Optional participant" : "Valinnainen osallistuja",
    "Non-participant" : "Osallistumaton",
    "_%n member_::_%n members_" : ["%n jäsen","%n jäsentä"],
    "Search for emails, users, contacts, contact groups or teams" : "Etsi sähköpostiosoitteita, käyttäjiä, yhteystietoja, yhteystietoryhmiä tai tiimejä",
    "No match found" : "Ei tuloksia",
    "(organizer)" : "(järjestäjä)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "[linkopen]Lisää sähköpostiosoitteesi henkilökohtaisiin asetuksiisi[linkclose] lähettääksesi kutsuja ja hallitaksesi vastauksia.",
    "Remove color" : "Poista väri",
    "Event title" : "Tapahtuman otsikko",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Koko päivän tapahtumia, jotka ovat osa toistuvaa tapahtumaa, ei voida muokata.",
    "From" : "Alkaen",
    "To" : "Päättyen",
    "Repeat" : "Toista",
    "_time_::_times_" : ["kerran","kertaa"],
    "never" : "ei koskaan",
    "on date" : "päivänä",
    "after" : "jälkeen",
    "End repeat" : "Lopeta toisto",
    "Select to end repeat" : "Valitse lopettaaksesi toiston",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Tämä tapahtuma on toistuvaan tapahtumaan tehty poikkeus. Et voi lisätä tähän uutta toistuvuutta.",
    "first" : "ensimmäinen",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Muutokset toistuvuusasetukseen vaikuttavat vain tähän ja tuleviin tapahtumakertoihin.",
    "Repeat every" : "Toista joka",
    "By day of the month" : "Kuukauden päivän mukaan",
    "On the" : "Ajankohtana",
    "_day_::_days_" : ["päivä","päivää"],
    "_week_::_weeks_" : ["viikko","viikkoa"],
    "_month_::_months_" : ["kuukausi","kuukautta"],
    "_year_::_years_" : ["vuosi","vuotta"],
    "On specific day" : "Tiettynä päivänä",
    "weekday" : "viikonpäivä",
    "weekend day" : "viikonloppupäivä",
    "Does not repeat" : "Ei toistu",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Tapahtuman toistuvuusasetus ei ole Nextcloudin tukema. Jos muokkaat toistuvuusasetusta, jotkin toistuvista tapahtumista saattavat kadota.",
    "No rooms or resources yet" : "Ei huoneita tai resursseja vielä",
    "Resources" : "Resurssit",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} istumapaikka","{seatingCapacity} istumapaikkaa"],
    "Add resource" : "Lisää resurssi",
    "Has a projector" : "On projektori",
    "Has a whiteboard" : "On valkotaulu",
    "Wheelchair accessible" : "Pääsy pyörätuolilla",
    "Remove resource" : "Poista resurssi",
    "Search for resources or rooms" : "Etsi resursseja tai huoneita",
    "available" : "saatavilla",
    "unavailable" : "ei saatavilla",
    "Show all rooms" : "Näytä kaikki huoneet",
    "Projector" : "Projektori",
    "Whiteboard" : "Valkotaulu",
    "Room type" : "Huoneen tyyppi",
    "Any" : "Mikä tahansa",
    "Minimum seating capacity" : "Istumapaikkoja vähintään",
    "More details" : "Lisätietoja",
    "Update this and all future" : "Päivitä tämä ja kaikki tulevat",
    "Update this occurrence" : "Päivitä tämä esiintymä",
    "Public calendar does not exist" : "Julkista kalenteria ei ole olemassa",
    "Maybe the share was deleted or has expired?" : "Kenties jako poistettiin tai se vanheni.",
    "Attendance required" : "Osallistuminen vaaditaan",
    "Attendance optional" : "Osallistuminen valinnaista",
    "Remove participant" : "Poista osallistuja",
    "Yes" : "Kyllä",
    "No" : "Ei",
    "Maybe" : "Ehkä",
    "None" : "Ei mitään",
    "Create a meeting for this date and time" : "Luo kokous tälle päivälle ja ajankohdalle",
    "Create" : "Luo",
    "from {formattedDate}" : "alkaen {formattedDate}",
    "to {formattedDate}" : "päättyen {formattedDate}",
    "on {formattedDate}" : "päivänä {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "alkaen {formattedDate} klo {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "päättyen {formattedDate} klo {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "päivänä {formattedDate} klo {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} klo {formattedTime}",
    "Please enter a valid date" : "Kirjoita kelvollinen päivä",
    "Please enter a valid date and time" : "Kirjoita kelvollinen päivä ja aika",
    "Select a time zone" : "Valitse aikavyöhyke",
    "Please select a time zone:" : "Valitse aikavyöhyke:",
    "Pick a time" : "Valitse aika",
    "Pick a date" : "Valitse päivä",
    "Type to search time zone" : "Kirjoita etsiäksesi aikavyöhykettä",
    "Global" : "Julkinen",
    "Holidays in {region}" : "Juhlapäivä alueella {region}",
    "Public holiday calendars" : "Juhlapäiväkalenterit",
    "Public calendars" : "Julkiset kalenterit",
    "No valid public calendars configured" : "Kelvollisia juhlakalentereita ei ole määritetty",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Juhlapäiväkalenterit tarjoaa Thunderbird. Kalenterin tiedot ladataan verkkosivustolta {website}",
    "By {authors}" : "Tekijä {authors}",
    "Subscribed" : "Tilattu",
    "Subscribe" : "Tilaa",
    "Select a date" : "Valitse päivämäärä",
    "Select slot" : "Valitse aikarako",
    "No slots available" : "Aikarakoja ei ole saatavilla",
    "The slot for your appointment has been confirmed" : "Aikarako tapaamiselle on vahvistettu",
    "Appointment Details:" : "Tapaamisen yksityiskohdat:",
    "Time:" : "Aika:",
    "Booked for:" : "Varattu:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Kiitos. varauksesi {startDate} - {endDate} on vahvistettu.",
    "Book another appointment:" : "Varaa toinen tapaaminen:",
    "See all available slots" : "Näytä kaikki saatavilla olevat aikaraot",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Aikarako tapaamiselle, {startDate} - {endDate}, ei ole enää saatavilla.",
    "Please book a different slot:" : "Varaa muu aikarako:",
    "Book an appointment with {name}" : "Varaa tapaaminen käyttäjän {name} kanssa",
    "No public appointments found for {name}" : "Käyttäjän {name} julkisia tapaamisia ei löydy",
    "Personal" : "Henkilökohtainen",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Automaattinen aikavyöhykkeentunnistus määritti aikavyöhykkeesi olevan UTC. \nTämä johtuu todennäköisesti selaimesi tietoturva-asetuksista.\nOle hyvä ja aseta aikavyöhykkeesi manuaalisesti kalenterin asetuksista.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Asettamaasi aikavyöhykettä ({timezoneId}) ei löytynyt. Vaihdetaan takaisin UTC:hen.\nOle hyvä ja vaihda aikavyöhykkeesi asetuksista ja ilmoita tästä ongelmasta.",
    "Show unscheduled tasks" : "Näytä ajastamattomat tehtävät",
    "Unscheduled tasks" : "Ajastamattomat tehtävät",
    "Discard event" : "Hylkää tapahtuma",
    "Edit event" : "Muokkaa tapahtumaa",
    "Event does not exist" : "Tapahtumaa ei ole olemassa",
    "Delete this occurrence" : "Poista tämä esiintymä",
    "Delete this and all future" : "Poista tämä ja kaikki tulevat",
    "All day" : "Koko päivä",
    "Managing shared access" : "Jaetun pääsyn hallinta",
    "Deny access" : "Estä pääsy",
    "Invite" : "Kutsu",
    "Discard changes?" : "Hylätäänkö muutokset?",
    "Are you sure you want to discard the changes made to this event?" : "Haluatko varmasti hylätä tähän tapahtumaan tehdyt muutokset?",
    "_User requires access to your file_::_Users require access to your file_" : ["Käyttäjä tarvitsee pääsyn tiedostoosi","Käyttäjät tarvitsevat pääsyn tiedostoosi"],
    "Untitled event" : "Nimetön tapahtuma",
    "Close" : "Sulje",
    "Meeting proposals overview" : "Kokousehdotusten yhteenveto",
    "Edit meeting proposal" : "Muokkaa kokousehdotusta",
    "Create meeting proposal" : "Luo kokousehdotus",
    "Update meeting proposal" : "Päivitä kokousehdotus",
    "Saving proposal \"{title}\"" : "Tallennetaan ehdotus \"{title}\"",
    "Successfully saved proposal" : "Ehdotus tallennettu",
    "Failed to save proposal" : "Ehdotuksen tallentaminen epäonnistui",
    "Creating meeting for {date}" : "Luo kokous päivälle {date}",
    "Please enter a valid duration in minutes." : "Kirjoita kelvollinen kesto minuutteina.",
    "Failed to fetch proposals" : "Ehdotusten noutaminen epäonnistui",
    "Selected" : "Valittu",
    "No Description" : "Ei kuvausta",
    "No Location" : "Ei sijaintia",
    "Edit this meeting proposal" : "Muokkaa tätä kokousehdotusta",
    "Delete this meeting proposal" : "Poista tämä kokousehdotus",
    "Title" : "Nimeke",
    "15 min" : "15 min",
    "30 min" : "30 min",
    "60 min" : "60 min",
    "90 min" : "90 min",
    "Participants" : "Osallistujat",
    "Selected times" : "Valitut ajat",
    "Loading meeting proposal" : "Ladataan kokousehdotusta",
    "No meeting proposal found" : "Kokousehdotusta ei löytynyt",
    "Thank you for your response!" : "Kiitos vastauksestasi!",
    "Unknown User" : "Tuntematon käyttäjä",
    "No Title" : "Ei otsikkoa",
    "No Duration" : "Ei kestoa",
    "Select a different time zone" : "Valitse eri aikavyöhyke",
    "Submit" : "Lähetä",
    "Subscribe to {name}" : "Tilaa {name}",
    "Export {name}" : "Vie {name}",
    "Show availability" : "Näytä saatavuus",
    "Anniversary" : "Vuosipäivä",
    "Appointment" : "Tapaaminen",
    "Business" : "Business",
    "Education" : "Koulutus",
    "Holiday" : "Loma",
    "Meeting" : "Kokous",
    "Miscellaneous" : "Sekalaiset",
    "Non-working hours" : "Ei-työnalaiset tunnit",
    "Not in office" : "Pois työpaikalta",
    "Phone call" : "Puhelinkeskustelu",
    "Sick day" : "Sairauspäivä",
    "Special occasion" : "Erikoistilaisuus",
    "Travel" : "Matka",
    "Vacation" : "Vapaalla töistä",
    "Midnight on the day the event starts" : "Keskiyöllä tapahtumapäivänä",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n päivä ennen tapahtumaa klo {formattedHourMinute}","%n  päivää ennen tapahtumaa klo {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n viikko ennen tapahtumaa klo {formattedHourMinute}","%n viikkoa ennen tapahtumaa klo {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "tapahtumapäivänä klo {formattedHourMinute}",
    "at the event's start" : "tapahtuman alkaessa",
    "at the event's end" : "tapahtuman päättyessä",
    "{time} before the event starts" : "{time} ennen tapahtuman alkua",
    "{time} before the event ends" : "{time} ennen tapahtuman päättymistä",
    "{time} after the event starts" : "{time} tapahtuman alkamisen jälkeen",
    "{time} after the event ends" : "{time} tapahtuman päättymisen jälkeen",
    "on {time}" : "klo {time}",
    "on {time} ({timezoneId})" : "klo {time} ({timezoneId})",
    "Week {number} of {year}" : "Viikko {number} vuonna {year}",
    "Daily" : "Päivittäin",
    "Weekly" : "Viikottain",
    "Monthly" : "Kuukausittain",
    "Yearly" : "Vuosittain",
    "_Every %n day_::_Every %n days_" : ["Päivittäin","Joka %n. päivä"],
    "_Every %n week_::_Every %n weeks_" : ["Viikottain","Joka %n. viikko "],
    "_Every %n month_::_Every %n months_" : ["Kuukausittain","Joka %n. kuukausi"],
    "_Every %n year_::_Every %n years_" : ["Vuosittain","Joka %n. vuosi"],
    "_on {weekday}_::_on {weekdays}_" : ["{weekday}na","viikonpäivinä {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["päivänä {dayOfMonthList}","päivinä {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "{ordinalNumber} {byDaySet}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "{monthNames}ssa {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "{untilDate} asti",
    "_%n time_::_%n times_" : ["%n kerran","%n kertaa"],
    "second" : "toinen",
    "third" : "kolmas",
    "fourth" : "neljäs",
    "fifth" : "viides",
    "second to last" : "toiseksi viimeinen",
    "last" : "viimeinen",
    "Untitled task" : "Nimetön tehtävä",
    "Please ask your administrator to enable the Tasks App." : "Pyydä järjestelmänvalvojaa ottamaan Tasks-sovellus käyttöön",
    "W" : "Vko",
    "%n more" : "%n lisää",
    "No events to display" : "Ei tapahtumia näytettäväksi",
    "All participants declined" : "Kaikki osallistujat kieltäytyivät",
    "Please confirm your participation" : "Vahvista osallistumisesi",
    "You declined this event" : "Kieltäydyit tästä tapahtumasta",
    "Your participation is tentative" : "Osallistumisesi on alustava.",
    "_+%n more_::_+%n more_" : ["+%n lisää","+%n lisää"],
    "No events" : "Ei tapahtumia",
    "Create a new event or change the visible time-range" : "Luo uusi tapahtuma tai vaihda näkyvää aikajanaa",
    "Failed to save event" : "Tapahtuman tallentaminen epäonnistui",
    "It might have been deleted, or there was a typo in a link" : "Se saattaa olla poistettu, tai linkissä oli kirjoitusvirhe",
    "It might have been deleted, or there was a typo in the link" : "Se saattaa olla poistettu, tai linkissä oli kirjoitusvirhe",
    "Meeting room" : "Kokoushuone",
    "Lecture hall" : "Luentosali",
    "Seminar room" : "Seminaarihuone",
    "Other" : "Muu",
    "When shared show" : "Jaettaessa näytä",
    "When shared show full event" : "Jaettaessa näytä koko tapahtuma",
    "When shared show only busy" : "Jaettaessa näytä vain varattuna oleminen",
    "When shared hide this event" : "Jaettaessa piilota tämä tapahtuma",
    "Add a location" : "Lisää sijainti",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Lisää kuvaus\n\n- Mitä tapaamisessa käsitellään\n- Asialista\n- Mitä hyvänsä mihin osallistujien tulisi valmistautua",
    "Status" : "Tila",
    "Confirmed" : "Vahvistettu",
    "Canceled" : "Peruttu",
    "Confirmation about the overall status of the event." : "Vahvistus tapahtuman yleiskuvasta.",
    "Show as" : "Näytä muodossa",
    "Take this event into account when calculating free-busy information." : "Huomioi tämä tapahtuma laskettaessa vapaita ja varattuja ajankohtia.",
    "Categories" : "Luokat",
    "Categories help you to structure and organize your events." : "Luokat auttavat sinua asettamaan tapahtumia rakenteellisiksi ja hallitsemaan niitä.",
    "Search or add categories" : "Etsi tai lisää luokkia",
    "Add this as a new category" : "Lisää tämä uutena luokkana",
    "Custom color" : "Mukautettu väri",
    "Special color of this event. Overrides the calendar-color." : "Tämän tapahtuman erikoisväri. Ylittää kalenterin väriarvon.",
    "Error while sharing file" : "Virhe tiedostoa jakaessa",
    "Error while sharing file with user" : "Virhe tiedostoa jakaessa käyttäjän kanssa",
    "Error creating a folder {folder}" : "Virhe luotaessa kansiota {folder}",
    "Attachment {fileName} already exists!" : "Liite {fileName} on jo olemassa!",
    "Attachment {fileName} added!" : "Liite {fileName} lisätty!",
    "An error occurred during uploading file {fileName}" : "Tiedostoa {fileName} lähettäessä tapahtui virhe",
    "An error occurred during getting file information" : "Tiedostojen tietoja noutaessa tapahtui virhe",
    "An error occurred, unable to delete the calendar." : "Tapahtui virhe, kalenteria ei voitu poistaa.",
    "Imported {filename}" : "Tuotiin {filename}",
    "This is an event reminder." : "Tämä on tapahtuman muistutus.",
    "Appointment not found" : "Tapaamista ei löydy",
    "User not found" : "Käyttäjää ei löydy",
    "Hidden" : "Piilotettu",
    "can edit" : "voi muokata",
    "Calendar name …" : "Kalenterin nimi…",
    "Default attachments location" : "Liitteiden oletussijainti",
    "Automatic ({detected})" : "Automaattinen ({detected})",
    "Shortcut overview" : "Pikakuvakenäkymä",
    "CalDAV link copied to clipboard." : "CalDAV-linkki kopioitu leikepöydälle.",
    "CalDAV link could not be copied to clipboard." : "CalDAV-linkkiä ei voitu kopioida leikepöydälle.",
    "Enable birthday calendar" : "Käytä syntymäpäiväkalenteria",
    "Show tasks in calendar" : "Näytä tehtävät kalenterissa",
    "Enable simplified editor" : "Käytä yksinkertaistettua muokkainta",
    "Limit the number of events displayed in the monthly view" : "Rajoita kuukausinäkymässä näytettävien tapahtumien määrää",
    "Show weekends" : "Näytä viikonloput",
    "Show week numbers" : "Näytä viikkonumerot",
    "Time increments" : "Aikavälit",
    "Default calendar for incoming invitations" : "Oletuskalenteri saapuville kutsuille",
    "Copy primary CalDAV address" : "Kopioi ensisijainen CalDAV-osoite",
    "Copy iOS/macOS CalDAV address" : "Kopioi iOS:in/macOS:n CalDAV-osoite",
    "Personal availability settings" : "Henkilökohtaiset saatavuusasetukset",
    "Show keyboard shortcuts" : "Näytä pikanäppäimet",
    "Create a new public conversation" : "Luo uusi julkinen keskustelu",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} kutsuttu, {confirmedCount} vahvistettu",
    "Successfully appended link to talk room to description." : "Linkki Talk-huoneeseen lisättiin onnistuneesti kuvaukseen.",
    "Error creating Talk room" : "Virhe luotaessa Talk-huonetta",
    "The visibility of this event in shared calendars." : "Tämän tapahtuman näkyvyys jaetuissa kalentereissa."
},
"nplurals=2; plural=(n != 1);");
