OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "La dirección de correo electrónico proporcionada es demasiado larga",
    "User-Session unexpectedly expired" : "La sesión de usuario ha expirado inesperadamente",
    "Provided email-address is not valid" : "La dirección de correo electrónico proporcionada no es válida",
    "%s has published the calendar »%s«" : "%s ha publicado el calendario »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Error inesperado al enviar el correo electrónico. Por favor, contacta a tu administrador.",
    "Successfully sent email to %1$s" : "Correo electrónico enviado correctamente a %1$s",
    "Hello," : "Hola,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Queremos informarte que %s ha publicado el calendario »%s«.",
    "Open »%s«" : "Abrir »%s«",
    "Cheers!" : "¡Saludos!",
    "Upcoming events" : "Próximos eventos",
    "No more events today" : "No hay más eventos hoy",
    "No upcoming events" : "No hay próximos eventos",
    "More events" : "Más eventos",
    "%1$s with %2$s" : "%1$s con %2$s",
    "Calendar" : "Calendario",
    "New booking {booking}" : "Nueva reserva {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) reservó la cita \"{config_display_name}\" el {date_time}.",
    "Appointments" : "Citas",
    "Schedule appointment \"%s\"" : "Programar cita \"%s\"",
    "Schedule an appointment" : "Programar una cita",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : "Preparar para %s",
    "Follow up for %s" : "Hacer seguimiento de %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Tu cita \"%s\" con %s necesita confirmación",
    "Dear %s, please confirm your booking" : "Estimado/a %s, por favor confirma tu reserva",
    "Confirm" : "Confirmar",
    "Description:" : "Descripción:",
    "This confirmation link expires in %s hours." : "Este enlace de confirmación caduca en %s horas.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Si deseas cancelar la cita, por favor contacta al organizador respondiendo a este correo electrónico o visitando su página de perfil.",
    "Your appointment \"%s\" with %s has been accepted" : "Tu cita \"%s\" con %s ha sido aceptada",
    "Dear %s, your booking has been accepted." : "Estimado/a %s, tu reserva ha sido aceptada.",
    "Appointment for:" : "Cita para:",
    "Date:" : "Fecha:",
    "Where:" : "Dónde:",
    "Comment:" : "Comentario:",
    "You have a new appointment booking \"%s\" from %s" : "Tienes una nueva reserva de cita \"%s\" de %s",
    "Dear %s, %s (%s) booked an appointment with you." : "Estimado/a %s, %s (%s) ha reservado una cita contigo.",
    "Location:" : "Ubicación:",
    "A Calendar app for Nextcloud" : "Una aplicación de calendario para Nextcloud",
    "Previous day" : "Día anterior",
    "Previous week" : "Semana anterior",
    "Previous year" : "Año anterior",
    "Previous month" : "Mes anterior",
    "Next day" : "Día siguiente",
    "Next week" : "Semana siguiente",
    "Next year" : "Año siguiente",
    "Next month" : "Mes siguiente",
    "Create new event" : "Crear nuevo evento",
    "Event" : "Evento",
    "Today" : "Hoy",
    "Day" : "Día",
    "Week" : "Semana",
    "Month" : "Mes",
    "Year" : "Año",
    "List" : "Lista",
    "Appointment link was copied to clipboard" : "El enlace de la cita se copió al portapapeles",
    "Appointment link could not be copied to clipboard" : "No se pudo copiar el enlace de la cita al portapapeles",
    "Preview" : "Previsualizar",
    "Copy link" : "Copiar liga",
    "Edit" : "Editar",
    "Delete" : "Borrar",
    "Create new" : "Crear nuevo",
    "Disable calendar \"{calendar}\"" : "Desactivar calendario \"{calendar}\"",
    "Disable untitled calendar" : "Desactivar calendario sin título",
    "Enable calendar \"{calendar}\"" : "Activar calendario \"{calendar}\"",
    "Enable untitled calendar" : "Activar calendario sin título",
    "An error occurred, unable to change visibility of the calendar." : "Ocurrió un error, no se pudo cambiar la visibilidad del calendario.",
    "Untitled calendar" : "Calendario sin título",
    "Shared with you by" : "Compartido contigo por",
    "Edit and share calendar" : "Editar y compartir calendario",
    "Edit calendar" : "Editar calendario",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Dejar de compartir el calendario en {countdown} segundo","Dejar de compartir el calendario en {countdown} segundos","Dejar de compartir el calendario en {countdown} segundos"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Eliminando el calendario en {countdown} segundo","Eliminando el calendario en {countdown} segundos","Eliminando el calendario en {countdown} segundos"],
    "An error occurred, unable to create the calendar." : "Ocurrió un error, no se pudo crear el calendario.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Por favor, ingresa un enlace válido (que comience con http://, https://, webcal:// o webcals://)",
    "Calendars" : "Calendarios",
    "Add new" : "Agregar nuevo",
    "New calendar" : "Nuevo calendario",
    "Name for new calendar" : "Nombre para el nuevo calendario",
    "Creating calendar …" : "Creando calendario …",
    "New calendar with task list" : "Nuevo calendario con lista de tareas",
    "New subscription from link (read-only)" : "Nueva suscripción desde enlace (solo lectura)",
    "Creating subscription …" : "Creando suscripción …",
    "Add public holiday calendar" : "Agregar calendario de días festivos",
    "Calendar link copied to clipboard." : "Enlace del calendario copiado al portapapeles.",
    "Calendar link could not be copied to clipboard." : "No se pudo copiar el enlace del calendario al portapapeles.",
    "Copy subscription link" : "Copiar enlace de suscripción",
    "Copying link …" : "Copiando enlace …",
    "Copied link" : "Enlace copiado",
    "Could not copy link" : "No se pudo copiar el enlace",
    "Export" : "Exportar",
    "Untitled item" : "Elemento sin título",
    "Unknown calendar" : "Calendario desconocido",
    "Could not load deleted calendars and objects" : "No se pudieron cargar los calendarios y objetos eliminados",
    "Could not delete calendar or event" : "No se pudo eliminar el calendario o el evento",
    "Could not restore calendar or event" : "No se pudo restaurar el calendario o evento",
    "Do you really want to empty the trash bin?" : "¿Realmente deseas vaciar la papelera?",
    "Empty trash bin" : "Eliminar papelera de reciclaje",
    "Trash bin" : "Papelera",
    "Loading deleted items." : "Cargando elementos eliminados.",
    "You do not have any deleted items." : "No tienes elementos eliminados.",
    "Name" : "Nombre",
    "Deleted" : "Borrado",
    "Restore" : "Restaurar",
    "Delete permanently" : "Borrar permanentemente",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Los elementos en la papelera se eliminan después de {numDays} día","Los elementos en la papelera se eliminan después de {numDays} días","Los elementos en la papelera se eliminan después de {numDays} días"],
    "Could not update calendar order." : "No se pudo actualizar el orden del calendario.",
    "Deck" : "Deck",
    "Internal link" : "Enlace interno",
    "A private link that can be used with external clients" : "Un enlace privado que puede usarse con clientes externos",
    "Copy internal link" : "Copiar enlace interno",
    "An error occurred, unable to publish calendar." : "Ocurrió un error, no se pudo publicar el calendario.",
    "An error occurred, unable to send email." : "Ocurrió un error, no se pudo enviar el correo electrónico.",
    "Embed code copied to clipboard." : "Código de incrustación copiado al portapapeles.",
    "Embed code could not be copied to clipboard." : "No se pudo copiar el código de incrustación al portapapeles.",
    "Unpublishing calendar failed" : "No se pudo publicar el calendario",
    "Share link" : "Compartir liga",
    "Copy public link" : "Copiar enlace público",
    "Send link to calendar via email" : "Enviar enlace del calendario por correo electrónico",
    "Enter one address" : "Ingresa una dirección",
    "Sending email …" : "Enviando correo electrónico …",
    "Copy embedding code" : "Copiar código de incrustación",
    "Copying code …" : "Copiando código …",
    "Copied code" : "Código copiado",
    "Could not copy code" : "No se pudo copiar el código",
    "Delete share link" : "Eliminar enlace compartido",
    "Deleting share link …" : "Eliminando enlace compartido …",
    "An error occurred while unsharing the calendar." : "Ocurrió un error al dejar de compartir el calendario.",
    "An error occurred, unable to change the permission of the share." : "Ocurrió un error, no se pudo cambiar el permiso de la compartición.",
    "Unshare with {displayName}" : "Dejar de compartir con {displayName}",
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "No users or groups" : "Sin usuarios ni grupos",
    "Failed to save calendar name and color" : "Error al guardar el nombre y el color del calendario",
    "Share calendar" : "Compartir calendario",
    "Unshare from me" : "Dejar de compartir conmigo",
    "Save" : "Guardar",
    "No title" : "Sin título",
    "View" : "Ver",
    "Import calendars" : "Importar calendarios",
    "Please select a calendar to import into …" : "Selecciona un calendario para importar en …",
    "Filename" : "Nombre del archivo",
    "Calendar to import into" : "Calendario para importar en",
    "Cancel" : "Cancelar",
    "_Import calendar_::_Import calendars_" : ["Importar calendario","Importar calendarios","Importar calendarios"],
    "Select the default location for attachments" : "Selecciona la ubicación predeterminada para los adjuntos",
    "Invalid location selected" : "Ubicación seleccionada no válida",
    "Attachments folder successfully saved." : "Carpeta de adjuntos guardada correctamente.",
    "Error on saving attachments folder." : "Error al guardar la carpeta de adjuntos.",
    "Attachments folder" : "Carpeta de archivos adjuntos",
    "{filename} could not be parsed" : "No se pudo analizar {filename}",
    "No valid files found, aborting import" : "No se encontraron archivos válidos, se cancela la importación",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Se importó correctamente %n evento","Se importaron correctamente %n eventos","Se importaron correctamente %n eventos"],
    "Import partially failed. Imported {accepted} out of {total}." : "La importación falló parcialmente. Se importaron {accepted} de {total}.",
    "Automatic" : "Automático",
    "Automatic ({timezone})" : "({timezone}) automática",
    "New setting was not saved successfully." : "No se guardó correctamente la nueva configuración.",
    "Timezone" : "Zona horaria",
    "Navigation" : "Navegación",
    "Previous period" : "Periodo anterior",
    "Next period" : "Periodo siguiente",
    "Views" : "Vistas",
    "Day view" : "Vista diaria",
    "Week view" : "Vista semanal",
    "Month view" : "Vista mensual",
    "Year view" : "Vista anual",
    "List view" : "Vista de lista",
    "Actions" : "Acciones",
    "Create event" : "Crear evento",
    "Show shortcuts" : "Mostrar accesos directos",
    "Editor" : "Editor",
    "Close editor" : "Cerrar editor",
    "Save edited event" : "Guardar evento editado",
    "Delete edited event" : "Eliminar evento editado",
    "Duplicate event" : "Duplicar evento",
    "or" : "o",
    "Calendar settings" : "Configuración del calendario",
    "No reminder" : "Sin recordatorio",
    "General" : "General",
    "Appearance" : "Apariencia",
    "Editing" : "Edición",
    "Default reminder" : "Recordatorio predeterminado",
    "Files" : "Archivo",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minuto","{duration} minutos","{duration} minutos"],
    "0 minutes" : "0 minutos",
    "_{duration} hour_::_{duration} hours_" : ["{duration} hora","{duration} horas","{duration} horas"],
    "_{duration} day_::_{duration} days_" : ["{duration} día","{duration} días","{duration} días"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} semana","{duration} semanas","{duration} semanas"],
    "_{duration} month_::_{duration} months_" : ["{duration} mes","{duration} meses","{duration} meses"],
    "_{duration} year_::_{duration} years_" : ["{duration} año","{duration} años","{duration} años"],
    "To configure appointments, add your email address in personal settings." : "Para configurar las citas, agrega tu dirección de correo electrónico en la configuración personal.",
    "Public – shown on the profile page" : "Público: se muestra en la página de perfil",
    "Private – only accessible via secret link" : "Privado: solo accesible mediante enlace secreto",
    "Update" : "Actualizar",
    "Appointment name" : "Nombre de la cita",
    "Location" : "Ubicación",
    "Description" : "Descripción",
    "Visibility" : "Visibilidad",
    "Duration" : "Duración",
    "Increments" : "Incrementos",
    "Additional calendars to check for conflicts" : "Calendarios adicionales para verificar conflictos",
    "Pick time ranges where appointments are allowed" : "Selecciona rangos de tiempo en los que se permiten citas",
    "to" : "para",
    "Delete slot" : "Eliminar ranura",
    "No times set" : "No se han establecido horarios",
    "Add" : "Agregar",
    "Monday" : "Lunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Jueves",
    "Friday" : "Viernes",
    "Saturday" : "Sábado",
    "Sunday" : "Domingo",
    "Add time before and after the event" : "Agregar tiempo antes y después del evento",
    "Before the event" : "Antes del evento",
    "After the event" : "Después del evento",
    "Planning restrictions" : "Restricciones de planificación",
    "Minimum time before next available slot" : "Tiempo mínimo antes del próximo espacio disponible",
    "Max slots per day" : "Máximo de espacios por día",
    "Limit how far in the future appointments can be booked" : "Limitar qué tan lejos en el futuro se pueden reservar citas",
    "Please confirm your reservation" : "Confirma tu reserva",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Te hemos enviado un correo electrónico con los detalles. Confirma tu cita utilizando el enlace del correo electrónico. Puedes cerrar esta página ahora.",
    "Your name" : "Tu nombre",
    "Your email address" : "Tu dirección de correo electrónico",
    "Please share anything that will help prepare for our meeting" : "Por favor, comparte cualquier información que ayude a prepararnos para nuestra reunión",
    "Could not book the appointment. Please try again later or contact the organizer." : "No se pudo reservar la cita. Inténtalo de nuevo más tarde o contacta al organizador.",
    "Back" : "Regresar",
    "Select conversation" : "Seleccionar conversación",
    "on" : "el",
    "at" : "a las",
    "before at" : "antes a las",
    "Notification" : "Notificación",
    "Email" : "Correo electrónico",
    "Audio notification" : "Notificación de audio",
    "Other notification" : "Otra notificación",
    "Relative to event" : "Relativo al evento",
    "On date" : "En fecha",
    "Edit time" : "Editar hora",
    "Save time" : "Guardar hora",
    "Remove reminder" : "Eliminar recordatorio",
    "Add reminder" : "Agregar recordatorio",
    "seconds" : "segundos",
    "minutes" : "minutos",
    "hours" : "horas",
    "days" : "días",
    "weeks" : "semanas",
    "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
    "Choose a file to share as a link" : "Elige un archivo para compartir como enlace",
    "Attachment {name} already exist!" : "¡El adjunto {name} ya existe!",
    "No attachments" : "Sin adjuntos",
    "Add from Files" : "Agregar desde Archivos",
    "Upload from device" : "Subir desde el dispositivo",
    "Delete file" : "Borrar archivo",
    "Confirmation" : "Confirmación",
    "_{count} attachment_::_{count} attachments_" : ["{count} adjunto","{count} adjuntos","{count} adjuntos"],
    "Suggested" : "Sugerido",
    "Available" : "Disponible",
    "Invitation accepted" : "Invitación aceptada",
    "Accepted {organizerName}'s invitation" : "Aceptó la invitación de {organizerName}",
    "Participation marked as tentative" : "Participación marcada como tentativa",
    "Invitation is delegated" : "La invitación ha sido delegada",
    "Not available" : "No disponible",
    "Invitation declined" : "Invitación rechazada",
    "Declined {organizerName}'s invitation" : "Rechazó la invitación de {organizerName}",
    "Checking availability" : "Verificando disponibilidad",
    "Has not responded to {organizerName}'s invitation yet" : "No ha respondido a la invitación de {organizerName} aún",
    "{organizer} (organizer)" : "{organizer} (organizador)",
    "Availability of attendees, resources and rooms" : "Disponibilidad de asistentes, recursos y salas",
    "Legend" : "Leyenda",
    "Out of office" : "Fuera de la oficina",
    "Attendees:" : "Asistentes:",
    "Done" : "Hecho",
    "Room name" : "Nombre de la sala",
    "Free" : "Disponible",
    "Busy (tentative)" : "Ocupado (tentativo)",
    "Busy" : "Ocupado",
    "Unknown" : "Desconocido",
    "The invitation has been accepted successfully." : "La invitación se aceptó correctamente.",
    "Failed to accept the invitation." : "No se pudo aceptar la invitación.",
    "The invitation has been declined successfully." : "La invitación se rechazó correctamente.",
    "Failed to decline the invitation." : "No se pudo rechazar la invitación.",
    "Your participation has been marked as tentative." : "Tu participación se ha marcado como tentativa.",
    "Failed to set the participation status to tentative." : "No se pudo establecer el estado de participación como tentativa.",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "Tentative" : "Tentativo",
    "No attendees yet" : "Aún no hay asistentes",
    "Attendees" : "Asistentes",
    "Remove group" : "Eliminar grupo",
    "Remove attendee" : "Eliminar asistente",
    "Chairperson" : "Presidente",
    "Required participant" : "Participante requerido",
    "Optional participant" : "Participante opcional",
    "Non-participant" : "No participante",
    "No match found" : "No se encontraron coincidencias",
    "(organizer)" : "(organizador)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Para enviar invitaciones y manejar respuestas, [linkopen]agrega tu dirección de correo electrónico en la configuración personal[linkclose].",
    "Remove color" : "Eliminar color",
    "Event title" : "Título del evento",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "No se puede modificar la configuración de todo el día para eventos que forman parte de un conjunto de repeticiones.",
    "From" : "De",
    "To" : "A",
    "Repeat" : "Repetir",
    "_time_::_times_" : ["hora","veces","veces"],
    "never" : "nunca",
    "on date" : "en la fecha",
    "after" : "después",
    "End repeat" : "Finalizar repetición",
    "Select to end repeat" : "Seleccionar para finalizar la repetición",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Este evento es una excepción de la recurrencia de un conjunto de repeticiones. No puedes agregar una regla de recurrencia a él.",
    "first" : "primero",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Los cambios en la regla de recurrencia solo se aplicarán a esta y a todas las siguientes ocurrencias.",
    "Repeat every" : "Repetir cada",
    "By day of the month" : "Por día del mes",
    "On the" : "El",
    "_day_::_days_" : ["día","días","días"],
    "_week_::_weeks_" : ["semana","semanas","semanas"],
    "_month_::_months_" : ["mes","meses","meses"],
    "_year_::_years_" : ["año","años","años"],
    "weekday" : "día de la semana",
    "weekend day" : "día de fin de semana",
    "Does not repeat" : "No se repite",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "La definición de recurrencia de este evento no es completamente compatible con Nextcloud. Si editas las opciones de recurrencia, es posible que se pierdan ciertas repeticiones.",
    "No rooms or resources yet" : "Aún no hay salas o recursos",
    "Resources" : "Recursos",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} asiento","{seatingCapacity} asientos","{seatingCapacity} asientos"],
    "Add resource" : "Agregar recurso",
    "Has a projector" : "Tiene proyector",
    "Has a whiteboard" : "Tiene pizarra",
    "Wheelchair accessible" : "Accesible en silla de ruedas",
    "Remove resource" : "Eliminar recurso",
    "Search for resources or rooms" : "Buscar recursos o salas",
    "available" : "disponible",
    "unavailable" : "no disponible",
    "Projector" : "Proyector",
    "Whiteboard" : "Pizarra",
    "Room type" : "Tipo de sala",
    "Any" : "Cualquiera",
    "Minimum seating capacity" : "Capacidad mínima de asientos",
    "Update this and all future" : "Actualizar esta y todas las siguientes",
    "Update this occurrence" : "Actualizar esta ocurrencia",
    "Public calendar does not exist" : "El calendario público no existe",
    "Maybe the share was deleted or has expired?" : "¿Tal vez la compartición fue eliminada o ha expirado?",
    "Maybe" : "Tal vez",
    "None" : "Ninguno",
    "Create" : "Crear",
    "from {formattedDate}" : "desde {formattedDate}",
    "to {formattedDate}" : "hasta {formattedDate}",
    "on {formattedDate}" : "el {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "desde {formattedDate} a las {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "hasta {formattedDate} a las {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "el {formattedDate} a las {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} a las {formattedTime}",
    "Please enter a valid date" : "Ingresa una fecha válida",
    "Please enter a valid date and time" : "Ingresa una fecha y hora válidas",
    "Please select a time zone:" : "Selecciona una zona horaria:",
    "Pick a time" : "Seleccionar una hora",
    "Pick a date" : "Selecciona una fecha",
    "Type to search time zone" : "Escribe para buscar la zona horaria",
    "Global" : "Global",
    "Holidays in {region}" : "Vacaciones en {región}",
    "Public holiday calendars" : "Calendarios de días festivos públicos",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Los calendarios de días festivos públicos son proporcionados por Thunderbird. Los datos del calendario se descargarán desde {website}",
    "By {authors}" : "Por {authors}",
    "Subscribed" : "Suscrito",
    "Subscribe" : "Suscribir",
    "Select slot" : "Seleccionar intervalo",
    "No slots available" : "No hay intervalos disponibles",
    "The slot for your appointment has been confirmed" : "El intervalo para tu cita ha sido confirmado",
    "Appointment Details:" : "Detalles de la cita:",
    "Time:" : "Hora:",
    "Booked for:" : "Reservado para:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Gracias. Tu reserva desde {startDate} hasta {endDate} ha sido confirmada.",
    "Book another appointment:" : "Reservar otra cita:",
    "See all available slots" : "Ver todos los intervalos disponibles",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "El intervalo para tu cita desde {startDate} hasta {endDate} ya no está disponible.",
    "Please book a different slot:" : "Por favor, reserva un intervalo diferente:",
    "Book an appointment with {name}" : "Reservar una cita con {name}",
    "No public appointments found for {name}" : "No se encontraron citas públicas para {name}",
    "Personal" : "Personal",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "La detección automática de la zona horaria determinó que tu zona horaria es UTC.\n      Esto es probablemente el resultado de medidas de seguridad de tu navegador web.\n      Por favor, establece tu zona horaria manualmente en la configuración del calendario.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "No se encontró tu zona horaria configurada ({timezoneId}). Se usará UTC.\n      Por favor, cambia tu zona horaria en la configuración y reporta este problema.",
    "Edit event" : "Editar evento",
    "Event does not exist" : "El evento no existe",
    "Duplicate" : "Duplicar",
    "Delete this occurrence" : "Eliminar esta ocurrencia",
    "Delete this and all future" : "Eliminar esta y todas las siguientes",
    "All day" : "Todo el día",
    "Managing shared access" : "Gestionar acceso compartido",
    "Deny access" : "Denegar acceso",
    "Invite" : "Invitar",
    "_User requires access to your file_::_Users require access to your file_" : ["El usuario necesita acceso a tu archivo","Los usuarios necesitan acceso a tu archivo","Los usuarios necesitan acceso a tu archivo"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["El adjunto requiere acceso compartido","Los adjuntos requieren acceso compartido","Los adjuntos requieren acceso compartido"],
    "Untitled event" : "Evento sin título",
    "Close" : "Cerrar",
    "Title" : "Título",
    "30 min" : "30 minutos",
    "Participants" : "Participantes",
    "Submit" : "Enviar",
    "Subscribe to {name}" : "Suscribirse a {name}",
    "Export {name}" : "Exportar {name}",
    "Anniversary" : "Aniversario",
    "Appointment" : "Cita",
    "Business" : "Negocios",
    "Education" : "Educación",
    "Holiday" : "Vacaciones",
    "Meeting" : "Reunión",
    "Miscellaneous" : "Varios",
    "Non-working hours" : "Horas no laborables",
    "Not in office" : "No en la oficina",
    "Phone call" : "Llamada telefónica",
    "Sick day" : "Día de enfermedad",
    "Special occasion" : "Ocasión especial",
    "Travel" : "Viaje",
    "Vacation" : "Vacaciones",
    "Midnight on the day the event starts" : "Medianoche en el día en que comienza el evento",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n día antes del evento a las {formattedHourMinute}","%n días antes del evento a las {formattedHourMinute}","%n días antes del evento a las {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n semana antes del evento a las {formattedHourMinute}","%n semanas antes del evento a las {formattedHourMinute}","%n semanas antes del evento a las {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "el día del evento a las {formattedHourMinute}",
    "at the event's start" : "al comienzo del evento",
    "at the event's end" : "al final del evento",
    "{time} before the event starts" : "{time} antes de que el evento comience",
    "{time} before the event ends" : "{time} antes de que el evento termine",
    "{time} after the event starts" : "{time} después de que el evento comienza",
    "{time} after the event ends" : "{time} después de que el evento termina",
    "on {time}" : "en {time}",
    "on {time} ({timezoneId})" : "en {time} ({timezoneId})",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "Monthly" : "Mensual",
    "Yearly" : "Anual",
    "_Every %n day_::_Every %n days_" : ["Cada %n día","Cada %n días","Cada %n días"],
    "_Every %n week_::_Every %n weeks_" : ["Cada %n semana","Cada %n semanas","Cada %n semanas"],
    "_Every %n month_::_Every %n months_" : ["Cada %n mes","Cada %n meses","Cada %n meses"],
    "_Every %n year_::_Every %n years_" : ["Cada %n año","Cada %n años","Cada %n años"],
    "_on {weekday}_::_on {weekdays}_" : ["en {weekday}","en {weekdays}","en {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["en el día {dayOfMonthList}","en los días {dayOfMonthList}","en los días {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "en el {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "en {monthNames} el {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "hasta {untilDate}",
    "_%n time_::_%n times_" : ["%n vez","%n veces","%n veces"],
    "second" : "segundo",
    "third" : "tercero",
    "fourth" : "cuarto",
    "fifth" : "quinto",
    "second to last" : "penúltimo",
    "last" : "último",
    "Untitled task" : "Tarea sin título",
    "Please ask your administrator to enable the Tasks App." : "Pide a tu administrador que habilite la aplicación de Tareas.",
    "W" : "S",
    "%n more" : "%n más",
    "No events to display" : "No hay eventos para mostrar",
    "_+%n more_::_+%n more_" : ["+%n más","+%n más","+%n más"],
    "No events" : "No hay eventos",
    "Create a new event or change the visible time-range" : "Crea un evento nuevo o cambia el rango de tiempo visible",
    "It might have been deleted, or there was a typo in a link" : "Puede que se haya eliminado o haya un error de escritura en el enlace",
    "It might have been deleted, or there was a typo in the link" : "Puede que se haya eliminado o haya un error de escritura en el enlace",
    "Meeting room" : "Sala de reuniones",
    "Lecture hall" : "Aula",
    "Seminar room" : "Sala de seminarios",
    "Other" : "Otro",
    "When shared show" : "Cuando se comparte, mostrar",
    "When shared show full event" : "Al compartir, mostrar el evento completo",
    "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
    "When shared hide this event" : "Al compartir, ocultar este evento ",
    "Add a location" : "Agregar una ubicación",
    "Status" : "Estatus",
    "Confirmed" : "Confirmado",
    "Canceled" : "Cancelada",
    "Confirmation about the overall status of the event." : "Confirmación sobre el estado general del evento.",
    "Show as" : "Mostrar como",
    "Take this event into account when calculating free-busy information." : "Tener en cuenta este evento al calcular la información de disponibilidad ocupado-libre.",
    "Categories" : "Categorías",
    "Categories help you to structure and organize your events." : "Las categorías te ayudan a estructurar y organizar tus eventos.",
    "Search or add categories" : "Buscar o agregar categorías",
    "Add this as a new category" : "Agregar esto como una nueva categoría",
    "Custom color" : "Color personalizado",
    "Special color of this event. Overrides the calendar-color." : "Color especial de este evento. Anula el color del calendario.",
    "Error while sharing file" : "Error al compartir el archivo",
    "Error while sharing file with user" : "Error al compartir el archivo con el usuario",
    "Attachment {fileName} already exists!" : "¡El adjunto {fileName} ya existe!",
    "An error occurred during getting file information" : "Ocurrió un error al obtener la información del archivo",
    "An error occurred, unable to delete the calendar." : "Ocurrió un error, no se pudo eliminar el calendario.",
    "Imported {filename}" : "Importado {filename}",
    "This is an event reminder." : "Esto es un recordatorio de evento.",
    "Appointment not found" : "Cita no encontrada",
    "User not found" : "No se encontró el usuario",
    "Hidden" : "Oculto",
    "can edit" : "puede editar",
    "Calendar name …" : "Nombre del calendario …",
    "Default attachments location" : "Ubicación predeterminada para adjuntos",
    "Automatic ({detected})" : "Automático ({detected})",
    "Shortcut overview" : "Resumen de accesos directos",
    "CalDAV link copied to clipboard." : "Enlace CalDAV copiado al portapapeles.",
    "CalDAV link could not be copied to clipboard." : "No se pudo copiar el enlace CalDAV al portapapeles.",
    "Enable birthday calendar" : "Habilitar calendario de cumpleaños",
    "Show tasks in calendar" : "Mostrar tareas en el calendario",
    "Enable simplified editor" : "Habilitar editor simplificado",
    "Limit the number of events displayed in the monthly view" : "Limitar la cantidad de eventos mostrados en la vista mensual",
    "Show weekends" : "Mostrar fines de semana",
    "Show week numbers" : "Mostrar número de semana",
    "Time increments" : "Incrementos de tiempo",
    "Copy primary CalDAV address" : "Copiar dirección CalDAV principal",
    "Copy iOS/macOS CalDAV address" : "Copiar dirección CalDAV para iOS/macOS",
    "Personal availability settings" : "Configuración de disponibilidad personal",
    "Show keyboard shortcuts" : "Mostrar accesos directos de teclado",
    "Successfully appended link to talk room to description." : "Enlace a la sala de Talk se agregó correctamente a la descripción.",
    "Error creating Talk room" : "Error al crear la sala de Talk",
    "The visibility of this event in shared calendars." : "La visibilidad de este evento en calendarios compartidos."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
