OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Provided email-address is too long",
    "User-Session unexpectedly expired" : "نشست کاربر به طور غیر منتظره منقضی شد",
    "Provided email-address is not valid" : "ایمیل ارائه شده معتبر نیست",
    "%s has published the calendar »%s«" : "%sتقویم %s را منتشر کرده است.",
    "Unexpected error sending email. Please contact your administrator." : "خطای غیر منتظره در ارسال ایمیل. لطفا با مدیر خود تماس بگیرید.",
    "Successfully sent email to %1$s" : "Successfully sent email to %1$s",
    "Hello," : "سلام،",
    "We wanted to inform you that %s has published the calendar »%s«." : "مایل هستیم به شما اطلاع دهیم که %s تقویم شماره %s را منتشر کرده است.",
    "Open »%s«" : "باز کن »%s«",
    "Cheers!" : "سلامتی!",
    "Upcoming events" : "رویدادهای پیش‌رو",
    "No more events today" : "هیچ رویداد دیگری برای امروز وجود ندارد",
    "No upcoming events" : "رویداد پیش‌رویی وجود ندارد",
    "More events" : "More events",
    "%1$s with %2$s" : "%1$s with %2$s",
    "Calendar" : "تقویم",
    "New booking {booking}" : "New booking {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}.",
    "Appointments" : "قرارها",
    "Schedule appointment \"%s\"" : "Schedule appointment \"%s\"",
    "Schedule an appointment" : "Schedule an appointment",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : "Prepare for %s",
    "Follow up for %s" : "Follow up for %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Your appointment \"%s\" with %s needs confirmation",
    "Dear %s, please confirm your booking" : "Dear %s, please confirm your booking",
    "Confirm" : "تائید",
    "Description:" : "توضیحات:",
    "This confirmation link expires in %s hours." : "This confirmation link expires in %s hours.",
    "Your appointment \"%s\" with %s has been accepted" : "Your appointment \"%s\" with %s has been accepted",
    "Dear %s, your booking has been accepted." : "Dear %s, your booking has been accepted.",
    "Appointment for:" : "Appointment for:",
    "Date:" : "تاریخ:",
    "Where:" : "مکان:",
    "Comment:" : "Comment:",
    "You have a new appointment booking \"%s\" from %s" : "You have a new appointment booking \"%s\" from %s",
    "Dear %s, %s (%s) booked an appointment with you." : "Dear %s, %s (%s) booked an appointment with you.",
    "Location:" : "مکان:",
    "A Calendar app for Nextcloud" : "یک برنامه تقویم برای نکست کلود",
    "Previous day" : "روز قبل",
    "Previous week" : "هفته قبل",
    "Previous year" : "Previous year",
    "Previous month" : "ماه قبل",
    "Next day" : "روز بعد",
    "Next week" : "هفته بعد",
    "Next year" : "Next year",
    "Next month" : "ماه بعد",
    "Create new event" : "Create new event",
    "Event" : "رویداد",
    "Today" : "امروز",
    "Day" : "روز",
    "Week" : "هفته",
    "Month" : "ماه",
    "Year" : "سال",
    "List" : "فهرست",
    "Appointment link was copied to clipboard" : "Appointment link was copied to clipboard",
    "Appointment link could not be copied to clipboard" : "Appointment link could not be copied to clipboard",
    "Preview" : "پیش‌نمایش",
    "Copy link" : "کپی کردن لینک",
    "Edit" : "ویرایش",
    "Delete" : "حذف",
    "Create new" : "ایجاد جدید",
    "Disable calendar \"{calendar}\"" : "Disable calendar \"{calendar}\"",
    "Disable untitled calendar" : "Disable untitled calendar",
    "Enable calendar \"{calendar}\"" : "Enable calendar \"{calendar}\"",
    "Enable untitled calendar" : "Enable untitled calendar",
    "An error occurred, unable to change visibility of the calendar." : "خطایی روی داد ، قادر به تغییر دیدگاه تقویم نیست.",
    "Untitled calendar" : "تقویم بدون عنوان",
    "Shared with you by" : "با شما به اشتراک گذاشته شده است",
    "Edit and share calendar" : "Edit and share calendar",
    "Edit calendar" : "ویرایش تقویم",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["اشتراک‌گذاری تقویم در {شمارش معکوس}. ثانیه","اشتراک‌گذاری تقویم در {شمارش معکوس}. ثانیه ها"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["حذف تقویم در {شمارش معکوس} ثانیه ها","حذف تقویم در {شمارش معکوس} ثانیه ها"],
    "An error occurred, unable to create the calendar." : "خطایی روی داد ، قادر به ایجاد تقویم نیست.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "لطفاً یک پیوند معتبر وارد کنید (با شروع http: // ، https: // ، webcal: // ، یا صفحات وب: //)",
    "Calendars" : "تقویم‌ها",
    "Add new" : "افزودن مورد تازه",
    "New calendar" : "تقویم جدید",
    "Name for new calendar" : "Name for new calendar",
    "Creating calendar …" : "ایجاد تقویم ...",
    "New calendar with task list" : "تقویم جدید با لیست کارها",
    "New subscription from link (read-only)" : "اشتراک جدید از پیوند (فقط خواندنی)",
    "Creating subscription …" : "ایجاد اشتراک…",
    "Add public holiday calendar" : "Add public holiday calendar",
    "Calendar link copied to clipboard." : "پیوند تقویم در کلیپ بورد کپی شد.",
    "Calendar link could not be copied to clipboard." : "پیوند تقویم را نمی توان در کلیپ بورد کپی کرد.",
    "Copy subscription link" : "پیوند اشتراک را کپی کنید",
    "Copying link …" : "کپی پیوند ...",
    "Copied link" : "پیوند کپی شد",
    "Could not copy link" : "نمی توان پیوند را کپی کرد",
    "Export" : "دریافت خروجی",
    "Untitled item" : "مورد بدون عنوان",
    "Unknown calendar" : "تقویم ناشناخته",
    "Could not load deleted calendars and objects" : "تقویم و اشیاء حذف شده بارگیری نشد",
    "Could not delete calendar or event" : "تقویم یا رویداد حذف نشد",
    "Could not restore calendar or event" : "تقویم یا رویداد بازیابی نشد",
    "Do you really want to empty the trash bin?" : "آیا واقعاً می خواهید سطل زباله را خالی کنید؟",
    "Empty trash bin" : "خالی کردن سطل زباله",
    "Trash bin" : "زباله‌دان",
    "Loading deleted items." : "Loading deleted items.",
    "You do not have any deleted items." : "You do not have any deleted items.",
    "Name" : "نام",
    "Deleted" : "حذف شده",
    "Restore" : "بازیابی",
    "Delete permanently" : "حذف قطعی",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Items in the trash bin are deleted after {numDays} day","Items in the trash bin are deleted after {numDays} days"],
    "Could not update calendar order." : "Could not update calendar order.",
    "Deck" : "برگه‌دان",
    "Internal link" : "پیوند داخلی",
    "A private link that can be used with external clients" : "A private link that can be used with external clients",
    "Copy internal link" : "کپی کردن پیوند داخلی",
    "An error occurred, unable to publish calendar." : "خطایی روی داد ، قادر به انتشار تقویم نیست.",
    "An error occurred, unable to send email." : "خطایی روی داد ، قادر به ارسال ایمیل نیست.",
    "Embed code copied to clipboard." : "کد قرار داده شده در حافظه کپی شد.",
    "Embed code could not be copied to clipboard." : "کد جاسازی را نمی توان در کلیپ بورد کپی کرد.",
    "Unpublishing calendar failed" : "عدم انتشار تقویم موفقیت آمیز نبود",
    "Share link" : "لینک را به اشتراک بگذارید",
    "Copy public link" : "پیوند عمومی را کپی کنید",
    "Send link to calendar via email" : "ارسال پیوند به تقویم از طریق ایمیل",
    "Enter one address" : "یک آدرس وارد کنید",
    "Sending email …" : "ارسال ایمیل…",
    "Copy embedding code" : "کد تعبیه شده را کپی کنید",
    "Copying code …" : "کپی کردن کد ...",
    "Copied code" : "کد کپی شد",
    "Could not copy code" : "نمی توان کد را کپی کرد",
    "Delete share link" : "پیوند اشتراک را حذف کنید",
    "Deleting share link …" : "در حال حذف پیوند اشتراک ...",
    "An error occurred while unsharing the calendar." : "An error occurred while unsharing the calendar.",
    "An error occurred, unable to change the permission of the share." : "خطایی روی داد ، قادر به تغییر مجوز اشتراک نیست.",
    "Unshare with {displayName}" : "عدم اشتراک گذاری با {displayName}",
    "Share with users or groups" : "اشتراک گذاری با کاربران یا گروه ها ...",
    "No users or groups" : "هیچ کاربر یا گروهی وجود ندارد",
    "Failed to save calendar name and color" : "Failed to save calendar name and color",
    "Share calendar" : "Share calendar",
    "Unshare from me" : "بی خبر از من",
    "Save" : "ذخیره",
    "No title" : "No title",
    "View" : "نمایش",
    "Import calendars" : "وارد کردن تقویم ها",
    "Please select a calendar to import into …" : "لطفاً یک تقویم را برای وارد کردن به… انتخاب کنید",
    "Filename" : "نام پرونده",
    "Calendar to import into" : "تقویم برای وارد کردن",
    "Cancel" : "منصرف شدن",
    "_Import calendar_::_Import calendars_" : ["وارد کردن تقویم","وارد کردن تقویم ها"],
    "Select the default location for attachments" : "Select the default location for attachments",
    "Invalid location selected" : "مکان نامعتبر انتخاب شده است",
    "Attachments folder successfully saved." : "Attachments folder successfully saved.",
    "Error on saving attachments folder." : "Error on saving attachments folder.",
    "Attachments folder" : "Attachments folder",
    "{filename} could not be parsed" : "{filename} could not be parsed",
    "No valid files found, aborting import" : "No valid files found, aborting import",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Successfully imported %n event","Successfully imported %n events"],
    "Import partially failed. Imported {accepted} out of {total}." : "وارد کردن تا حدودی انجام نشد. وارد شده {accepted} بیرون از {total}.",
    "Automatic" : "خودکار",
    "Automatic ({timezone})" : "خودکار ({شناسایی})",
    "New setting was not saved successfully." : "تنظیم جدید با موفقیت ذخیره نشد.",
    "Navigation" : "جهت یابی",
    "Previous period" : "دوره قبلی",
    "Next period" : "دوره بعدی",
    "Views" : "بازدیدها",
    "Day view" : "نمای روز",
    "Week view" : "نمای هفته",
    "Month view" : "نمای ماه",
    "Year view" : "نمای سال",
    "List view" : "نمایش لیست",
    "Actions" : "فعالیت ها",
    "Create event" : "ایجاد رویداد",
    "Show shortcuts" : "نمایش میانبرها",
    "Editor" : "ویرایشگر",
    "Close editor" : "ویرایشگر را ببندید",
    "Save edited event" : "رویداد ویرایش شده را ذخیره کنید",
    "Delete edited event" : "حذف رویداد ویرایش شده",
    "Duplicate event" : "رویداد تکراری",
    "or" : "یا",
    "Calendar settings" : "تنظیمات تقویم",
    "No reminder" : "No reminder",
    "General" : "عمومی",
    "Appearance" : "ظاهر",
    "Editing" : "ویرایش کردن",
    "Default reminder" : "Default reminder",
    "Files" : "پرونده‌ها",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minute","{duration} minutes"],
    "0 minutes" : "0 minutes",
    "_{duration} hour_::_{duration} hours_" : ["{duration} hour","{duration} hours"],
    "_{duration} day_::_{duration} days_" : ["{duration} day","{duration} days"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} week","{duration} weeks"],
    "_{duration} month_::_{duration} months_" : ["{duration} month","{duration} months"],
    "_{duration} year_::_{duration} years_" : ["{duration} year","{duration} years"],
    "To configure appointments, add your email address in personal settings." : "To configure appointments, add your email address in personal settings.",
    "Public – shown on the profile page" : "عمومی – در صفحهٔ نمایه نشان داده می‌شود",
    "Private – only accessible via secret link" : "Private – only accessible via secret link",
    "Update" : "به روز رسانی",
    "Appointment name" : "Appointment name",
    "Location" : "مکان",
    "Create a Talk room" : "ایجاد اتاق گفتگو",
    "Description" : "توضیحات",
    "Visibility" : "Visibility",
    "Duration" : "مدت زمان",
    "Increments" : "Increments",
    "Additional calendars to check for conflicts" : "Additional calendars to check for conflicts",
    "Pick time ranges where appointments are allowed" : "Pick time ranges where appointments are allowed",
    "to" : "به",
    "Delete slot" : "Delete slot",
    "No times set" : "No times set",
    "Add" : "افزودن",
    "Monday" : "دوشنبه",
    "Tuesday" : "سه‌شنبه",
    "Wednesday" : "چهارشنبه",
    "Thursday" : "پنج‌شنبه",
    "Friday" : "جمعه",
    "Saturday" : "شنبه",
    "Sunday" : "یکشنبه",
    "Weekdays" : "روزهای هفته",
    "Add time before and after the event" : "Add time before and after the event",
    "Before the event" : "Before the event",
    "After the event" : "After the event",
    "Planning restrictions" : "Planning restrictions",
    "Minimum time before next available slot" : "Minimum time before next available slot",
    "Max slots per day" : "Max slots per day",
    "Limit how far in the future appointments can be booked" : "Limit how far in the future appointments can be booked",
    "Please confirm your reservation" : "Please confirm your reservation",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now.",
    "Your name" : "اسم شما",
    "Your email address" : "پست الکترونیکی شما",
    "Could not book the appointment. Please try again later or contact the organizer." : "Could not book the appointment. Please try again later or contact the organizer.",
    "Back" : "Back",
    "Select conversation" : "مکالمه را انتخاب کنید",
    "on" : "بر",
    "at" : "در",
    "before at" : "قبل از در",
    "Notification" : "اطلاع",
    "Email" : "ایمیل",
    "Audio notification" : "اعلان صوتی",
    "Other notification" : "سایر اعلان ها",
    "Relative to event" : "نسبت به واقعه",
    "On date" : "در تاریخ",
    "Edit time" : "ویرایش زمان",
    "Save time" : "صرفه جویی در وقت",
    "Remove reminder" : "یادآوری را حذف کنید",
    "Add reminder" : "Add reminder",
    "seconds" : "ثانیه ها",
    "minutes" : "دقیقه",
    "hours" : "ساعت",
    "days" : "روز",
    "weeks" : "هفته",
    "Choose a file to add as attachment" : "پرونده ای را برای اضافه کردن به عنوان پیوست انتخاب کنید",
    "Choose a file to share as a link" : "Choose a file to share as a link",
    "Attachment {name} already exist!" : "Attachment {name} already exist!",
    "Proceed" : "ادامه دادن",
    "No attachments" : "No attachments",
    "Add from Files" : "Add from Files",
    "Upload from device" : "Upload from device",
    "Delete file" : "حذف پرونده",
    "Confirmation" : "Confirmation",
    "_{count} attachment_::_{count} attachments_" : ["{count} attachment","{count} attachments"],
    "Suggested" : "Suggested",
    "Available" : "در دسترس",
    "Invitation accepted" : "Invitation accepted",
    "Accepted {organizerName}'s invitation" : "Accepted {organizerName}'s invitation",
    "Participation marked as tentative" : "Participation marked as tentative",
    "Invitation is delegated" : "Invitation is delegated",
    "Not available" : "در دسترس نیست",
    "Invitation declined" : "Invitation declined",
    "Declined {organizerName}'s invitation" : "Declined {organizerName}'s invitation",
    "Checking availability" : "Checking availability",
    "Has not responded to {organizerName}'s invitation yet" : "Has not responded to {organizerName}'s invitation yet",
    "{organizer} (organizer)" : "{organizer} (organizer)",
    "Availability of attendees, resources and rooms" : "در دسترس بودن شرکت کنندگان ، منابع و اتاق ها",
    "Legend" : "Legend",
    "Out of office" : "بیرون از دفتر",
    "Attendees:" : "شرکت‌کنندگان:",
    "Done" : "Done",
    "Room name" : "Room name",
    "Free" : "آزاد",
    "Busy (tentative)" : "مشغول (آزمایشی)",
    "Busy" : "مشغول",
    "Unknown" : "نامشخص",
    "The invitation has been accepted successfully." : "The invitation has been accepted successfully.",
    "Failed to accept the invitation." : "Failed to accept the invitation.",
    "The invitation has been declined successfully." : "The invitation has been declined successfully.",
    "Failed to decline the invitation." : "Failed to decline the invitation.",
    "Your participation has been marked as tentative." : "Your participation has been marked as tentative.",
    "Failed to set the participation status to tentative." : "Failed to set the participation status to tentative.",
    "Accept" : "تایید",
    "Decline" : "کاهش می یابد",
    "Tentative" : "آزمایشی",
    "No attendees yet" : "هنوز هیچ حضوری وجود ندارد",
    "Attendees" : "شرکت کنندگان",
    "Remove group" : "برداشتن گروه",
    "Remove attendee" : "شرکت کننده را حذف کنید",
    "Chairperson" : "رئیس",
    "Required participant" : "شرکت کننده مورد نیاز",
    "Optional participant" : "شرکت کننده اختیاری",
    "Non-participant" : "غیر شرکت کننده",
    "_%n member_::_%n members_" : ["%n عضو","%n عضو"],
    "No match found" : "هیچ تطبیقی یافت نشد",
    "(organizer)" : "(تنظیم کننده)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose].",
    "Remove color" : "Remove color",
    "Event title" : "عنوان رویداد",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Cannot modify all-day setting for events that are part of a recurrence-set.",
    "From" : "از",
    "To" : "به",
    "Repeat" : "تکرار",
    "_time_::_times_" : ["بار","بارها"],
    "never" : "هرگز",
    "on date" : "در تاریخ",
    "after" : "بعد از",
    "End repeat" : "پایان تکرار ",
    "Select to end repeat" : "برای پایان دادن به تکرار انتخاب کنید",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it.",
    "first" : "اولین",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "تغییر در قانون بازگشتی فقط در مورد این و همه وقایع آینده اعمال خواهد شد.",
    "Repeat every" : "همه را تکرار کنید",
    "By day of the month" : "تا روز ماه",
    "On the" : "در",
    "_day_::_days_" : ["روز","روز"],
    "_week_::_weeks_" : ["هفته","هفته"],
    "_month_::_months_" : ["ماه","ماه ها"],
    "_year_::_years_" : ["سال","سال ها"],
    "weekday" : "روز هفته",
    "weekend day" : " آخر  هفته",
    "Does not repeat" : "تکرار نمی کند",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "تعریف بازگشتی از این رویداد توسط نکست کلود کاملاً پشتیبانی نمی شود. اگر گزینه های بازگشتی را ویرایش کنید ، ممکن است بازگشتی های خاصی از بین بروند.",
    "No rooms or resources yet" : "No rooms or resources yet",
    "Resources" : "منابع",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} seat","{seatingCapacity} seats"],
    "Add resource" : "Add resource",
    "Has a projector" : "Has a projector",
    "Has a whiteboard" : "Has a whiteboard",
    "Wheelchair accessible" : "Wheelchair accessible",
    "Remove resource" : "Remove resource",
    "Search for resources or rooms" : "Search for resources or rooms",
    "available" : "در دسترس",
    "unavailable" : "unavailable",
    "Projector" : "Projector",
    "Whiteboard" : "Whiteboard",
    "Room type" : "Room type",
    "Any" : "Any",
    "Minimum seating capacity" : "Minimum seating capacity",
    "Update this and all future" : "این و همه آینده را به روز کنید",
    "Update this occurrence" : "این رویداد را به روز کنید",
    "Public calendar does not exist" : "تقویم عمومی وجود ندارد",
    "Maybe the share was deleted or has expired?" : "شاید اشتراک حذف شده باشد یا منقضی شده باشد؟",
    "Yes" : "بله",
    "No" : "خیر",
    "Maybe" : "Maybe",
    "None" : "هیچ‌کدام",
    "Create" : "ایجاد",
    "from {formattedDate}" : "از {formattedDate}",
    "to {formattedDate}" : "به {formattedDate}",
    "on {formattedDate}" : "در {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "از {formattedDate} در {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "به {formattedDate} در {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "در {formattedDate} در {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} در {formattedTime}",
    "Please enter a valid date" : "لطفا یک تاریخ معتبر وارد کنید",
    "Please enter a valid date and time" : "لطفاً یک تاریخ و زمان معتبر وارد کنید",
    "Please select a time zone:" : "Please select a time zone:",
    "Pick a time" : "Pick a time",
    "Pick a date" : "Pick a date",
    "Type to search time zone" : "Type to search time zone",
    "Global" : "عمومی",
    "Holidays in {region}" : "Holidays in {region}",
    "Public holiday calendars" : "Public holiday calendars",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}",
    "By {authors}" : "By {authors}",
    "Subscribed" : "Subscribed",
    "Subscribe" : "اشتراک گذاری",
    "Select a date" : "تاریخ را انتخاب کنید",
    "Select slot" : "Select slot",
    "No slots available" : "No slots available",
    "The slot for your appointment has been confirmed" : "The slot for your appointment has been confirmed",
    "Appointment Details:" : "Appointment Details:",
    "Time:" : "Time:",
    "Booked for:" : "Booked for:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Thank you. Your booking from {startDate} to {endDate} has been confirmed.",
    "Book another appointment:" : "Book another appointment:",
    "See all available slots" : "See all available slots",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "The slot for your appointment from {startDate} to {endDate} is not available any more.",
    "Please book a different slot:" : "Please book a different slot:",
    "Book an appointment with {name}" : "Book an appointment with {name}",
    "No public appointments found for {name}" : "No public appointments found for {name}",
    "Personal" : "شخصی",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue.",
    "Edit event" : "ویرایش رویداد",
    "Event does not exist" : "رویداد وجود ندارد",
    "Duplicate" : "Duplicate",
    "Delete this occurrence" : "این رخداد را حذف کنید",
    "Delete this and all future" : "این و همه آینده را حذف کنید",
    "All day" : "تمام روز",
    "Managing shared access" : "Managing shared access",
    "Deny access" : "Deny access",
    "Invite" : "Invite",
    "_User requires access to your file_::_Users require access to your file_" : ["User requires access to your file","Users require access to your file"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Attachment requires shared access","Attachments requiring shared access"],
    "Untitled event" : "رویداد بدون عنوان",
    "Close" : "بستن",
    "Title" : "Title",
    "30 min" : "30 min",
    "Participants" : "شركت كنندگان",
    "Submit" : "ارسال",
    "Subscribe to {name}" : "اشتراک در {name}",
    "Export {name}" : "دریافت خروجی از {name}",
    "Anniversary" : "سالگرد",
    "Appointment" : "وقت ملاقات",
    "Business" : "کسب و کار",
    "Education" : "تحصیلات",
    "Holiday" : "تعطیلات",
    "Meeting" : "ملاقات",
    "Miscellaneous" : "متفرقه",
    "Non-working hours" : "ساعات غیر کاری",
    "Not in office" : "در دفتر نیست",
    "Phone call" : "تماس تلفنی",
    "Sick day" : "روز بیماری",
    "Special occasion" : "مناسبت ویژه",
    "Travel" : "مسافرت رفتن",
    "Vacation" : "تعطیلات",
    "Midnight on the day the event starts" : "نیمه شب در روز آغاز این رویداد",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n روز قبل از این رویداد در {formattedHourMinute}","%n روزهای قبل از این رویداد در {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n هفته قبل از این رویداد در {formattedHourMinute}","%n هفته قبل از این رویدادها در {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "در روز رویداد در {formattedHourMinute}",
    "at the event's start" : "در شروع رویداد",
    "at the event's end" : "در پایان رویداد",
    "{time} before the event starts" : "{زمان} قبل از شروع رویداد",
    "{time} before the event ends" : "{زمان} قبل از پایان این رویداد",
    "{time} after the event starts" : "{زمان} بعد از شروع رویداد",
    "{time} after the event ends" : "{زمان} پس از پایان این رویداد",
    "on {time}" : "به {موقع}",
    "on {time} ({timezoneId})" : "در {time} ({timezoneId})",
    "Week {number} of {year}" : "هفتهٔ {number} از {year}",
    "Daily" : "روزانه",
    "Weekly" : "هفته گی",
    "Monthly" : "ماهانه",
    "Yearly" : "سالانه",
    "_Every %n day_::_Every %n days_" : ["هر %n روز","هر %n روزها"],
    "_Every %n week_::_Every %n weeks_" : ["هر %n هفته","هر %n هفته"],
    "_Every %n month_::_Every %n months_" : ["هر %n ماه","هر %n ماه ها"],
    "_Every %n year_::_Every %n years_" : ["هر %n سال","هر %n سال ها"],
    "_on {weekday}_::_on {weekdays}_" : ["در {weekday}","در {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["در روز {dayOfMonthList}","در روزها {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "روی {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "در {monthNames} در {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "تا زمان {untilDate}",
    "_%n time_::_%n times_" : ["%n بار","%n بارها"],
    "second" : "دومین",
    "third" : "سوم",
    "fourth" : "چهارم",
    "fifth" : "پنجم",
    "second to last" : "دوم تا آخرین",
    "last" : "آخر",
    "Untitled task" : "کار بدون عنوان",
    "Please ask your administrator to enable the Tasks App." : "Please ask your administrator to enable the Tasks App.",
    "W" : "W",
    "%n more" : "%n more",
    "No events to display" : "هیچ رویدادی برای نمایش وجود ندارد",
    "_+%n more_::_+%n more_" : ["+%n بیشتر","+%n بیشتر"],
    "No events" : "رویدادی وجود ندارد",
    "Create a new event or change the visible time-range" : "یک رویداد تازه بسازید یا بازه زمانی خود را تغییر بدهید",
    "It might have been deleted, or there was a typo in a link" : "It might have been deleted, or there was a typo in a link",
    "It might have been deleted, or there was a typo in the link" : "It might have been deleted, or there was a typo in the link",
    "Meeting room" : "Meeting room",
    "Lecture hall" : "Lecture hall",
    "Seminar room" : "Seminar room",
    "Other" : "دیگر",
    "When shared show" : "هنگام نمایش مشترک",
    "When shared show full event" : "هنگام اشتراک گذاری ، رویداد کامل را نشان می دهد",
    "When shared show only busy" : "وقتی نمایش اشتراکی فقط مشغول است",
    "When shared hide this event" : "هنگام اشتراک گذاری این رویداد را پنهان کنید",
    "Add a location" : "افزودن یک محل",
    "Status" : "وضعیت",
    "Confirmed" : "تایید شده",
    "Canceled" : "لغو شد",
    "Confirmation about the overall status of the event." : "تأیید درباره وضعیت کلی این رویداد.",
    "Show as" : "نمایش به عنوان",
    "Take this event into account when calculating free-busy information." : "این رویداد در زمان محاسبهٔ اطلاعات آزاد/مشغول، در نظر گرفته شود.",
    "Categories" : "دسته بندی ها",
    "Categories help you to structure and organize your events." : "دسته بندی ها به شما کمک می کنند تا وقایع خود را تنظیم و سازماندهی کنید.",
    "Search or add categories" : "دسته ها را جستجو یا اضافه کنید",
    "Add this as a new category" : "این را به عنوان یک دسته جدید اضافه کنید",
    "Custom color" : "رنگ سفارشی",
    "Special color of this event. Overrides the calendar-color." : "رنگ ویژه این رویداد. رنگ تقویم را نادیده می گیرد.",
    "Error while sharing file" : "Error while sharing file",
    "Error while sharing file with user" : "Error while sharing file with user",
    "Attachment {fileName} already exists!" : "Attachment {fileName} already exists!",
    "An error occurred during getting file information" : "An error occurred during getting file information",
    "An error occurred, unable to delete the calendar." : "خطایی روی داد ، قادر به حذف تقویم نیست.",
    "Imported {filename}" : "وارد شده {نام پرونده}",
    "This is an event reminder." : "This is an event reminder.",
    "Appointment not found" : "Appointment not found",
    "User not found" : "کاربر یافت نشد",
    "Hidden" : "مخفی",
    "can edit" : "می توان ویرایش کرد",
    "Calendar name …" : "نام تقویم …",
    "Default attachments location" : "Default attachments location",
    "Automatic ({detected})" : "خودکار ({شناسایی})",
    "Shortcut overview" : "Shortcut overview",
    "CalDAV link copied to clipboard." : "پیوند CalDAV در کلیپ بورد کپی شد.",
    "CalDAV link could not be copied to clipboard." : "پیوند CalDAV در کلیپ بورد قابل کپی نیست.",
    "Enable birthday calendar" : "تقویم تولد را فعال کنید",
    "Show tasks in calendar" : "نمایش وظایف در تقویم",
    "Enable simplified editor" : "ویرایشگر ساده شده را فعال کنید",
    "Limit the number of events displayed in the monthly view" : "Limit the number of events displayed in the monthly view",
    "Show weekends" : "آخر هفته ها را نشان دهید",
    "Show week numbers" : "نمایش شماره های هفته",
    "Time increments" : "Time increments",
    "Copy primary CalDAV address" : "آدرس اصلی CalDAV را کپی کنید",
    "Copy iOS/macOS CalDAV address" : "آدرس CalDAV iOS / macOS را کپی کنید",
    "Personal availability settings" : "Personal availability settings",
    "Show keyboard shortcuts" : "Show keyboard shortcuts",
    "Successfully appended link to talk room to location." : "Successfully appended link to talk room to location.",
    "Successfully appended link to talk room to description." : "پیوند موفقیت آمیز پیوند به اتاق گفتگو به توضیحات.",
    "Error creating Talk room" : "خطا در ایجاد اتاق گفتگو",
    "The visibility of this event in shared calendars." : "قابلیت مشاهده این رویداد در تقویمهای مشترک."
},
"nplurals=2; plural=(n > 1);");
