"use strict";(self.webpackChunkcalendar=self.webpackChunkcalendar||[]).push([["node_modules_nextcloud_vue_dist_Components_NcSelect_mjs"],{67607:(e,s,a)=>{a.r(s),a.d(s,{default:()=>c.N});var c=a(999)}}]);