OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Opgegeven e-mailadres is te lang",
    "User-Session unexpectedly expired" : "Gebruikerssessie onverwacht vervallen",
    "Provided email-address is not valid" : "Het opgegeven e-mailadres is niet geldig",
    "%s has published the calendar »%s«" : "%s heeft de kalender gepubliceerd \"%s\"",
    "Unexpected error sending email. Please contact your administrator." : "Kon e-mail niet versturen. Neem contact op met je beheerder.",
    "Successfully sent email to %1$s" : "E-mail is succesvol verzonden naar %1$s",
    "Hello," : "Hallo,",
    "We wanted to inform you that %s has published the calendar »%s«." : "We willen je laten weten dat %s de agenda %s heeft gepubliceerd.",
    "Open »%s«" : "Open \"%s\"",
    "Cheers!" : "Proficiat!",
    "Upcoming events" : "Aanstaande activiteiten",
    "No more events today" : "Geen activiteiten meer vandaag",
    "No upcoming events" : "Geen aanstaande activiteiten",
    "More events" : "Meer activiteiten",
    "%1$s with %2$s" : "%1$s met %2$s",
    "Calendar" : "Agenda",
    "New booking {booking}" : "Nieuwe boeking {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) heeft de afspraak \"{config_display_name}\" geboekt op {date_time}.",
    "Appointments" : "Afspraken",
    "Schedule appointment \"%s\"" : "Plan afspraak \"%s\"",
    "Schedule an appointment" : "Plan een afspraak",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : "Voorbereiden op %s",
    "Follow up for %s" : "Follow-up voor %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Je afspraak \"%s\" met %s moet nog bevestigd worden",
    "Dear %s, please confirm your booking" : "Beste %s, bevestig alsjeblieft je boeking",
    "Confirm" : "Bevestigen",
    "Appointment with:" : "Afspraak met:",
    "Description:" : "Omschrijving:",
    "This confirmation link expires in %s hours." : "Deze bevestigingslink verloopt over %s uur.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Als je de afspraak toch wilt annuleren, neem dan contact op met de organisator door te antwoorden op deze e-mail of door hun profielpagina te bezoeken.",
    "Your appointment \"%s\" with %s has been accepted" : "Je afspraak \"%s\" met %sis geaccepteerd",
    "Dear %s, your booking has been accepted." : "Beste %s, je boeking is aanvaard.",
    "Appointment for:" : "Afspraak voor:",
    "Date:" : "Datum:",
    "You will receive a link with the confirmation email" : "Je ontvangt een link met de bevestigingsmail",
    "Where:" : "Waar:",
    "Comment:" : "Opmerking:",
    "You have a new appointment booking \"%s\" from %s" : "Je hebt een nieuwe afspraakboeking \"%s\" van %s",
    "Dear %s, %s (%s) booked an appointment with you." : "Beste %s, %s (%s) heeft een afspraak met je geboekt.",
    "Location:" : "Locatie:",
    "Duration:" : "Duur:",
    "A Calendar app for Nextcloud" : "Een agenda-app voor Nextcloud",
    "Previous day" : "Vorige dag",
    "Previous week" : "Vorige week",
    "Previous year" : "Vorig jaar",
    "Previous month" : "Vorige maand",
    "Next day" : "Volgende dag",
    "Next week" : "Volgende week",
    "Next year" : "Volgend jaar",
    "Next month" : "Volgende maand",
    "Create new event" : "Maak nieuw evenement",
    "Event" : "Evenement",
    "Today" : "Vandaag",
    "Day" : "Dag",
    "Week" : "Week",
    "Month" : "Maand",
    "Year" : "Jaar",
    "List" : "Lijst",
    "Appointment link was copied to clipboard" : "Afspraaklink gekopieerd naar klembord",
    "Appointment link could not be copied to clipboard" : "Afspraaklink kon niet naar klembord gekopieerd worden",
    "Preview" : "Voorbeeld",
    "Copy link" : "Link kopiëren",
    "Edit" : "Bewerk",
    "Delete" : "Verwijderen",
    "Appointment schedules" : "Afspraakschema's",
    "Create new" : "Maak nieuw",
    "Disable calendar \"{calendar}\"" : "Maak agenda \"{calendar}\" onbeschikbaar",
    "Disable untitled calendar" : "Maak naamloze agenda onbeschikbaar",
    "Enable calendar \"{calendar}\"" : "Maak agenda \"{calendar}\" beschikbaar",
    "Enable untitled calendar" : "Maak naamloze agenda beschikbaar",
    "An error occurred, unable to change visibility of the calendar." : "Er is een fout opgetreden waardoor de zichtbaarheid van de agenda niet kan worden gewijzigd.",
    "Untitled calendar" : "Naamloze calender",
    "Shared with you by" : "Gedeeld met jou door",
    "Edit and share calendar" : "Bewerk en deel agenda",
    "Edit calendar" : "Bewerk kalender",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Het delen van de agenda wordt in {countdown} seconde gestopt","Het delen van de agenda wordt in {countdown} seconden gestopt"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Agenda wordt verwijderd in {countdown} seconde","Agenda wordt verwijderd in {countdown} seconden"],
    "An error occurred, unable to create the calendar." : "Er is een fout opgetreden waardoor het niet mogelijk is om de agenda te creëren.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Geef geldige urls op - die moeten starten met http://, https://, webcal:// of webcals://",
    "Calendars" : "Agenda's",
    "Add new" : "Nieuwe toevoegen",
    "New calendar" : "Nieuwe agenda",
    "Name for new calendar" : "Naam van nieuwe kalender",
    "Creating calendar …" : "Creëren agenda ...",
    "New calendar with task list" : "Nieuwe agenda met taak lijst",
    "New subscription from link (read-only)" : "Nieuw abonnement via link (alleen lezen)",
    "Creating subscription …" : "Creëren abonnement ...",
    "Add public holiday calendar" : "Voeg de kalender van openbare feestdagen toe.",
    "Add custom public calendar" : "Voeg custom openbare agenda toe",
    "Calendar link copied to clipboard." : "Agendalink gekopiëerd naar klembord",
    "Calendar link could not be copied to clipboard." : "De agendalink kon niet naar het klembord worden gekopieerd.",
    "Copy subscription link" : "Kopieer abonnementslink",
    "Copying link …" : "Link kopiëren …",
    "Copied link" : "Link gekopieerd",
    "Could not copy link" : "Kan link niet kopiëren",
    "Export" : "Exporteren",
    "Untitled item" : "Object zonder titel",
    "Unknown calendar" : "Onbekende kalender",
    "Could not load deleted calendars and objects" : "Kon de verwijderde agenda en objecten niet herstellen",
    "Could not delete calendar or event" : "Kon kalender of afspraak niet verwijderen",
    "Could not restore calendar or event" : "Kon de agenda en objecten niet herstellen",
    "Do you really want to empty the trash bin?" : "Wil je de prullenbak echt leegmaken?",
    "Empty trash bin" : "Prullenbak legen",
    "Trash bin" : "Prullenbak",
    "Loading deleted items." : "Laden van verwijderde items.",
    "You do not have any deleted items." : "Je hebt geen verwijderde items.",
    "Name" : "Naam",
    "Deleted" : "Verwijderd",
    "Restore" : "Herstellen",
    "Delete permanently" : "Definitief verwijderen",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Items in de prullenmand worden na {numDays} dag verwijderd","Items in de prullenmand worden na {numDays} dagen verwijderd"],
    "Could not update calendar order." : "Kon de volgorde van agenda's niet bijwerken.",
    "Shared calendars" : "Gedeelde agenda's",
    "Deck" : "Deck",
    "Internal link" : "Interne link",
    "A private link that can be used with external clients" : "Een privélink die kan worden gebruikt met externe clients",
    "Copy internal link" : "Kopieer interne link",
    "An error occurred, unable to publish calendar." : "Er is een fout opgetreden, kan agenda niet publiceren.",
    "An error occurred, unable to send email." : "Er is een fout opgetreden, kon e-mail niet versturen.",
    "Embed code copied to clipboard." : "Embed code gekopieerd naar klembord",
    "Embed code could not be copied to clipboard." : "Embed code kan niet gekopieerd worden naar klembord",
    "Unpublishing calendar failed" : "Agenda depubliceren is niet gelukt",
    "Share link" : "Deel link",
    "Copy public link" : "Kopieer openbare link",
    "Send link to calendar via email" : "Stuur link naar de agenda via e-mail",
    "Enter one address" : "Geef één adres op",
    "Sending email …" : "Versturen e-mail …",
    "Copy embedding code" : "Kopieer embedded code",
    "Copying code …" : "Kopiëren code  ...",
    "Copied code" : "Code gekopieerd",
    "Could not copy code" : "Kan code niet kopiëren",
    "Delete share link" : "Verwijder deellink",
    "Deleting share link …" : "Verwijderen deellink ...",
    "{teamDisplayName} (Team)" : "{teamDisplayName}(Team)",
    "An error occurred while unsharing the calendar." : "Er is een fout opgetreden bij het delen van de kalender.",
    "An error occurred, unable to change the permission of the share." : "Er is een fout opgetreden, het is niet mogelijk om de machtiging van de share te wijzigen",
    "Unshare with {displayName}" : "Stop delen met {displayName}",
    "Share with users or groups" : "Deel met gebruikers of groepen",
    "No users or groups" : "Geen gebruikers of groepen",
    "Failed to save calendar name and color" : "Niet gelukt om de naam en kleur van de kalender op te slaan",
    "Never show me as busy (set this calendar to transparent)" : "Toon mij nooit als bezet (stel deze agenda in als transparant)",
    "Share calendar" : "Delen kalender",
    "Unshare from me" : "Stop delen met mij",
    "Save" : "Opslaan",
    "No title" : "Geen titel",
    "View" : "Bekijken",
    "Import calendars" : "Importeer agenda's",
    "Please select a calendar to import into …" : "Selecteer een agenda om naar te importeren  ...",
    "Filename" : "Bestandsnaam",
    "Calendar to import into" : "Agenda om naar te importeren",
    "Cancel" : "Annuleren",
    "_Import calendar_::_Import calendars_" : ["Importeer agenda","Importeer agenda's"],
    "Select the default location for attachments" : "Selecteer de standaardlocatie voor bijlagen",
    "Pick" : "Kies",
    "Invalid location selected" : "Ongeldige locatie geselecteerd",
    "Attachments folder successfully saved." : "Bijlagenmap succesvol opgeslagen.",
    "Error on saving attachments folder." : "Fout bij het opslaan van de bijlagenmap.",
    "Attachments folder" : "Bijlagemap",
    "{filename} could not be parsed" : "{filename} kon niet worden geanalyseerd",
    "No valid files found, aborting import" : "Geen geldige bestand gevonden, import afgebroken",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["%nafspraak succesvol geïmporteerd","%n afspraken succesvol geïmporteerd"],
    "Import partially failed. Imported {accepted} out of {total}." : "Import is gedeeltelijk gelukt. Geïmporteerd {accepted} van de {total}.",
    "Automatic" : "Automatisch",
    "Automatic ({timezone})" : "Automatisch ({timezone})",
    "New setting was not saved successfully." : "De nieuwe instelling is niet goed opgeslagen.",
    "Timezone" : "Tijdzone",
    "Navigation" : "Navigatie",
    "Previous period" : "Vorige periode",
    "Next period" : "Volgende periode",
    "Views" : "Bekeken",
    "Day view" : "Dagoverzicht",
    "Week view" : "Weekoverzicht",
    "Month view" : "Maandoverzicht",
    "Year view" : "Jaaroverzicht",
    "List view" : "Lijstweergave",
    "Actions" : "Acties",
    "Create event" : "Creëer afspraak",
    "Show shortcuts" : "Toon sneltoetsen",
    "Editor" : "Editor",
    "Close editor" : "Sluit editor",
    "Save edited event" : "Aangepaste afspraak opslaan",
    "Delete edited event" : "Aangepaste afspraak verwijderen",
    "Duplicate event" : "Duplicaat afspraak",
    "or" : "of",
    "Calendar settings" : "Agenda instellingen",
    "At event start" : "Bij start gebeurtenis",
    "No reminder" : "Geen herinnering",
    "Failed to save default calendar" : "Kon standaardagenda niet opslaan",
    "General" : "Algemeen",
    "Appearance" : "Uiterlijk",
    "Editing" : "Bewerken",
    "Default reminder" : "Standaard herinnering",
    "Files" : "Bestanden",
    "Appointment schedule successfully created" : "Afspraakschema succesvol aangemaakt",
    "Appointment schedule successfully updated" : "Afspraakschema succesvol aangepast",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minuut","{duration} minuten"],
    "0 minutes" : "0 minuten",
    "_{duration} hour_::_{duration} hours_" : ["{duration} uur","{duration} uur"],
    "_{duration} day_::_{duration} days_" : ["{duration} dag","{duration} dagen"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} week","{duration} weken"],
    "_{duration} month_::_{duration} months_" : ["{duration} maand","{duration} maanden"],
    "_{duration} year_::_{duration} years_" : ["{duration} jaar","{duration} jaar"],
    "To configure appointments, add your email address in personal settings." : "Om afspraken te configureren, voeg je e-mailadres toe in persoonlijke instellingen.",
    "Public – shown on the profile page" : "Openbaar – zichtbaar op de profielpagina",
    "Private – only accessible via secret link" : "Privé – alleen toegankelijk via geheime link",
    "Appointment schedule saved" : "Afspraakschema opgeslagen",
    "Create appointment schedule" : "Maak afspraakschema",
    "Edit appointment schedule" : "Bewerk afspraakschema",
    "Update" : "Bijwerken",
    "Appointment name" : "Afspraak benaming",
    "Location" : "Locatie",
    "Create a Talk room" : "Maak een Talk ruimte",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Een unieke link wordt gegenereerd voor elke geboekte afspraak en verzonden via een bevestigingsemail.",
    "Description" : "Omschrijving",
    "Visibility" : "Zichtbaarheid",
    "Duration" : "Duur",
    "Increments" : "Stappen",
    "Additional calendars to check for conflicts" : "Extra agenda's om te controleren op conflicten",
    "Pick time ranges where appointments are allowed" : "Selecteer tijden waar afspraken toegestaan zijn",
    "to" : "aan",
    "Delete slot" : "Verwijder tijdslot",
    "No times set" : "Geen tijden ingesteld",
    "Add" : "Toevoegen",
    "Monday" : "maandag",
    "Tuesday" : "dinsdag",
    "Wednesday" : "woensdag",
    "Thursday" : "donderdag",
    "Friday" : "vrijdag",
    "Saturday" : "zaterdag",
    "Sunday" : "zondag",
    "Weekdays" : "Weekdagen",
    "Add time before and after the event" : "Voeg tijd voor en na afspraak toe",
    "Before the event" : "Voor de afspraak",
    "After the event" : "Na de afspraak",
    "Planning restrictions" : "Planningsbeperkingen",
    "Minimum time before next available slot" : "Minimale tijd voor volgend beschikbaar tijdslot",
    "Max slots per day" : "Max tijdsloten per dag",
    "Limit how far in the future appointments can be booked" : "Beperk hoe in de toekomst afspraken toegevoerd kunnen worden",
    "It seems a rate limit has been reached. Please try again later." : "Het lijkt erop dat een limiet bereikt is. Probeer het later nog eens a.u.b.",
    "Please confirm your reservation" : "Gelieve jouw reservatie te bevestigen.",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "We hebben je een e-mail met details verzonden. Bevestig je afspraak met de link in de e-mail. Je kunt deze pagina sluiten.",
    "Your name" : "Je naam",
    "Your email address" : "Je e-mailadres",
    "Please share anything that will help prepare for our meeting" : "Deel alsjeblieft alles wat kan helpen in de voorbereiding van de afspraak",
    "Could not book the appointment. Please try again later or contact the organizer." : "Kon afspraak niet boeken. Probeer later opnieuw of neem contact op met de organisator.",
    "Back" : "Terug",
    "Book appointment" : "Boek afspraak",
    "Select conversation" : "Selecteer een gesprek",
    "on" : "op",
    "at" : "om",
    "before at" : "ervoor om",
    "Notification" : "Melding",
    "Email" : "Email",
    "Audio notification" : "Audio melding",
    "Other notification" : "Andere melding",
    "Relative to event" : "Relatief tot afspraak",
    "On date" : "Op datum",
    "Edit time" : "Bewerk tijd",
    "Save time" : "Bewaar tijd",
    "Remove reminder" : "Verwijder herinnering",
    "Add reminder" : "Voeg herinnering toe",
    "seconds" : "seconden",
    "minutes" : "minuten",
    "hours" : "uur",
    "days" : "dagen",
    "weeks" : "weken",
    "Choose a file to add as attachment" : "Kies een bestand om als bijlage toe te voegen",
    "Choose a file to share as a link" : "Kies een bestand om als link te delen",
    "Attachment {name} already exist!" : "Bijlage {name} bestaat al!",
    "Could not upload attachment(s)" : "Kon geen bijlage(n) uploaden",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Je gaat naar {host}. Wil je doorgaan? Link: {link}",
    "Proceed" : "Doorgaan",
    "No attachments" : "Geen bijlagen",
    "Add from Files" : "Toevoegen uit bestanden",
    "Upload from device" : "Uploaden vanaf apparaat",
    "Delete file" : "Verwijder bestand",
    "Confirmation" : "Bevestiging",
    "_{count} attachment_::_{count} attachments_" : ["{count} bijlagen","{count} bijlagen"],
    "Suggested" : "Aanbevolen",
    "Available" : "Beschikbaar",
    "Invitation accepted" : "Uitnodiging geaccepteerd",
    "Accepted {organizerName}'s invitation" : "Uitnodiging van {organizerName} aanvaard",
    "Participation marked as tentative" : "Deelname gemarkeerd als voorlopig",
    "Invitation is delegated" : "Uitnodiging is gedelegeerd",
    "Not available" : "Niet beschikbaar",
    "Invitation declined" : "Uitnodiging geweigerd",
    "Declined {organizerName}'s invitation" : "Uitnodiging van {organizerName} geweigerd",
    "Awaiting response" : "Wachten op antwoord",
    "Checking availability" : "Beschikbaarheid controleren",
    "Has not responded to {organizerName}'s invitation yet" : "Er is nog niet gereageerd op de uitnodiging van {organizerName}.",
    "chairperson" : "voorzitter",
    "required participant" : "vereiste deelnemer",
    "non-participant" : "geen-deelnemer",
    "optional participant" : "optionele deelnemer",
    "{organizer} (organizer)" : "{organizer} (organizer)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Availability of attendees, resources and rooms" : "Beschikbaarheid van aanwezigen, objecten en ruimtes",
    "Suggestion accepted" : "Voorstel geaccepteerd",
    "Legend" : "Legenda",
    "Out of office" : "Niet op kantoor",
    "Attendees:" : "Deelnemers:",
    "Done" : "Klaar",
    "Search room" : "Zoek ruimte",
    "Room name" : "Kamernaam",
    "Check room availability" : "Beschikbaarheid ruimtes controleren",
    "Free" : "Vrij",
    "Busy (tentative)" : "Bezig (voorlopig)",
    "Busy" : "Bezet",
    "Unknown" : "Onbekend",
    "Find a time" : "Vind een tijdstip",
    "The invitation has been accepted successfully." : "De uitnodiging is succesvol geaccepteerd.",
    "Failed to accept the invitation." : "Aanemen van uitnodiging is mislukt",
    "The invitation has been declined successfully." : "De uitnodiging is succesvol geweigerd.",
    "Failed to decline the invitation." : "Afwijzen van uitnodiging is mislukt",
    "Your participation has been marked as tentative." : "Uw deelname is aangeduid als voorlopig.",
    "Failed to set the participation status to tentative." : "Niet gelukt om de deelname status op voorlopig in te stellen.",
    "Accept" : "Accepteren",
    "Decline" : "Afwijzen",
    "Tentative" : "Voorlopig",
    "No attendees yet" : "Nog geen deelnemers",
    "Attendees" : "Deelnemers",
    "Remove group" : "Groep verwijderen",
    "Remove attendee" : "Verwijder genodigde",
    "Request reply" : "Vraag antwoord",
    "Chairperson" : "Voorzitter",
    "Required participant" : "Vereiste deelnemer",
    "Optional participant" : "Optionele deelnemer",
    "Non-participant" : "Geen deelnemer",
    "_%n member_::_%n members_" : ["%n leden","1%n leden"],
    "No match found" : "Geen overeenkomst gevonden",
    "Note that members of circles get invited but are not synced yet." : "Bedenk dat deenemers aan cirkels uitgenodigd, maar niet gesynchroniseerd worden.",
    "Note that members of contact groups get invited but are not synced yet." : "Bedenk dat deenemers van contactgroepen uitgenodigd, maar niet gesynchroniseerd worden.",
    "(organizer)" : "(organisator)",
    "Make {label} the organizer" : "Maak {label} de organisator",
    "Make {label} the organizer and attend" : "Maak {label} de organisator en neem deel",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Om uitnodigingen te versturen en antwoorden te behandelen,  [linkopen]voeg je e-mailadres toe in persoonlijke instellingen[linkclose].",
    "Remove color" : "Verwijderen kleur",
    "Event title" : "Afspraaknaam",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Het lukt niet om de gehele-dag instelling aan te passen voor afspraken die onderdeel zijn van een herhaalde-set.",
    "From" : "Van",
    "To" : "Naar",
    "Repeat" : "Herhaling",
    "_time_::_times_" : ["keer","keer"],
    "never" : "geen",
    "on date" : "op datum",
    "after" : "na",
    "End repeat" : "Beëindig herhalen",
    "Select to end repeat" : "Selecteer om herhaling te beëindigen",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Deze afspraak is een uitzondering van een herhaalde-set. Je kunt hieraan geen herhalingsregel toevoegen.",
    "first" : "eerste",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Wijzigingen op de herhaling zal alleen worden toegepast op deze en toekomstige afspraken.",
    "Repeat every" : "Herhaal elke",
    "By day of the month" : "Op dag van de maand",
    "On the" : "Op de",
    "_day_::_days_" : ["dag","dagen"],
    "_week_::_weeks_" : ["week","weken"],
    "_month_::_months_" : ["maand","maanden"],
    "_year_::_years_" : ["jaar","jaren"],
    "weekday" : "weekdag",
    "weekend day" : "weekend dag",
    "Does not repeat" : "Niet herhalen",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "De herhaal instelling van deze afspraak wordt niet volledig ondersteund door Nextcloud. Als je de herhaal instellingen wijzigt, gaan bepaalde herhalingen mogelijk verloren.",
    "No rooms or resources yet" : "Nog geen kamers of bronnen",
    "Resources" : "Bronnen",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} plaats","{seatingCapacity} plaatsen"],
    "Add resource" : "Voeg resource toe",
    "Has a projector" : "Heeft een projector",
    "Has a whiteboard" : "Heeft een whiteboard",
    "Wheelchair accessible" : "Rolstoel toegangelijk",
    "Remove resource" : "Verwijder bron",
    "Search for resources or rooms" : "Zoeken naar bronnen of kamers",
    "available" : "beschikbaar",
    "unavailable" : "niet beschikbaar",
    "Show all rooms" : "Toon alle ruimtes",
    "Projector" : "Projector",
    "Whiteboard" : "Whiteboard",
    "Room type" : "Kamer type",
    "Any" : "Alle",
    "Minimum seating capacity" : "Minimale zit capaciteit",
    "More details" : "Meer details",
    "Update this and all future" : "Deze en toekomstige afspraken bijwerken",
    "Update this occurrence" : "Deze afspraak bijwerken",
    "Public calendar does not exist" : "Publieke agenda bestaat niet",
    "Maybe the share was deleted or has expired?" : "Mogelijk is het gedeelde item verwijderd of verlopen?",
    "Yes" : "Ja",
    "No" : "Nee",
    "None" : "Geen",
    "Create" : "Creëer",
    "from {formattedDate}" : "van {formattedDate}",
    "to {formattedDate}" : "tot {formattedDate}",
    "on {formattedDate}" : "op {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "van {formattedDate} om {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "tot {formattedDate} om {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "op {formattedDate} om {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} om {formattedTime}",
    "Please enter a valid date" : "Geef een geldige datum op",
    "Please enter a valid date and time" : "Geef een geldige datum en tijdstip op",
    "Select a time zone" : "Selecteer een tijdzone",
    "Please select a time zone:" : "Selecteer een tijdzone:",
    "Pick a time" : "Kies een tijd",
    "Pick a date" : "Kies een datum",
    "Type to search time zone" : "Type om tijdzone te zoeken",
    "Global" : "Globaal",
    "Holidays in {region}" : "Vakanties in {regio}",
    "An error occurred, unable to read public calendars." : "Er is een fout opgetreden, kan openbare agenda's niet lezen.",
    "An error occurred, unable to subscribe to calendar." : "Er is een fout opgetreden, kan niet abonneren op de agenda.",
    "Public holiday calendars" : "Openbare vakantie kalenders",
    "Public calendars" : "Openbare agenda's",
    "No valid public calendars configured" : "Geen juiste openbare agenda's ingesteld",
    "Speak to the server administrator to resolve this issue." : "Vraag je beheerder om dit probleem op te lossen.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Openbare feestdagenkalenders worden verstrekt door Thunderbird. Kalendergegevens worden gedownload van {website}.",
    "By {authors}" : "Door {authors}",
    "Subscribed" : "Geabonneerd",
    "Subscribe" : "Abonneren",
    "Could not fetch slots" : "Kon slots niet ophalen",
    "Select a date" : "Selecteer een datum",
    "Select slot" : "Selecteer tijdslot",
    "No slots available" : "Geen tijdsloten beschikbaar",
    "The slot for your appointment has been confirmed" : "Het tijdslot van je afspraak is bevestigd",
    "Appointment Details:" : "Afspraak Details:",
    "Time:" : "Tijd:",
    "Booked for:" : "Geboekt voor:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Bedankt. Je boeking van {startDate} tot {endDate} is bevestigd.",
    "Book another appointment:" : "Boek nog een afspraak:",
    "See all available slots" : "Bekijk alle beschikbare tijdsloten",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Het tijdslot voor je afspraak van {startDate} tot {endDate} is niet meer beschikbaar.",
    "Please book a different slot:" : "Boek alsjeblieft een ander tijdslot:",
    "Book an appointment with {name}" : "Boek een afspraak met {name}",
    "No public appointments found for {name}" : "Geen publieke afspraken gevonden voor {name}",
    "Personal" : "Persoonlijk",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "De automatisch gedetecteerde tijdzone is UTC.\nDit komt waarschijnlijk door beveiligingsmaatregelen van je webbrowser. Stel de tijdzone handmatig in bij de agenda-instellingen.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Je ingestelde tijdzone ({timezoneId}) werd niet gevonden. Er wordt teruggevallen op UTC.\nWijzig je tijdzone in instellingen en meld het incident.",
    "Edit event" : "Bewerk gebeurtenis",
    "Event does not exist" : "Activiteit bestaat niet",
    "Duplicate" : "Duplicaat",
    "Delete this occurrence" : "Verwijder deze afspraak",
    "Delete this and all future" : "Verwijder deze en toekomstige",
    "All day" : "Hele dag",
    "Managing shared access" : "Beheren van gedeelde toegang",
    "Deny access" : "Weiger toegang",
    "Invite" : "Uitnodigen",
    "_User requires access to your file_::_Users require access to your file_" : ["Gebruikers hebben toegang nodig tot uw bestand","Gebruikers hebben toegang nodig tot uw bestand"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Bijlagen die gedeelde toegang vereisen","Bijlagen die gedeelde toegang vereisen"],
    "Untitled event" : "Afspraken zonder naam",
    "Close" : "Sluiten",
    "Selected" : "Geselecteerd",
    "Title" : "Titel",
    "30 min" : "30 min",
    "Participants" : "Deelnemers",
    "Submit" : "Indienen",
    "Subscribe to {name}" : "Abonneren op {name}",
    "Export {name}" : "Exporteer {name}",
    "Anniversary" : "Verjaardag",
    "Appointment" : "Afspraak",
    "Business" : "Zakelijk",
    "Education" : "Onderwijs",
    "Holiday" : "Vakantie",
    "Meeting" : "Vergadering",
    "Miscellaneous" : "Diversen",
    "Non-working hours" : "buiten werkuren",
    "Not in office" : "Niet in het kantoor",
    "Phone call" : "Telefoongesprek",
    "Sick day" : "Ziektedag",
    "Special occasion" : "Bijzondere gelegenheid",
    "Travel" : "Reizen",
    "Vacation" : "Vakantie",
    "Midnight on the day the event starts" : "Middernacht op de dag van de afspraak",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n dag voor het begin van de afspraak om {formattedHourMinute}","%n dagen voor het begin van de afspraak om {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n week voor de afspraak om {formattedHourMinute}","%n weken voor de afspraak om {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "op de dag van de afspraak om {formattedHourMinute}",
    "at the event's start" : "bij het begin van de afspraak",
    "at the event's end" : "op het eind van de afspraak",
    "{time} before the event starts" : "{time} voor begin van de afspraak",
    "{time} before the event ends" : "{time} voor het eind van de afspraak",
    "{time} after the event starts" : "{time} na begin van de afspraak",
    "{time} after the event ends" : "{time} na afloop van de afspraak",
    "on {time}" : "om {time}",
    "on {time} ({timezoneId})" : "om {time} ({timezoneId})",
    "Week {number} of {year}" : "Week {number} van {year}",
    "Daily" : "Dagelijks",
    "Weekly" : "Wekelijks",
    "Monthly" : "Maandelijks",
    "Yearly" : "Jaarlijks",
    "_Every %n day_::_Every %n days_" : ["Elke dag","Elke%n dag"],
    "_Every %n week_::_Every %n weeks_" : ["Elke week","Elke %n weken"],
    "_Every %n month_::_Every %n months_" : ["Elke maand","Elke %n maand"],
    "_Every %n year_::_Every %n years_" : ["Elk jaar","Elk %n jaar"],
    "_on {weekday}_::_on {weekdays}_" : ["op {weekday}","op {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["op dag {dayOfMonthList}","op de dagen {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "op de {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "in {monthNames} op de {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "tot {untilDate}",
    "_%n time_::_%n times_" : ["%n keer","%n keer"],
    "second" : "tweede",
    "third" : "derde",
    "fourth" : "vierde",
    "fifth" : "vijfde",
    "second to last" : "op 2 na laatste",
    "last" : "laatste",
    "Untitled task" : "Naamloze taak",
    "Please ask your administrator to enable the Tasks App." : "Vraag je beheerder om de Taken App te installeren.",
    "W" : "W",
    "%n more" : "+%n meer",
    "No events to display" : "Geen activiteiten meer te tonen",
    "_+%n more_::_+%n more_" : ["+%n meer","+%n meer"],
    "No events" : "Geen activiteiten",
    "Create a new event or change the visible time-range" : "Maak een nieuwe activiteit of wijzig de zichtbare tijdsperiode",
    "Failed to save event" : "Opslaan van gebeurtenis mislukt",
    "It might have been deleted, or there was a typo in a link" : "Het zou kunnen verwijderd zijn, of er stond een typfout in de link.",
    "It might have been deleted, or there was a typo in the link" : "Het zou kunnen verwijderd zijn, of er stond een typfout in de link.",
    "Meeting room" : "Meetingroom",
    "Lecture hall" : "Collegezaal",
    "Seminar room" : "Seminarroom",
    "Other" : "Andere",
    "When shared show" : "Wanneer gedeeld toon",
    "When shared show full event" : "Wanneer gedeeld, toon gehele afspraak",
    "When shared show only busy" : "Wanneer gedeeld, toon alleen onbeschikbaarheid",
    "When shared hide this event" : "Wanneer gedeeld, verberg deze afspraak",
    "Add a location" : "Een locatie toevoegen",
    "Status" : "Status",
    "Confirmed" : "Bevestigd",
    "Canceled" : "Geannuleerd",
    "Confirmation about the overall status of the event." : "Bevestiging over de globale status van de afspraak.",
    "Show as" : "Toon als",
    "Take this event into account when calculating free-busy information." : "Houd rekening met deze afspraak bij het berekenen van vrij-bezetinformatie.",
    "Categories" : "Categorieën",
    "Categories help you to structure and organize your events." : "Categorieën helpen je om je afspraken te structureren en organiseren.",
    "Search or add categories" : "Zoek categorieën of voeg deze toe",
    "Add this as a new category" : "Voeg dit toe als een nieuwe categorie",
    "Custom color" : "Kleur op maat",
    "Special color of this event. Overrides the calendar-color." : "Bijzondere kleur van deze afspraak. Overschrijft de agenda kleur.",
    "Error while sharing file" : "Fout bij delen bestand",
    "Error while sharing file with user" : "Fout bij het delen van het bestand met de gebruiker",
    "Attachment {fileName} already exists!" : "Bijlage {fileName} bestaat al!",
    "An error occurred during getting file information" : "Er is een fout opgetreden tijdens het ophalen van bestandsinformatie.",
    "An error occurred, unable to delete the calendar." : "Er is een fout opgetreden waardoor de agenda niet kan worden verwijderd.",
    "Imported {filename}" : "Geïmporteerd {filename}",
    "This is an event reminder." : "Dit is een herinnering aan een evenement.",
    "Appointment not found" : "Afspraak niet gevonden",
    "User not found" : "Gebruiker niet gevonden",
    "Hidden" : "Verborgen",
    "can edit" : "kan wijzigen",
    "Calendar name …" : "Kalendernaam ...",
    "Default attachments location" : "Standaard bijlagenlocatie",
    "Automatic ({detected})" : "Automatisch ({detected})",
    "Shortcut overview" : "Snelkoppeling overzicht",
    "CalDAV link copied to clipboard." : "CalDAV link gekopiëerd naar klembord.",
    "CalDAV link could not be copied to clipboard." : "CalDAV link kon niet worden gekopieerd naar klembord.",
    "Enable birthday calendar" : "Verjaardagskalender inschakelen",
    "Show tasks in calendar" : "Toon taken in agenda",
    "Enable simplified editor" : "Eenvoudige editor inschakelen",
    "Limit the number of events displayed in the monthly view" : "Beperk het aantal evenementen dat wordt weergegeven in de maandweergave",
    "Show weekends" : "Toon weekenden",
    "Show week numbers" : "Tonen weeknummers",
    "Time increments" : "Time-toename",
    "Default calendar for incoming invitations" : "Standaardagenda voor inkomende uitnodigingen",
    "Copy primary CalDAV address" : "Kopieer primair CalDAV adres",
    "Copy iOS/macOS CalDAV address" : "Kopieer iOS/macOS CalDAV adres",
    "Personal availability settings" : "Persoonlijke beschikbaarheidsinstellingen",
    "Show keyboard shortcuts" : "Toon sneltoetsen",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} uitgenodigd, {confirmedCount} bevestigd",
    "Successfully appended link to talk room to location." : "Succesvol de link naar de Talk ruimte aan de locatie toegevoegd.",
    "Successfully appended link to talk room to description." : "Met succes een link naar de gespreksruimte toegevoegd aan de beschrijving.",
    "Error creating Talk room" : "Fout tijdens aanmaken gespreksruimte",
    "The visibility of this event in shared calendars." : "De zichtbaarheid van deze afspraak in gedeelde agenda's."
},
"nplurals=2; plural=(n != 1);");
