OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Alamat-mel yang diberikan terlalu panjang",
    "User-Session unexpectedly expired" : "Sesi-Pengguna tamat secara tidak dijangka.",
    "Provided email-address is not valid" : "Alamat-mel yang diberikan tidak sah",
    "%s has published the calendar »%s«" : "%stelah telah menerbitkan kalendar%s",
    "Unexpected error sending email. Please contact your administrator." : "Ralat tidak dijangka ketika menghantar e-mel. Sila hubungi admin anda.",
    "Successfully sent email to %1$s" : "Berjaya menghantar e-mel ke %1$s",
    "Hello," : "Helo,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Kami ingin memaklumkan kepada anda yang %s telah menerbitkan kalendar %s.",
    "Open »%s«" : "Buka %s",
    "Cheers!" : "Cheers!",
    "Upcoming events" : "Acara yang akan datang",
    "No more events today" : "Tiada lagi acara hari ini",
    "No upcoming events" : "Tiada acara akan datang",
    "More events" : "Lebih banyak acara",
    "%1$s with %2$s" : "%1$sdengan %2$s",
    "Calendar" : "Kalendar",
    "New booking {booking}" : "Janji temu baharu{booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email})telah membuat Janji temu\"{config_display_name}\" pada {date_time}.",
    "Appointments" : "Janji temu",
    "Schedule appointment \"%s\"" : "Jadual janji temu \"%s\"",
    "Schedule an appointment" : "Jadualkan janji temu",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : "Menyediakan untuk %s",
    "Appointment with:" : "Janji temu dengan:",
    "Description:" : "Penerangan:",
    "Date:" : "Tarikh:",
    "Where:" : "Di mana:",
    "Comment:" : "Komen:",
    "A Calendar app for Nextcloud" : "Aplikasi kalendar untuk Nextcloud",
    "Previous day" : "Semalam",
    "Previous week" : "Minggu sebelumnya",
    "Previous year" : "Tahun sebelumnya",
    "Previous month" : "Bulan sebelumnya",
    "Next day" : "Esok",
    "Next week" : "Minggu seterusnya",
    "Next year" : "Tahun seterusnya",
    "Today" : "Hari ini",
    "Day" : "Hari",
    "Week" : "Minggu",
    "Month" : "Bulan",
    "Edit" : "Sunting",
    "Delete" : "Padam",
    "New calendar" : "Kalendar baru",
    "Export" : "Eksport",
    "Name" : "Nama",
    "Deleted" : "Dipadam",
    "Restore" : "Pulihkan",
    "Share link" : "Share link",
    "Save" : "Simpan",
    "Cancel" : "Batal",
    "General" : "Umum",
    "Files" : "Fail-fail",
    "Update" : "Kemaskini",
    "Location" : "Lokasi",
    "Description" : "Keterangan",
    "to" : "kepada",
    "Add" : "Tambah",
    "Monday" : "Isnin",
    "Tuesday" : "Selasa",
    "Wednesday" : "Rabu",
    "Thursday" : "Khamis",
    "Friday" : "Jumaat",
    "Saturday" : "Sabtu",
    "Sunday" : "Ahad",
    "Your email address" : "Alamat emel anda",
    "Notification" : "Pemberitahuan",
    "Email" : "Email",
    "Done" : "Selesai",
    "Attendees" : "Jemputan",
    "Repeat" : "Ulang",
    "never" : "jangan",
    "Yes" : "Ya",
    "No" : "Tidak",
    "Personal" : "Peribadi",
    "Edit event" : "Ubah peristiwa",
    "Close" : "Tutup",
    "Daily" : "Setiap hari",
    "Weekly" : "Setiap minggu",
    "second" : "kedua",
    "Other" : "Lain",
    "can edit" : "boleh mengubah"
},
"nplurals=1; plural=0;");
