OC.L10N.register(
    "calendar",
    {
    "Cheers!" : "Cheers!",
    "Calendar" : "Kalendar",
    "Today" : "Danas",
    "Day" : "Dan",
    "Week" : "Sedmica",
    "Month" : "Mjesec",
    "Edit" : "Izmjeni",
    "Delete" : "Obriši",
    "New calendar" : "Novi kalendar",
    "Export" : "Izvezi",
    "Name" : "Ime",
    "Restore" : "Obnovi",
    "Share link" : "Podijelite vezu",
    "Save" : "Spremi",
    "Cancel" : "Odustani",
    "Actions" : "Radnje",
    "Update" : "Ažuriraj",
    "Location" : "Lokacija",
    "Description" : "Opis",
    "to" : "do",
    "Add" : "Dodaj",
    "Monday" : "Ponedjeljak",
    "Tuesday" : "Utorak",
    "Wednesday" : "Srijeda",
    "Thursday" : "Četvrtak",
    "Friday" : "Petak",
    "Saturday" : "Subota",
    "Sunday" : "Nedjelja",
    "Your email address" : "Vaša adresa e-pošte",
    "Email" : "E-pošta",
    "seconds" : "sekundi",
    "minutes" : "minuta",
    "hours" : "sati",
    "days" : "dana",
    "weeks" : "sedmica",
    "Busy" : "Zauzet",
    "Unknown" : "Nepoznato",
    "Accept" : "Prihvati",
    "Decline" : "Odbij",
    "Attendees" : "Sudionici",
    "Repeat" : "Ponovi",
    "never" : "nikad",
    "Yes" : "Da",
    "No" : "Ne",
    "None" : "Ništa",
    "Create" : "Kreiraj",
    "Personal" : "Osobno",
    "Edit event" : "Izmjeni događaj",
    "Close" : "Zatvori",
    "Title" : "Naslov",
    "Daily" : "Dnevno",
    "Weekly" : "Sedmično",
    "second" : "drugi",
    "Other" : "Ostali",
    "Status" : "Status",
    "can edit" : "mogu mijenjati"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
