OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "تەمىنلەنگەن ئېلېكترونلۇق خەت ئادرېسى بەك ئۇزۇن",
    "User-Session unexpectedly expired" : "ئىشلەتكۈچى-يىغىن ئويلىمىغان يەردىن توشىدۇ",
    "Provided email-address is not valid" : "تەمىنلەنگەن ئېلېكترونلۇق خەت ئادرېسى ئىناۋەتلىك ئەمەس",
    "%s has published the calendar »%s«" : "%s كالېندارنى ئېلان قىلدى »%s«",
    "Unexpected error sending email. Please contact your administrator." : "ئېلېكترونلۇق خەت ئەۋەتىشتە كۈتۈلمىگەن خاتالىق. باشقۇرغۇچىڭىز بىلەن ئالاقىلىشىڭ.",
    "Successfully sent email to %1$s" : "مۇۋەپپەقىيەتلىك ھالدا %1$s غا ئېلېكترونلۇق خەت ئەۋەتكەن",
    "Hello," : "ياخشىمۇسىز ،",
    "We wanted to inform you that %s has published the calendar »%s«." : "بىز سىزگە %s كالېندارنى ئېلان قىلدى »%s«.",
    "Open »%s«" : "ئېچىڭ »%s«",
    "Cheers!" : "خۇشال بولۇڭ!",
    "Upcoming events" : "ئالدىمىزدىكى ۋەقەلەر",
    "No more events today" : "بۈگۈن باشقا پائالىيەتلەر يوق",
    "No upcoming events" : "پات ئارىدا يۈز بېرىدىغان ئىشلار يوق",
    "More events" : "تېخىمۇ كۆپ ۋەقەلەر",
    "%1$s with %2$s" : "%1$s بىلەن %2$s",
    "Calendar" : "يىلنامە",
    "New booking {booking}" : "يېڭى زاكاز {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) {date_time} دا «{config_display_name}» تەيىنلەشنى زاكاس قىلدى.",
    "Appointments" : "تەيىنلەش",
    "Schedule appointment \"%s\"" : "ۋاقىت جەدۋىلى \"%s\"",
    "Schedule an appointment" : "ئۇچرىشىشنى ئورۇنلاشتۇرۇڭ",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : "%s ئۈچۈن تەييارلىق قىلىڭ",
    "Follow up for %s" : "%s غا ئەگىشىڭ",
    "Your appointment \"%s\" with %s needs confirmation" : "سىزنىڭ %s بىلەن \"%s\" ئۇچرىشىشىڭىز جەزملەشتۈرۈشكە موھتاج",
    "Dear %s, please confirm your booking" : "ھۆرمەتلىك %s ، زاكاسلىرىڭىزنى جەزملەشتۈرۈڭ",
    "Confirm" : "جەزملەشتۈرۈڭ",
    "Appointment with:" : "تەيىنلەش:",
    "Description:" : "چۈشەندۈرۈش:",
    "This confirmation link expires in %s hours." : "بۇ جەزملەشتۈرۈش ئۇلىنىشى %s سائەت ئىچىدە توشىدۇ.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "زادى ئۇچرىشىشنى ئەمەلدىن قالدۇرماقچى بولسىڭىز ، بۇ ئېلېكترونلۇق خەتكە جاۋاب قايتۇرۇش ياكى ئۇلارنىڭ ئارخىپ بېتىنى زىيارەت قىلىش ئارقىلىق تەشكىللىگۈچىڭىز بىلەن ئالاقىلىشىڭ.",
    "Your appointment \"%s\" with %s has been accepted" : "سىزنىڭ %s بىلەن «%s» تەيىنلىنىشىڭىز قوبۇل قىلىندى",
    "Dear %s, your booking has been accepted." : "ھۆرمەتلىك %s ، زاكاس قوبۇل قىلىندى.",
    "Appointment for:" : "تەيىنلەش:",
    "Date:" : "چېسلا:",
    "You will receive a link with the confirmation email" : "جەزملەش ئېلخېتى بىلەن ئۇلىنىش تاپشۇرۇۋالىسىز",
    "Where:" : "قەيەردە:",
    "Comment:" : "باھا:",
    "You have a new appointment booking \"%s\" from %s" : "سىزدە %s دىن «%s» نى زاكاز قىلىش يېڭى زاكاس تالونى بار",
    "Dear %s, %s (%s) booked an appointment with you." : "ھۆرمەتلىك %s, %s (%s) سىز بىلەن كۆرۈشۈشنى زاكاز قىلدى.",
    "%s has proposed a meeting" : "%s بىر كۆرۈشۈشكە تەكلىپ قىلدى",
    "%s has updated a proposed meeting" : "%s بىر تەكلىپ قىلىنغان يىغىننى يېڭىلىدى",
    "%s has canceled a proposed meeting" : "%s بىر تەكلىپ قىلىنغان يىغىننى ئەمەلدىن قالدۇردى",
    "Dear %s, a new meeting has been proposed" : "ھۆرمەتلىك %s ، بىر يېڭى يىغىن تەكلىپ قىلىندى.",
    "Dear %s, a proposed meeting has been updated" : "ھۆرمەتلىك %s ، بىر تەكلىپ قىلىنغان يىغىن يېڭىلاندى.",
    "Dear %s, a proposed meeting has been cancelled" : "ھۆرمەتلىك %s ، بىر تەكلىپ قىلىنغان يىغىن ئەمەلدىن قالدى.",
    "Location:" : "ئورنى:",
    "Duration:" : "ئۇزۇنلىقى:",
    "%1$s from %2$s to %3$s" : "%3$s كە %2$s دىن %1$s",
    "Dates:" : "چېسلا:",
    "Respond" : "جاۋاپ بەر",
    "A Calendar app for Nextcloud" : "Nextcloud ئۈچۈن كالېندار دېتالى",
    "A Calendar app for Nextcloud. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Like Contacts, Talk, Tasks, Deck and Circles\n* 🌐 **WebCal Support!** Want to see your favorite team's matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 **Search!** Find your events at ease\n* ☑️ **Tasks!** See tasks or Deck cards with a due date directly in the calendar\n* 🔈 **Talk rooms!** Create an associated Talk room when booking a meeting with just one click\n* 📆 **Appointment booking** Send people a link so they can book an appointment with you [using this app](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Attachments!** Add, upload and view event attachments\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Nextcloud ئۈچۈن كالېندار ئەپ. ھەر خىل ئۈسكۈنىلەردىكى پائالىيەتلەرنى Nextcloud بىلەن ئاسانلا ماسلاشتۇرۇڭ ۋە توردا تەھرىرلەڭ.\n\n* 🚀 **باشقا Nextcloud ئەپلىرى بىلەن بىر گەۋدىلىشىش!** مەسىلەن، ئالاقە، سۆھبەت، ۋەزىپە، ئۈستەل ۋە چەمبەرلەر\n* 🌐 **WebCal قوللىشى!** ياقتۇرىدىغان كوماندىڭىزنىڭ مۇسابىقە كۈنلىرىنى كالېندارىڭىزدا كۆرمەكچىمۇ؟ مەسىلە يوق!\n* 🙋 **قاتناشقۇچىلار!** پائالىيەتلىرىڭىزگە كىشىلەرنى تەكلىپ قىلىڭ\n* ⌚ **بوش/ئالدى!** قاتناشقۇچىلارنىڭ قاچان يىغىن ئاچالايدىغانلىقىنى كۆرۈڭ\n* ⏰ **ئەسكەرتىشلەر!** تور كۆرگۈچ ئىچىدە ۋە ئېلخەت ئارقىلىق پائالىيەتلەر ئۈچۈن ئاگاھلاندۇرۇش سىگنالى ئېلىڭ\n* 🔍 **ئىزدەڭ!** پائالىيەتلىرىڭىزنى ئاسانلا تېپىڭ\n* ☑️ **ۋەزىپىلەر!** كالېنداردا بىۋاسىتە تاماملاش ۋاقتى بار ۋەزىپىلەرنى ياكى كارتىلارنى كۆرۈڭ\n* 🔈 **سۆھبەت ئۆيلىرى!** پەقەت بىر چېكىش ئارقىلىق يىغىن زاكاز قىلغاندا مۇناسىۋەتلىك سۆھبەت ئۆيى قۇرۇڭ\n* 📆 **مۇلاقىمەت زاكاز قىلىش** كىشىلەرگە ئۇلىنىش ئەۋەتىڭ، شۇنداق قىلسا ئۇلار [بۇ ئەپنى ئىشلىتىپ] سىز بىلەن كۆرۈشۈش زاكاز قىلالايدۇ (https://apps.nextcloud.com/apps/appointments)\n* 📎 **قوشۇمچە ھۆججەتلەر!** پائالىيەت قوشۇمچە ھۆججەتلىرىنى قوشۇش، يۈكلەش ۋە كۆرۈش\n* 🙈 **بىز چاقنى قايتا ئىجاد قىلمايمىز!** ئېسىل [c-dav] غا ئاساسەن كۇتۇپخانا](https://github.com/nextcloud/cdav-library)، [ical.js](https://github.com/mozilla-comm/ical.js) ۋە [fullcalendar](https://github.com/fullcalendar/fullcalendar) كۇتۇپخانىلىرى.",
    "Previous day" : "ئالدىنقى كۈن",
    "Previous week" : "ئالدىنقى ھەپتە",
    "Previous year" : "ئالدىنقى يىل",
    "Previous month" : "ئالدىنقى ئاي",
    "Next day" : "ئەتىسى",
    "Next week" : "كېلەر ھەپتە",
    "Next year" : "كېلەر يىلى",
    "Next month" : "كېلەر ئاي",
    "Create new event" : "يېڭى پائالىيەت قۇر",
    "Event" : "پائالىيەت",
    "Today" : "بۈگۈن",
    "Day" : "كۈن",
    "Week" : "ھەپتە",
    "Month" : "ئاي",
    "Year" : "يىل",
    "List" : "تىزىملىك",
    "Appointment link was copied to clipboard" : "تەيىنلەش ئۇلانمىسى چاپلاش تاختىسىغا كۆچۈرۈلدى",
    "Appointment link could not be copied to clipboard" : "تەيىنلەش ئۇلانمىسىنى چاپلاش تاختىسىغا كۆچۈرگىلى بولمايدۇ",
    "Preview" : "ئالدىن كۆرۈش",
    "Copy link" : "ئۇلانمىنى كۆچۈرۈڭ",
    "Edit" : "تەھرىر",
    "Delete" : "ئۆچۈر",
    "Appointment schedules" : "تەيىنلەش ۋاقىت جەدۋىلى",
    "Create new" : "يېڭى قۇر",
    "Disable calendar \"{calendar}\"" : "كالېندار \"{calendar}\" نى چەكلەڭ",
    "Disable untitled calendar" : "نامسىز كالېندارنى چەكلەڭ",
    "Enable calendar \"{calendar}\"" : "كالېندار \"{calendar}\" نى قوزغىتىڭ",
    "Enable untitled calendar" : "نامسىز كالېندارنى قوزغىتىڭ",
    "An error occurred, unable to change visibility of the calendar." : "كالېندارنىڭ كۆرۈنۈشچانلىقىنى ئۆزگەرتەلمەيدىغان خاتالىق كۆرۈلدى.",
    "Untitled calendar" : "نامسىز كالېندار",
    "Shared with you by" : "سىز بىلەن ئورتاقلاشتى",
    "Edit and share calendar" : "كالېندارنى تەھرىرلەش ۋە ئورتاقلىشىش",
    "Edit calendar" : "كالېندارنى تەھرىرلەش",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["{countdown} سىكۇنتتا كالىندار ھەمبەھىرلەنمەيدۇ","{countdown} سىكۇنتتا كالىندار ھەمبەھىرلەنمەيدۇ"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["{countdown} سىكۇنتتا كالىندار ئۆچۈرۈلدۇ","{countdown} سىكۇنتتا كالىندار ئۆچۈرۈلدۇ"],
    "An error occurred, unable to create the calendar." : "كالېندارنى قۇرالماسلىقتا خاتالىق كۆرۈلدى.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "ئىناۋەتلىك ئۇلىنىشنى كىرگۈزۈڭ (http: // ، https: // ، webcal: // ياكى webcals: // دىن باشلاڭ)",
    "Calendars" : "كالېندار",
    "Add new" : "يېڭى قوشۇڭ",
    "New calendar" : "يېڭى يىلنامە",
    "Name for new calendar" : "يېڭى كالېندارنىڭ ئىسمى",
    "Creating calendar …" : "كالېندار قۇرۇش…",
    "New calendar with task list" : "ۋەزىپە تىزىملىكى بىلەن يېڭى كالېندار",
    "New subscription from link (read-only)" : "ئۇلىنىشتىن يېڭى مۇشتەرىلىك (پەقەت ئوقۇشقىلا بولىدۇ)",
    "Creating subscription …" : "مۇشتەرى بولۇش…",
    "Add public holiday calendar" : "ئاممىۋى دەم ئېلىش كالېندارىنى قوشۇڭ",
    "Add custom public calendar" : "ئىختىيارىي كالېندارنى قوشۇڭ",
    "Calendar link copied to clipboard." : "كالېندار ئۇلىنىشى چاپلاش تاختىسىغا كۆچۈرۈلدى.",
    "Calendar link could not be copied to clipboard." : "كالېندار ئۇلىنىشىنى چاپلاش تاختىسىغا كۆچۈرگىلى بولمايدۇ.",
    "Copy subscription link" : "مۇشتەرىلىك ئۇلانمىسىنى كۆچۈرۈڭ",
    "Copying link …" : "كۆچۈرۈش ئۇلانمىسى…",
    "Copied link" : "كۆچۈرۈلگەن ئۇلىنىش",
    "Could not copy link" : "ئۇلانمىنى كۆچۈرەلمىدى",
    "Export" : "چىقار",
    "Untitled item" : "نامسىز تۈر",
    "Unknown calendar" : "نامەلۇم كالېندار",
    "Could not load deleted calendars and objects" : "ئۆچۈرۈلگەن كالېندار ۋە ئوبيېكتلارنى يۈكلىيەلمىدى",
    "Could not delete calendar or event" : "كالېندار ياكى ۋەقەنى ئۆچۈرەلمىدى",
    "Could not restore calendar or event" : "كالېندار ياكى ھادىسىنى ئەسلىگە كەلتۈرەلمىدى",
    "Do you really want to empty the trash bin?" : "ئەخلەت ساندۇقىنى بوشاتماقچىمۇ؟",
    "Empty trash bin" : "ئەخلەت ساندۇقى",
    "Trash bin" : "ئەخلەت ساندۇقى",
    "Loading deleted items." : "ئۆچۈرۈلگەن تۈرلەرنى يۈكلەۋاتىدۇ.",
    "You do not have any deleted items." : "ئۆچۈرۈلگەن تۈرلىرىڭىز يوق.",
    "Name" : "ئاتى",
    "Deleted" : "ئۆچۈرۈلدى",
    "Restore" : "ئەسلىگە كەلتۈرۈش",
    "Delete permanently" : "مەڭگۈلۈك ئۆچۈر",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["ئەخلەت ساندۇقىدىكى ئېلېمېنتلار {numDays} كۈندىن كېيىن ئۆچۈرۈلدى","ئەخلەت ساندۇقىدىكى ئېلېمېنتلار {numDays} كۈندىن كېيىن ئۆچۈرۈلدى"],
    "Could not update calendar order." : "كالېندار تەرتىپىنى يېڭىلىيالمىدى.",
    "Shared calendars" : "ئورتاق كالېندار",
    "Deck" : "پالۋان",
    "Internal link" : "ئىچكى ئۇلىنىش",
    "A private link that can be used with external clients" : "سىرتقى خېرىدارلار بىلەن ئىشلىتىشكە بولىدىغان شەخسىي ئۇلىنىش",
    "Copy internal link" : "ئىچكى ئۇلىنىشنى كۆچۈرۈڭ",
    "An error occurred, unable to publish calendar." : "كالېندارنى ئېلان قىلالماي خاتالىق كۆرۈلدى.",
    "An error occurred, unable to send email." : "ئېلېكترونلۇق خەت ئەۋەتەلمەي خاتالىق كۆرۈلدى.",
    "Embed code copied to clipboard." : "قىستۇرما تاختىغا كۆچۈرۈلگەن كود.",
    "Embed code could not be copied to clipboard." : "قىستۇرما كودنى چاپلاش تاختىسىغا كۆچۈرگىلى بولمايدۇ.",
    "Unpublishing calendar failed" : "كالېندارنى ئېلان قىلىش مەغلۇب بولدى",
    "Share link" : "ئۇلىنىشنى ھەمبەھىرلە",
    "Copy public link" : "ئاممىۋى ئۇلىنىشنى كۆچۈرۈڭ",
    "Send link to calendar via email" : "ئېلېكترونلۇق خەت ئارقىلىق كالېندارغا ئۇلىنىش ئەۋەتىڭ",
    "Enter one address" : "بىر ئادرېسنى كىرگۈزۈڭ",
    "Sending email …" : "ئېلېكترونلۇق خەت ئەۋەتىش…",
    "Copy embedding code" : "قىستۇرما كودىنى كۆچۈرۈڭ",
    "Copying code …" : "كۆچۈرۈش كودى…",
    "Copied code" : "كۆچۈرۈلگەن كود",
    "Could not copy code" : "كودنى كۆچۈرەلمىدى",
    "Delete share link" : "ھەمبەھىر ئۇلىنىشنى ئۆچۈرۈڭ",
    "Deleting share link …" : "ھەمبەھىر ئۇلىنىشنى ئۆچۈرۈۋاتىدۇ…",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (ئەتىرەت)",
    "An error occurred while unsharing the calendar." : "كالېندارنى ھەمبەھىرلەۋاتقاندا خاتالىق كۆرۈلدى.",
    "An error occurred, unable to change the permission of the share." : "ئورتاقلىشىشنىڭ رۇخسىتىنى ئۆزگەرتەلمەي خاتالىق كۆرۈلدى.",
    "can edit and see confidential events" : "مەخپىي پائالىيەتلەرنى كۆرەلەيدۇ ھەمدە تەھرىرلىيەلەيدۇ",
    "Unshare with {displayName}" : "{displayName} بىلەن ئورتاقلاشماسلىق",
    "Share with users or groups" : "ئىشلەتكۈچىلەر ياكى گۇرۇپپىلار بىلەن ئورتاقلىشىڭ",
    "No users or groups" : "ئىشلەتكۈچى ياكى گۇرۇپپا يوق",
    "Failed to save calendar name and color" : "كالېندار ئىسمى ۋە رەڭنى ساقلاش مەغلۇب بولدى",
    "Calendar name …" : "كالېندار ئىسمى …",
    "Never show me as busy (set this calendar to transparent)" : "مېنى ھەرگىز ئالدىراش دەپ كۆرسەتمەڭ (بۇ كالېندارنى سۈزۈك قىلىپ تەڭشەڭ)",
    "Share calendar" : "كالېندارنى ئورتاقلىشىش",
    "Unshare from me" : "مەندىن تەڭداشسىز",
    "Save" : "ساقلا",
    "No title" : "ئۇنىۋانى يوق",
    "Are you sure you want to delete \"{title}\"?" : "\"{title}\" نى ئۆچۈرۈشنى جەزىملەشتۈرەمسىز؟",
    "Deleting proposal \"{title}\"" : "\"{title}\" تەكلىپنى ئۆچۈرۋاتىدۇ",
    "Successfully deleted proposal" : "تەكلىپ مۇۋەپپەقىيەتلىك ئۆچۈرۈلدى",
    "Failed to delete proposal" : "تەكلىپنى ئۆچۈرۈش مەغلۇپ بولدى",
    "Failed to retrieve proposals" : "تەكلىپنى چۈشۈرۈش مەغلۇپ بولدى",
    "Meeting proposals" : "يىغىن تەكلىپى",
    "A configured email address is required to use meeting proposals" : "يىغىن تەكلىپىنى ئىشلىتىش ئۈچۈن ئېلېكترونلۇق خەت ئادرېسىڭىز تەلەپ قىلىنىدۇ.",
    "No active meeting proposals" : "جانلىق يىغىن تەكلىپى يوق",
    "View" : "كۆرۈش",
    "Import calendars" : "كالېندار ئەكىرىڭ",
    "Please select a calendar to import into …" : "ئىمپورت قىلىدىغان كالېندارنى تاللاڭ.",
    "Filename" : "ھۆججەت ئىسمى",
    "Calendar to import into" : "كىرگۈزمەكچى بولغان كالېندار",
    "Cancel" : "ۋاز كەچ",
    "_Import calendar_::_Import calendars_" : ["كالېندار ئەكىرىڭ","كالېندار ئەكىرىڭ"],
    "Select the default location for attachments" : "قوشۇمچە ھۆججەتلەرنىڭ سۈكۈتتىكى ئورنىنى تاللاڭ",
    "Pick" : "تاللاڭ",
    "Invalid location selected" : "ئىناۋەتسىز ئورۇن تاللانغان",
    "Attachments folder successfully saved." : "قوشۇمچە ھۆججەت قىسقۇچ مۇۋەپپەقىيەتلىك ساقلاندى.",
    "Error on saving attachments folder." : "قوشۇمچە ھۆججەت قىسقۇچنى ساقلاشتا خاتالىق.",
    "Attachments folder" : "قوشۇمچە ھۆججەت قىسقۇچ",
    "{filename} could not be parsed" : "{filename} تەھلىل قىلىشقا بولمايدۇ",
    "No valid files found, aborting import" : "ئۈنۈملۈك ھۆججەت تېپىلمىدى ، ئىمپورتنى ئەمەلدىن قالدۇردى",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["%n پائالىيەتلەر مۇۋاپىقىيەتلىك ئەكىرىلدى","%n پائالىيەتلەر مۇۋاپىقىيەتلىك ئەكىرىلدى"],
    "Import partially failed. Imported {accepted} out of {total}." : "ئىمپورت قىسمەن مەغلۇپ بولدى. {total} دىن {accepted} سى ئىمپورت قىلىندى.",
    "Automatic" : "ئاپتوماتىك",
    "Automatic ({timezone})" : "ئاپتوماتىك ({timezone})",
    "New setting was not saved successfully." : "يېڭى تەڭشەك مۇۋەپپەقىيەتلىك ساقلانمىدى.",
    "Timezone" : "ۋاقىت رايۇنى",
    "Navigation" : "يول باشلاش",
    "Previous period" : "ئالدىنقى مەزگىل",
    "Next period" : "كېيىنكى مەزگىل",
    "Views" : "كۆرۈنۈشلەر",
    "Day view" : "كۈن كۆرۈنۈشى",
    "Week view" : "ھەپتە كۆرۈنۈشى",
    "Month view" : "ئاي كۆرۈنۈشى",
    "Year view" : "يىل كۆرۈنۈشى",
    "List view" : "تىزىملىك كۆرۈنۈشى",
    "Actions" : "مەشغۇلاتلار",
    "Create event" : "ھادىسە قۇرۇش",
    "Show shortcuts" : "تېزلەتمىلەرنى كۆرسەت",
    "Editor" : "تەھرىر",
    "Close editor" : "تەھرىرلىگۈچنى تاقاش",
    "Save edited event" : "تەھرىرلەنگەن پائالىيەتنى ساقلاڭ",
    "Delete edited event" : "تەھرىرلەنگەن ۋەقەنى ئۆچۈرۈڭ",
    "Duplicate event" : "كۆپەيتىلگەن ھادىسە",
    "or" : "ياكى",
    "Calendar settings" : "كالېندار تەڭشىكى",
    "At event start" : "پائالىيەت باشلانغاندا",
    "No reminder" : "ئەسكەرتىش يوق",
    "Failed to save default calendar" : "سۈكۈتتىكى كالېندارنى ساقلىيالمىدى",
    "General" : "ئۇمۇمىي",
    "Availability settings" : "ھازىرلىق تەڭشەكلىرى",
    "CalDAV" : "CalDAV",
    "Access Nextcloud calendars from other apps and devices" : "Nextcloud يىلنامىسىگە باشقا ئەپ ياكى ئۈسكۈنىلەردىن كىرىڭ",
    "CalDAV URL" : "CalDAV URL",
    "Server Address for iOS and macOS" : " iOS and macOS لارنىڭ مۇلازىمېتىر ئادىرىسلىرى",
    "Appearance" : "كۆرۈنۈش",
    "Birthday calendar" : "تۇغۇلغان كۈن كالىندارى",
    "Tasks in calendar" : "كالېنداردىكى ۋەزىپىلەر",
    "Weekends" : "ھەپتە ئاخىرى",
    "Week numbers" : "ھەپتە نۇمۇرلىرى",
    "Limit number of events shown in Month view" : "ئايلىق كۆرۈنۈشتە كۆرسىتىلگەن پائالىيەت سانىنى چەكلەڭ",
    "Density in Day and Week View" : "كۈن ھەمدە ھەپتە كۆرۈنۈشىدىكى زىچلىق",
    "Editing" : "تەھرىرلەش",
    "Default reminder" : "كۆڭۈلدىكى ئەسكەرتىش",
    "Simple event editor" : "ئاددىي پائالىيەت تەھرىرلىگۈچى",
    "\"More details\" opens the detailed editor" : "\"تېخىمۇ تەپسىلىي\" تەپسىلىي تەھرىرلىگۈچنى ئاچىدۇ",
    "Files" : "ھۆججەتلەر",
    "Appointment schedule successfully created" : "تەيىنلەش جەدۋىلى مۇۋەپپەقىيەتلىك قۇرۇلدى",
    "Appointment schedule successfully updated" : "تەيىنلەش جەدۋىلى مۇۋەپپەقىيەتلىك يېڭىلاندى",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} مىنۇت","{duration} مىنۇت"],
    "0 minutes" : "0 مىنۇت",
    "_{duration} hour_::_{duration} hours_" : ["{duration} سائەت","{duration} سائەت"],
    "_{duration} day_::_{duration} days_" : ["{duration} كۈن","{duration} كۈن"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} ھەپتە","{duration} ھەپتە"],
    "_{duration} month_::_{duration} months_" : ["{duration} ئاي","{duration} ئاي"],
    "_{duration} year_::_{duration} years_" : ["{duration} يىل","{duration} يىل"],
    "To configure appointments, add your email address in personal settings." : "ئۇچرىشىشنى تەڭشەش ئۈچۈن ئېلېكترونلۇق خەت ئادرېسىڭىزنى شەخسىي تەڭشەكلەرگە قوشۇڭ.",
    "Public – shown on the profile page" : "ئاممىۋى - ئارخىپ بېتىدە كۆرسىتىلدى",
    "Private – only accessible via secret link" : "شەخسىي - پەقەت مەخپىي ئۇلىنىش ئارقىلىقلا زىيارەت قىلغىلى بولىدۇ",
    "Appointment schedule saved" : "ئۇچۇرشىش پىلانى ساقلاندى",
    "Create appointment schedule" : "ئۇچرىشىش جەدۋىلىنى تۈزۈڭ",
    "Edit appointment schedule" : "تەيىنلەش جەدۋىلىنى تەھرىرلەڭ",
    "Update" : "يېڭىلا",
    "Appointment name" : "تەيىنلەش ئىسمى",
    "Location" : "ئورنى",
    "Create a Talk room" : "پاراڭلىشىش ئۆيى قۇرۇش",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "ھەر بىر زاكاس قىلىنغان ئۇچرىشىشتا ئۆزگىچە ئۇلىنىش ھاسىل قىلىنىدۇ ۋە جەزملەشتۈرۈش ئېلخېتى ئارقىلىق ئەۋەتىلىدۇ",
    "Description" : "چۈشەندۈرۈش",
    "Visibility" : "كۆرۈنۈشچانلىقى",
    "Duration" : "ئۇزۇنلىقى:",
    "Increments" : "كۆپەيتىش",
    "Additional calendars to check for conflicts" : "زىددىيەتلەرنى تەكشۈرۈش ئۈچۈن قوشۇمچە كالېندار",
    "Pick time ranges where appointments are allowed" : "ئۇچرىشىشقا رۇخسەت قىلىنغان ۋاقىت دائىرىسىنى تاللاڭ",
    "to" : "غا",
    "Delete slot" : "ئورۇننى ئۆچۈرۈڭ",
    "No times set" : "ۋاقىت بەلگىلەنمىدى",
    "Add" : "قوش",
    "Monday" : "دۈشەنبە",
    "Tuesday" : "سەيشەنبە",
    "Wednesday" : "چارشەنبە",
    "Thursday" : "پەيشەنبە",
    "Friday" : "جۈمە",
    "Saturday" : "شەنبە",
    "Sunday" : "يەكشەنبە",
    "Weekdays" : "ھەپتە كۈنلىرى",
    "Add time before and after the event" : "پائالىيەتنىڭ ئالدى-كەينىدە ۋاقىت قوشۇڭ",
    "Before the event" : "پائالىيەتتىن ئىلگىرى",
    "After the event" : "پائالىيەتتىن كېيىن",
    "Planning restrictions" : "پىلان چەكلىمىسى",
    "Minimum time before next available slot" : "كېيىنكى ئىشلەتكىلى بولىدىغان ئورۇننىڭ ئەڭ تۆۋەن ۋاقتى",
    "Max slots per day" : "كۈنىگە ئەڭ چوڭ ئورۇن",
    "Limit how far in the future appointments can be booked" : "كەلگۈسىدىكى ئۇچرىشىشلارنىڭ قانچىلىك دەرىجىدە زاكاس قىلىنىدىغانلىقىنى چەكلەڭ",
    "It seems a rate limit has been reached. Please try again later." : "قارىماققا ئۆسۈم چېكىگە يەتكەندەك قىلىدۇ. كېيىن قايتا سىناڭ.",
    "Please confirm your reservation" : "زاكاسلىرىڭىزنى جەزملەشتۈرۈڭ",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "بىز سىزگە تەپسىلاتلار بىلەن ئېلېكترونلۇق خەت ئەۋەتتۇق. ئېلېكترونلۇق خەتتىكى ئۇلىنىش ئارقىلىق ئۇچرىشىشىڭىزنى جەزملەشتۈرۈڭ. بۇ بەتنى ھازىر ياپالايسىز.",
    "Your name" : "ئىسمىڭىز",
    "Your email address" : "تورخەت ئادرېسىڭىز",
    "Please share anything that will help prepare for our meeting" : "ئۇچرىشىشىمىزغا تەييارلىق قىلىشقا ياردىمى بولىدىغان نەرسىلەرنى ئورتاقلىشىڭ",
    "Could not book the appointment. Please try again later or contact the organizer." : "ئۇچرىشىشنى زاكاز قىلالمىدى. كېيىن قايتا سىناڭ ياكى تەشكىللىگۈچى بىلەن ئالاقىلىشىڭ.",
    "Back" : "قايتىش",
    "Book appointment" : "ئۇچرىشىشنى زاكاس قىل",
    "Error fetching Talk conversations." : "پاراڭ سۆھپىتىنى چۈشۈرۈشتە خاتالىق",
    "Conversation does not have a valid URL." : "سۆھبەتنىڭ بىر ئىناۋەتلىك ئۇلىنىشى يوق",
    "Successfully added Talk conversation link to location." : "ئورۇنغان پاراڭ سۆھپەت ئۇلىنىشنى قېتىش مۇۋاپىقىيەتلىك بولدى",
    "Successfully added Talk conversation link to description." : "چۈشەندۈرۈشكە پاراڭ سۆھپەت ئۇلىنىشنى قېتىش مۇۋاپىقىيەتلىك بولدى",
    "Failed to apply Talk room." : "پاراڭ ئۈيىگە ئىلتىماس قىلىش مەغلۇپ بولدى",
    "Talk conversation for event" : "پائالىيەتنىڭ پاراڭ سۆھپىتى",
    "Error creating Talk conversation" : "پاراڭ سۆھپىتىنى قۇرۇشتا خاتالىق",
    "Select a Talk Room" : "پاراڭلىشىش ئۆيى تاللا",
    "Add Talk conversation" : "پاراڭ سۆھپىتى قوش",
    "Fetching Talk rooms…" : "پاراڭ ئۆيىنى چۈشۈرۋاتىدۇ...",
    "No Talk room available" : "پاراڭ ئۆيى بوش ئەمەس",
    "Create public conversation" : "ئاممىۋىي پاراڭ قۇر",
    "Select conversation" : "سۆھبەتنى تاللا",
    "on" : "دا",
    "at" : "دا",
    "before at" : "دىن بۇرۇن",
    "Notification" : "ئۇقتۇرۇش",
    "Email" : "تورخەت",
    "Audio notification" : "ئاۋازلىق ئۇقتۇرۇش",
    "Other notification" : "باشقا ئۇقتۇرۇش",
    "Relative to event" : "ۋەقەگە مۇناسىۋەتلىك",
    "On date" : "چېسلا",
    "Edit time" : "ۋاقىتنى تەھرىرلەش",
    "Save time" : "ۋاقىت تېجەڭ",
    "Remove reminder" : "ئەسكەرتىشنى ئۆچۈرۈڭ",
    "Add reminder" : "ئەسكەرتىش قوشۇڭ",
    "seconds" : "سېكۇنت",
    "minutes" : "مىنۇت",
    "hours" : "سائەت",
    "days" : "كۈنلەر",
    "weeks" : "ھەپتە",
    "Choose a file to add as attachment" : "قوشۇمچە قىلىپ قوشماقچى بولغان ھۆججەتنى تاللاڭ",
    "Choose a file to share as a link" : "ئۇلىنىش سۈپىتىدە ھەمبەھىرلىنىدىغان ھۆججەتنى تاللاڭ",
    "Attachment {name} already exist!" : "قوشۇمچە {name} مەۋجۇت!",
    "Could not upload attachment(s)" : "قوشۇمچە ھۆججەت(لەر)نى يۈكلىيەلمىدى",
    "You are about to navigate to {link}. Are you sure to proceed?" : "{link} نى زىيارەت قىلماقچى بولىۋاتىسىز. داۋاملاشتۇرامسىز؟",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "سىز {host} غا يۆتكىمەكچى بولۇۋاتىسىز. داۋاملاشتۇرامسىز؟ ئۇلىنىش: {link}",
    "Proceed" : "داۋاملاشتۇرۇڭ",
    "No attachments" : "قوشۇمچە ھۆججەت يوق",
    "Add from Files" : "ھۆججەتلەردىن قوشۇڭ",
    "Upload from device" : "ئۈسكۈنىدىن يۈكلەش",
    "Delete file" : "ھۆججەتنى ئۆچۈرۈڭ",
    "Confirmation" : "جەزملەشتۈرۈش",
    "_{count} attachment_::_{count} attachments_" : ["{count} يوللانما","{count} يوللانمىلار"],
    "Suggested" : "تەكلىپ بەردى",
    "Available" : "ئىشلەتكىلى بولىدۇ",
    "Invitation accepted" : "تەكلىپ قوبۇل قىلىندى",
    "Accepted {organizerName}'s invitation" : "{organizerName} نىڭ تەكلىپىنى قوبۇل قىلدى",
    "Participation marked as tentative" : "قاتنىشىش ۋاقتىنچە بەلگە قىلىندى",
    "Invitation is delegated" : "تەكلىپنامە ئەۋەتىلدى",
    "Not available" : "ئىشلەتكىلى بولمايدۇ",
    "Invitation declined" : "تەكلىپ رەت قىلىندى",
    "Declined {organizerName}'s invitation" : "رەت قىلىنغان {organizerName} نىڭ تەكلىپنامىسى",
    "Availability will be checked" : "بىكارلىقى تەكشۈرۈلدۇ",
    "Invitation will be sent" : "تەكلىپ يوللىندۇ",
    "Failed to check availability" : "بىكارلىقىنى تەكشۈرۈش مەغلۇپ بولدى",
    "Failed to deliver invitation" : "تەكلىپنى يەتكۈزۈش مەغلۇپ بولدى",
    "Awaiting response" : "جاۋاب كۈتۈش",
    "Checking availability" : "بار-يوقلۇقىنى تەكشۈرۈش",
    "Has not responded to {organizerName}'s invitation yet" : "{organizerName} نىڭ تەكلىپىگە تېخى جاۋاب بەرمىدى",
    "Suggested times" : "تەۋسىيە قىلىنغان ۋاقىتلار",
    "chairperson" : "رەئىس",
    "required participant" : "تەلەپچان قاتناشقۇچى",
    "non-participant" : "قاتناشمىغان",
    "optional participant" : "ئىختىيارى قاتناشقۇچى",
    "{organizer} (organizer)" : "{organizer} (تەشكىللىگۈچى)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Selected slot" : "ئورۇننى تاللاڭ",
    "Availability of attendees, resources and rooms" : "قاتناشقۇچىلار ، بايلىق ۋە ياتاقلار",
    "Suggestion accepted" : "تەكلىپ قوبۇل قىلىندى",
    "Previous date" : "ئالدىنقى چېسلا",
    "Next date" : "كېيىنكى چېسلا",
    "Legend" : "رىۋايەت",
    "Out of office" : "ئىشخانىدىن چىقتى",
    "Attendees:" : "قاتناشقۇچىلار:",
    "local time" : "يەرلىك ۋاقىت",
    "Done" : "تامام",
    "Search room" : "ئىزدەش ئۆيى",
    "Room name" : "ياتاق ئىسمى",
    "Check room availability" : "ياتاقنىڭ بار-يوقلۇقىنى تەكشۈرۈڭ",
    "Free" : "ھەقسىز",
    "Busy (tentative)" : "ئالدىراش (ۋاقىتلىق)",
    "Busy" : "ئالدىراش",
    "Unknown" : "نامەلۇم",
    "Find a time" : "ۋاقىت تېپىڭ",
    "The invitation has been accepted successfully." : "تەكلىپ مۇۋەپپەقىيەتلىك قوبۇل قىلىندى.",
    "Failed to accept the invitation." : "تەكلىپنى قوبۇل قىلالمىدى.",
    "The invitation has been declined successfully." : "تەكلىپ مۇۋەپپەقىيەتلىك رەت قىلىندى.",
    "Failed to decline the invitation." : "تەكلىپنى رەت قىلدى.",
    "Your participation has been marked as tentative." : "سىزنىڭ قاتنىشىشىڭىز ۋاقتىنچە بەلگە قىلىندى.",
    "Failed to set the participation status to tentative." : "قاتنىشىش ھالىتىنى ۋاقتىنچە بەلگىلىيەلمىدى.",
    "Accept" : "قوبۇل قىلىڭ",
    "Decline" : "رەت قىلىش",
    "Tentative" : "Tentative",
    "No attendees yet" : "ھازىرغىچە قاتناشقۇچىلار يوق",
    "{confirmedCount} confirmed, {waitingCount} awaiting response" : "{confirmedCount} جەزىملەشتۈرۈلدى، {waitingCount} جاۋاپ ساقلاۋاتىدۇ",
    "Please add at least one attendee to use the \"Find a time\" feature." : "\"ۋاقىت ئىزدە\" ئىقتىدارىنى ئىشلىتىش ئۈچۈن ئەڭ كەمدە بىر قاتناشقۇچى تاللاڭ.",
    "Attendees" : "قاتناشقۇچىلار",
    "_%n more attendee_::_%n more attendees_" : ["يەنە %n قاتناشقۇچى","يەنە %n قاتناشقۇچى"],
    "Remove group" : "گۇرۇپپىنى ئۆچۈرۈڭ",
    "Remove attendee" : "قاتناشقۇچىلارنى ئېلىۋېتىڭ",
    "Request reply" : "جاۋاب تەلەپ قىلىڭ",
    "Chairperson" : "رەئىس",
    "Required participant" : "تەلەپچان قاتناشقۇچى",
    "Optional participant" : "ئىختىيارى قاتناشقۇچى",
    "Non-participant" : "قاتناشمىغان",
    "_%n member_::_%n members_" : ["%n ئەزا","%n ئەزا"],
    "Search for emails, users, contacts, contact groups or teams" : "ئېلخەت، ئىشلەتكۈچى، ئالاقىداش، ئالاقىداش گۇرۇپپا ياكى ئەتىرەت ئىزدە",
    "No match found" : "ماس كەلمىدى",
    "Note that members of circles get invited but are not synced yet." : "چەمبىرەك ئەزالىرىنىڭ تەكلىپ قىلىنغانلىقىغا دىققەت قىلىڭ ، ئەمما تېخى ماسلاشمىدى.",
    "Note that members of contact groups get invited but are not synced yet." : "ئالاقە گۇرۇپپىلىرىنىڭ ئەزالىرى تەكلىپ قىلىنىدىغانلىقىغا، ئەمما ھازىرغىچە ماسلاشتۇرۇلمىغانلىقىغا دىققەت قىلىڭ.",
    "(organizer)" : "(تەشكىللىگۈچى)",
    "Make {label} the organizer" : "{label} تەشكىللىگۈچى",
    "Make {label} the organizer and attend" : "{label} تەشكىللىگۈچى ۋە قاتنىشىڭ",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "تەكلىپنامە ئەۋەتىش ۋە جاۋابلارنى بىر تەرەپ قىلىش ئۈچۈن ، [linkopen] ئېلېكترونلۇق خەت ئادرېسىڭىزنى شەخسىي تەڭشەكلەرگە قوشۇڭ [linkclose].",
    "Remove color" : "رەڭنى ئۆچۈرۈڭ",
    "Event title" : "پائالىيەت ئىسمى",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "تەكرارلىنىشنىڭ بىر قىسمى بولغان ۋەقەلەرنىڭ پۈتۈن كۈنلۈك تەڭشىكىنى ئۆزگەرتەلمەيدۇ.",
    "From" : "دىن",
    "To" : "غا",
    "Your Time" : "ۋاقتىڭىز",
    "Repeat" : "قايتىلا",
    "Repeat event" : "پائالىيەتنى تەكرارلا",
    "_time_::_times_" : ["ۋاقىت","ۋاقىت"],
    "never" : "ھەرگىز",
    "on date" : "ۋاقتىدا",
    "after" : "كىيىن",
    "End repeat" : "تەكرارلاش",
    "Select to end repeat" : "تەكرارلاشنى ئاخىرلاشتۇرۇشنى تاللاڭ",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "بۇ ھادىسە قايتا-قايتا تەكرارلانغاندىن باشقا. ئۇنىڭغا قايتا-قايتا قائىدە قوشالمايسىز.",
    "first" : "بىرىنچى",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "تەكرارلىنىش قائىدىسىگە ئۆزگەرتىش پەقەت مۇشۇ ۋە كەلگۈسىدىكى بارلىق ئىشلارغا ماس كېلىدۇ.",
    "Repeat every" : "ھەممىنى تەكرارلاڭ",
    "By day of the month" : "ئاينىڭ كۈنىگە قەدەر",
    "On the" : "ئۈستىدە",
    "_day_::_days_" : ["كۈن","كۈن"],
    "_week_::_weeks_" : ["ھەپتە","ھەپتە"],
    "_month_::_months_" : ["ئاي","ئاي"],
    "_year_::_years_" : ["يىل","يىللار"],
    "On specific day" : "بەلگىلىك بىر كۈندە",
    "weekday" : "ھەپتە",
    "weekend day" : "ھەپتە ئاخىرى",
    "Does not repeat" : "تەكرارلانمايدۇ",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "بۇ پائالىيەتنىڭ قايتا-قايتا ئېنىقلىنىشى Nextcloud تەرىپىدىن تولۇق قوللىمايدۇ. ئەگەر قايتا-قايتا تاللاشلارنى تەھرىرلىسىڭىز ، بەزى تەكرارلىنىشلار يوقاپ كېتىشى مۇمكىن.",
    "No rooms or resources yet" : "ھازىرچە ياتاق ۋە بايلىق يوق",
    "Resources" : "بايلىق",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} ئورۇن","{seatingCapacity} ئورۇن"],
    "Add resource" : "بايلىق قوشۇڭ",
    "Has a projector" : "بىر پروجېكتور بار",
    "Has a whiteboard" : "ئاق دوسكىسى بار",
    "Wheelchair accessible" : "چاقلىق ئورۇندۇقنى زىيارەت قىلغىلى بولىدۇ",
    "Remove resource" : "مەنبەنى ئۆچۈرۈڭ",
    "Search for resources or rooms" : "بايلىق ياكى ئۆي ئىزدەڭ",
    "available" : "ئىشلەتكىلى بولىدۇ",
    "unavailable" : "ئىشلەتكىلى بولمايدۇ",
    "Show all rooms" : "بارلىق ئۆيلەرنى كۆرسەت",
    "Projector" : "پرويېكتور",
    "Whiteboard" : "ئاق دوسكا",
    "Room type" : "ياتاق تىپى",
    "Any" : "ھەر قانداق",
    "Minimum seating capacity" : "ئەڭ تۆۋەن ئولتۇرۇش ئىقتىدارى",
    "More details" : "تېخىمۇ كۆپ تەپسىلاتلار",
    "Update this and all future" : "بۇنى ۋە كەلگۈسىنى يېڭىلاڭ",
    "Update this occurrence" : "بۇ ھادىسىنى يېڭىلاڭ",
    "Public calendar does not exist" : "ئاممىۋى كالېندار مەۋجۇت ئەمەس",
    "Maybe the share was deleted or has expired?" : "بەلكىم ھەمبەھىر ئۆچۈرۈلگەن ياكى ۋاقتى توشقان بولۇشى مۇمكىن؟",
    "Remove date" : "چېسلانى ئۆچۈر",
    "Attendance required" : "قاتنىشىش تەلەپ قىلىندۇ",
    "Attendance optional" : "قاتنىشىش ئىختىيارى",
    "Remove participant" : "قاتناشقۇچىنى ئېلىۋېتىڭ",
    "Yes" : "ھەئە",
    "No" : "ياق",
    "Maybe" : "مۇمكىن",
    "None" : "يوق",
    "Select your meeting availability" : "كۆرۈشۈش ۋاقتىڭىزنى تاللاڭ",
    "Create a meeting for this date and time" : "مۇشۇ كۈن ھەم ۋاقىتتا بىر يىغىن قۇر",
    "Create" : "قۇر",
    "No participants or dates available" : "قاتناشقۇچى ياكى چىسلا يوق",
    "from {formattedDate}" : "from {formattedDate}",
    "to {formattedDate}" : "to {formattedDate}",
    "on {formattedDate}" : "on {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "{formattedDate} دىن {formattedTime} دا",
    "to {formattedDate} at {formattedTime}" : "{formattedDate} دىكى {formattedTime}غا ",
    "on {formattedDate} at {formattedTime}" : "{formattedDate} دىكى {formattedTime}دا",
    "{formattedDate} at {formattedTime}" : "{formattedDate} at {formattedTime}",
    "Please enter a valid date" : "ئىناۋەتلىك چېسلانى كىرگۈزۈڭ",
    "Please enter a valid date and time" : "ئىناۋەتلىك چېسلا ۋە ۋاقىتنى كىرگۈزۈڭ",
    "Select a time zone" : "ۋاقىت رايونىنى تاللاڭ",
    "Please select a time zone:" : "ۋاقىت رايونىنى تاللاڭ:",
    "Pick a time" : "ۋاقىت تاللاڭ",
    "Pick a date" : "چېسلا تاللاڭ",
    "Type to search time zone" : "ئىزدەش ۋاقىت رايونىغا كىرگۈزۈڭ",
    "Global" : "ئۇمۇمىي",
    "Holidays in {region}" : "{region} دا دەم ئېلىش",
    "An error occurred, unable to read public calendars." : "ئاممىۋى كالېندارنى ئوقۇيالماي خاتالىق كۆرۈلدى.",
    "An error occurred, unable to subscribe to calendar." : "كالېندارغا مۇشتەرى بولالمىغان خاتالىق كۆرۈلدى.",
    "Public holiday calendars" : "ئاممىۋى دەم ئېلىش كالېندارى",
    "Public calendars" : "ئاممىۋى كالېندار",
    "No valid public calendars configured" : "ئىناۋەتلىك ئاممىۋى كالېندار سەپلەنمىدى",
    "Speak to the server administrator to resolve this issue." : "بۇ مەسىلىنى ھەل قىلىش ئۈچۈن مۇلازىمېتىر باشقۇرغۇچىغا سۆزلەڭ.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "ئاممىۋى دەم ئېلىش كالېندارىنى Thunderbird تەمىنلەيدۇ. كالېندار سانلىق مەلۇماتلىرى {website} دىن چۈشۈرۈلىدۇ",
    "These public calendars are suggested by the server administrator. Calendar data will be downloaded from the respective website." : "بۇ ئاممىۋى كالېندارلار مۇلازىمېتىر باشقۇرغۇچىسى تەرىپىدىن تەۋسىيە قىلىنىدۇ. كالېندار سانلىق مەلۇماتلىرى ئايرىم تور بېكەتتىن چۈشۈرۈلىدۇ.",
    "By {authors}" : "{authors}",
    "Subscribed" : "مۇشتەرى بولدى",
    "Subscribe" : "مۇشتەرى بولۇش",
    "Could not fetch slots" : "ئورۇن ئالالمىدى",
    "Select a date" : "چېسلانى تاللاڭ",
    "Select slot" : "ئورۇننى تاللاڭ",
    "No slots available" : "ئورۇن يوق",
    "The slot for your appointment has been confirmed" : "سىزنىڭ ۋەزىپىگە تەيىنلەنگەنلىكىڭىز جەزملەشتۈرۈلدى",
    "Appointment Details:" : "تەيىنلەش تەپسىلاتى:",
    "Time:" : "ۋاقىت:",
    "Booked for:" : "زاكاز قىلىندى:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "رەھمەت سىزگە. سىزنىڭ {startDate} دىن {endDate} گىچە زاكاس قىلىشىڭىز جەزملەشتۈرۈلدى.",
    "Book another appointment:" : "باشقا ئۇچرىشىشنى زاكاز قىلىڭ:",
    "See all available slots" : "بارلىق ئورۇنلارنى كۆرۈڭ",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "سىزنىڭ ئۇچرىشىشىڭىزنىڭ {startDate} دىن {endDate} غىچە بولغان ئورنى ئەمدى يوق.",
    "Please book a different slot:" : "باشقا بىر كىتابنى زاكاز قىلىڭ:",
    "Book an appointment with {name}" : "{name} بىلەن ئۇچرىشىشنى زاكاز قىلىڭ",
    "No public appointments found for {name}" : "{name} ئۈچۈن ئاممىۋى ئۇچرىشىش تېپىلمىدى",
    "Personal" : "شەخسىي",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "ئاپتوماتىك ۋاقىت رايونىنى تەكشۈرۈش سىزنىڭ ۋاقىت رايونىڭىزنىڭ UTC ئىكەنلىكىنى بەلگىلىدى.\nبۇ بەلكىم توركۆرگۈڭىزنىڭ بىخەتەرلىك تەدبىرلىرىنىڭ نەتىجىسى بولۇشى مۇمكىن.\nۋاقىت رايونىنى كالېندار تەڭشىكىدە قولدا تەڭشەڭ.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "تەڭشەلگەن ۋاقىت رايونىڭىز ({timezoneId}) تېپىلمىدى. UTC غا قايتىش.\nتەڭشەكتىكى ۋاقىت رايونىڭىزنى ئۆزگەرتىپ بۇ مەسىلىنى دوكلات قىلىڭ.",
    "Show unscheduled tasks" : "پىلانلانمىغان ۋەزىپىلەرنى كۆرسەت",
    "Unscheduled tasks" : "پىلانلانمىغان ۋەزىپىلەر",
    "Availability of {displayName}" : "{displayName} نىڭ بىكار ۋاقىتلىرى",
    "Discard event" : "پائالىيەتنى تاشلىۋەت",
    "Edit event" : "پائالىيەتنى تەھرىرلە",
    "Event does not exist" : "ھادىسە مەۋجۇت ئەمەس",
    "Duplicate" : "كۆپەيتىلگەن",
    "Delete this occurrence" : "بۇ ھادىسىنى ئۆچۈرۈڭ",
    "Delete this and all future" : "بۇنى ۋە كەلگۈسىنى ئۆچۈرۈڭ",
    "All day" : "پۈتۈن كۈن",
    "Modifications wont get propagated to the organizer and other attendees" : "ئۆزگەرتىشلەر تەشكىللىگۈچى ۋە باشقا قاتناشقۇچىلارغا تارقىتىلمايدۇ",
    "Managing shared access" : "ئورتاق زىيارەتنى باشقۇرۇش",
    "Deny access" : "زىيارەتنى رەت قىلىش",
    "Invite" : "تەكلىپ قىلىڭ",
    "Discard changes?" : "ئۆزگەرتىشلەرنى تاشلىۋېتەمسىز؟",
    "Are you sure you want to discard the changes made to this event?" : "بۇ پائالىيەتكە كىرگۈزۈلگەن ئۆزگەرتىشلەرنى راستىنلا بىكار قىلماقچىمۇ؟",
    "_User requires access to your file_::_Users require access to your file_" : ["ئىشلەتكۈچىلەر سىزنىڭ ھۆججىتىڭىزگە كىرىشنى تەلەپ قىلىدۇ","ئىشلەتكۈچىلەر سىزنىڭ ھۆججىتىڭىزگە كىرىشنى تەلەپ قىلىدۇ"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["ئورتاق كىرىشنى تەلەپ قىلىدىغان يوللانمىلار","ئورتاق كىرىشنى تەلەپ قىلىدىغان يوللانمىلار"],
    "Untitled event" : "نامسىز ھادىسە",
    "Close" : "ياپ",
    "Modifications will not get propagated to the organizer and other attendees" : "ئۆزگەرتىشلەر تەشكىللىگۈچى ۋە باشقا قاتناشقۇچىلارغا تارقىتىلمايدۇ",
    "Meeting proposals overview" : "يىغىن تەكلىپى ئەھۋالى",
    "Edit meeting proposal" : "يىغىن تەكلىپىنى تەھرىرلە",
    "Create meeting proposal" : "يىغىن تەكلىپى قۇر",
    "Update meeting proposal" : "يىغىن تەكلىپىنى يېڭىلا",
    "Saving proposal \"{title}\"" : "تەكلىپ \"{title}\" نى ساقلاۋاتىدۇ",
    "Successfully saved proposal" : "تەكلىپ مۇۋەپپەقىيەتلىك ساقلاندى",
    "Failed to save proposal" : "تەكلىپنى ساقلاش مەغلۇپ بولدى",
    "Create a meeting for \"{date}\"? This will create a calendar event with all participants." : "«{date}» ئۈچۈن يىغىن قۇرامسىز؟ بۇ بارلىق قاتناشقۇچىلارنى ئۆز ئىچىگە ئالغان كالېندار پائالىيىتىنى قۇرىدۇ.",
    "Creating meeting for {date}" : "{date} دا يىغىن قۇرىۋاتىدۇ",
    "Successfully created meeting for {date}" : "{date} دا يىغىن مۇۋاپىقىيەتلىك قۇرۇلدى",
    "Failed to create a meeting for {date}" : "{date} دا يىغىن قۇرۇش مەغلۇپ بولدى",
    "Please enter a valid duration in minutes." : "ئىناۋەتلىك بىر مىنۇتلۇق ئۇزۇنلۇقنى كىرگۈزۈڭ.",
    "Failed to fetch proposals" : "تەكلىپنى چۈشۈرۈش مەغلۇپ بولدى",
    "Failed to fetch free/busy data" : "بىكار/ئالدىراش ئۇچۇرنى چۈشۈرۈش مەغلۇپ بولدى",
    "Selected" : "تاللانغان",
    "No Description" : "چۈشەندۈرۈش يوق",
    "No Location" : "ئورۇن يوق",
    "Edit this meeting proposal" : "يىغىن تەكلىپىنى تەھرىرلە",
    "Delete this meeting proposal" : "يىغىن تەكلىپىنى ئۆچۈر",
    "Title" : "ماۋزۇ",
    "15 min" : "15 مىنۇت",
    "30 min" : "30 مىنۇت",
    "60 min" : "60 مىنۇت",
    "90 min" : "90 مىنۇت",
    "Participants" : "قاتناشقۇچىلار",
    "Selected times" : "تاللانغان ۋاقىتلار",
    "Previous span" : "ئالدىنقى دائىرە",
    "Next span" : "كىيىنكى دائىرە",
    "Less days" : "ئاز كۈن",
    "More days" : "جىق كۈن",
    "Loading meeting proposal" : "يىغىن تەكلىپىنى يۈكلەۋاتىدۇ",
    "No meeting proposal found" : "يىغىن تەكلىپى تېپىلمىدى",
    "Please wait while we load the meeting proposal." : "بىز يىغىن تەكلىپىنى يۈكلەۋاتقاندا بىر ئاز ساقلاڭ.",
    "The link you followed may be broken, or the meeting proposal may no longer exist." : "سىز ئەگەشكەن ئۇلىنىش ئۈزۈلۈپ قالغان بولۇشى ياكى يىغىن تەكلىپى مەۋجۇت بولماسلىقى مۇمكىن.",
    "Thank you for your response!" : "جاۋابىڭىزغا رەھمەت!",
    "Your vote has been recorded. Thank you for participating!" : "بېلىتىڭىز ساقلاندى. قاتناشقىنىڭىزغا رەھمەت!",
    "Unknown User" : "نامەلۇم ئىشلەتكۈچى",
    "No Title" : "ئۇنىۋانى يوق",
    "No Duration" : "ئۇزۇنلۇقى يوق",
    "Select a different time zone" : "باشقا ۋاقىت رايونىنى تاللا",
    "Submit" : "يوللاڭ",
    "Subscribe to {name}" : "{name} غا مۇشتەرى بولۇڭ",
    "Export {name}" : "چىقىرىش {name}",
    "Show availability" : "بىكارلىقنى كۆرسەت",
    "Anniversary" : "يىللىق خاتىرە كۈنى",
    "Appointment" : "تەيىنلەش",
    "Business" : "سودا",
    "Education" : "مائارىپ",
    "Holiday" : "دەم ئېلىش",
    "Meeting" : "يىغىن",
    "Miscellaneous" : "ھەرخىل",
    "Non-working hours" : "خىزمەت ۋاقتى يوق",
    "Not in office" : "ئىشخانىدا ئەمەس",
    "Phone call" : "تېلېفون",
    "Sick day" : "كېسەل كۈنى",
    "Special occasion" : "ئالاھىدە سورۇن",
    "Travel" : "ساياھەت",
    "Vacation" : "دەم ئېلىش",
    "Midnight on the day the event starts" : "پائالىيەت باشلانغان كۈنى يېرىم كېچىدە",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["{formattedHourMinute} دىكى پائالىيەتتىن %n كۈن بۇرۇن","{formattedHourMinute} دىكى پائالىيەتتىن %n كۈن بۇرۇن"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["{formattedHourMinute} دىكى پائالىيەتتىن %n ھەپتە بۇرۇن","{formattedHourMinute} دىكى پائالىيەتتىن %n ھەپتە بۇرۇن"],
    "on the day of the event at {formattedHourMinute}" : "{formattedHourMinute} دىكى پائالىيەت كۈنىدە",
    "at the event's start" : "پائالىيەت باشلانغاندا",
    "at the event's end" : "پائالىيەت ئاخىرلاشقاندا",
    "{time} before the event starts" : "پائالىيەت باشلىنىشتىن بۇرۇن {time}",
    "{time} before the event ends" : "پائالىيەت ئاخىرلىشىشتىن بۇرۇن {time}",
    "{time} after the event starts" : "پائالىيەت باشلانغاندىن كېيىن {time}",
    "{time} after the event ends" : "پائالىيەت ئاخىرلاشقاندىن كېيىن {time}",
    "on {time}" : "on {time}",
    "on {time} ({timezoneId})" : "on {time} ({timezoneId})",
    "Week {number} of {year}" : "{year} نىڭ {number} ھەپتىسى",
    "Daily" : "كۈندىلىك",
    "Weekly" : "ھەپتىلىك",
    "Monthly" : "ئايلىق",
    "Yearly" : "يىللىق",
    "_Every %n day_::_Every %n days_" : ["ھەر %n كۈندە","ھەر %n كۈندە"],
    "_Every %n week_::_Every %n weeks_" : ["ھەر %n ھەپتىدە","ھەر %n ھەپتىدە"],
    "_Every %n month_::_Every %n months_" : ["ھەر %n ئايدا","ھەر %n ئايدا"],
    "_Every %n year_::_Every %n years_" : ["ھەر %n يىلدا","ھەر %n يىلدا"],
    "_on {weekday}_::_on {weekdays}_" : ["{weekday} دا","{weekdays} دا"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["{dayOfMonthList} كۈنلىرىدە","{dayOfMonthList} كۈنلىرىدە"],
    "on the {ordinalNumber} {byDaySet}" : "{byDaySet} نىڭ {ordinalNumber} دا",
    "in {monthNames} on the {dayOfMonthList}" : "{dayOfMonthList} دىكى {monthNames}دا",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "{monthNames} دا {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "{untilDate} غىچە",
    "_%n time_::_%n times_" : ["%n قېتىم","%n قېتىم"],
    "second" : "ئىككىنچى",
    "third" : "ئۈچىنچىسى",
    "fourth" : "تۆتىنچى",
    "fifth" : "بەشىنچى",
    "second to last" : "ئىككىنچىدىن ئاخىرقىسى",
    "last" : "ئاخىرقى",
    "Untitled task" : "نامسىز ۋەزىپە",
    "Please ask your administrator to enable the Tasks App." : "باشقۇرغۇچىدىن ۋەزىپە ئەپىنى قوزغىتىشنى تەلەپ قىلىڭ.",
    "You are not allowed to edit this event as an attendee." : "سىز بىر قاتناشقۇچى سۈپىتىدە بۇ پائالىيەتنى تەھرىرلەشكە يول قۇيۇلمايسىز.",
    "W" : "ھ.",
    "%n more" : "%n تېخىمۇ كۆپ",
    "No events to display" : "كۆرسىتىدىغان ھېچقانداق ھادىسە يوق",
    "All participants declined" : "ھەممە قاتناشقۇچى رەت قىلدى",
    "Please confirm your participation" : "قاتنىشىدىغانلىقىڭىزنى جەزىملەڭ",
    "You declined this event" : "سىز بۇ پائالىيەتنى رەت قىلدىڭىز",
    "Your participation is tentative" : "قاتنىشىشىڭىز ئېنىقسىز",
    "_+%n more_::_+%n more_" : ["%n+ كۆپ","%n+ كۆپ"],
    "No events" : "ھېچقانداق ۋەقە يوق",
    "Create a new event or change the visible time-range" : "يېڭى ھادىسە قۇرۇڭ ياكى كۆرۈنگەن ۋاقىت دائىرىسىنى ئۆزگەرتىڭ",
    "Failed to save event" : "پائالىيەتنى ساقلىيالمىدى",
    "It might have been deleted, or there was a typo in a link" : "ئۇ ئۆچۈرۈلگەن بولۇشى مۇمكىن ، ياكى ئۇلىنىشتا خاتالىق بار",
    "It might have been deleted, or there was a typo in the link" : "ئۇ ئۆچۈرۈلگەن بولۇشى مۇمكىن ، ياكى ئۇلىنىشتا خاتالىق بار",
    "Meeting room" : "يىغىن زالى",
    "Lecture hall" : "لېكسىيە زالى",
    "Seminar room" : "مۇھاكىمە ئۆيى",
    "Other" : "باشقا",
    "When shared show" : "ھەمبەھىرلەنگەندە",
    "When shared show full event" : "ھەمبەھىرلەنگەندە تولۇق پائالىيەتنى كۆرسىتىدۇ",
    "When shared show only busy" : "ئورتاقلاشقاندا پەقەت ئالدىراش",
    "When shared hide this event" : "ئورتاقلاشقاندا بۇ پائالىيەتنى يوشۇرۇڭ",
    "The visibility of this event in read-only shared calendars." : "بۇ پائالىيەتنىڭ كۆرۈنۈشچانلىقى ئوقۇشقىلا-بولىدىغان ئورتاق يىلنامىدە.",
    "Add a location" : "ئورۇن قوشۇڭ",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "چۈشەندۈرۈش قوشۇڭ\n\n- بۇ يىغىن نېمە ھەققىدە\n- كۈنتەرتىپ تۈرلىرى\n- قاتناشقۇچىلارنىڭ تەييارلىشى كېرەك بولغان ھەر قانداق نەرسە",
    "Status" : "ھالەت",
    "Confirmed" : "جەزملەشتۈرۈلدى",
    "Canceled" : "ئەمەلدىن قالدۇرۇلدى",
    "Confirmation about the overall status of the event." : "پائالىيەتنىڭ ئومۇمىي ئەھۋالى توغرىسىدىكى جەزملەشتۈرۈش.",
    "Show as" : "كۆرسەت",
    "Take this event into account when calculating free-busy information." : "ھەقسىز ئالدىراش ئۇچۇرلارنى ھېسابلىغاندا بۇ پائالىيەتنى ئويلاڭ.",
    "Categories" : "سەھىپىلەر",
    "Categories help you to structure and organize your events." : "سەھىپىلەر سىزنىڭ پائالىيەتلىرىڭىزنى تەشكىللىشىڭىز ۋە تەشكىللىشىڭىزگە ياردەم بېرىدۇ.",
    "Search or add categories" : "تۈرلەرنى ئىزدەڭ ياكى قوشۇڭ",
    "Add this as a new category" : "بۇنى يېڭى سەھىپە قىلىپ قوشۇڭ",
    "Custom color" : "ئىختىيارى رەڭ",
    "Special color of this event. Overrides the calendar-color." : "بۇ پائالىيەتنىڭ ئالاھىدە رەڭگى. كالېندار-رەڭنى قاپلايدۇ.",
    "Error while sharing file" : "ھۆججەتنى ھەمبەھىرلەشتە خاتالىق",
    "Error while sharing file with user" : "ئىشلەتكۈچى بىلەن ھۆججەتنى ھەمبەھىرلەشتە خاتالىق",
    "Error creating a folder {folder}" : "قىسقۇچ {folder} نى قۇرۇش خاتالىقى",
    "Attachment {fileName} already exists!" : "قوشۇمچە ھۆججەت {fileName} مەۋجۇت!",
    "Attachment {fileName} added!" : "يوللانما {fileName} قوشۇلدى!",
    "An error occurred during uploading file {fileName}" : "ھۆججەت {fileName} نى چىقىرۋاتقاندا بىر خاتالىق كۆرۈلدى",
    "An error occurred during getting file information" : "ھۆججەت ئۇچۇرىغا ئېرىشىش جەريانىدا خاتالىق كۆرۈلدى",
    "Talk conversation for proposal" : "تەكلىپنىڭ پاراڭ سۆھپىتى",
    "An error occurred, unable to delete the calendar." : "كالېندارنى ئۆچۈرەلمەي خاتالىق كۆرۈلدى.",
    "Imported {filename}" : "{filename} ئىمپورت قىلىندى",
    "This is an event reminder." : "بۇ بىر ۋەقە ئەسكەرتىش.",
    "Error while parsing a PROPFIND error" : "PROPFIND خاتالىقىنى تەھلىل قىلغاندا خاتالىق",
    "Appointment not found" : "تەيىنلەنمىدى",
    "User not found" : "ئىشلەتكۈچى تېپىلمىدى",
    "Hidden" : "يۇشۇرۇن",
    "can edit" : "تەھرىرلىيەلەيدۇ",
    "Calendar name …" : "كالېندار ئىسمى…",
    "Default attachments location" : "كۆڭۈلدىكى قوشۇمچە ئورنى",
    "Automatic ({detected})" : "ئاپتوماتىك ({detected})",
    "Shortcut overview" : "تېزلەتمە ئومۇمىي كۆرۈنۈش",
    "CalDAV link copied to clipboard." : "CalDAV ئۇلىنىشى چاپلاش تاختىسىغا كۆچۈرۈلدى.",
    "CalDAV link could not be copied to clipboard." : "CalDAV ئۇلانمىسىنى چاپلاش تاختىسىغا كۆچۈرگىلى بولمايدۇ.",
    "Enable birthday calendar" : "تۇغۇلغان كۈن كالىندارىنى قوزغىتىڭ",
    "Show tasks in calendar" : "كالېنداردىكى ۋەزىپىلەرنى كۆرسەت",
    "Enable simplified editor" : "ئاددىيلاشتۇرۇلغان تەھرىرلىگۈچنى قوزغىتىڭ",
    "Limit the number of events displayed in the monthly view" : "ئايلىق كۆرۈنۈشتە كۆرسىتىلگەن پائالىيەت سانىنى چەكلەڭ",
    "Show weekends" : "ھەپتە ئاخىرىنى كۆرسەت",
    "Show week numbers" : "ھەپتە نومۇرىنى كۆرسەت",
    "Time increments" : "ۋاقىت كۆپەيدى",
    "Default calendar for incoming invitations" : "كەلگەن تەكلىپلەرنىڭ سۈكۈتتىكى كالېندارى",
    "Copy primary CalDAV address" : "دەسلەپكى CalDAV ئادرېسىنى كۆچۈرۈڭ",
    "Copy iOS/macOS CalDAV address" : "IOS / macOS CalDAV ئادرېسىنى كۆچۈرۈڭ",
    "Personal availability settings" : "شەخسىي ئىشلىتىش تەڭشىكى",
    "Show keyboard shortcuts" : "كۇنۇپكا تاختىسىنىڭ تېزلەتمىسىنى كۆرسەت",
    "Create a new public conversation" : "يېڭى بىر ئاممىۋى سۆھبەت قۇر",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} تەكلىپ قىلىنغان ، {confirmedCount} جەزملەشتۈرۈلگەن",
    "Successfully appended link to talk room to location." : "مۇۋەپپەقىيەتلىك ھالدا پاراڭلىشىش ئۆيىگە ئۇلىنىش قوشۇلدى.",
    "Successfully appended link to talk room to description." : "مۇۋەپپەقىيەتلىك ھالدا سۆزلىشىش ئۆيىگە ئۇلىنىش قوشۇلدى.",
    "Error creating Talk room" : "سۆھبەت ئۆيى قۇرۇشتا خاتالىق",
    "_%n more guest_::_%n more guests_" : ["يەنە %n مىھمانلار","يەنە %n مىھمانلار"],
    "The visibility of this event in shared calendars." : "ئورتاق كالېنداردا بۇ پائالىيەتنىڭ كۆرۈنۈشچانلىقى."
},
"nplurals=2; plural=(n != 1);");
