OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Die eingegebene Adresse ist zu lang.",
    "User-Session unexpectedly expired" : "Sitzung unerwartet abgelaufen",
    "Provided email-address is not valid" : "Angegebene E-Mail-Adresse ist ungültig",
    "%s has published the calendar »%s«" : "%s hat den Kalender »%s« veröffentlicht",
    "Unexpected error sending email. Please contact your administrator." : "Unerwarteter Fehler beim Senden der E-Mail. Bitte kontaktiere die Administration.",
    "Successfully sent email to %1$s" : "E-Mail an %1$s gesendet",
    "Hello," : "Hallo,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Information: %s hat den Kalender »%s« veröffentlicht.",
    "Open »%s«" : "»%s« öffnen",
    "Cheers!" : "Noch einen schönen Tag!",
    "Upcoming events" : "Anstehende Termine",
    "No more events today" : "Heute keine weiteren Termine",
    "No upcoming events" : "Keine anstehenden Termine",
    "More events" : "Weitere Termine",
    "%1$s with %2$s" : "%1$s mit %2$s",
    "Calendar" : "Kalender",
    "New booking {booking}" : "Neue Buchung {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) hat den Termin \"{config_display_name}\" am {date_time} gebucht.",
    "Appointments" : "Termine",
    "Schedule appointment \"%s\"" : "Termin planen \"%s\"",
    "Schedule an appointment" : "Vereinbare einen Termin",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : "Bereite dich auf %s vor",
    "Follow up for %s" : "Nachbereitung: %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Für deine Terminvereinbarung \"%s\" mit %s steht die Bestätigung noch aus.",
    "Dear %s, please confirm your booking" : "Hallo %s, bitte bestätige die Terminbuchung",
    "Confirm" : "Bestätigen",
    "Appointment with:" : "Termin mit:",
    "Description:" : "Beschreibung:",
    "This confirmation link expires in %s hours." : "Dieser Bestätigungslink läuft in %s Stunden ab.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Wenn du den Termin doch stornieren möchtest, wende dich bitte an deinen Organisator, indem du auf diese E-Mail antwortest oder dessen Profilseite besuchst.",
    "Your appointment \"%s\" with %s has been accepted" : "Deine Terminvereinbarung \"%s\" mit %s wurde angenommen.",
    "Dear %s, your booking has been accepted." : "Hallo %s, dein Buchung wurde akzeptiert.",
    "Appointment for:" : "Termin für:",
    "Date:" : "Datum:",
    "You will receive a link with the confirmation email" : "Du erhältst eine E-Mail mit einem Bestätigungslink",
    "Where:" : "Ort:",
    "Comment:" : "Kommentar:",
    "You have a new appointment booking \"%s\" from %s" : "Du hast eine neue Terminbuchung \"%s\" von %s.",
    "Dear %s, %s (%s) booked an appointment with you." : "Hallo %s, %s (%s) hat einen Termin mit dir gebucht.",
    "%s has proposed a meeting" : "%s hat eine Besprechung vorgeschlagen",
    "%s has updated a proposed meeting" : "%s hat eine vorgeschlagene Besprechung aktualisiert",
    "%s has canceled a proposed meeting" : "%s hat eine vorgeschlagene Besprechung abgesagt",
    "Dear %s, a new meeting has been proposed" : "Hallo %s, es wurde eine neue Besprechung vorgeschlagen",
    "Dear %s, a proposed meeting has been updated" : "Hallo %s, eine vorgeschlagene Besprechung wurde aktualisiert",
    "Dear %s, a proposed meeting has been cancelled" : "Hallo %s, eine vorgeschlagene Besprechung wurde abgesagt",
    "Location:" : "Ort:",
    "Duration:" : "Dauer:",
    "%1$s from %2$s to %3$s" : "%1$s von %2$s bis %3$s",
    "Dates:" : "Daten:",
    "Respond" : "Antworten",
    "A Calendar app for Nextcloud" : "Eine Kalender-App für Nextcloud",
    "A Calendar app for Nextcloud. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Like Contacts, Talk, Tasks, Deck and Circles\n* 🌐 **WebCal Support!** Want to see your favorite team's matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 **Search!** Find your events at ease\n* ☑️ **Tasks!** See tasks or Deck cards with a due date directly in the calendar\n* 🔈 **Talk rooms!** Create an associated Talk room when booking a meeting with just one click\n* 📆 **Appointment booking** Send people a link so they can book an appointment with you [using this app](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Attachments!** Add, upload and view event attachments\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Eine Kalender-App für Nextcloud. Termine von verschiedenen Geräten ganz einfach mit Ihrer Nextcloud synchronisieren und online bearbeiten.\n\n* 🚀 **Integration mit anderen Nextcloud-Apps!** Wie Kontakte, Talk, Aufgaben, Deck und Kreise\n* 🌐 **WebCal-Unterstützung!** Sollen die Spieltage deiner Lieblingsmannschaft in deinem Kalender stehen? Kein Problem!\n* 🙋 **Teilnehmer!** Lade Personen zu deinen Veranstaltungen ein.\n* ⌚ **Frei/Beschäftigt!** Sieh nach, wann deine Teilnehmer verfügbar sind.\n* ⏰ **Erinnerungen!** Erhalte Benachrichtigungen für Veranstaltungen direkt im Browser und per E-Mail.\n* 🔍 **Suche!** Finde deine Veranstaltungen ganz einfach.\n* ☑️ **Aufgaben!** Sieh Aufgaben oder Karten mit Fälligkeitsdatum direkt im Kalender.\n* 🔈 **Chatrooms!** Erstelle beim Buchen eines Meetings mit nur einem Klick einen zugehörigen Chatroom.\n* 📆 **Terminbuchung** Sende Personen einen Link, damit sie [mit dieser App](https://apps.nextcloud.com/apps/appointments) einen Termin mit dir buchen können.\n* 📎 **Anhänge!** Füge Veranstaltungsanhänge hinzu, lade sie hoch und sieh sie ein.\n* 🙈 **Wir erfinden das Rad nicht neu!** Basierend auf den großartigen [c-dav Bibliothek](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) und [fullcalendar](https://github.com/fullcalendar/fullcalendar) Bibliotheken.",
    "Previous day" : "Vorheriger Tag",
    "Previous week" : "Vorherige Woche",
    "Previous year" : "Vorheriges Jahr",
    "Previous month" : "Vorheriger Monat",
    "Next day" : "Nächster Tag",
    "Next week" : "Nächste Woche",
    "Next year" : "Nächstes Jahr",
    "Next month" : "Nächster Monat",
    "Create new event" : "Neuen Termin erstellen",
    "Event" : "Ereignis",
    "Today" : "Heute",
    "Day" : "Tag",
    "Week" : "Woche",
    "Month" : "Monat",
    "Year" : "Jahr",
    "List" : "Liste",
    "Appointment link was copied to clipboard" : "Link für den Termin wurde in die Zwischenablage kopiert",
    "Appointment link could not be copied to clipboard" : "Link für den Termin konnte nicht in die Zwischenablage kopiert werden",
    "Preview" : "Vorschau",
    "Copy link" : "Link kopieren",
    "Edit" : "Bearbeiten",
    "Delete" : "Löschen",
    "Appointment schedules" : "Terminpläne",
    "Create new" : "Neu erstellen",
    "Disable calendar \"{calendar}\"" : "Kalender \"{calendar}\" deaktivieren",
    "Disable untitled calendar" : "Unbenannte Kalender deaktivieren",
    "Enable calendar \"{calendar}\"" : "Kalender \"{calendar}\" aktivieren",
    "Enable untitled calendar" : "Unbenannte Kalender aktivieren",
    "An error occurred, unable to change visibility of the calendar." : "Es ist ein Fehler aufgetreten, die Sichtbarkeit des Kalenders konnte nicht geändert werden.",
    "Untitled calendar" : "Unbenannter Kalender",
    "Shared with you by" : "Geteilt mit dir von",
    "Edit and share calendar" : "Kalender bearbeiten und teilen",
    "Edit calendar" : "Kalender bearbeiten",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Kalenderfreigabe wird in {countdown} Sekunde beendet","Kalenderfreigabe wird in {countdown} Sekunden beendet"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Kalender wird in {countdown} Sekunde gelöscht","Kalender werden in {countdown} Sekunden gelöscht"],
    "An error occurred, unable to create the calendar." : "Es ist ein Fehler aufgetreten, der Kalender konnte nicht erstellt werden.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Bitte einen gültigen Link eingeben (beginnend mit http://, https://, webcal://, oder webcals://)",
    "Calendars" : "Kalender",
    "Add new" : "Neu hinzufügen",
    "New calendar" : "Neuer Kalender",
    "Name for new calendar" : "Name für neuen Kalender",
    "Creating calendar …" : "Erstelle Kalender …",
    "New calendar with task list" : "Neuer Kalender mit Aufgabenliste",
    "New subscription from link (read-only)" : "Neues Abonnement aus Link (schreibgeschützt)",
    "Creating subscription …" : "Erstelle Abonnement …",
    "Add public holiday calendar" : "Feiertagskalender hinzufügen",
    "Add custom public calendar" : "Benutzerdefinierten öffentlichen Kalender hinzufügen",
    "Calendar link copied to clipboard." : "Kalender-Link in die Zwischenablage kopiert.",
    "Calendar link could not be copied to clipboard." : "Kalender-Link konnte nicht in die Zwischenablage kopiert werden.",
    "Copy subscription link" : "Abonnement-Link kopieren",
    "Copying link …" : "Link wird kopiert …",
    "Copied link" : "Link kopiert",
    "Could not copy link" : "Link konnte nicht kopiert werden",
    "Export" : "Exportieren",
    "Untitled item" : "Eintrag ohne Namen",
    "Unknown calendar" : "Unbekannter Kalender",
    "Could not load deleted calendars and objects" : "Gelöschte Kalender und Objekte konnten nicht geladen werden",
    "Could not delete calendar or event" : "Kalender oder Termin konnte nicht gelöscht werden",
    "Could not restore calendar or event" : "Kalender oder Termin konnte nicht wiederhergestellt werden",
    "Do you really want to empty the trash bin?" : "Möchtest du wirklich den Papierkorb leeren?",
    "Empty trash bin" : "Papierkorb leeren",
    "Trash bin" : "Papierkorb",
    "Loading deleted items." : "Lade gelöschte Elemente",
    "You do not have any deleted items." : "Du hast keine gelöschten Elemente",
    "Name" : "Name",
    "Deleted" : "Gelöscht",
    "Restore" : "Wiederherstellen",
    "Delete permanently" : "Endgültig löschen",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Element im Papierkorb wird nach {numDays} Tagen gelöscht","Elemente im Papierkorb werden nach {numDays} Tagen gelöscht"],
    "Could not update calendar order." : "Kalenderreihenfolge konnte nicht aktualisiert werden.",
    "Shared calendars" : "Geteilte Kalender",
    "Deck" : "Deck",
    "Internal link" : "Interner Link",
    "A private link that can be used with external clients" : "Ein privater Link, der mit externen Clients verwendet werden kann.",
    "Copy internal link" : "Internen Link kopieren",
    "An error occurred, unable to publish calendar." : "Es ist ein Fehler aufgetreten, Kalender konnte nicht veröffentlicht werden.",
    "An error occurred, unable to send email." : "Es ist ein Fehler aufgetreten, E-Mail konnte nicht versandt werden.",
    "Embed code copied to clipboard." : "Einbettungscode in die Zwischenablage kopiert.",
    "Embed code could not be copied to clipboard." : "Einbettungscode konnte nicht in die Zwischenablage kopiert werden.",
    "Unpublishing calendar failed" : "Aufhebung der Veröffentlichung des Kalenders fehlgeschlagen",
    "Share link" : "Link teilen",
    "Copy public link" : "Öffentlichen Link kopieren",
    "Send link to calendar via email" : "Link zum Kalender als E-Mail verschicken",
    "Enter one address" : "Eine Adresse eingeben",
    "Sending email …" : "Sende E-Mail …",
    "Copy embedding code" : "Einbettungscode kopieren",
    "Copying code …" : "Kopiere Code …",
    "Copied code" : "Code kopiert",
    "Could not copy code" : "Code konnte nicht kopiert werden",
    "Delete share link" : "Freigabe-Link löschen",
    "Deleting share link …" : "Freigabe-Link löschen …",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Team)",
    "An error occurred while unsharing the calendar." : "Es ist ein Fehler beim Aufheben der Freigabe des Kalenders aufgetreten.",
    "An error occurred, unable to change the permission of the share." : "Es ist ein Fehler aufgetreten, die Berechtigung für die Freigabe konnte nicht geändert werden.",
    "can edit and see confidential events" : "kann vertrauliche Termine einsehen und bearbeiten",
    "Unshare with {displayName}" : "Mit {displayName} nicht mehr teilen",
    "Share with users or groups" : "Mit Benutzern oder Gruppen teilen",
    "No users or groups" : "Keine Benutzer oder Gruppen",
    "Failed to save calendar name and color" : "Kalendername oder -farbe konnte nicht gespeichert werden.",
    "Calendar name …" : "Kalendername …",
    "Never show me as busy (set this calendar to transparent)" : "Mich nie als beschäftigt anzeigen (diesen Kalender auf transparent setzen)",
    "Share calendar" : "Kalender teilen",
    "Unshare from me" : "Nicht mehr mit mir teilen",
    "Save" : "Speichern",
    "No title" : "Kein Titel",
    "Are you sure you want to delete \"{title}\"?" : "Soll \"{title}\" wirklich gelöscht werden?",
    "Deleting proposal \"{title}\"" : "Lösche Vorschlag \"{title}\"",
    "Successfully deleted proposal" : "Vorschlag wurde gelöscht",
    "Failed to delete proposal" : "Vorschlag konnte nicht gelöscht werden",
    "Failed to retrieve proposals" : "Vorschläge konnten nicht abgerufen werden",
    "Meeting proposals" : "Besprechungsvorschläge",
    "A configured email address is required to use meeting proposals" : "Um Besprechungsvorschläge zu verwenden ist eine eingerichtete E-Mail-Adresse erforderlich",
    "No active meeting proposals" : "Keine aktiven Besprechungsvorschläge",
    "View" : "Ansehen",
    "Import calendars" : "Kalender importieren",
    "Please select a calendar to import into …" : "Bitte wähle einen Kalender aus, in den importiert werden soll …",
    "Filename" : "Dateiname",
    "Calendar to import into" : "Kalender in den importiert werden soll.",
    "Cancel" : "Abbrechen",
    "_Import calendar_::_Import calendars_" : ["Kalender importieren","Kalender importieren"],
    "Select the default location for attachments" : "Standard-Speicherort für Anhänge auswählen",
    "Pick" : "Auswählen",
    "Invalid location selected" : "Ungültiger Speicherort ausgewählt",
    "Attachments folder successfully saved." : "Speicherort für Anhänge gespeichert",
    "Error on saving attachments folder." : "Fehler beim Speichern des Speicherorts für Anhänge",
    "Attachments folder" : "Ordner für Anhänge",
    "{filename} could not be parsed" : "{filename} konnte nicht analysiert werden",
    "No valid files found, aborting import" : "Keine gültige Dateien gefunden, Import wird abgebrochen.",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["%n Termin importiert","%n Termine importiert"],
    "Import partially failed. Imported {accepted} out of {total}." : "Der Import ist teilweise fehlgeschlagen. {accepted} von {total} importiert.",
    "Automatic" : "Automatisch",
    "Automatic ({timezone})" : "Automatisch ({timezone})",
    "New setting was not saved successfully." : "Neue Einstellung konnte nicht gespeichert werden.",
    "Timezone" : "Zeitzone",
    "Navigation" : "Navigation",
    "Previous period" : "Vorherige Zeitspanne",
    "Next period" : "Nächste Zeitspanne",
    "Views" : "Ansichten",
    "Day view" : "Tagesansicht",
    "Week view" : "Wochenansicht",
    "Month view" : "Monatsansicht",
    "Year view" : "Jahresansicht",
    "List view" : "Listenansicht",
    "Actions" : "Aktionen",
    "Create event" : "Termin erstellen",
    "Show shortcuts" : "Tastaturkürzel anzeigen",
    "Editor" : "Editor",
    "Close editor" : "Bearbeitung schließen",
    "Save edited event" : "Bearbeitetes Ereignis speichern",
    "Delete edited event" : "Bearbeitetes Ereignis löschen",
    "Duplicate event" : "Termin duplizieren",
    "or" : "oder",
    "Calendar settings" : "Kalender-Einstellungen",
    "At event start" : "Zu Beginn des Termins",
    "No reminder" : "Keine Erinnerung",
    "Failed to save default calendar" : "Standardkalender konnte nicht gespeichert werden",
    "General" : "Allgemein",
    "Availability settings" : "Verfügbare Einstellungen",
    "CalDAV" : "CalDAV",
    "Access Nextcloud calendars from other apps and devices" : "Von anderen Apps und Geräten aus auf Nextcloud-Kalender zugreifen",
    "CalDAV URL" : "CalDAV-URL",
    "Server Address for iOS and macOS" : "Serveradresse für iOS und macOS",
    "Appearance" : "Aussehen",
    "Birthday calendar" : "Geburtstagskalender",
    "Tasks in calendar" : "Aufgaben im Kalender",
    "Weekends" : "Wochenenden",
    "Week numbers" : "Wochennummern",
    "Limit number of events shown in Month view" : "Die Anzahl der in der Monatsansicht angezeigten Termine begrenzen",
    "Density in Day and Week View" : "Dichte in der Tages- und Wochenansicht",
    "Editing" : "Bearbeitung",
    "Default reminder" : "Standarderinnerung",
    "Simple event editor" : "Einfacher Termineditor",
    "\"More details\" opens the detailed editor" : "\"Weitere Details\" öffnet den Detaileditor",
    "Files" : "Dateien",
    "Appointment schedule successfully created" : "Terminplan wurde erstellt",
    "Appointment schedule successfully updated" : "Terminplan wurde aktualisiert",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} Minute","{duration} Minuten"],
    "0 minutes" : "0 Minuten",
    "_{duration} hour_::_{duration} hours_" : ["{duration} Stunde","{duration} Stunden"],
    "_{duration} day_::_{duration} days_" : ["{duration} Tag","{duration} Tage"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} Woche","{duration} Wochen"],
    "_{duration} month_::_{duration} months_" : ["{duration} Monat","{duration} Monate"],
    "_{duration} year_::_{duration} years_" : ["{duration} Jahr","{duration} Jahre"],
    "To configure appointments, add your email address in personal settings." : "Um Termine zu vereinbaren, füge deine E-Mail-Adresse in den persönlichen Einstellungen hinzu.",
    "Public – shown on the profile page" : "Öffentlich – wird auf der Profilseite angezeigt",
    "Private – only accessible via secret link" : "Privat – nur über geheimen Link sichtbar",
    "Appointment schedule saved" : "Terminplan wurde gespeichert",
    "Create appointment schedule" : "Terminplan erstellen",
    "Edit appointment schedule" : "Terminplan bearbieten",
    "Update" : "Aktualisieren",
    "Appointment name" : "Terminname",
    "Location" : "Ort",
    "Create a Talk room" : "Einen Gesprächsraum erstellen",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Für jeden gebuchten Termin wird ein eindeutiger Link generiert und mit der Bestätigungs-E-Mail versendet.",
    "Description" : "Beschreibung",
    "Visibility" : "Sichtbarkeit",
    "Duration" : "Dauer",
    "Increments" : "Schritte",
    "Additional calendars to check for conflicts" : "Zusätzliche Kalender zur Überprüfung auf Konflikte",
    "Pick time ranges where appointments are allowed" : "Wähle Zeitbereiche, in denen Termine erlaubt sind",
    "to" : "bis",
    "Delete slot" : "Zeitfenster löschen",
    "No times set" : "Keine Zeiten gesetzt",
    "Add" : "Hinzufügen",
    "Monday" : "Montag",
    "Tuesday" : "Dienstag",
    "Wednesday" : "Mittwoch",
    "Thursday" : "Donnerstag",
    "Friday" : "Freitag",
    "Saturday" : "Samstag",
    "Sunday" : "Sonntag",
    "Weekdays" : "Wochentage",
    "Add time before and after the event" : "Zeit vor und nach dem Termin hinzufügen",
    "Before the event" : "Vor dem Termin",
    "After the event" : "Nach dem Termin",
    "Planning restrictions" : "Planungsbeschränkungen",
    "Minimum time before next available slot" : "Mindestzeit bis zum nächsten verfügbaren Zeitfenster",
    "Max slots per day" : "Maximale Zeitfenster pro Tag",
    "Limit how far in the future appointments can be booked" : "Begrenzung, wie weit in der Zukunft Termine gebucht werden können",
    "It seems a rate limit has been reached. Please try again later." : "Es scheint, dass ein Limit erreicht wurde. Bitte versuche es später noch einmal.",
    "Please confirm your reservation" : "Bitte bestätige deine Reservierung",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Wir haben dir eine E-Mail mit Details gesendet. Bitte bestätige deinen Termin über den Link in der E-Mail. Du kannst diese Seite jetzt schließen.",
    "Your name" : "Dein Name",
    "Your email address" : "Deine E-Mail-Adresse",
    "Please share anything that will help prepare for our meeting" : "Bitte sende uns alles, was zur Vorbereitung unseres Treffens beiträgt.",
    "Could not book the appointment. Please try again later or contact the organizer." : "Termin konnte nicht gebucht werden. Bitte versuche es später erneut oder wende dich an den Organisator.",
    "Back" : "Zurück",
    "Book appointment" : "Termin buchen",
    "Error fetching Talk conversations." : "Fehler beim Abruf der Talk-Unterhaltungen.",
    "Conversation does not have a valid URL." : "Die Unterhaltung hat keine gültige URL.",
    "Successfully added Talk conversation link to location." : "Talk-Unterhaltungslink wurde zum Standort hinzugefügt.",
    "Successfully added Talk conversation link to description." : "Talk-Unterhaltungslink wurde zur Beschreibung hinzugefügt.",
    "Failed to apply Talk room." : "Talk-Raum konnte nicht angewendet werden.",
    "Talk conversation for event" : "Talk-Unterhaltung für ein Ereignis",
    "Error creating Talk conversation" : "Fehler beim Erstellen der Talk-Unterhaltung",
    "Select a Talk Room" : "Einen Talk-Raum wählen",
    "Add Talk conversation" : "Talk-Unterhaltung hinzufügen",
    "Fetching Talk rooms…" : "Talk-Räume abrufen…",
    "No Talk room available" : "Kein Talk-Raum verfügbar",
    "Create public conversation" : "Öffentliche Unterhaltung erstellen",
    "Select conversation" : "Unterhaltung auswählen",
    "on" : "am",
    "at" : "um",
    "before at" : "vorher um",
    "Notification" : "Benachrichtigung",
    "Email" : "E-Mail-Adresse",
    "Audio notification" : "Audio-Benachrichtigung",
    "Other notification" : "Andere Benachrichtigung",
    "Relative to event" : "Relativ zum Termin",
    "On date" : "Zum Datum",
    "Edit time" : "Zeit ändern",
    "Save time" : "Zeit speichern",
    "Remove reminder" : "Erinnerung entfernen",
    "Add reminder" : "Erinnerung hinzufügen",
    "seconds" : "Sekunden",
    "minutes" : "Minuten",
    "hours" : "Stunden",
    "days" : "Tagen",
    "weeks" : "Wochen",
    "Choose a file to add as attachment" : "Datei auswählen, die als Anhang angefügt werden soll",
    "Choose a file to share as a link" : "Datei auswählen welche als Link geteilt wird",
    "Attachment {name} already exist!" : "Anhang {name} existiert bereits",
    "Could not upload attachment(s)" : "Anhänge konnten nicht hochgeladen werden.",
    "You are about to navigate to {link}. Are you sure to proceed?" : "Du bist dabei, zu {link} zu navigieren. Wirklich fortfahren?",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Du bist dabei, zu {host} zu navigieren. Wirklich fortfahren? Link: {link}",
    "Proceed" : "Fortsetzen",
    "No attachments" : "Keine Anhänge",
    "Add from Files" : "Anhang hinzufügen",
    "Upload from device" : "Von Gerät hochladen",
    "Delete file" : "Datei löschen",
    "Confirmation" : "Bestätigung",
    "_{count} attachment_::_{count} attachments_" : ["{count} Anhang","{count} Anhänge"],
    "Suggested" : "Vorgeschlagen",
    "Available" : "Verfügbar",
    "Invitation accepted" : "Einladung angenommen",
    "Accepted {organizerName}'s invitation" : "Einladung von {organizerName} angenommen",
    "Participation marked as tentative" : "Teilnahme als vorläufig markiert",
    "Invitation is delegated" : "Einladung ist delegiert",
    "Not available" : "Nicht verfügbar",
    "Invitation declined" : "Einladung abgelehnt",
    "Declined {organizerName}'s invitation" : "Einladung von {organizerName} abgelehnt",
    "Availability will be checked" : "Verfügbarkeit wird geprüft",
    "Invitation will be sent" : "Einladung wird verschickt",
    "Failed to check availability" : "Verfügbarkeit konnte nicht geprüft werden",
    "Failed to deliver invitation" : "Einladung konnte nicht zugestellt werden",
    "Awaiting response" : "Warte auf Antwort",
    "Checking availability" : "Verfügbarkeit prüfen",
    "Has not responded to {organizerName}'s invitation yet" : "Hat noch nicht auf die Einladung von {organizerName} geantwortet",
    "Suggested times" : "Vorgeschlagene Zeiten",
    "chairperson" : "Vorsitz",
    "required participant" : "Benötigter Teilnehmer",
    "non-participant" : "Nicht-Teilnehmer",
    "optional participant" : "Optionaler Teilnehmer",
    "{organizer} (organizer)" : "{organizer} (Organisator)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Selected slot" : "Gewähltes Zeitfenster",
    "Availability of attendees, resources and rooms" : "Verfügbarkeit von Teilnehmern, Resourcen und Räumen",
    "Suggestion accepted" : "Vorschlag angenommen",
    "Previous date" : "Vorheriger Termin",
    "Next date" : "Nächster Termin",
    "Legend" : "Legende",
    "Out of office" : "Nicht im Büro",
    "Attendees:" : "Teilnehmer:",
    "local time" : "Lokale Zeit",
    "Done" : "Erledigt",
    "Search room" : "Raum suchen",
    "Room name" : "Raumname",
    "Check room availability" : "Verfügbarkeit des Raums prüfen",
    "Free" : "Frei",
    "Busy (tentative)" : "Beschäftigt (vorläufig)",
    "Busy" : "Beschäftigt",
    "Unknown" : "Unbekannt",
    "Find a time" : "Zeit auswählen",
    "The invitation has been accepted successfully." : "Die Einladung wurde angenommen.",
    "Failed to accept the invitation." : "Die Einladung konnte nicht angenommen werden.",
    "The invitation has been declined successfully." : "Die Einladung wurde abgelehnt.",
    "Failed to decline the invitation." : "Die Einladung konnte nicht abgelehnt werden.",
    "Your participation has been marked as tentative." : "Deine Teilnahme wurde als vorläufig markiert.",
    "Failed to set the participation status to tentative." : "Deine Teilnahme konnte nicht als vorläufig markiert werden.",
    "Accept" : "Annehmen",
    "Decline" : "Ablehnen",
    "Tentative" : "Vorläufig",
    "No attendees yet" : "Keine Teilnehmer bislang",
    "{confirmedCount} confirmed, {waitingCount} awaiting response" : "{confirmedCount} bestätigt, {waitingCount} warten auf Antwort",
    "Please add at least one attendee to use the \"Find a time\" feature." : "Zum Verwenden der Funktion \"Zeit finden\", bitte mindestens einen Teilnehmer hinzufügen.",
    "Attendees" : "Teilnehmer",
    "_%n more attendee_::_%n more attendees_" : ["%n weiterer Teilnehmer","%n weitere Teilnehmer"],
    "Remove group" : "Gruppe entfernen",
    "Remove attendee" : "Teilnehmer entfernen",
    "Request reply" : "Antwort anfordern",
    "Chairperson" : "Vorsitz",
    "Required participant" : "Benötigter Teilnehmer",
    "Optional participant" : "Optionaler Teilnehmer",
    "Non-participant" : "Nicht-Teilnehmer",
    "_%n member_::_%n members_" : ["%n Mitglied","%n Mitglieder"],
    "Search for emails, users, contacts, contact groups or teams" : "Suche nach E-Mails, Benutzern, Kontakten, Kontaktgruppen oder Teams",
    "No match found" : "Keine Übereinstimmung gefunden",
    "Note that members of circles get invited but are not synced yet." : "Beachte, dass Mitglieder von Kreisen eingeladen werden, aber noch nicht synchronisiert sind.",
    "Note that members of contact groups get invited but are not synced yet." : "Beachte, dass Mitglieder von Kontaktgruppen eingeladen werden, aber noch nicht synchronisiert sind.",
    "(organizer)" : "(Organisator)",
    "Make {label} the organizer" : "{label} zum Organisator ernennen",
    "Make {label} the organizer and attend" : "{label} zum Organisator ernennen und teilnehmen",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Um das Senden von Einladungen und deren Antworten zu ermöglichen, [linkopen] füge deine E-Mail-Adresse in den persönlichen Einstellungen hinzu.[linkclose].",
    "Remove color" : "Farbe entfernen",
    "Event title" : "Titel des Termins",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Die Einstellung ganztägig kann für sich wiederholende Termine nicht geändert werden.",
    "From" : "Von",
    "To" : "Bis",
    "Your Time" : "Deine Zeit",
    "Repeat" : "Wiederholen",
    "Repeat event" : "Termin wiederholen",
    "_time_::_times_" : ["Mal","Mal"],
    "never" : "Niemals",
    "on date" : "am Datum",
    "after" : "Nach",
    "End repeat" : "Wiederholung beenden",
    "Select to end repeat" : "Auswählen um Wiederholung beenden",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Dieser Termin ist die Wiederholungsausnahme eines sich wiederholenden Termins. Du kannst keine Wiederholungsregel hinzufügen.",
    "first" : "ersten",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Änderungen an der Wiederholungsregel werden nur auf dieses und alle zukünftigen Wiederholungen angewendet.",
    "Repeat every" : "Wiederhole jeden",
    "By day of the month" : "Nach Tag des Monats",
    "On the" : "Am",
    "_day_::_days_" : ["Tag","Tage"],
    "_week_::_weeks_" : ["Woche","Wochen"],
    "_month_::_months_" : ["Monat","Monate"],
    "_year_::_years_" : ["Jahr","Jahre"],
    "On specific day" : "An einem bestimmten Tag",
    "weekday" : "Wochentag",
    "weekend day" : "Wochenendtag",
    "Does not repeat" : "Wiederholt sich nicht",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Die Wiederholungs-Definition dieses Termins wird nicht vollständig von Nextcloud unterstützt. Wenn du die Wiederholungs-Optionen bearbeitest, könnten bestimmte Wiederholungen verlorengehen.",
    "No rooms or resources yet" : "Noch keine Räume oder Ressourcen",
    "Resources" : "Ressourcen",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} Platz","{seatingCapacity} Plätze"],
    "Add resource" : "Ressource hinzufügen",
    "Has a projector" : "Hat einen Projektor",
    "Has a whiteboard" : "Hat ein Whiteboard",
    "Wheelchair accessible" : "Barrierefrei",
    "Remove resource" : "Ressource entfernen",
    "Search for resources or rooms" : "Nach Ressourcen oder Räumen suchen",
    "available" : "verfügbar",
    "unavailable" : "Nicht verfügbar",
    "Show all rooms" : "Alle Räume anzeigen",
    "Projector" : "Projektor",
    "Whiteboard" : "Whiteboard",
    "Room type" : "Raum-Typ",
    "Any" : "Irgendein",
    "Minimum seating capacity" : "Mindestsitzplatzkapazität",
    "More details" : "Weitere Einzelheiten",
    "Update this and all future" : "Aktualisiere dieses und alle Künftigen",
    "Update this occurrence" : "Diese Wiederholung aktualisieren",
    "Public calendar does not exist" : "Öffentlicher Kalender existiert nicht",
    "Maybe the share was deleted or has expired?" : "Vielleicht wurde die Freigabe gelöscht oder ist abgelaufen?",
    "Remove date" : "Datum entfernen",
    "Attendance required" : "Teilnahme erforderlich",
    "Attendance optional" : "Teilnahme optional",
    "Remove participant" : "Teilnehmer entfernen",
    "Yes" : "Ja",
    "No" : "Nein",
    "Maybe" : "Vielleicht",
    "None" : "Keine",
    "Select your meeting availability" : "Deine Besprechungsverfügbarkeit auswählen",
    "Create a meeting for this date and time" : "Eine Besprechung für dieses Datum und diese Uhrzeit erstellen",
    "Create" : "Erstellen",
    "No participants or dates available" : "Keine Teilnehmer oder Daten verfügbar",
    "from {formattedDate}" : "Von {formattedDate}",
    "to {formattedDate}" : "bis {formattedDate}",
    "on {formattedDate}" : "am {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "von {formattedDate} um {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "bis {formattedDate} um {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "am {formattedDate} um {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} um {formattedTime}",
    "Please enter a valid date" : "Bitte ein gültiges Datum angeben",
    "Please enter a valid date and time" : "Bitte gültiges Datum und Uhrzeit angeben",
    "Select a time zone" : "Eine Zeitzone auswählen",
    "Please select a time zone:" : "Bitte eine Zeitzone wählen:",
    "Pick a time" : "Zeit auswählen",
    "Pick a date" : "Datum auswählen",
    "Type to search time zone" : "Zum Suchen der Zeitzone tippen",
    "Global" : "Weltweit",
    "Holidays in {region}" : "Feiertage in {region}",
    "An error occurred, unable to read public calendars." : "Es ist ein Fehler aufgetreten, öffentliche Kalender können nicht gelesen werden.",
    "An error occurred, unable to subscribe to calendar." : "Es ist ein Fehler aufgetreten, Kalender konnte nicht abonniert werden.",
    "Public holiday calendars" : "Feiertagskalender",
    "Public calendars" : "Öffentliche Kalender",
    "No valid public calendars configured" : "Keine gültigen öffentlichen Kalender eingerichtet.",
    "Speak to the server administrator to resolve this issue." : "Spreche bitte die Administration an, um dieses Problem zu lösen.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Feiertagskalender werden von Thunderbird bereitgestellt. Kalenderdaten werden von {website} heruntergeladen.",
    "These public calendars are suggested by the server administrator. Calendar data will be downloaded from the respective website." : "Diese öffentlichen Kalender werden von der Serveradministration vorgeschlagen. Kalenderdaten werden von der entsprechenden Webseite heruntergeladen.",
    "By {authors}" : "Von {authors}",
    "Subscribed" : "Abonniert",
    "Subscribe" : "Abonnieren",
    "Could not fetch slots" : "Abruf der Zeitfenster fehlgeschlagen",
    "Select a date" : "Datum auswählen",
    "Select slot" : "Zeitfenster auswählen",
    "No slots available" : "Keine Zeitfenster verfügbar",
    "The slot for your appointment has been confirmed" : "Das Zeitfenster für deinen Termin wurde bestätigt",
    "Appointment Details:" : "Termindetails:",
    "Time:" : "Zeit:",
    "Booked for:" : "Gebucht für:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Danke schön. Deine Buchung vom {startDate} bis {endDate} wurde bestätigt.",
    "Book another appointment:" : "Einen weiteren Termin buchen:",
    "See all available slots" : "Alle verfügbaren Zeitfenster anzeigen",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Das Zeitfenster für deinen Termin von {startDate} bis {endDate} ist nicht mehr verfügbar.",
    "Please book a different slot:" : "Buche bitte ein anderes Zeitfenster:",
    "Book an appointment with {name}" : "Einen Termin mit {name} buchen",
    "No public appointments found for {name}" : "Keine öffentlichen Termine für {name} gefunden",
    "Personal" : "Persönlich",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Die automatische Erkennung der Zeitzone hat als Ergebnis UTC ermittelt.\nDies ist meist das Ergebnis von Sicherheitsmaßnahmen deines Webbrowsers.\nBitte stelle deine Zeitzone manuell in den Kalendereinstellungen ein.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Die konfigurierte Zeitzone ({timezoneId}) wurde nicht gefunden. Rückfall auf UTC.\nBitte die Zeitzone in den Einstellungen ändern und dieses Problem melden.",
    "Show unscheduled tasks" : "Ungeplante Aufgaben anzeigen",
    "Unscheduled tasks" : "Ungeplante Aufgaben",
    "Availability of {displayName}" : "Verfügbarkeit von {displayName}",
    "Discard event" : "Termin verwerfen",
    "Edit event" : "Ereignis bearbeiten",
    "Event does not exist" : "Der Termin existiert nicht",
    "Duplicate" : "Duplizieren",
    "Delete this occurrence" : "Diese Wiederholung löschen",
    "Delete this and all future" : "Dieses und alle Künftigen löschen",
    "All day" : "Ganztägig",
    "Modifications wont get propagated to the organizer and other attendees" : "Änderungen werden nicht an den Organisator und andere Teilnehmer weitergegeben",
    "Managing shared access" : "Geteilten Zugriff verwalten",
    "Deny access" : "Zugriff verweigern",
    "Invite" : "Einladen",
    "Discard changes?" : "Änderungen verwerfen?",
    "Are you sure you want to discard the changes made to this event?" : "Sollen die an diesen Termin vorgenommenen Änderungen verworfen werden?",
    "_User requires access to your file_::_Users require access to your file_" : ["Benutzer benötigt Zugang zu deiner Datei","Benutzer benötigen Zugang zu deiner Datei"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Anhang erfordert geteilten Zugriff","Anhänge, die einen gemeinsamen Zugriff erfordern"],
    "Untitled event" : "Unbenannter Termin",
    "Close" : "Schließen",
    "Modifications will not get propagated to the organizer and other attendees" : "Änderungen werden nicht an den Organisator und andere Teilnehmer weitergegeben",
    "Meeting proposals overview" : "Überblick der Besprechungsvorschläge",
    "Edit meeting proposal" : "Besprechungsvorschlag bearbeiten",
    "Create meeting proposal" : "Besprechungsvorschlag erstellen",
    "Update meeting proposal" : "Besprechungsvorschlag aktualisieren",
    "Saving proposal \"{title}\"" : "Vorschlag \"{title}\" speichern",
    "Successfully saved proposal" : "Vorschlag wurde gespeichert",
    "Failed to save proposal" : "Vorschlag konnte nicht gespeichert werden",
    "Create a meeting for \"{date}\"? This will create a calendar event with all participants." : "Besprechung für den \"{date}\" erstellen? Es wird ein Kalendereintrag mit allen Teilnehmern erstellt.",
    "Creating meeting for {date}" : "Erstelle Besprechung für den {date}",
    "Successfully created meeting for {date}" : "Besprechung für den {date} wurde erstellt",
    "Failed to create a meeting for {date}" : "Besprechung für den {date} konnte nicht erstellt werden",
    "Please enter a valid duration in minutes." : "Bitte eine gültige Dauer in Minuten eingeben",
    "Failed to fetch proposals" : "Vorschläge konnten nicht abgerufen werden",
    "Failed to fetch free/busy data" : "Frei/Beschäftigt-Daten konnten nicht abgerufen werden",
    "Selected" : "Ausgewählt",
    "No Description" : "Keine Beschreibung",
    "No Location" : "Kein Ort",
    "Edit this meeting proposal" : "Diesen Besprechungsvorschlag bearbeiten",
    "Delete this meeting proposal" : "Diesen Besprechungsvorschlag löschen",
    "Title" : "Titel",
    "15 min" : "15 Minuten",
    "30 min" : "30 Minuten",
    "60 min" : "60 Minuten",
    "90 min" : "90 Minuten",
    "Participants" : "Teilnehmer",
    "Selected times" : "Ausgewählte Zeiten",
    "Previous span" : "Vorherige Zeitspanne",
    "Next span" : "Nächste Zeitspanne",
    "Less days" : "Weniger Tage",
    "More days" : "Mehr Tage",
    "Loading meeting proposal" : "Lade Besprechungsvorschlag",
    "No meeting proposal found" : "Keinen Besprechungsvorschlag gefunden",
    "Please wait while we load the meeting proposal." : "Bitte warten, während die Besprechungsvorschläge geladen werden.",
    "The link you followed may be broken, or the meeting proposal may no longer exist." : "Der Link, dem du gefolgt bist, ist möglicherweise defekt oder der Besprechungsvorschlag existiert vielleicht nicht mehr.",
    "Thank you for your response!" : "Vielen Dank für deine Antwort!",
    "Your vote has been recorded. Thank you for participating!" : "Deine Stimme wurde registriert. Danke für deine Teilnahme!",
    "Unknown User" : "Unbekannter Benutzer",
    "No Title" : "Kein Titel",
    "No Duration" : "Keine Dauer",
    "Select a different time zone" : "Eine andere Zeitzone wählen",
    "Submit" : "Übermitteln",
    "Subscribe to {name}" : "{name} abonnieren",
    "Export {name}" : "Exportiere {name}",
    "Show availability" : "Verfügbarkeit anzeigen",
    "Anniversary" : "Jahrestag",
    "Appointment" : "Verabredung",
    "Business" : "Geschäftlich",
    "Education" : "Bildung",
    "Holiday" : "Feiertag",
    "Meeting" : "Treffen",
    "Miscellaneous" : "Verschiedenes",
    "Non-working hours" : "Arbeitsfreie Stunden",
    "Not in office" : "Nicht im Büro",
    "Phone call" : "Anruf",
    "Sick day" : "Krankheitstag",
    "Special occasion" : "Besondere Gelegenheit",
    "Travel" : "Reise",
    "Vacation" : "Urlaub",
    "Midnight on the day the event starts" : "Mitternacht am Tag des Starts des Termins",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n Tag vor dem Start des Termins um {formattedHourMinute}","%n Tage vor dem Start des Termins um {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n Woche vor dem Start des Termins um {formattedHourMinute}","%n Wochen vor dem Start des Termins um {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "Am Tag des Termins um {formattedHourMinute}",
    "at the event's start" : "Zu Beginn des Termins",
    "at the event's end" : "Am Ende des Termins",
    "{time} before the event starts" : "{time} vor Beginn des Termins",
    "{time} before the event ends" : "{time} vor Ende des Termins",
    "{time} after the event starts" : "{time} nach Beginn des Termins",
    "{time} after the event ends" : "{time} nach Ende des Termins",
    "on {time}" : "um {time}",
    "on {time} ({timezoneId})" : "um {time} ({timezoneId})",
    "Week {number} of {year}" : "Woche {number} aus {year}",
    "Daily" : "Täglich",
    "Weekly" : "Wöchentlich",
    "Monthly" : "Monatlich",
    "Yearly" : "Jährlich",
    "_Every %n day_::_Every %n days_" : ["Jeden %n Tag","Alle %n Tage"],
    "_Every %n week_::_Every %n weeks_" : ["Jede %n Woche","Alle %n Wochen"],
    "_Every %n month_::_Every %n months_" : ["Jeden %n Monat","Alle %n Monate"],
    "_Every %n year_::_Every %n years_" : ["Jedes %n Jahr","Alle %n Jahre"],
    "_on {weekday}_::_on {weekdays}_" : ["am {weekday}","am {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["am Tag {dayOfMonthList}","an den Tagen {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "am {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {dayOfMonthList}" : "im {monthNames} am {dayOfMonthList}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "im {monthNames} am {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "bis {untilDate}",
    "_%n time_::_%n times_" : ["%n mal","%n mal"],
    "second" : "zweiten",
    "third" : "dritten",
    "fourth" : "vierten",
    "fifth" : "fünften",
    "second to last" : "vorletzten",
    "last" : "letzten",
    "Untitled task" : "Unbenannte Aufgabe",
    "Please ask your administrator to enable the Tasks App." : "Bitte deine Administration, die Aufgaben-App (Tasks) zu aktivieren.",
    "You are not allowed to edit this event as an attendee." : "Keine Berechtigung diese Veranstaltung als Teilnehmer zu bearbeiten.",
    "W" : "W",
    "%n more" : "%n weitere",
    "No events to display" : "Keine Ereignisse zum Anzeigen",
    "All participants declined" : "Alle Teilnehmenden haben abgelehnt",
    "Please confirm your participation" : "Bitte Teilnahme bestätigen",
    "You declined this event" : "Du hast diesen Termin abgelehnt",
    "Your participation is tentative" : "Deine Teilnahme ist vorläufig",
    "_+%n more_::_+%n more_" : ["+%n weiterer","+%n weitere"],
    "No events" : "Keine Termine",
    "Create a new event or change the visible time-range" : "Neuen Termin erstellen oder den sichtbaren Zeitbereich ändern",
    "Failed to save event" : "Termin konnte nicht gespeichert werden",
    "It might have been deleted, or there was a typo in a link" : "Möglicherweise wurde dies gelöscht oder es gab einen Tippfehler in einem Link",
    "It might have been deleted, or there was a typo in the link" : "Möglicherweise wurde dies gelöscht oder es gab einen Tippfehler in einem Link",
    "Meeting room" : "Besprechungsraum",
    "Lecture hall" : "Hörsaal",
    "Seminar room" : "Seminarraum",
    "Other" : "Sonstiges",
    "When shared show" : "Wenn geteilt, zeige",
    "When shared show full event" : "Wenn geteilt, zeige den vollständigen Termin an",
    "When shared show only busy" : "Wenn geteilt, zeige nur den Status \"beschäftigt\" an",
    "When shared hide this event" : "Wenn geteilt, zeige diesen Termin nicht an",
    "The visibility of this event in read-only shared calendars." : "Sichtbarkeit dieses Termins in schreibgeschützten geteilten Kalendern.",
    "Add a location" : "Ort hinzufügen",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Beschreibung hinzufügen\n\n- Thema des Meetings\n- Tagesordnungspunkte\n- Alles, was die Teilnehmer vorbereiten müssen",
    "Status" : "Status",
    "Confirmed" : "Bestätigt",
    "Canceled" : "Abgesagt",
    "Confirmation about the overall status of the event." : "Bestätigung über den Gesamtstatus des Termins.",
    "Show as" : "Anzeigen als",
    "Take this event into account when calculating free-busy information." : "Diesen Termin bei der Berechnung der Frei- / Gebucht-Informationen berücksichtigen.",
    "Categories" : "Kategorien",
    "Categories help you to structure and organize your events." : "Mithilfe von Kategorien kannst du deine Termine strukturieren und organisieren.",
    "Search or add categories" : "Suche oder füge Kategorien hinzu",
    "Add this as a new category" : "Dies als neue Kategorie hinzufügen",
    "Custom color" : "Benutzerdefinierte Farbe",
    "Special color of this event. Overrides the calendar-color." : "Sonderfarbe für diesen Termin. Überschreibt die Kalenderfarbe.",
    "Error while sharing file" : "Fehler beim Teilen der Datei",
    "Error while sharing file with user" : "Fehler beim Teilen der Datei mit Benutzer",
    "Error creating a folder {folder}" : "Fehler beim Erstellen des Ordners {folder}",
    "Attachment {fileName} already exists!" : "Anhang {fileName} existiert bereits",
    "Attachment {fileName} added!" : "Anhang {fileName} hinzugefügt!",
    "An error occurred during uploading file {fileName}" : "Es ist ein Fehler beim Hochladen der Datei {fileName} aufgetreten",
    "An error occurred during getting file information" : "Es ist ein Fehler beim Abrufen von Dateiinformationen aufgetreten.",
    "Talk conversation for proposal" : "Talk-Unterhaltung für einen Vorschlag",
    "An error occurred, unable to delete the calendar." : "Es ist ein Fehler aufgetreten, Kalender konnte nicht gelöscht werden.",
    "Imported {filename}" : "{filename} importiert ",
    "This is an event reminder." : "Dies ist eine Terminerinnerung.",
    "Error while parsing a PROPFIND error" : "Fehler beim Parsen eines PROPFIND-Fehlers",
    "Appointment not found" : "Termin nicht gefunden",
    "User not found" : "Benutzer nicht gefunden",
    "Hidden" : "Versteckt",
    "can edit" : "kann bearbeiten",
    "Calendar name …" : "Kalender-Name …",
    "Default attachments location" : "Standard-Speicherort für Anhänge",
    "Automatic ({detected})" : "Automatisch ({detected})",
    "Shortcut overview" : "Übersicht der Tastaturkürzel",
    "CalDAV link copied to clipboard." : "CalDAV-Link in die Zwischenablage kopiert.",
    "CalDAV link could not be copied to clipboard." : "CalDAV-Link konnte nicht in die Zwischenablage kopiert werden.",
    "Enable birthday calendar" : "Geburtstagskalender aktivieren",
    "Show tasks in calendar" : "Aufgaben im Kalender anzeigen",
    "Enable simplified editor" : "Einfachen Editor aktivieren",
    "Limit the number of events displayed in the monthly view" : "Anzahl der in der Monatsansicht angezeigten Termine begrenzen",
    "Show weekends" : "Wochenenden anzeigen",
    "Show week numbers" : "Kalenderwochen anzeigen",
    "Time increments" : "Zeitschritte",
    "Default calendar for incoming invitations" : "Standardkalender für eingehende Einladungen",
    "Copy primary CalDAV address" : "Primäre CalDAV-Adresse kopieren",
    "Copy iOS/macOS CalDAV address" : "iOS/macOS CalDAV-Adresse kopieren",
    "Personal availability settings" : "Persönliche Einstellungen zur Verfügbarkeit",
    "Show keyboard shortcuts" : "Tastaturkürzel anzeigen",
    "Create a new public conversation" : "Neue öffentliche Unterhaltung erstellen",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} eingeladen, {confirmedCount} bestätigt",
    "Successfully appended link to talk room to location." : "Link des Talk-Raums zur Ortsangabe hinzugefügt.",
    "Successfully appended link to talk room to description." : "Link zur Beschreibung des Besprechungsraums hinzugefügt.",
    "Error creating Talk room" : "Fehler beim Erstellen des Besprechungsraumes",
    "_%n more guest_::_%n more guests_" : ["%n weiterer Gast","%n weitere Gäste"],
    "The visibility of this event in shared calendars." : "Sichtbarkeit dieses Termins in geteilten Kalendern."
},
"nplurals=2; plural=(n != 1);");
