OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "Sessione utente iscadida in manera no prevìdida",
    "Provided email-address is not valid" : "S'indiritzu de posta eletrònica frunidu no est bàlidu.",
    "%s has published the calendar »%s«" : "%s at publicadu su calendàriu »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Errore non prevìdidu imbiende su messàgiu de posta eletrònica. Cuntata s'amministratzione.",
    "Successfully sent email to %1$s" : "Messàgiu de posta eletrònica imbiadu in manera curreta a %1$s",
    "Hello," : "Salude,",
    "We wanted to inform you that %s has published the calendar »%s«." : "T'informamus chi %s at publicadu su calendàriu »%s«.",
    "Open »%s«" : "Aberi »%s«",
    "Cheers!" : "Salude!",
    "Upcoming events" : "Eventos abarrados",
    "No more events today" : "No b'at àteros eventos oe",
    "No upcoming events" : "Perunu eventu abarradu",
    "More events" : "Àteros eventos",
    "Calendar" : "Calendàriu",
    "Appointments" : "Apuntamentos",
    "Confirm" : "Cunfirma",
    "Description:" : "Descritzione:",
    "Date:" : "Data:",
    "Where:" : "Ue:",
    "Location:" : "Positzione:",
    "Duration:" : "Durata:",
    "A Calendar app for Nextcloud" : "Un'aplicatzione de calendàriu pro Nextcloud",
    "Previous day" : "Die in antis",
    "Previous week" : "Chida in antis",
    "Previous month" : "Mese in antis",
    "Next day" : "Die imbeniente",
    "Next week" : "Sa chida chi benit",
    "Next year" : "Annu pustis",
    "Next month" : "Su mese chi benit",
    "Create new event" : "Crea un'eventu nou",
    "Today" : "Oe",
    "Day" : "Die",
    "Week" : "Chida",
    "Month" : "Mese",
    "Year" : "Annu",
    "List" : "Lista",
    "Preview" : "Anteprima",
    "Copy link" : "Còpia ligòngiu",
    "Edit" : "Modìfica",
    "Delete" : "Cantzella",
    "Create new" : "Crea un'archìviu nou",
    "An error occurred, unable to change visibility of the calendar." : "B'at àpidu un'errore, no at fatu a cambiare sa visibilidade de su calendàriu.",
    "Untitled calendar" : "Calendàriu chene tìtulu",
    "Shared with you by" : "Cumpartzidu cun tegus dae",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Annullamentu de sa cumpartzidura de su calendàriu intre {tempus} segundu","Annullamentu de sa cumpartzidura de su calendàriu intre {countdown} segundos"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Su calendàriu s'at a cantzellare intre {tempus} segundu","Su calendàriu s'at a cantzellare intre {countdown} segundos"],
    "An error occurred, unable to create the calendar." : "B'at àpidu un'errore, no at fatu a creare su calendàriu.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Inserta unu ligòngiu vàlidu (chi cumintzet cun http://, https://, webcal://, o webcals://)",
    "Calendars" : "Calendàrios",
    "Add new" : "Agiunghe nou",
    "New calendar" : "Calendàriu nou",
    "Name for new calendar" : "Nùmene pro su calendàriu nou",
    "Creating calendar …" : "Creende calendàriu …",
    "New calendar with task list" : "Calendàriu nou cun lista de atividades",
    "New subscription from link (read-only)" : "Sutaiscritzione noa dae ligòngiu (letura sola)",
    "Creating subscription …" : "Creende sutascritzione …",
    "Calendar link copied to clipboard." : "Ligòngiu de su calendàriu copiadu in is apuntos.",
    "Calendar link could not be copied to clipboard." : "No at fatu a copiare su ligòngiu de su calendàriu in is apuntos.",
    "Copy subscription link" : "Còpia ligòngiu de sutascritzione",
    "Copying link …" : "Copiende su ligòngiu …",
    "Copied link" : "Ligòngiu copiadu",
    "Could not copy link" : "No at fatu a copiare su ligòngiu",
    "Export" : "Esporta",
    "Untitled item" : "Elementu chene tìtulu",
    "Could not load deleted calendars and objects" : "No at fatu a carrigare is calendàrios e is ogetos cantzellados",
    "Could not restore calendar or event" : "No at fatu a recuperare su calendàriu o s'eventu",
    "Empty trash bin" : "Bòida s'àliga",
    "Trash bin" : " Àliga",
    "Name" : "Nùmene",
    "Deleted" : "Cantzelladu",
    "Restore" : "Riprìstina",
    "Delete permanently" : "Cantzella in manera permanente",
    "Could not update calendar order." : "No at fatu a agiornare s'òrdne de su calendàriu.",
    "Deck" : "Deck",
    "Copy internal link" : "Còpia ligòngiu internu",
    "An error occurred, unable to publish calendar." : "B'at àpidu un'errore, no at fatu a publicare su calendàriu.",
    "An error occurred, unable to send email." : "B'at àpidu un'errore, no at fatu a imbiare su messàgiu de posta.",
    "Embed code copied to clipboard." : "Su còdighe de insertada est istadu copiadu in punta de billete.",
    "Embed code could not be copied to clipboard." : "No at fatu a copiare in punta de billete su còdighe de insertada.",
    "Unpublishing calendar failed" : "No at fatu a annullare sa publicatzione de su calendàriu",
    "Share link" : "Cumpartzi ligòngiu",
    "Copy public link" : "Còpia ligòngiu pùblicu",
    "Send link to calendar via email" : "Imbia ligòngiu pro su calendàriu tràmite posta eletrònica",
    "Enter one address" : "Inserta un'indiritzu",
    "Sending email …" : "Imbiende su messàgui de posta eletrònica …",
    "Copy embedding code" : "Còpia su còdighe de insertada",
    "Copying code …" : "Copiende su còdighe …",
    "Copied code" : "Còdighe copiadu",
    "Could not copy code" : "No at fatu a copiare su còdighe",
    "Delete share link" : "Cantzella ligòngiu de cumpartzidura",
    "Deleting share link …" : "Cantzellende su ligòngiu de cumpartzidura …",
    "An error occurred, unable to change the permission of the share." : "B'at àpidu un'errore, no at fatu a cambiare su permissu de cumpartzidura.",
    "Unshare with {displayName}" : "Annulla sa cumpartzidura cun {displayName}",
    "Share with users or groups" : "Cumpartzi cun utentes o grupos",
    "No users or groups" : "Peruna utèntzia o grupu",
    "Unshare from me" : "Annulla sa cumpartzidura cun me",
    "Save" : "Sarva",
    "View" : "Visualiza",
    "Import calendars" : "Importa calendàrios",
    "Please select a calendar to import into …" : "Seletziona unu calendàriu de importare in …",
    "Filename" : "Nùmene de s'archìviu",
    "Calendar to import into" : "Calendàriu de importare in",
    "Cancel" : "Annulla",
    "_Import calendar_::_Import calendars_" : ["Importa calendàriu","Importa calendàrios"],
    "Attachments folder" : "Cartella de alligongiados",
    "{filename} could not be parsed" : "No at fatu a analizare {filename} ",
    "No valid files found, aborting import" : "Perunu archìviu vàlidu agatadu, annullende s'importatzione",
    "Import partially failed. Imported {accepted} out of {total}." : "Parte de s'importatzione est andada male. Importados {accepted} de {total}.",
    "Automatic" : "Automàticu",
    "Automatic ({timezone})" : "Automàticu ({timezone})",
    "New setting was not saved successfully." : "Sa cunfiguratzione noa no est istada sarvada in manera curreta.",
    "Navigation" : "Navigatzione",
    "Previous period" : "Tempus in antis",
    "Next period" : "Tempus imbeniente",
    "Views" : "Visualizatziones",
    "Day view" : "Bista de sa die",
    "Week view" : "Bista de sa chida",
    "Month view" : "Bista de su mese",
    "List view" : "Bista de s'elencu",
    "Actions" : "Atziones",
    "Create event" : "Crea eventu",
    "Show shortcuts" : "Mustra curtziadòrgios",
    "or" : "o",
    "No reminder" : "Perunu promemòria",
    "Appearance" : "Aspetu",
    "Default reminder" : "Promemòria predefinidu",
    "Files" : "Archìvios",
    "Update" : "Agiorna",
    "Location" : "Positzione",
    "Description" : "Descritzione",
    "Visibility" : "Visibilidade",
    "Duration" : "Durata",
    "to" : "a",
    "Add" : "Agiunghe",
    "Monday" : "Lunis",
    "Tuesday" : "Martis",
    "Wednesday" : "Mércuris",
    "Thursday" : "Giòbia",
    "Friday" : "Chenàbura",
    "Saturday" : "Sàbudu",
    "Sunday" : "Domìnigu",
    "Your email address" : "Indiritzu tuo de posta eletrònica",
    "Back" : "In segus",
    "Select conversation" : "Seletziona resonada",
    "on" : "allutu",
    "at" : "a",
    "before at" : "antis de is",
    "Notification" : "Notìfica",
    "Email" : "Posta eletrònica",
    "Audio notification" : "Notìfica àudio",
    "Other notification" : "Àtera notìfica",
    "Relative to event" : "Relativu a s'eventu",
    "On date" : "In data",
    "Edit time" : "Modìfica ora",
    "Save time" : "Sarva ora",
    "Remove reminder" : "Boga•nche promemòria",
    "seconds" : "segundos",
    "minutes" : "minutos",
    "hours" : "oras",
    "days" : "dies",
    "weeks" : "chidas",
    "Choose a file to add as attachment" : "Sèbera un'archìviu de agiùnghere comente alligongiadu",
    "Choose a file to share as a link" : "Sèbera un'archìviu de cumpartzire comente ligòngiu",
    "Upload from device" : "Càrriga dae su dispositivu",
    "Delete file" : "Cantzella archìviu",
    "Available" : "A disponimentu",
    "Not available" : "No a disponimentu",
    "{organizer} (organizer)" : "{organizer} (chie organizat)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Availability of attendees, resources and rooms" : "Disponibilidade de partetzipantes, resursas e aposentos",
    "Out of office" : "Foras de serbìtziu",
    "Attendees:" : "Partetzipadores:",
    "Room name" : "Nùmene istantza",
    "Free" : "Lìberu",
    "Busy (tentative)" : "Ocupadu (intentu)",
    "Busy" : "Faghende cosa",
    "Unknown" : "Non connotu",
    "Accept" : "Atzeta",
    "Decline" : "Refuda",
    "Tentative" : "Intentu",
    "No attendees yet" : "Ancora peruna persone pro partetzipare",
    "Attendees" : "Partetzipantes",
    "Remove group" : "Boga·nche grupu",
    "Remove attendee" : "Boga•nche partetzipante",
    "Chairperson" : "Presidente",
    "Required participant" : "Persone netzessària",
    "Optional participant" : "Persone optzionale",
    "Non-participant" : "No partetzipante",
    "No match found" : "Peruna currispondèntzia agatada",
    "(organizer)" : "(persona organizadora)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Pro imbiare invitos e gestire respostas, [linkopen]agiunghe s'indiritzu tuo de posta eletrònica in sa cunfiguratzione personale[linkclose].",
    "Remove color" : "Boga colore",
    "Event title" : "Tìtulu de s'eventu",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "No faghet a modificare sa cunfiguratzione de totu sa die pro eventos chi sunt parte de una filera de atividades recurrentes",
    "From" : "Dae",
    "To" : "A",
    "Repeat" : "Repiti",
    "_time_::_times_" : ["borta","bortas"],
    "never" : "mai",
    "on date" : "in data",
    "after" : "a pustis",
    "End repeat" : "Acabba ripetitzione",
    "Select to end repeat" : "Seletziona pro acabbare sa ripetitzione",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Custu eventu est s'etzetzione de una filera de recurrèntzias. No ddi podes agiùnghere una règula de recurrèntzia.",
    "first" : "primu",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Is càmbios a sa règula de recurrèntzia s'ant a aplicare isceti a custa e a is occurrèntzias imbenientes.",
    "Repeat every" : "Repite cada",
    "By day of the month" : "Pro die de su mese",
    "On the" : "Su",
    "_day_::_days_" : ["die","dies"],
    "_week_::_weeks_" : ["chida","chidas"],
    "_month_::_months_" : ["mese","meses"],
    "_year_::_years_" : ["Annos","annos"],
    "weekday" : "die de fatu",
    "weekend day" : "die de fine de chida",
    "Does not repeat" : "No se repitit",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Sa definitzione de recurrèntzia de custu eventu no est suportada dae Nextcloud in manera totale. Si modìficas is optziones de recurrèntzia, calecuna recurrèntzia s'at a pòdere pèrdere.",
    "No rooms or resources yet" : "Ancora peruna istantza o risorsa",
    "Resources" : "Risorsas",
    "Remove resource" : "Boga·nche risorsa",
    "Search for resources or rooms" : "Chirca risorsas o istantzas",
    "Update this and all future" : "Agiorna custa e is àteras imbenientes",
    "Update this occurrence" : "Agiorna custa ocurrèntzia",
    "Public calendar does not exist" : "Su calendàriu pùblicu no esistit",
    "Maybe the share was deleted or has expired?" : "Mancai sa cumpartzidura est istada cantzellada o est iscadida?",
    "Remove participant" : " Boga·nche partetzipante",
    "Yes" : "Si",
    "No" : "No",
    "None" : "Perunu",
    "Create" : "Crea",
    "from {formattedDate}" : "dae {formattedDate}",
    "to {formattedDate}" : "a {formattedDate}",
    "on {formattedDate}" : "su {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "dae {formattedDate} a is {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "a {formattedDate} a is {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "su {formattedDate} a is {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} a is {formattedTime}",
    "Please enter a valid date" : "Inserta•nche una data bàlida",
    "Please enter a valid date and time" : "Inserta•nche una data e un'ora bàlidas",
    "Please select a time zone:" : "Sèbera unu fusu oràriu:",
    "Pick a time" : "Sèbera una ora",
    "Pick a date" : "Sèbera una data",
    "Type to search time zone" : "Iscrire pro chircare fusu oràriu",
    "Global" : "Globale",
    "Subscribed" : "Sutaiscritu",
    "Subscribe" : "Sutaiscrie",
    "Time:" : "Tempus:",
    "Personal" : "Personale",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Sa rilevada automàtica de su fusu oràriu at determinadu ca su tuo est UTC.\nEst probàbile chi custu siat su resurtadu de calicuna mesura de seguridade de su navigadore tuo.\nCunfigura su fusu oràriu tuo a manu in sa cunfiguratzione de su calendàriu.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Su fusu oràriu cunfiguradu ({timezoneId}) no est istadu agatadu. Torro a s'UTC.\nCàmbia su fusu oràriu tuo in sa cunfiguratzione e signala custu problema.",
    "Event does not exist" : "S'eventu no esistit",
    "Delete this occurrence" : "Cantzella custa ocurrèntzia",
    "Delete this and all future" : "Cantzella custa e is àteras imbenientes",
    "All day" : "Totu sa die",
    "Invite" : "Invita",
    "Untitled event" : "Eventu chene tìtulu",
    "Close" : "Serra",
    "Selected" : "Seletzionadu",
    "Title" : "Tìtulu",
    "Participants" : "Partetzipantes",
    "Submit" : "Imbia",
    "Subscribe to {name}" : "Sutaiscrie a {name}",
    "Anniversary" : "Anniversàriu",
    "Appointment" : "Apuntamentu",
    "Business" : "Afàrios",
    "Education" : "Educatzione",
    "Holiday" : "Vacàntzias",
    "Meeting" : "Atòbiu",
    "Miscellaneous" : "Vàriu",
    "Non-working hours" : "Oras chena traballu",
    "Not in office" : "No est in ofìtziu",
    "Phone call" : "Mutida de telèfonu",
    "Sick day" : "Die de maladia",
    "Special occasion" : "Ocasione ispetziale",
    "Travel" : "Viàgiu",
    "Vacation" : "Ausèntzia",
    "Midnight on the day the event starts" : "Mesunotte de sa die in ue s'eventu cumintzat",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n die in antis de s'eventu a is {formattedHourMinute}","%n dies in antis de s'eventu a is {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n die in antis de s'eventu a is {formattedHourMinute}","%n chidas in antis de s'eventu a is {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "sa die de s'eventu a is {formattedHourMinute}",
    "at the event's start" : "a su cumintzu de s'eventu",
    "at the event's end" : "a sa fine de s'eventu",
    "{time} before the event starts" : "{time} antis de su cumintzu de s'eventu",
    "{time} before the event ends" : "{time} antis de sa fine de s'eventu",
    "{time} after the event starts" : "{time} pustis de su cumintzu de s'eventu",
    "{time} after the event ends" : "{time} pustis de sa fine de s'eventu",
    "on {time}" : "a is {time} ",
    "on {time} ({timezoneId})" : "a is {time} ({timezoneId})",
    "Week {number} of {year}" : "Chida {number} de {year}",
    "Daily" : "Ogni die",
    "Weekly" : "Ogni chida",
    "Monthly" : "Ogni mese",
    "Yearly" : "Ogni annu",
    "_Every %n day_::_Every %n days_" : ["Cada %n die","Cada %n dies"],
    "_Every %n week_::_Every %n weeks_" : ["Cada %n chida","Cada %n chidas"],
    "_Every %n month_::_Every %n months_" : ["Cada %n mese","Cada %n meses"],
    "_Every %n year_::_Every %n years_" : ["Cada %n annu","Cada %n annos"],
    "_on {weekday}_::_on {weekdays}_" : ["su {weekday}","su {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["sa die {dayOfMonthList}","is dies {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "su {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "in {monthNames} su {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "finas a {untilDate}",
    "_%n time_::_%n times_" : ["%n borta","%n bortas"],
    "second" : "segundu",
    "third" : "de tres",
    "fourth" : "de bator",
    "fifth" : "de chimbe",
    "second to last" : "penùltimu",
    "last" : "ùltimu",
    "Untitled task" : "Atividade chene tìtulu",
    "Please ask your administrator to enable the Tasks App." : "Pedi a s'amministratzione de ativare sa Task App.",
    "W" : "C",
    "%n more" : "%n in prus",
    "No events to display" : "Perunu eventu de mustrare",
    "_+%n more_::_+%n more_" : ["+%n àteru","+%n àteros"],
    "No events" : "Perunu eventu",
    "Create a new event or change the visible time-range" : "Crea un'eventu nou o càmbia s'intervallu de tempus visìbile",
    "It might have been deleted, or there was a typo in a link" : "Fortzis est istadu cantzelladu, o b'at àpidu un'errore de digitatzione in unu ligòngiu",
    "It might have been deleted, or there was a typo in the link" : "Fortzis est istadu cantzelladu, o b'at àpidu un'errore de digitatzione in suligòngiu",
    "Other" : "Àteru",
    "When shared show" : "Cando si cumpartzit, mustra•ddu",
    "When shared show full event" : "Cando si cumpartzit mustra totu s'eventu",
    "When shared show only busy" : "Cando si cumpartzit, mustra isceti ocupadu",
    "When shared hide this event" : "Cando si cumpartzit, cua custu eventu",
    "Add a location" : "Agiunghe una positzione",
    "Status" : "Istadu",
    "Confirmed" : "Cunfirmadu",
    "Canceled" : "Annulladu",
    "Confirmation about the overall status of the event." : "Cunfirma subra s'istadu generale de s'eventu.",
    "Show as" : "Mustra comente",
    "Take this event into account when calculating free-busy information." : "Cunsìdera custu eventu cando si càrculant is informatziones lìberu-ocupadu.",
    "Categories" : "Categorias",
    "Categories help you to structure and organize your events." : "Is categorias t'agiudant a istruturare e organizare is eventos tuos.",
    "Search or add categories" : "Chirca o agiunghe categorias",
    "Add this as a new category" : "Agiunghe custa comente categoria noa",
    "Custom color" : "Personaliza colore",
    "Special color of this event. Overrides the calendar-color." : "Colore ispetziale de custu eventu. Ignora su colore de su calendàriu.",
    "Error while sharing file" : "Errore in sa cumpartzidura de s'archìviu",
    "An error occurred, unable to delete the calendar." : "B'at àpidu un'errore, no at fatu a cantzellare su calendàriu.",
    "Imported {filename}" : "Importadu {filename}",
    "User not found" : "Utèntzia no agatada",
    "Hidden" : "Cuadu",
    "can edit" : "podet modificare",
    "Automatic ({detected})" : "Automàticu ({detected})",
    "Shortcut overview" : "Bista generale de is curtziadòrgiu",
    "CalDAV link copied to clipboard." : "Ligòngiu CalDAV copiadu in punta de billete.",
    "CalDAV link could not be copied to clipboard." : "No at fatu a copiare su ligòngiu CalDAV in punta de billete.",
    "Enable birthday calendar" : "Ativa su calendàriu de cumpleannos",
    "Show tasks in calendar" : "Mustra atividades in su calendàriu",
    "Enable simplified editor" : "Ativa s'editore semplificadu",
    "Show weekends" : "Mustra fines de chida",
    "Show week numbers" : "Mustra nùmeru de chidas",
    "Time increments" : "Crèschidas de tempus",
    "Copy primary CalDAV address" : "Còpia s'indiritzu CalDAV printzipale",
    "Copy iOS/macOS CalDAV address" : "Còpia s'indiritzu CalDAV iOS/macOS",
    "Show keyboard shortcuts" : "Mustra curtziadòrgios de tecladu",
    "Successfully appended link to talk room to description." : "Ligòngiu apicadu in manera curreta in sa descritzione de s'aposentu de cunversatzione",
    "Error creating Talk room" : "Errore in sa creatzione de s'aposentu Talk",
    "The visibility of this event in shared calendars." : "Sa visibilidade de custu eventu in is calendàrios cumpartzidos"
},
"nplurals=2; plural=(n != 1);");
