OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Mail được nhập quá dài",
    "User-Session unexpectedly expired" : "Tiến trình của người dùng đã hết hạn một cách không được mong đợi trước",
    "Provided email-address is not valid" : "Thư điện tử được cung cấp không khả dụng",
    "%s has published the calendar »%s«" : "%s vừa đăng tải thông tin vào lịch »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Một lỗi không mong đợi khi đang gửi thư điện tử. Vui lòng liên hệ quản trị viên của bạn",
    "Successfully sent email to %1$s" : "Đã gửi email thành công đến %1$s",
    "Hello," : "Xin chào,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Chúng tôi muốn thông báo với bạn rằng %s vừa đăng tải thông tin vào lịch »%s«.",
    "Open »%s«" : "Mở »%s«",
    "Cheers!" : "Xin chúc mừng!",
    "Upcoming events" : "Các sự kiện sắp diễn ra",
    "No more events today" : "Không có thêm sự kiện nào hôm nay",
    "No upcoming events" : "Không có sự kiện sắp diễn ra ",
    "More events" : "Sự kiện khác",
    "%1$s with %2$s" : "%1$s với %2$s",
    "Calendar" : "Lịch",
    "New booking {booking}" : "Book lịch mới{booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) đã book lịch hẹn với \"{config_display_name}\" vào {date_time}.",
    "Appointments" : "Các lịch hẹn ",
    "Schedule appointment \"%s\"" : "Lên lịch lịch hẹn \"%s\"",
    "Schedule an appointment" : "Lên lịch một lịch hẹn",
    "%1$s - %2$s" : "%1$s-%2$s",
    "Prepare for %s" : "Chuản bị cho %s",
    "Follow up for %s" : "Diễn tiến cho %s",
    "Dear %s, please confirm your booking" : "%s thân ái, vui lòng xác nhận lịch đặt hẹn của bạn",
    "Confirm" : "Xác nhận",
    "Description:" : "Mô tả:",
    "This confirmation link expires in %s hours." : "Liên kết xác nhận sẽ hết hạn trong %s giờ.",
    "Appointment for:" : "Lịch hẹn cho: ",
    "Date:" : "Ngày:",
    "You will receive a link with the confirmation email" : "Bạn sẽ nhận được liên kết cùng với email xác nhận",
    "Where:" : "Địa điểm:",
    "Comment:" : "Bình luận",
    "You have a new appointment booking \"%s\" from %s" : "Bạn có lịch hẹn mới được book bởi \"%s\" vào lúc %s",
    "Dear %s, %s (%s) booked an appointment with you." : "Gửi %s,%s(%s) đã book lịch hẹn với bạn.",
    "Location:" : "Đến từ :",
    "A Calendar app for Nextcloud" : "Một ứng dụng Lịch nhắc nhở cho Hệ thống",
    "Previous day" : "Ngày trước",
    "Previous week" : "Tuần trước",
    "Previous year" : "Năm trước",
    "Previous month" : "Tháng trước",
    "Next day" : "Ngày hôm sau",
    "Next week" : "Tuần sau",
    "Next year" : "Năm tiếp theo",
    "Next month" : "Tháng sau",
    "Create new event" : "Tạo sự kiện mới",
    "Event" : "Sự kiện",
    "Today" : "Hôm nay",
    "Day" : "Ngày",
    "Week" : "Tuần",
    "Month" : "Tháng",
    "Year" : "Năm",
    "List" : "Danh sách",
    "Appointment link was copied to clipboard" : "Liên kết cuộc hẹn đã được sao chép vào bảng tạm",
    "Appointment link could not be copied to clipboard" : "Liên kết cuộc hẹn không thể được sao chép vào bảng tạm",
    "Preview" : "Xem trước",
    "Copy link" : "Sao chép liên kết",
    "Edit" : "Chỉnh sửa",
    "Delete" : "Xóa",
    "Appointment schedules" : "Lên lịch hẹn",
    "Create new" : "Tạo mới",
    "An error occurred, unable to change visibility of the calendar." : "Một lỗi đã xảy ra, không thể thay đổi tính hiển thị của lịch.",
    "Untitled calendar" : "Lịch không tiêu đề",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Đang gỡ chia sẻ của lịch trong {countdown} giây"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Đang xóa lịch trong {countdown} giây"],
    "An error occurred, unable to create the calendar." : "Một lỗi đã xảy ra, không thẻ tạo lịch.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Vui lòng nhập vào một liên kết khả dụng ( bắt đầu với http://, https://, webcal://, hoặc webcals://)",
    "Calendars" : "Lịch",
    "Add new" : "Thêm mới",
    "New calendar" : "Lịch mới",
    "Name for new calendar" : "Tên cho lịch mới",
    "Creating calendar …" : "Đang tạo lịch  …",
    "New calendar with task list" : "Lịch mới với danh sách nhiệm vụ",
    "New subscription from link (read-only)" : "Đăng kí theo dõi mới từ liên kết (Chỉ-đọc)",
    "Creating subscription …" : "Đang tạo đăng kí theo dõi mới  …",
    "Calendar link copied to clipboard." : "Liên kết của lịch đã được sao chép vào bảng tạm.",
    "Calendar link could not be copied to clipboard." : "Liên kết của lịch không thể sao chép vào bảng tạm.",
    "Copy subscription link" : "Sao chép liên kết theo dõi ",
    "Copying link …" : "Sao chép liên kết  ...",
    "Copied link" : "Liên kết đã được sao chép",
    "Could not copy link" : "Không thể sao chép liên kết",
    "Export" : "Xuất ra",
    "Unknown calendar" : "Lịch không rõ nguồn",
    "Could not load deleted calendars and objects" : "Không thể hiển thị lịch hoặc các đối tượng đã xoá",
    "Could not restore calendar or event" : "Không thể khôi phục lịch hoặc sự kiện",
    "Do you really want to empty the trash bin?" : "Bạn có chắc là muốn dọn sạch thùng rác hay không?",
    "Empty trash bin" : "Dọn thùng rác",
    "Trash bin" : "Thùng rác",
    "Name" : "Tên",
    "Deleted" : "Đã xoá",
    "Restore" : "Khôi phục",
    "Delete permanently" : "Xoá vĩnh viễn",
    "Could not update calendar order." : "Không thể cập nhật thứ tự của lịch",
    "Deck" : "Kế hoạch",
    "Internal link" : "Liên kết nội bộ",
    "An error occurred, unable to publish calendar." : "Có lỗi đã xảy ra, không thể công khai lịch.",
    "An error occurred, unable to send email." : "Một lỗi đã xảy ra, không thể gửi email.",
    "Embed code copied to clipboard." : "Mã nhúng đã được sao chép vào bảng tạm.",
    "Embed code could not be copied to clipboard." : "Mã nhúng không thể được sao chép vào bảng tạm.",
    "Unpublishing calendar failed" : "Gỡ công khai cho lịch thất bại",
    "Share link" : "Liên kết chia sẽ",
    "Copy public link" : "Sao chép liên kết công khai",
    "Send link to calendar via email" : "Gửi liên kết đến lịch thông qua thư điện tử",
    "Enter one address" : "Điền vào môt địa chỉ",
    "Sending email …" : "Đang gửi email ...",
    "Copy embedding code" : "Đang sao chép mã nhúng",
    "Copying code …" : "Đang sao chép mã  ...",
    "Copied code" : "Đã sao chép dòng lệnh",
    "Could not copy code" : "Không thể sao chép dòng lệnh",
    "Delete share link" : "Xóa liên kết chia sẻ",
    "Deleting share link …" : "Đang xóa liên kết chia sẻ  ...",
    "An error occurred, unable to change the permission of the share." : "Một lỗi đã diễn ra, không thể thay đổi quyền hạn chia sẻ",
    "Unshare with {displayName}" : "Gỡ chia sẻ với {displayName}",
    "Share with users or groups" : "Chia sẽ với người dùng hoặc nhóm",
    "No users or groups" : "Không có người dùng hay nhóm",
    "Unshare from me" : "Gỡ chia sẻ khỏi tôi",
    "Save" : "Lưu",
    "View" : "Xem",
    "Import calendars" : "Nhập lịch",
    "Please select a calendar to import into …" : "Vui lòng chọn một lịch để nhập vào  …",
    "Filename" : "Tên tập tin",
    "Calendar to import into" : "Lịch để nhập vào",
    "Cancel" : "Hủy",
    "_Import calendar_::_Import calendars_" : ["Nhập lịch"],
    "Attachments folder" : "Thư mục đính kèm",
    "{filename} could not be parsed" : "{filename} không thể được phân tách",
    "No valid files found, aborting import" : "Không có tệp khả dụng được tìm thấy, đang hủy quá trình nhập",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["%n sự kiện đã được nhập vào thành công"],
    "Import partially failed. Imported {accepted} out of {total}." : "Quá trình nhập thất bại 1 phần. Đã nhập {accepted} trong tổng {total}.",
    "Automatic" : "Tự động",
    "Automatic ({timezone})" : "Tự động ({timezone})",
    "New setting was not saved successfully." : "Thiết lập mới không được lưu thành công",
    "Timezone" : "Múi giờ",
    "Navigation" : "Điều hướng",
    "Previous period" : "Kỳ trước",
    "Next period" : "Kỳ tiếp theo",
    "Views" : "Lượt xem",
    "Day view" : "Xem theo ngày",
    "Week view" : "Xem theo tuần",
    "Month view" : "Xem theo tháng",
    "List view" : "Xem theo danh sách",
    "Actions" : "Hành động",
    "Create event" : "Tạo sự kiện mới",
    "Show shortcuts" : "Hiển thị các phím tắt",
    "Editor" : "Trình biên tập",
    "Close editor" : "Đóng trình biên tập",
    "Save edited event" : "Lưu lại sự kiện được chỉnh sửa",
    "Delete edited event" : "Xoá sự kiện được chỉnh sửa",
    "or" : "hoặc",
    "No reminder" : "Không có nhắc hẹn",
    "General" : "Cài đặt chung",
    "Appearance" : "Giao diện",
    "Editing" : "Chỉnh sửa",
    "Default reminder" : "Nhác hẹn mặc định",
    "Files" : "Tệp Tin",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} phút"],
    "0 minutes" : "0 phút",
    "_{duration} hour_::_{duration} hours_" : ["{duration} giờ"],
    "_{duration} day_::_{duration} days_" : ["{duration} ngày"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} tuần"],
    "_{duration} month_::_{duration} months_" : ["{duration} tháng"],
    "_{duration} year_::_{duration} years_" : ["{duration} năm"],
    "To configure appointments, add your email address in personal settings." : "Để cấu hình lịch hẹn, thêm vào địa chỉ email trong thiết lập cá nhân.",
    "Public – shown on the profile page" : "Công cộng - Được hiển thị công khai trên trang thông tin cá nhân",
    "Private – only accessible via secret link" : "Riêng tư - Chỉ có thể truy cập thông qua liên kết bí mật",
    "Update" : "Cập nhật",
    "Location" : "Vị trí",
    "Description" : "Mô tả",
    "Visibility" : "Hiển thị",
    "Duration" : "Khoảng thời gian",
    "Increments" : "Tăng thêm",
    "Additional calendars to check for conflicts" : "Lịch phụ để kiểm tra trùng lặp",
    "Pick time ranges where appointments are allowed" : "Chọn khoản thời gian khả dĩ cho các cuộc hẹn",
    "to" : "đến",
    "Delete slot" : "Xoá suất",
    "No times set" : "Thời gian không được thiết lập",
    "Add" : "Thêm",
    "Monday" : "Thứ 2",
    "Tuesday" : "Thứ ba",
    "Wednesday" : "Thứ tư",
    "Thursday" : "Thứ năm",
    "Friday" : "Thứ sáu",
    "Saturday" : "Thứ bảy",
    "Sunday" : "Chủ Nhật",
    "Add time before and after the event" : "Thêm thời gian trước và sau sự kiện",
    "Before the event" : "Trước sự kiện",
    "After the event" : "Sau sự kiện",
    "Planning restrictions" : "Các loại trừ cho kế hoạch",
    "Minimum time before next available slot" : "Thời gian tối thiểu trước một suất mở",
    "Max slots per day" : "Số suất tối đa trong ngày",
    "Limit how far in the future appointments can be booked" : "Giới hạn khoảng thời gian bao xa trong tương lai mà lịch hẹn có thể được đặt",
    "Please confirm your reservation" : "Vui lòng xác nhận đặt chỗ của bạn",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Chúng tôi đã gửi bạn một email với đầy đủ chi tiết. Vui lòng xác nhận lịch hẹn của bạn bằng liên kết trong email. Bây giờ bạn đã có thể đóng trang này.",
    "Your name" : "Tên của bạn",
    "Your email address" : "Địa chỉ email của bạn",
    "Please share anything that will help prepare for our meeting" : "Vui lòng chia sẻ bất cứ gì có thể giúp cho việc chuẩn bị cho cuộc hẹn  ",
    "Could not book the appointment. Please try again later or contact the organizer." : "Không thể đặt lịch hẹn. Vui lòng thử lại sau hoặc liên hệ với người tổ chức.",
    "Back" : "Trở lại",
    "Select conversation" : "Chọn cuộc trò chuyện",
    "on" : "trên",
    "at" : "vào lúc",
    "before at" : "trước lúc",
    "Notification" : "Thông báo",
    "Email" : "Thư điện tử",
    "Audio notification" : "Thông báo âm thanh",
    "Other notification" : "Các thông báo khác",
    "Relative to event" : "Liên quan tới sự kiện",
    "On date" : "Vào ngày",
    "Edit time" : "Chỉnh sửa thời gian",
    "Save time" : "Lưu thời gian",
    "Remove reminder" : "Gỡ bỏ lịch nhắc hẹn",
    "Add reminder" : "Thêm vào nhắc hẹn",
    "seconds" : "giây",
    "minutes" : "phút",
    "hours" : "giờ",
    "days" : "ngày",
    "weeks" : "tuần",
    "Choose a file to add as attachment" : "Chọn một tệp để thêm dưới dạng tệp đính kèm",
    "Choose a file to share as a link" : "Chọn một tệp để chia sẻ dưới dạng liên kết",
    "Proceed" : "Tiến hành",
    "Delete file" : "Xóa tệp",
    "Suggested" : "Được đề xuất",
    "Available" : "khả dụng",
    "Invitation accepted" : "Lời mời đã được chấp nhận",
    "Accepted {organizerName}'s invitation" : "Đã chấp nhận lời mời của {organizerName}",
    "Not available" : "Không khả dụng",
    "Invitation declined" : "Lời mời đã bị từ chối",
    "Declined {organizerName}'s invitation" : "Đã từ chối lời mời của {organizerName}",
    "Checking availability" : "Đang kiểm tra lịch trống",
    "{organizer} (organizer)" : "{organizer} (người tổ chức)",
    "Availability of attendees, resources and rooms" : "Tình trạng tham gia của người dự, nguồn lực và phòng ",
    "Out of office" : "Không ở văn phòng",
    "Done" : "Hoàn thành",
    "Room name" : "Tên phòng",
    "Free" : "Rãnh",
    "Busy (tentative)" : "Bận (có khả năng thay đổi)",
    "Busy" : "Bận",
    "Unknown" : "Không xác định",
    "Accept" : "Đồng ý",
    "Decline" : "Từ chối",
    "Tentative" : "Chưa chắc chắn",
    "No attendees yet" : "Chưa có giờ tham gia",
    "Attendees" : "Người tham gia",
    "Remove group" : "Xóa nhóm",
    "Remove attendee" : "Gỡ bỏ người tham gia",
    "Chairperson" : "Chủ tịch",
    "Required participant" : "Người tham gia được yêu cầu",
    "Optional participant" : "Người tham gia không bắt buộc",
    "Non-participant" : "Người không tham gia",
    "No match found" : "Không có khớp lệnh nào được tìm thấy",
    "(organizer)" : "(organizer)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Để gửi lời mời và tiếp nhận các phản hồi, [linkopen] thêm địa chỉ email riêng của bạn trong phần cài đặt cá nhân[linkclose].",
    "Remove color" : "Gỡ màu",
    "Event title" : "Tiêu đề sự kiện",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Không thể điều chỉnh thiết lập cả-ngày cho các sự kiện là một phần của sự kiện-lặp lại.",
    "From" : "Từ",
    "To" : "Tới",
    "Repeat" : "Lặp lại",
    "_time_::_times_" : ["lần"],
    "never" : "không thay đổi",
    "on date" : "vào ngày",
    "after" : "sau khi",
    "End repeat" : "Kết thúc lập lại",
    "Select to end repeat" : "Chọn thời gian kết thúc lặp lại",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Sự kiện này là loại trừ trong một bộ sự kiện-lặp lại. Bạn không thể thêm bất cứ qui tắc-lặp lại nào vào nó. ",
    "first" : "đầu tiên",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "các thay đổi đến luật lệ định kỳ này sẽ chỉ áp dụng cho định kỳ này và các định kỳ tương lai của nó ",
    "Repeat every" : "Lặp lại mỗi",
    "By day of the month" : "Vào ngày của tháng",
    "On the" : "Trên",
    "_day_::_days_" : ["ngày"],
    "_week_::_weeks_" : ["tuần"],
    "_month_::_months_" : ["tháng"],
    "_year_::_years_" : ["năm"],
    "weekday" : "ngày làm việc",
    "weekend day" : "ngày cuối tuần",
    "Does not repeat" : "Không lặp lại",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Định nghĩa về định kỳ của sự kiện này không hoàn toàn được hỗ trợ bởi vWorkspace. Nếu bạn sửa các lựa chọn định kỳ này, một vài định kỳ có thể sẽ bị mất ",
    "No rooms or resources yet" : "Chưa có phòng hoặc nguồn lực",
    "Resources" : "Các nguồn lực",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} chỗ ngồi"],
    "Add resource" : "Thêm nguồn lực",
    "Has a projector" : "Có máy chiếu",
    "Has a whiteboard" : "Có bảng đen ",
    "Wheelchair accessible" : "Có lối đi cho người khuyết tật",
    "Remove resource" : "Gỡ bỏ nguồn lực",
    "Search for resources or rooms" : "Tìm kiếm cho nguồn lực hoặc phòng trống",
    "available" : "khả dụng",
    "unavailable" : "không khả dụng",
    "Projector" : "Máy chiếu",
    "Whiteboard" : "Bảng viết",
    "Room type" : "Loại phòng",
    "Any" : "Bất cứ",
    "Minimum seating capacity" : "Số ghế ngồi tối thiểu",
    "Update this and all future" : "Cập nhập định kỳ này và cho toàn bộ tương lai",
    "Update this occurrence" : "Cập nhập định kỳ này",
    "Public calendar does not exist" : "Lịch công khai không tồn tại",
    "Maybe the share was deleted or has expired?" : "Có lẽ chia sẽ đã bị xóa hoặc hết hạn ? ",
    "Yes" : "Có",
    "No" : "Không",
    "None" : "Không có",
    "Create" : "Tạo",
    "from {formattedDate}" : "từ {formattedDate}",
    "to {formattedDate}" : "đến {formattedDate}",
    "on {formattedDate}" : "vào {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "từ {formattedDate} vào lúc {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "đến {formattedDate} vào lúc {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "vào {formattedDate} vào lúc {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} vào lúc {formattedTime}",
    "Please enter a valid date" : "Vui lòng điền vào 1 ngày khả dụng",
    "Please enter a valid date and time" : "Vui lòng điền vào 1 ngày và thời gian khả dụng",
    "Please select a time zone:" : "Vui lòng chọn múi thời gian:",
    "Pick a time" : "Chọn thời gian",
    "Pick a date" : "Chọn ngày",
    "Type to search time zone" : "Nhập để kiếm cho múi thời gian",
    "Global" : "Chung",
    "Subscribed" : "Đã đăng ký",
    "Subscribe" : "Theo dõi",
    "Select slot" : "Chọn suất",
    "No slots available" : "Không có suất trống",
    "The slot for your appointment has been confirmed" : "Suất cho cuộc hẹn của bạn đã được xác nhận",
    "Appointment Details:" : "Chi tiết cuộc hẹn:",
    "Time:" : "Thời gian:",
    "Booked for:" : "Đã đặt cho:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Cảm ơn. Lịch hẹn của bạn từ {startDate} đến {endDate} đã được xác nhận.",
    "Book another appointment:" : "Đặt một cuộc hẹn khác:",
    "See all available slots" : "Hiển thị toàn bộ các suất trống ",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Suất cho cuộc hẹn của bạn từ {startDate} đến {endDate} hiện không còn trống.",
    "Please book a different slot:" : "Vui lòng đặt một suất khác:",
    "Book an appointment with {name}" : "Đặt một cuộc hẹn với {name}",
    "No public appointments found for {name}" : "Không cuộc hẹn công khai nào cho {name} được tìm thấy",
    "Personal" : "Cá nhân",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Chức năng tự động phát hiện múi giờ đã xác định múi giờ của bạn là UTC. \nRất có khả năng đây là kết quả lấy từ các tuỳ chỉnh bảo mật trong trình duyệt của bạn.\nVui lòng chuyển đổi thủ công múi của giờ của bạn trong phần thiết lập của Lịch",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Không tìm thấy múi giờ ({timezoneId}) được cấu hình của bạn. Thiết lập múi giờ sẽ được trở về lại UTC. Vui lòng thay đổi múi giờ của bạn trong phần cài đặt và hãy báo cáo sự cố này. ",
    "Edit event" : "Sửa sự kiện",
    "Event does not exist" : "Sự kiện không tồn tại",
    "Delete this occurrence" : "Xóa định kỳ này",
    "Delete this and all future" : "Xóa địnhy kỳ này và tất cả tương lai của nó",
    "All day" : "Cả ngày",
    "Invite" : "Mời",
    "Untitled event" : "Sự kiện không tiêu đề",
    "Close" : "Đóng",
    "Title" : "Tên",
    "Participants" : "Người tham gia",
    "Submit" : "Gửi",
    "Subscribe to {name}" : "Dõi theo {name}",
    "Export {name}" : "Xuất dữ liệu bảng {name}",
    "Anniversary" : "Ngày kỷ niệm",
    "Appointment" : "Cuộc hẹn",
    "Business" : "Doanh nghiệp",
    "Education" : "Giáo dục",
    "Holiday" : "Ngày lễ",
    "Meeting" : "Cuộc họp",
    "Miscellaneous" : "Hỗn hợp",
    "Non-working hours" : "Ngoài giờ làm việc",
    "Not in office" : "Ngoài văn phòng",
    "Phone call" : "Cuộc gọi",
    "Sick day" : "Ngày nghỉ ốm",
    "Special occasion" : "Dịp đặc biệt",
    "Travel" : "Du lịch",
    "Vacation" : "Kì nghỉ",
    "Midnight on the day the event starts" : "Giữa đêm vào ngày mà sự kiện bắt đầu",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n ngày trước khi sự kiện bắt đầu vào lúc {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n tuần trước khi sự kiện bắt đầu vào lúc {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "vào ngày sự kiện bắt đầu vào lúc {formattedHourMinute}",
    "at the event's start" : "vào lúc sự kiện bắt đầu",
    "at the event's end" : "vào lúc sự kiện kết thúc",
    "{time} before the event starts" : "{time} trước khi sự kiện bắt đầu",
    "{time} before the event ends" : "{time} trước khi sự kiện kết thúc",
    "{time} after the event starts" : "{time} sau khi sự kiện bắt đầu",
    "{time} after the event ends" : "{time} sau khi sự kiện kết thúc",
    "on {time}" : "vào  {time}",
    "on {time} ({timezoneId})" : "vào {time} ({timezoneId})",
    "Week {number} of {year}" : "Tuần thứ {number} của năm {year}",
    "Daily" : "Hằng ngày",
    "Weekly" : "Hằng tuần",
    "Monthly" : "Hằng tháng",
    "Yearly" : "Hằng năm",
    "_Every %n day_::_Every %n days_" : ["Mỗi %n ngày"],
    "_Every %n week_::_Every %n weeks_" : ["Mỗi %n tuần"],
    "_Every %n month_::_Every %n months_" : ["Mỗi %n tháng"],
    "_Every %n year_::_Every %n years_" : ["Mỗi %n năm"],
    "_on {weekday}_::_on {weekdays}_" : ["vào  {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["vào các ngày {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "vào {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "trong {monthNames} trên {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "cho đến {untilDate}",
    "_%n time_::_%n times_" : ["%n lần"],
    "second" : "Thứ hai",
    "third" : "vị trí thứ ba",
    "fourth" : "vị trí thứ tư",
    "fifth" : "vị trí thứ năm",
    "second to last" : "kế cuối",
    "last" : "cuối cùng",
    "Untitled task" : "Nhiệm vụ không tiêu đề",
    "Please ask your administrator to enable the Tasks App." : "Vui lòng hỏi quản trị viên của bạn để bật ứng dụng Nhiệm Vụ",
    "W" : "T",
    "%n more" : "thêm %n",
    "No events to display" : "không có sự kiện để hiển thị",
    "_+%n more_::_+%n more_" : ["+ thêm %n "],
    "No events" : "Không có sự kiện",
    "Create a new event or change the visible time-range" : "Tạo sự kiện mới hoặc thay đổi khung thời gian hiển thị",
    "It might have been deleted, or there was a typo in a link" : "Đường dẫn có thể đã bị xóa, hoặc đã có lỗi đánh máy trong liên kết",
    "It might have been deleted, or there was a typo in the link" : "Đường dẫn có thể đã bị xóa, hoặc đã có lỗi đánh máy trong liên kết",
    "Meeting room" : "Phòng họp",
    "Lecture hall" : "Giảng đường",
    "Seminar room" : "Phòng hội nghị",
    "Other" : "Khác",
    "When shared show" : "Khi được chia sẻ thì hiển thị",
    "When shared show full event" : "Khi được chia sẻ thì hiển thị đầy đủ sự kiện",
    "When shared show only busy" : "Khi được chia sẻ thì chỉ hiển thị đang bận",
    "When shared hide this event" : "Khi được chia sẻ thì ẩn sự kiện này đi",
    "Add a location" : "Thêm vào một địa điểm",
    "Status" : "Trạng thái",
    "Confirmed" : "Đã xác nhận",
    "Canceled" : "Đã bị hủy",
    "Confirmation about the overall status of the event." : "Xác nhận về tình trạng tổng thể của sự kiện.",
    "Show as" : "Hiển thị như",
    "Take this event into account when calculating free-busy information." : "Lưu ý đến sự kiện này khi tính toán về thông tin bận-rãnh",
    "Categories" : "Các hạng mục",
    "Categories help you to structure and organize your events." : "Các hạng mục này giúp bạn lên sườn và sắp xếp các sự kiện của bạn",
    "Search or add categories" : "Tìm kiếm và thêm vào các hạng mục",
    "Add this as a new category" : "Thêm mục này như là hạng mục mới",
    "Custom color" : "Tùy chỉnh màu",
    "Special color of this event. Overrides the calendar-color." : "Dùng màu đặc biệt cho sự kiện này. Ghi đè lên màu hiện hành",
    "Error while sharing file" : "Lỗi khi chia sẻ tệp",
    "An error occurred, unable to delete the calendar." : "Một lỗi đã xảy ra, không thể xóa lịch.",
    "Imported {filename}" : " {filename} đã được nhập",
    "Appointment not found" : "Không tìm thấy cuộc hẹn",
    "User not found" : "Không tìm thấy người dùng",
    "Hidden" : "Ẩn",
    "can edit" : "có thể chỉnh sửa",
    "Automatic ({detected})" : " ({detected}) tự động",
    "Shortcut overview" : "Bản xem trước của lối tắt",
    "CalDAV link copied to clipboard." : "Liên kết CalDAV đã được sao chép vào bảng tạm",
    "CalDAV link could not be copied to clipboard." : "Liên kết CalDAV không thể được sao chép vào bảng tạm.",
    "Enable birthday calendar" : "Bật lịch sinh nhật",
    "Show tasks in calendar" : "Cho thấy nhiệm vụ trong lịch",
    "Enable simplified editor" : "Bật chỉnh sửa đơn giản",
    "Show weekends" : "Cho thấy ngày cuối tuần",
    "Show week numbers" : "Hiển thị số tuần",
    "Time increments" : "Mức tăng thời gian",
    "Copy primary CalDAV address" : "Sao chép địa chỉ CalDAV chính",
    "Copy iOS/macOS CalDAV address" : "Sao chép địa chỉ CalDAV cho iOS/macOC",
    "Personal availability settings" : "Thiết lập lịch trống cá nhân",
    "Show keyboard shortcuts" : "Hiển thị các phím tắt",
    "Successfully appended link to talk room to description." : "Liên kết đã được thêm thành công vào mô tả trong phòng trò chuyện ",
    "Error creating Talk room" : "Có lõi xảy ra khi tạo phòng Trò chuyện",
    "The visibility of this event in shared calendars." : "Khả năng nhìn thấy của sự kiện này trong các lịch được chia sẻ"
},
"nplurals=1; plural=0;");
