OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Belirtilen e-posta adresi çok uzun",
    "User-Session unexpectedly expired" : "Kullanıcı oturumunun geçerlilik süresi beklenmedik şekilde doldu",
    "Provided email-address is not valid" : "Belirtilen e-posta adresi geçersiz",
    "%s has published the calendar »%s«" : "%s, »%s« takvimini yayınladı",
    "Unexpected error sending email. Please contact your administrator." : "E-posta gönderilirken beklenmeyen bir sorun çıktı. Lütfen BT yöneticiniz ile görüşün.",
    "Successfully sent email to %1$s" : "E-posta %1$s adresine gönderildi",
    "Hello," : "Merhaba,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Bu ileti %s tarafından »%s« takviminin yayınlandığını bildirmek için gönderilmiştir.",
    "Open »%s«" : "»%s« aç",
    "Cheers!" : "Görüşmek üzere",
    "Upcoming events" : "Yaklaşan etkinlikler",
    "No more events today" : "Bugün başka bir etkinlik yok",
    "No upcoming events" : "Yaklaşan bir etkinlik yok",
    "More events" : "Diğer etkinlikler",
    "%1$s with %2$s" : "%2$s ile %1$s ",
    "Calendar" : "Takvim",
    "New booking {booking}" : "Yeni {booking} alma",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) \"{config_display_name}\" randevusunu aldı. Tarih: {date_time}.",
    "Appointments" : "Randevular",
    "Schedule appointment \"%s\"" : "\"%s\" randevusu al",
    "Schedule an appointment" : "Bir randevu alın",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : "%s için hazırlan",
    "Follow up for %s" : "%s için takip",
    "Your appointment \"%s\" with %s needs confirmation" : "\"%s\" randevunuzun (%s ile) onaylanması gerekiyor",
    "Dear %s, please confirm your booking" : "Sayın %s, lütfen randevunuzu onaylayın",
    "Confirm" : "Onayla",
    "Appointment with:" : "Şu kişiyle randevu:",
    "Description:" : "Açıklama:",
    "This confirmation link expires in %s hours." : "Bu onay bağlantısının geçerlilik süresi %s saat sonra dolacak.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Sonuçta randevuyu iptal etmek isterseniz, lütfen bu e-postayı yanıtlayarak ya da profil sayfasını ziyaret ederek düzenleyici ile görüşün.",
    "Your appointment \"%s\" with %s has been accepted" : "\"%s\" randevunuz (%s ile) onaylandı",
    "Dear %s, your booking has been accepted." : "Sayın %s, randevunuz onaylandı.",
    "Appointment for:" : "Randevu:",
    "Date:" : "Tarih:",
    "You will receive a link with the confirmation email" : "E-posta ile bir doğrulama bağlantısı alacaksınız",
    "Where:" : "Yer:",
    "Comment:" : "Açıklama:",
    "You have a new appointment booking \"%s\" from %s" : "\"%s\" randevusunu %s üzerinden aldınız",
    "Dear %s, %s (%s) booked an appointment with you." : "Sayın %s, %s (%s) sizin için bir randevu aldı.",
    "%s has proposed a meeting" : "%s bir toplantı önerisinde bulundu",
    "%s has updated a proposed meeting" : "%s bir toplantı önerisini güncelledi",
    "%s has canceled a proposed meeting" : "%s bir toplantı önerisini iptal etti",
    "Dear %s, a new meeting has been proposed" : "Sayın %s, yeni bir toplantı önerildi",
    "Dear %s, a proposed meeting has been updated" : "Sayın %s, bir toplantı önerisi güncellendi",
    "Dear %s, a proposed meeting has been cancelled" : "Sayın %s, bir toplantı önerisi iptal edildi",
    "Location:" : "Konum:",
    "Duration:" : "Süre:",
    "%1$s from %2$s to %3$s" : "%1$s, %2$s ile %3$s arasında",
    "Dates:" : "Tarihler",
    "Respond" : "Yanıtla",
    "A Calendar app for Nextcloud" : "Nextcloud takvim uygulaması",
    "A Calendar app for Nextcloud. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Like Contacts, Talk, Tasks, Deck and Circles\n* 🌐 **WebCal Support!** Want to see your favorite team's matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 **Search!** Find your events at ease\n* ☑️ **Tasks!** See tasks or Deck cards with a due date directly in the calendar\n* 🔈 **Talk rooms!** Create an associated Talk room when booking a meeting with just one click\n* 📆 **Appointment booking** Send people a link so they can book an appointment with you [using this app](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Attachments!** Add, upload and view event attachments\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Nextcloud için Takvim uygulaması. Çeşitli aygıtlardaki etkinlikleri Nextcloud kopyanızla kolayca eşitleyin ve çevrim içi olarak düzenleyin.\n\n* 🚀 **Diğer Nextcloud uygulamalarıyla bütünleşik!** Kişiler, Konuş, Görevler, Tahta ve Çevreler gibi\n* 🌐 **WebCal Desteği!** Tuttuğunuz takımın maç günlerini takviminizde görmek ister misiniz? Sorun değil!\n* 🙋 **Katılımcılar!** Etkinliklerinize insanları davet edin\n* ⌚ **Boş/Meşgul!** Katılımcılarınızın ne zaman buluşmaya uygun olduğunu görün\n* ⏰ **Anımsatıcılar!** Tarayıcınızın içinden ve e-posta ile etkinliklerle ilgili uyarılar alın\n* 🔍 **Arama!** Etkinliklerinizi kolayca bulun\n* ☑️ **Görevler!** Görevleri veya Tahta kartlarını doğrudan takvimde son teslim tarihiyle görün\n* 🔈 **Konuş odaları!** Tek bir tıklamayla bir toplantı rezervasyonu yaparken ilişkili bir Konuş odası oluşturun\n* 📆 **Randevu rezervasyonu** İnsanlara bir bağlantı gönderin, böylece sizinle [bu uygulamayı kullanarak](https://apps.nextcloud.com/apps/appointments) randevu alabilirler\n* 📎 **Ek dosyalar!** Etkinliklere dosyalar ekleyin, yükleyin ve görüntüleyin\n* 🙈 **Tekerleği yeniden icat etmiyoruz!** Harika [c-dav kitaplığı](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) ve [fullcalendar](https://github.com/fullcalendar/fullcalendar) kitaplıkları.",
    "Previous day" : "Önceki gün",
    "Previous week" : "Önceki hafta",
    "Previous year" : "Önceki yıl",
    "Previous month" : "Önceki ay",
    "Next day" : "Sonraki gün",
    "Next week" : "Sonraki hafta",
    "Next year" : "Sonraki yıl",
    "Next month" : "Sonraki ay",
    "Create new event" : "Etkinlik ekle",
    "Event" : "Etkinlik",
    "Today" : "Bugün",
    "Day" : "Gün",
    "Week" : "Hafta",
    "Month" : "Ay",
    "Year" : "Yıl",
    "List" : "Listele",
    "Appointment link was copied to clipboard" : "Randevu bağlantısı panoya kopyalandı",
    "Appointment link could not be copied to clipboard" : "Randevu bağlantısı panoya kopyalanamadı",
    "Preview" : "Ön izleme",
    "Copy link" : "Bağlantıyı kopyala",
    "Edit" : "Düzenle",
    "Delete" : "Sil",
    "Appointment schedules" : "Randevu zamanları",
    "Create new" : "Yeni ekle",
    "Disable calendar \"{calendar}\"" : "\"{calendar}\" takvimini kullanımdan kaldır",
    "Disable untitled calendar" : "Adlandırılmamış takvimi kullanımdan kaldır",
    "Enable calendar \"{calendar}\"" : "\"{calendar}\" takvimini kullanıma al",
    "Enable untitled calendar" : "Adlandırılmamış takvimi kullanıma al",
    "An error occurred, unable to change visibility of the calendar." : "Bir sorun çıktı. Takvimin görünürlüğü değiştirilemedi.",
    "Untitled calendar" : "Adlandırılmamış takvim",
    "Shared with you by" : "Sizinle paylaşan",
    "Edit and share calendar" : "Takvimi düzenle ve paylaş",
    "Edit calendar" : "Takvimi düzenle",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Takvim {countdown} saniye içinde paylaşımdan kaldırılacak","Takvim {countdown} saniye içinde paylaşımdan kaldırılacak"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Takvim {countdown} saniye içinde silinecek","Takvim {countdown} saniye içinde silinecek"],
    "An error occurred, unable to create the calendar." : "Bir sorun çıktı. Takvim eklenemedi.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Lütfen geçerli bir bağlantı yazın (http://, https://, webcal:// ya da webcals:// ile başlayan)",
    "Calendars" : "Takvimler",
    "Add new" : "Yeni ekle",
    "New calendar" : "Takvim ekle",
    "Name for new calendar" : "Yeni takvimin adı",
    "Creating calendar …" : "Takvim oluşturuluyor …",
    "New calendar with task list" : "Görev listesi ile yeni takvim",
    "New subscription from link (read-only)" : "Bağlantıdan yeni abonelik (salt okunur)",
    "Creating subscription …" : "Abonelik oluşturuluyor …",
    "Add public holiday calendar" : "Resmi tatil takvimi ekle",
    "Add custom public calendar" : "Özel herkese açık takvim ekle",
    "Calendar link copied to clipboard." : "Takvim bağlantısı panoya kopyalandı.",
    "Calendar link could not be copied to clipboard." : "Takvim bağlantısı panoya kopyalanamadı.",
    "Copy subscription link" : "Abonelik bağlantısını kopyala",
    "Copying link …" : "Bağlantı kopyalanıyor …",
    "Copied link" : "Bağlantı kopyalandı",
    "Could not copy link" : "Bağlantı kopyalanamadı",
    "Export" : "Dışa aktar",
    "Untitled item" : "Adlandırılmamış öge",
    "Unknown calendar" : "Bilinmeyen takvim",
    "Could not load deleted calendars and objects" : "Silinmiş takvim ve nesneler yüklenemedi",
    "Could not delete calendar or event" : "Takvim ya da etkinlik silinemedi",
    "Could not restore calendar or event" : "Takvim ya da etkinlik geri yüklenemedi",
    "Do you really want to empty the trash bin?" : "Çöp kutusunu boşaltmak istediğinize emin misiniz?",
    "Empty trash bin" : "Çöp kutusunu boşalt",
    "Trash bin" : "Çöp kutusu",
    "Loading deleted items." : "Silinmiş ögeler yükleniyor.",
    "You do not have any deleted items." : "Silinmiş herhangi bir ögeniz yok.",
    "Name" : "Ad",
    "Deleted" : "Silinmiş",
    "Restore" : "Geri yükle",
    "Delete permanently" : "Kalıcı olarak sil",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Çöp kutusundaki ögeler {numDays} gün sonra silinir","Çöp kutusundaki ögeler {numDays} gün sonra silinir"],
    "Could not update calendar order." : "Takvim sıralaması güncellenemedi.",
    "Shared calendars" : "Paylaşılan takvimler",
    "Deck" : "Tahta",
    "Internal link" : "İç bağlantı",
    "A private link that can be used with external clients" : "Dış istemcilerle kullanılabilecek özel bir bağlantı",
    "Copy internal link" : "İç bağlantıyı kopyala",
    "An error occurred, unable to publish calendar." : "Bir sorun çıktı. Takvim yayınlanamadı.",
    "An error occurred, unable to send email." : "Bir sorun çıktığından e-posta gönderilemedi.",
    "Embed code copied to clipboard." : "Gömme kodu panoya kopyalandı.",
    "Embed code could not be copied to clipboard." : "Gömme kodu panoya kopyalanamadı.",
    "Unpublishing calendar failed" : "Takvim yayından kaldırılamadı",
    "Share link" : "Paylaşım bağlantısı",
    "Copy public link" : "Herkese açık bağlantıyı kopyala",
    "Send link to calendar via email" : "Takvim bağlantısını e-posta ile gönder",
    "Enter one address" : "Bir adres yazın",
    "Sending email …" : "E-posta kaydediliyor…",
    "Copy embedding code" : "Gömme kodunu kopyala",
    "Copying code …" : "Kod kopyalanıyor …",
    "Copied code" : "Kod kopyalandı",
    "Could not copy code" : "Kod kopyalanamadı",
    "Delete share link" : "Paylaşım bağlantısını sil",
    "Deleting share link …" : "Paylaşım bağlantısı siliniyor …",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Takım)",
    "An error occurred while unsharing the calendar." : "Takvim paylaşımdan kaldırılırken bir sorun çıktı",
    "An error occurred, unable to change the permission of the share." : "Bir sorun çıktı. Takvimin izin ayarı değiştirilemedi.",
    "can edit and see confidential events" : "düzenleyebilir ve gizli etkinlikleri görebilir",
    "Unshare with {displayName}" : "{displayName} ile paylaşımı kaldır",
    "Share with users or groups" : "Kullanıcı ya da gruplar ile paylaş",
    "No users or groups" : "Herhangi bir kullanıcı ya da grup yok",
    "Failed to save calendar name and color" : "Takvim adı ve rengi kaydedilemedi",
    "Calendar name …" : "Takvim adı…",
    "Never show me as busy (set this calendar to transparent)" : "Beni asla meşgul olarak gösterme (bu takvimi şeffaf olarak ayarla)",
    "Share calendar" : "Takvimi paylaş",
    "Unshare from me" : "Benimle paylaşımı kaldır",
    "Save" : "Kaydet",
    "No title" : "Başlıksız",
    "Are you sure you want to delete \"{title}\"?" : "\"{title}\" toplantı önerisini silmek istediğinize emin misiniz?",
    "Deleting proposal \"{title}\"" : "\"{title}\" toplantı önerisi siliniyor",
    "Successfully deleted proposal" : "Toplantı önerisi silindi",
    "Failed to delete proposal" : "Toplantı önerisi silinemedi",
    "Failed to retrieve proposals" : "Toplantı önerileri alınamadı",
    "Meeting proposals" : "Toplantı önerileri",
    "A configured email address is required to use meeting proposals" : "Toplantı önerilerini kullanabilmek için bir e-posta adresi ayarlanmış olmalıdır",
    "No active meeting proposals" : "Herhangi bir etkin toplantı önerisi yok",
    "View" : "Görüntüle",
    "Import calendars" : "Takvimleri içe aktar",
    "Please select a calendar to import into …" : "Lütfen içine aktarılacak bir takvim seçin…",
    "Filename" : "Dosya adı",
    "Calendar to import into" : "İçine aktarılacak takvim",
    "Cancel" : "İptal",
    "_Import calendar_::_Import calendars_" : ["Takvimi içe aktar","Takvimleri içe aktar"],
    "Select the default location for attachments" : "Ek dosyalarının varsayılan konumunu seçin",
    "Pick" : "Seçin",
    "Invalid location selected" : "Seçilen konum geçersiz",
    "Attachments folder successfully saved." : "Ek dosya klasörü kaydedildi.",
    "Error on saving attachments folder." : "Ek dosya klasörü kaydedilirken sorun çıktı.",
    "Attachments folder" : "Ek dosya klasörü",
    "{filename} could not be parsed" : "{filename} işlenemedi",
    "No valid files found, aborting import" : "Geçerli bir dosya bulunamadı, içe aktarım iptal ediliyor",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["%n etkinlik içe aktarıldı","%n etkinlik içe aktarıldı"],
    "Import partially failed. Imported {accepted} out of {total}." : "Etkinliklerin tümü içe aktarılamadı. İçe aktarılan: {accepted}, toplam: {total}.",
    "Automatic" : "Otomatik",
    "Automatic ({timezone})" : "Otomatik ({timezone})",
    "New setting was not saved successfully." : "Yeni ayarlar kaydedilemedi.",
    "Timezone" : "Saat dilimi",
    "Navigation" : "Gezinme",
    "Previous period" : "Önceki dönem",
    "Next period" : "Sonraki dönem",
    "Views" : "Görünümler",
    "Day view" : "Günlük görünüm",
    "Week view" : "Haftalık görünüm",
    "Month view" : "Aylık görünüm",
    "Year view" : "Yıllık görünüm",
    "List view" : "Liste görünümü",
    "Actions" : "İşlemler",
    "Create event" : "Etkinlik ekle",
    "Show shortcuts" : "Kısayolları görüntüle",
    "Editor" : "Düzenleyici",
    "Close editor" : "Düzenleyiciyi kapat",
    "Save edited event" : "Düzenlenmiş etkinliği kaydet",
    "Delete edited event" : "Düzenlenmiş etkinliği sil",
    "Duplicate event" : "Etkinliği çoğalt",
    "or" : "ya da",
    "Calendar settings" : "Takvim ayarları",
    "At event start" : "Etkinlik başlangıcında",
    "No reminder" : "Herhangi bir anımsatıcı yok",
    "Failed to save default calendar" : "Varsayılan takvim kaydedilemedi",
    "General" : "Genel",
    "Availability settings" : "Uygunluk ayarları",
    "CalDAV" : "CalDAV",
    "Access Nextcloud calendars from other apps and devices" : "Nextcloud takvimlerine diğer uygulamalardan ve aygıtlardan erişin",
    "CalDAV URL" : "CalDAV adresi",
    "Appearance" : "Görünüm",
    "Birthday calendar" : "Doğum günü takvimi",
    "Tasks in calendar" : "Görevler takvimde",
    "Weekends" : "Hafta sonları",
    "Week numbers" : "Hafta numaraları",
    "Limit number of events shown in Month view" : "Aylık görünümde görüntülenecek etkinlik sayısı sınırlansın",
    "Density in Day and Week View" : "Gün ve hafta görünümünün yoğunluğu",
    "Editing" : "Düzenleme",
    "Default reminder" : "Varsayılan anımsatıcı",
    "Simple event editor" : "Basit etkinlik düzenleyici",
    "\"More details\" opens the detailed editor" : "\"Ayrıntılar\" ayrıntılı düzenleyiciyi açar",
    "Files" : "Dosyalar",
    "Appointment schedule successfully created" : "Randevu zamanı eklendi",
    "Appointment schedule successfully updated" : "Randevu zamanı güncellendi",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} dakika","{duration} dakika"],
    "0 minutes" : "0 dakika",
    "_{duration} hour_::_{duration} hours_" : ["{duration} saat","{duration} saat"],
    "_{duration} day_::_{duration} days_" : ["{duration} gün","{duration} gün"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} hafta","{duration} hafta"],
    "_{duration} month_::_{duration} months_" : ["{duration} ay","{duration} ay"],
    "_{duration} year_::_{duration} years_" : ["{duration} yıl","{duration} yıl"],
    "To configure appointments, add your email address in personal settings." : "Randevuları yapılandırmak için kişisel ayarlar bölümünden e-posta adresinizi yazın.",
    "Public – shown on the profile page" : "Herkese açık - Profil sayfasında görüntülenir",
    "Private – only accessible via secret link" : "Bireysel - Yalnızca gizli bir bağlantı ile erişilebilir",
    "Appointment schedule saved" : "Randevu zamanlaması kaydedildi",
    "Create appointment schedule" : "Randevu zamanı ekle",
    "Edit appointment schedule" : "Randevu zamanını düzenle",
    "Update" : "Güncelle",
    "Appointment name" : "Randevu adı",
    "Location" : "Konum",
    "Create a Talk room" : "Bir Konuş odası oluştur",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Alınan her randevu için benzersiz bir bağlantı oluşturularak onay e-postası ile gönderilecek.",
    "Description" : "Açıklama",
    "Visibility" : "Görünürlük",
    "Duration" : "Süre",
    "Increments" : "Artımlar",
    "Additional calendars to check for conflicts" : "Çakışmaların denetleneceği diğer takvimler",
    "Pick time ranges where appointments are allowed" : "Randevuların verilebileceği zaman aralıklarını seçin",
    "to" : "ile",
    "Delete slot" : "Aralığı sil",
    "No times set" : "Herhangi bir zaman ayarlanmamış",
    "Add" : "Ekle",
    "Monday" : "Pazartesi",
    "Tuesday" : "Salı",
    "Wednesday" : "Çarşamba",
    "Thursday" : "Perşembe",
    "Friday" : "Cuma",
    "Saturday" : "Cumartesi",
    "Sunday" : "Pazar",
    "Weekdays" : "Hafta içi günleri",
    "Add time before and after the event" : "Etkinlik öncesi ve sonrası zaman ekle",
    "Before the event" : "Etkinlik öncesi",
    "After the event" : "Etkinlik sonrası",
    "Planning restrictions" : "Planlama kısıtlamaları",
    "Minimum time before next available slot" : "Sonraki uygun aralıktan önceki en az süre",
    "Max slots per day" : "Bir gündeki en fazla aralık",
    "Limit how far in the future appointments can be booked" : "Gelecekteki randevuların ne kadar uzağa alınabileceğini sınırlayın",
    "It seems a rate limit has been reached. Please try again later." : "Sınıra ulaşıldı. Lütfen bir süre sonra yeniden deneyin.",
    "Please confirm your reservation" : "Lütfen randevunuzu onaylayın",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Randevu bilgilerinizi içeren bir e-posta gönderildi. Randevunuzu onaylamak için lütfen e-posta içeriğindeki bağlantıya tıklayın. Bu sayfayı kapatabilirsiniz.",
    "Your name" : "Adınız",
    "Your email address" : "E-posta adresiniz",
    "Please share anything that will help prepare for our meeting" : "Lütfen görüşmeye hazırlanmak için yardımcı olabilecek şeyleri paylaşın",
    "Could not book the appointment. Please try again later or contact the organizer." : "Randevu alınamadı. Lütfen bir süre sonra yeniden deneyin ya da düzenleyici ile görüşün.",
    "Back" : "Geri",
    "Book appointment" : "Randevu al",
    "Error fetching Talk conversations." : "Konuş görüşmeleri alınırken sorun çıktı.",
    "Conversation does not have a valid URL." : "Görüşmenin geçerli bir adresi yok.",
    "Successfully added Talk conversation link to location." : "Konuş görüşme bağlantısı konuma eklendi.",
    "Successfully added Talk conversation link to description." : "Konuş görüşme bağlantısı açıklamaya eklendi.",
    "Failed to apply Talk room." : "Konuş odası uygulanamadı.",
    "Talk conversation for event" : "Etkinlik için Konuş görüşmesi",
    "Error creating Talk conversation" : "Konuş görüşmesi oluşturulurken sorun çıktı",
    "Select a Talk Room" : "Bir Konuş odası seçin",
    "Add Talk conversation" : "Konuş görüşmesi ekle",
    "Fetching Talk rooms…" : "Konuş odaları alınıyor…",
    "No Talk room available" : "Kullanılabilecek bir Konuş odası yok",
    "Select conversation" : "Görüşme seçin",
    "on" : "şu gün",
    "at" : "şu saatte",
    "before at" : "şundan önce",
    "Notification" : "Bildirim",
    "Email" : "E-posta",
    "Audio notification" : "Sesli bildirim",
    "Other notification" : "Diğer bildirim",
    "Relative to event" : "Etkinliğe göre",
    "On date" : "Şu tarihte",
    "Edit time" : "Zamanı düzenle",
    "Save time" : "Zamanı kaydet",
    "Remove reminder" : "Anımsatıcıyı kaldır",
    "Add reminder" : "Anımsatıcı ekle",
    "seconds" : "saniye",
    "minutes" : "dakika",
    "hours" : "saat",
    "days" : "gün",
    "weeks" : "hafta",
    "Choose a file to add as attachment" : "Ek dosya olarak eklenecek dosyayı seçin",
    "Choose a file to share as a link" : "Bağlantı olarak paylaşılacak bir dosya seçin",
    "Attachment {name} already exist!" : "{name} ek dosyası zaten var!",
    "Could not upload attachment(s)" : "Ek dosyalar yüklenemedi",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "{host} bağlantısını açmak üzeresiniz. İlerlemek istediğinize emin misiniz? Bağlantı: {link}",
    "Proceed" : "İlerle",
    "No attachments" : "Herhangi bir ek dosya yok",
    "Add from Files" : "Dosyalardan ekle",
    "Upload from device" : "Aygıttan yükle",
    "Delete file" : "Dosyayı sil",
    "Confirmation" : "Onaylama",
    "_{count} attachment_::_{count} attachments_" : ["{count} ek dosya","{count} ek dosya"],
    "Suggested" : "Önerildi",
    "Available" : "Uygun",
    "Invitation accepted" : "Davet kabul edildi",
    "Accepted {organizerName}'s invitation" : "{organizerName} tarafından yapılan davet kabul edildi",
    "Participation marked as tentative" : "Katılım belirsiz olarak işaretlendi",
    "Invitation is delegated" : "Davet iletildi",
    "Not available" : "Kullanılamaz",
    "Invitation declined" : "Davet reddedildi",
    "Declined {organizerName}'s invitation" : "{organizerName} tarafından yapılan davet reddedildi",
    "Availability will be checked" : "Uygunluk denetlenecek",
    "Invitation will be sent" : "Davet gönderilecek",
    "Failed to check availability" : "Uygunluk denetlenemedi",
    "Failed to deliver invitation" : "Davet iletilemedi",
    "Awaiting response" : "Yanıt bekleniyor",
    "Checking availability" : "Uygunluk denetleniyor",
    "Has not responded to {organizerName}'s invitation yet" : "{organizerName} tarafından yapılan daveti yanıtlamadı",
    "Suggested times" : "Önerilen zamanlar",
    "chairperson" : "oturum başkanı",
    "required participant" : "zorunlu katılımcı",
    "non-participant" : "katılımcı değil",
    "optional participant" : "isteğe bağlı katılımcı",
    "{organizer} (organizer)" : "{organizer} (organizer)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Selected slot" : "Seçilmiş aralık",
    "Availability of attendees, resources and rooms" : "Katılımcı, kaynak ve odaların kullanılabilirliği",
    "Suggestion accepted" : "Öneri kabul edildi",
    "Previous date" : "Önceki tarih",
    "Next date" : "Sonraki tarih",
    "Legend" : "İşaret",
    "Out of office" : "İş yeri dışında",
    "Attendees:" : "Katılımcılar:",
    "local time" : "yerel saat",
    "Done" : "Tamamlandı",
    "Search room" : "Oda ara",
    "Room name" : "Oda adı",
    "Check room availability" : "Oda uygunluğuna bak",
    "Free" : "Uygun",
    "Busy (tentative)" : "Meşgul (belirsiz)",
    "Busy" : "Meşgul",
    "Unknown" : "Bilinmiyor",
    "Find a time" : "Bir zaman bulun",
    "The invitation has been accepted successfully." : "Davet kabul edildi.",
    "Failed to accept the invitation." : "Davet kabul edilemedi.",
    "The invitation has been declined successfully." : "Davet reddedildi.",
    "Failed to decline the invitation." : "Davet reddedilemedi.",
    "Your participation has been marked as tentative." : "Katılım durumunuz belirsiz olarak işaretlendi.",
    "Failed to set the participation status to tentative." : "Katılım durumunuz belirsiz olarak işaretlenemedi.",
    "Accept" : "Kabul et",
    "Decline" : "Reddet",
    "Tentative" : "Belirsiz",
    "No attendees yet" : "Henüz bir katılımcı yok",
    "Please add at least one attendee to use the \"Find a time\" feature." : "Lütfen \"Bir zaman bul\" özelliğini kullanmak için en az bir katılımcı ekleyin.",
    "Attendees" : "Katılanlar",
    "Remove group" : "Grubu sil",
    "Remove attendee" : "Katılımcıyı çıkar",
    "Request reply" : "Yanıt iste",
    "Chairperson" : "Oturum başkanı",
    "Required participant" : "Zorunlu katılımcı",
    "Optional participant" : "İsteğe bağlı katılımcı",
    "Non-participant" : "Katılımcı değil",
    "_%n member_::_%n members_" : ["%n üye","%n üye"],
    "Search for emails, users, contacts, contact groups or teams" : "E-posta, kullanıcı, kişi, kişi grubu ya da takım arayın",
    "No match found" : "Herhangi bir sonuç bulunamadı",
    "Note that members of circles get invited but are not synced yet." : "Takım üyelerinin davet edildiğini ancak henüz eşitlenmediğini unutmayın.",
    "Note that members of contact groups get invited but are not synced yet." : "Kişi gruplarının üyelerinin davet edildiğini ancak henüz eşitlenmediğini unutmayın.",
    "(organizer)" : "(düzenleyen)",
    "Make {label} the organizer" : "{label} düzenleyici olsun",
    "Make {label} the organizer and attend" : "{label} düzenleyici olsun ve katıl",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Davet göndermek ve yanıtları işlemek için, [linkopen]kişisel ayarlar bölümünden e-posta adresinizi ekleyin[linkclose].",
    "Remove color" : "Rengi kaldır",
    "Event title" : "Etkinlik başlığı",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Bir yinelenme kümesinin ögesi olan etkinlikler tüm gün olarak ayarlanamaz.",
    "From" : "Başlangıç",
    "To" : "Bitiş",
    "Your Time" : "Zamanınız",
    "Repeat" : "Yineleme",
    "Repeat event" : "Etkinlik yinelensin",
    "_time_::_times_" : ["kez","kez"],
    "never" : "asla",
    "on date" : "şu tarihte",
    "after" : "şundan sonra",
    "End repeat" : "Yinelenme sonu",
    "Select to end repeat" : "Yinelenme sonunu seçin",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Bu etkinlik bir yinelenen etkinlik kümesinin ögesi. Bu nedenle bu ögeye bir yinelenme kuralı ekleyemezsiniz.",
    "first" : "birinci",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Yinelenme kuralındaki değişiklikler yalnızca bu ve sonraki etkinlikler için geçerli olacak.",
    "Repeat every" : "Yinelenme sıklığı",
    "By day of the month" : "Ayın gününde",
    "On the" : "Şu zamanda",
    "_day_::_days_" : ["gün","gün"],
    "_week_::_weeks_" : ["hafta","hafta"],
    "_month_::_months_" : ["ay","ay"],
    "_year_::_years_" : ["yıl","yıl"],
    "On specific day" : "Belirli günde",
    "weekday" : "hafta içi günleri",
    "weekend day" : "hafta sonu günü",
    "Does not repeat" : "Yinelenmiyor",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Bu etkinliğin yinelenme ayarları Nextcloud tarafından tam olarak desteklenmiyor. Yinelenme ayarlarını düzenlerseniz yinelenen bazı etkinlikler kaybolabilir.",
    "No rooms or resources yet" : "Henüz bir oda ya da kaynak yok",
    "Resources" : "Kaynaklar",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} koltuk","{seatingCapacity} koltuk"],
    "Add resource" : "Kaynak ekle",
    "Has a projector" : "Projeksiyon var",
    "Has a whiteboard" : "Beyaz Tahta var",
    "Wheelchair accessible" : "Tekerlekli sandalyeye uygun",
    "Remove resource" : "Kaynağı sil",
    "Search for resources or rooms" : "Kaynak ya da oda ara",
    "available" : "kullanılabilir",
    "unavailable" : "kullanılamaz",
    "Show all rooms" : "Tüm odaları görüntüle",
    "Projector" : "Projeksiyon",
    "Whiteboard" : "Beyaz Tahta",
    "Room type" : "Oda türü",
    "Any" : "Tümü",
    "Minimum seating capacity" : "En az oturma yeri sayısı",
    "More details" : "Ayrıntılar",
    "Update this and all future" : "Bu ve sonraki etkinlikleri güncelle",
    "Update this occurrence" : "Bu etkinliği güncelle",
    "Public calendar does not exist" : "Herkese açık takvim bulunamadı",
    "Maybe the share was deleted or has expired?" : "Paylaşım silinmiş ya da geçerlilik süresi dolmuş olabilir mi?",
    "Remove date" : "Tarihi kaldır",
    "Attendance required" : "Katılım zorunlu",
    "Attendance optional" : "Katılım isteğe bağlı",
    "Remove participant" : "Katılımcıyı çıkar",
    "Yes" : "Evet",
    "No" : "Hayır",
    "Maybe" : "Belki",
    "None" : "Yok",
    "Select your meeting availability" : "Toplantınızın uygunluğunu seçin",
    "Create a meeting for this date and time" : "Bu tarih ve saatte bir toplantı oluştur",
    "Create" : "Oluştur",
    "No participants or dates available" : "Hiç bir katılımcı ya da tarih uygun değil",
    "from {formattedDate}" : "{formattedDate} tarihinden",
    "to {formattedDate}" : "{formattedDate} tarihine",
    "on {formattedDate}" : "{formattedDate} tarihinde",
    "from {formattedDate} at {formattedTime}" : "{formattedDate} tarihi {formattedTime} saatinden",
    "to {formattedDate} at {formattedTime}" : "{formattedDate} tarihi {formattedTime} saatine",
    "on {formattedDate} at {formattedTime}" : "{formattedDate} tarihi {formattedTime} saatinde",
    "{formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime} saatinde",
    "Please enter a valid date" : "Lütfen geçerli bir tarih yazın",
    "Please enter a valid date and time" : "Lütfen geçerli bir tarih ve saat yazın",
    "Select a time zone" : "Bir saat dilimi seçin",
    "Please select a time zone:" : "Lütfen bir saat dilimi seçin:",
    "Pick a time" : "Bir saat seçin",
    "Pick a date" : "Bir tarih seçin",
    "Type to search time zone" : "Saat dilimi aramak için yazmaya başlayın",
    "Global" : "Genel",
    "Holidays in {region}" : "{region} tatilleri",
    "An error occurred, unable to read public calendars." : "Bir sorun çıktı. Herkese açık takvimler okunamadı.",
    "An error occurred, unable to subscribe to calendar." : "Bir sorun çıktı. Takvime abone olunamadı.",
    "Public holiday calendars" : "Resmi tatil takvimleri",
    "Public calendars" : "Herkese açık takvimler",
    "No valid public calendars configured" : "Yapılandırılmış geçerli bir herkese açık takvim yok",
    "Speak to the server administrator to resolve this issue." : "Lütfen bu sorunu çözmesi için sunucu yöneticiniz ile görüşün.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Resmi tatil takvimleri Thunderbird tarafından sağlanır. Takvim verileri {website} üzerinden indirilir",
    "These public calendars are suggested by the server administrator. Calendar data will be downloaded from the respective website." : "Sunucu yöneticisi şu herkese açık takvimleri öneriyor. Takvim verileri ilgili siteden indirilir.",
    "By {authors}" : "{authors} tarafından",
    "Subscribed" : "Abone olundu",
    "Subscribe" : "Abone ol",
    "Could not fetch slots" : "Aralıklar alınamadı",
    "Select a date" : "Bir tarih seçin",
    "Select slot" : "Aralık seçin",
    "No slots available" : "Seçilebilecek bir aralık yok",
    "The slot for your appointment has been confirmed" : "Randevunuzun aralığı onaylandı",
    "Appointment Details:" : "Randevu bilgileri:",
    "Time:" : "Saat:",
    "Booked for:" : "Ayırtılan:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Teşekkürler. {startDate} - {endDate} randevunuz onaylandı.",
    "Book another appointment:" : "Başka bir randevu daha al:",
    "See all available slots" : "Tüm aralıkları görüntüle",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Randevunuzun {startDate} - {endDate} aralığı artık uygun değil.",
    "Please book a different slot:" : "Lütfen farklı bir aralık seçin:",
    "Book an appointment with {name}" : "{name} için bir randevu alın",
    "No public appointments found for {name}" : "{name} için herkese açık bir randevu bulunamadı",
    "Personal" : "Kişisel",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Otomatik saat dilimi algılaması saat diliminizi UTC olarak belirledi.\nBu durum genellikle tarayıcınızın sağladığı bir güvenlik önleminden kaynaklanır.\nLütfen takvim ayarları bölümünden saat diliminizi el ile ayarlayın.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Yapılandırılmış saat diliminiz {{timezoneId}} bulunamadı. UTC dilimine dönülüyor.\nLütfen ayarlar bölümünden saat diliminizi değiştirin ve bu sorunu bildirin.",
    "Show unscheduled tasks" : "Zamanlanmamış görevleri görüntüle",
    "Unscheduled tasks" : "Zamanlanmamış görevler",
    "Availability of {displayName}" : "{displayName} uygunluğu",
    "Discard event" : "Etkinliği sil",
    "Edit event" : "Etkinliği düzenle",
    "Event does not exist" : "Etkinlik bulunamadı",
    "Duplicate" : "Çoğalt",
    "Delete this occurrence" : "Bu etkinliği sil",
    "Delete this and all future" : "Bu ve sonraki etkinlikleri sil",
    "All day" : "Tüm gün",
    "Modifications wont get propagated to the organizer and other attendees" : "Değişiklikler düzenleyiciye ve diğer katılımcılara iletilmeyecek",
    "Managing shared access" : "Paylaşılmış erişim yönetimi",
    "Deny access" : "Erişimi reddet",
    "Invite" : "Çağır",
    "Discard changes?" : "Değişikler yok sayılsın mı?",
    "Are you sure you want to discard the changes made to this event?" : "Bu etkinlikte yaptığınız değişiklikleri yok saymak istediğinize emin misiniz?",
    "_User requires access to your file_::_Users require access to your file_" : ["Dosyanıza erişme izni isteyen kullanıcı","Dosyanıza erişme izni isteyen kullanıcılar"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Paylaşılmış erişim gereken ek dosya","Paylaşılmış erişim gereken ek dosyalar"],
    "Untitled event" : "Adlandırılmamış etkinlik",
    "Close" : "Kapat",
    "Modifications will not get propagated to the organizer and other attendees" : "Değişiklikler düzenleyiciye ve diğer katılımcılara iletilmeyecek",
    "Meeting proposals overview" : "Toplantı önerileri özeti",
    "Edit meeting proposal" : "Toplantı önerisini düzenle",
    "Create meeting proposal" : "Toplantı önerisi oluştur",
    "Update meeting proposal" : "Toplantı önerisini güncelle",
    "Saving proposal \"{title}\"" : "\"{title}\" toplantı önerisi kaydediliyor",
    "Successfully saved proposal" : "Toplantı önerisi kaydedildi",
    "Failed to save proposal" : "Toplantı önerisi kaydedilemedi",
    "Create a meeting for \"{date}\"? This will create a calendar event with all participants." : "\"{date}\" için bir toplantı oluşturulsun mu? Tüm katılımcılar ile bir takvim etkinliği oluşturulacak.",
    "Creating meeting for {date}" : "{date} için toplantı oluşturuluyor",
    "Successfully created meeting for {date}" : "{date} için toplantı oluşturuldu",
    "Failed to create a meeting for {date}" : "{date} için toplantı oluşturulamadı",
    "Please enter a valid duration in minutes." : "Lütfen dakika olarak geçerli bir süre yazın.",
    "Failed to fetch proposals" : "Toplantı önerileri alınamadı",
    "Failed to fetch free/busy data" : "Serbest/meşgul verileri alınamadı",
    "Selected" : "Seçilmiş",
    "No Description" : "Açıklama belirtilmemiş",
    "No Location" : "Konum belirtilmemiş",
    "Edit this meeting proposal" : "Bu toplantı önerisini düzenle",
    "Delete this meeting proposal" : "Bu toplantı önerisini sil",
    "Title" : "Başlık",
    "15 min" : "15 dakika",
    "30 min" : "30 dakika",
    "60 min" : "60 dakika",
    "90 min" : "90 dakika",
    "Participants" : "Katılımcılar",
    "Selected times" : "Seçilmiş zamanlar",
    "Previous span" : "Önceki aralık",
    "Next span" : "Sonraki aralık",
    "Less days" : "Daha az gün",
    "More days" : "Daha çok gün",
    "Loading meeting proposal" : "Toplantı önerileri yükleniyor",
    "No meeting proposal found" : "Herhangi bir toplantı önerisi bulunamadı",
    "Please wait while we load the meeting proposal." : "Toplantı önerisi yükleniyor. Lütfen bekleyin.",
    "The link you followed may be broken, or the meeting proposal may no longer exist." : "Kullandığınız bağlantı geçersiz olabilir ya da toplantı önerisi artık yok.",
    "Thank you for your response!" : "Yanıt verdiğiniz için teşekkür ederiz!",
    "Your vote has been recorded. Thank you for participating!" : "Oyunuz kaydedildi. Katıldığınız için teşekkür ederiz!",
    "Unknown User" : "Kullanıcı bilinmiyor",
    "No Title" : "Başlıksız",
    "No Duration" : "Süre belirtilmemiş",
    "Select a different time zone" : "Farklı bir saat dilimi seçin",
    "Submit" : "Gönder",
    "Subscribe to {name}" : "{name} takvimine abone ol",
    "Export {name}" : "{name} dışa aktar",
    "Show availability" : "Uygunluğu görüntüle",
    "Anniversary" : "Yıl dönümü",
    "Appointment" : "Randevu",
    "Business" : "İş",
    "Education" : "Eğitim",
    "Holiday" : "Tatil",
    "Meeting" : "Toplantı",
    "Miscellaneous" : "Diğer",
    "Non-working hours" : "Çalışma dışı saatler",
    "Not in office" : "İş yerinde değil",
    "Phone call" : "Telefon çağrısı",
    "Sick day" : "Hastalık",
    "Special occasion" : "Özel durum",
    "Travel" : "Gezi",
    "Vacation" : "Tatil",
    "Midnight on the day the event starts" : "Etkinliğin başladığı günün gece yarısı",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["etkinlikten %n gün önce {formattedHourMinute}","etkinlikten %n gün önce {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["etkinlikten %n hafta önce {formattedHourMinute}","etkinlikten %n hafta önce {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "etkinlik gününde {formattedHourMinute} saatinde",
    "at the event's start" : "etkinlik başlangıcında",
    "at the event's end" : "etkinlik bitiminde",
    "{time} before the event starts" : "etkinlik başlamadan {time} önce",
    "{time} before the event ends" : "etkinlik bitiminden {time} önce",
    "{time} after the event starts" : "etkinlik başlangıcından {time} sonra",
    "{time} after the event ends" : "etkinlik bitiminden {time} sonra",
    "on {time}" : "{time} saatinde",
    "on {time} ({timezoneId})" : "{time} ({timezoneId}) zamanında",
    "Week {number} of {year}" : "{year} yılının {number}. haftasında",
    "Daily" : "Günlük",
    "Weekly" : "Haftalık",
    "Monthly" : "Aylık",
    "Yearly" : "Yıllık",
    "_Every %n day_::_Every %n days_" : ["1%n günde bir","1%n günde bir"],
    "_Every %n week_::_Every %n weeks_" : ["1%n haftada bir","1%n haftada bir"],
    "_Every %n month_::_Every %n months_" : ["1%n ayda bir","1%n ayda bir"],
    "_Every %n year_::_Every %n years_" : ["1%n yılda bir","1%n yılda bir"],
    "_on {weekday}_::_on {weekdays}_" : ["{weekday} gününde","{weekdays} günlerinde"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["{dayOfMonthList} gününde","{dayOfMonthList} günlerinde"],
    "on the {ordinalNumber} {byDaySet}" : "{ordinalNumber} {byDaySet} gününde",
    "in {monthNames} on the {dayOfMonthList}" : "{monthNames} ayı {dayOfMonthList} gününde",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "{monthNames} aylarında {ordinalNumber} {byDaySet} gününde",
    "until {untilDate}" : "{untilDate} tarihine kadar",
    "_%n time_::_%n times_" : ["%n kez","%n kez"],
    "second" : "saniye",
    "third" : "üçüncü",
    "fourth" : "dördüncü",
    "fifth" : "beşinci",
    "second to last" : "ikinciden sonuncuya",
    "last" : "sonuncu",
    "Untitled task" : "Adlandırılmamış görev",
    "Please ask your administrator to enable the Tasks App." : "Lütfen Görevler uygulamasını kullanıma alması için BT yöneticiniz ile görüşün.",
    "You are not allowed to edit this event as an attendee." : "Bir katılımcı olarak bu etkinliği düzenleme izniniz yok.",
    "W" : "W",
    "%n more" : "%n diğer",
    "No events to display" : "Görüntülenebilecek bir etkinlik yok",
    "All participants declined" : "Tüm katılımcılar katılmayı reddetti",
    "Please confirm your participation" : "Lütfen katılacağınızı onaylayın",
    "You declined this event" : "Bu etkinliğe katılmayı reddettiniz",
    "Your participation is tentative" : "Katılım durumunuz belirsiz",
    "_+%n more_::_+%n more_" : ["+%n diğer","+%n diğer"],
    "No events" : "Henüz bir etkinlik yok",
    "Create a new event or change the visible time-range" : "Yeni bir etkinlik ekleyin ya da görüntülenen zaman aralığını değiştirin",
    "Failed to save event" : "Etkinlik kaydedilemedi",
    "It might have been deleted, or there was a typo in a link" : "Silinmiş olabilir ya da bir bağlantıda bir yazım hatası var",
    "It might have been deleted, or there was a typo in the link" : "Silinmiş olabilir ya da bağlantıda bir yazım hatası var",
    "Meeting room" : "Toplantı odası",
    "Lecture hall" : "Konferans salonu",
    "Seminar room" : "Seminer odası",
    "Other" : "Diğer",
    "When shared show" : "Paylaşıldığında görüntülenecek",
    "When shared show full event" : "Paylaşıldığında tüm etkinlik ayrıntıları görüntülensin",
    "When shared show only busy" : "Paylaşıldığında yalnızca meşgul olarak görüntülensin",
    "When shared hide this event" : "Paylaşıldığında bu etkinlik gizlensin",
    "The visibility of this event in read-only shared calendars." : "Bu etkinliğin paylaşılmış salt okunur takvimlerdeki görünümü.",
    "Add a location" : "Bir konum ekleyin",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Bir açıklama yazın\n\n- Bu toplantı neyle ilgili\n- Gündem maddeleri\n- Katılımcıların hazırlaması gereken her şey",
    "Status" : "Durum",
    "Confirmed" : "Kabul edildi",
    "Canceled" : "İptal edildi",
    "Confirmation about the overall status of the event." : "Etkinliğin genel kabul edilme durumu.",
    "Show as" : "Şu şekilde görüntülensin",
    "Take this event into account when calculating free-busy information." : "Uygun, meşgul zamanlar hesaplanırken bu etkinlik hesaba katılsın.",
    "Categories" : "Kategoriler",
    "Categories help you to structure and organize your events." : "Kategorileri kullanarak etkinliklerinizi düzenleyebilirsiniz.",
    "Search or add categories" : "Kategori ara ya da ekle",
    "Add this as a new category" : "Bunu yeni bir kategori olarak ekle",
    "Custom color" : "Özel renk",
    "Special color of this event. Overrides the calendar-color." : "Özel etkinlik rengi, takvim renginin yerine kullanılır.",
    "Error while sharing file" : "Dosya paylaşılırken sorun çıktı",
    "Error while sharing file with user" : "Dosya kullanıcı ile paylaşılırken sorun çıktı",
    "Error creating a folder {folder}" : "{folder} klasörü oluşturulurken sorun çıktı",
    "Attachment {fileName} already exists!" : "{fileName} ek dosyası zaten var!",
    "Attachment {fileName} added!" : "{fileName} dosyası eklendi!",
    "An error occurred during uploading file {fileName}" : "{fileName} dosyası yüklenirken bir sorun çıktı",
    "An error occurred during getting file information" : "Dosya bilgileri alınırken bir sorun çıktı",
    "Talk conversation for proposal" : "Öneri için Konuş görüşmesi",
    "An error occurred, unable to delete the calendar." : "Bir sorun çıktı. Takvim silinemedi.",
    "Imported {filename}" : "{filename} içe aktarıldı",
    "This is an event reminder." : "Bu bir etkinlik hatırlatıcısıdır.",
    "Error while parsing a PROPFIND error" : "PROPFIND hatası işlenirken sorun çıktı",
    "Appointment not found" : "Randevu bulunamadı",
    "User not found" : "Kullanıcı bulunamadı",
    "Hidden" : "Gizli",
    "can edit" : "düzenleyebilir",
    "Calendar name …" : "Takvim adı…",
    "Default attachments location" : "Ek dosyaların varsayılan konumu",
    "Automatic ({detected})" : "Otomatik ({detected})",
    "Shortcut overview" : "Kısayol özeti",
    "CalDAV link copied to clipboard." : "CalDAV bağlantısı panoya kopyalandı.",
    "CalDAV link could not be copied to clipboard." : "CalDAV bağlantısı panoya kopyalanamadı.",
    "Enable birthday calendar" : "Doğum günü takvimi kullanılsın",
    "Show tasks in calendar" : "Görevler takvimde görüntülensin",
    "Enable simplified editor" : "Basitleştirilmiş düzenleyici kullanılsın",
    "Limit the number of events displayed in the monthly view" : "Aylık görünümde görüntülenecek etkinlik sayısı sınırlansın",
    "Show weekends" : "Hafta sonları görüntülensin",
    "Show week numbers" : "Hafta numaraları görüntülensin",
    "Time increments" : "Zaman artışı",
    "Default calendar for incoming invitations" : "Gelen davetler için varsayılan takvim",
    "Copy primary CalDAV address" : "Birincil CalDAV adresini kopyala",
    "Copy iOS/macOS CalDAV address" : "iOS/macOS CalDAV adresini kopyala",
    "Personal availability settings" : "Kişisel uygunluk ayarları",
    "Show keyboard shortcuts" : "Kısayol tuşlarını görüntüle",
    "Create a new public conversation" : "Yeni bir herkese açık görüşme oluştur",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} davet edildi, {confirmedCount} kabul etti",
    "Successfully appended link to talk room to location." : "Bağlantı konumu Konuş odasına eklendi.",
    "Successfully appended link to talk room to description." : "Bağlantı Konuş odası açıklamasına eklendi.",
    "Error creating Talk room" : "Konuş odası oluştururken sorun çıktı",
    "_%n more guest_::_%n more guests_" : ["%n diğer konuk","%n diğer konuk"],
    "The visibility of this event in shared calendars." : "Bu etkinliğin paylaşılmış takvimlerdeki görünümü."
},
"nplurals=2; plural=(n > 1);");
