OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Podany adres e-mail jest za długi",
    "User-Session unexpectedly expired" : "Sesja użytkownika nieoczekiwanie wygasła",
    "Provided email-address is not valid" : "Podany adres e-mail jest nieprawidłowy",
    "%s has published the calendar »%s«" : "%s publikuje kalendarz »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Nieoczekiwany błąd podczas wysyłania wiadomości e-mail. Skontaktuj się z administratorem.",
    "Successfully sent email to %1$s" : "Pomyślnie wysłano wiadomość e-mail do %1$s",
    "Hello," : "Witaj,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Chcieliśmy poinformować, że %s udostępnia kalendarz %s.",
    "Open »%s«" : "Otwórz »%s«",
    "Cheers!" : "Zdrówko!",
    "Upcoming events" : "Nadchodzące wydarzenia",
    "No more events today" : "Nie ma więcej wydarzeń na dzisiaj",
    "No upcoming events" : "Brak nadchodzących wydarzeń",
    "More events" : "Więcej wydarzeń",
    "%1$s with %2$s" : "%1$s przez %2$s",
    "Calendar" : "Kalendarz",
    "New booking {booking}" : "Nowa rezerwacja {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) rezerwuje spotkanie \"{config_display_name}\" dnia {date_time}.",
    "Appointments" : "Spotkania",
    "Schedule appointment \"%s\"" : "Umówione spotkanie \"%s\"",
    "Schedule an appointment" : "Umów się na spotkanie",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : "Przygotuj się na %s",
    "Follow up for %s" : "Obserwuj %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Twoje spotkanie \"%s\" z %s wymaga potwierdzenia",
    "Dear %s, please confirm your booking" : "%s, proszę o potwierdzenie rezerwacji",
    "Confirm" : "Potwierdź",
    "Appointment with:" : "Spotkanie z:",
    "Description:" : "Opis:",
    "This confirmation link expires in %s hours." : "Ten link potwierdzający wygaśnie za %s godzin.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Jeśli mimo wszystko chcesz anulować spotkanie, skontaktuj się z organizującą je osobą, odpowiadając na ten e-mail lub odwiedzając jej stronę profilu.",
    "Your appointment \"%s\" with %s has been accepted" : "Twoje spotkanie \"%s\" z %s zostało zaakceptowane",
    "Dear %s, your booking has been accepted." : "%s, Twoja rezerwacja została zaakceptowana.",
    "Appointment for:" : "Spotkanie na:",
    "Date:" : "Data:",
    "You will receive a link with the confirmation email" : "Otrzymasz wiadomość e-mail z linkiem weryfikacyjnym",
    "Where:" : "Gdzie:",
    "Comment:" : "Komentarz:",
    "You have a new appointment booking \"%s\" from %s" : "Masz nową rezerwację spotkania \"%s\" z %s",
    "Dear %s, %s (%s) booked an appointment with you." : "%s, %s (%s) rezerwuje czas na spotkanie z tobą.",
    "%s has proposed a meeting" : "%s zaproponował spotkanie",
    "%s has updated a proposed meeting" : "%s zaktualizował proponowane spotkanie",
    "%s has canceled a proposed meeting" : "%s anulował proponowane spotkanie",
    "Dear %s, a new meeting has been proposed" : "Drogi(a) %s, zaproponowano nowe spotkanie",
    "Dear %s, a proposed meeting has been updated" : "Drogi(a) %s, proponowane spotkanie zostało zaktualizowane",
    "Dear %s, a proposed meeting has been cancelled" : "Drogi(a) %s, proponowane spotkanie zostało anulowane",
    "Location:" : "Lokalizacja:",
    "Duration:" : "Czas trwania:",
    "%1$s from %2$s to %3$s" : "%1$s od %2$s do %3$s ",
    "Dates:" : "Daty:",
    "Respond" : "Odpowiedz",
    "A Calendar app for Nextcloud" : "Aplikacja Kalendarz dla Nextcloud",
    "A Calendar app for Nextcloud. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Like Contacts, Talk, Tasks, Deck and Circles\n* 🌐 **WebCal Support!** Want to see your favorite team's matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 **Search!** Find your events at ease\n* ☑️ **Tasks!** See tasks or Deck cards with a due date directly in the calendar\n* 🔈 **Talk rooms!** Create an associated Talk room when booking a meeting with just one click\n* 📆 **Appointment booking** Send people a link so they can book an appointment with you [using this app](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Attachments!** Add, upload and view event attachments\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Aplikacja kalendarza dla Nextcloud. Łatwo synchronizuj wydarzenia z różnych urządzeń z Nextcloud i edytuj je online.\n\n* 🚀 **Integracja z innymi aplikacjami Nextcloud, takimi jak Kontakty, Talk, Zadania, Deck i Kręgi.\n* 🌐 **Wsparcie WebCal!** Chcesz zobaczyć dni meczów swojej ulubionej drużyny w kalendarzu? Nie ma problemu! \n* 🙋 **Uczestnicy!** Zapraszaj ludzi na swoje wydarzenia\n* ⌚ **Wolny/zajęty!** Zobacz, kiedy potencjalni uczestnicy są dostępni, aby się spotkać\n* ⏰ **Przypomnienia!** Otrzymuj alarmy o wydarzeniach w przeglądarce i przez e-mail\n* 🔍 **Szukaj!** Znajdź swoje wydarzenia z łatwością\n* ☑️ **Zadania!** Zobacz zadania lub karty Deck z terminem realizacji bezpośrednio w kalendarzu\n* 🔈 **Pokoje rozmów!** Utwórz powiązany pokój rozmów podczas rezerwacji spotkania jednym kliknięciem\n* 📆 **Bookowanie spotkań** Wyślij ludziom link, pozwalający zarezerwować spotkanie z Tobą [za pomocą tej aplikacji] (https://apps.nextcloud.com/apps/appointments)\n* 📎 **Załączniki!** Dodawanie, przesyłanie i przeglądanie załączników do wydarzeń\n* 🙈 **Nie wymyślamy nic od zera** oparte na świetnych bibliotekach [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) i [fullcalendar](https://github.com/fullcalendar/fullcalendar).",
    "Previous day" : "Poprzedni dzień",
    "Previous week" : "Poprzedni tydzień",
    "Previous year" : "Poprzedni rok",
    "Previous month" : "Poprzedni miesiąc",
    "Next day" : "Następny dzień",
    "Next week" : "Następny tydzień",
    "Next year" : "Następny rok",
    "Next month" : "Następny miesiąc",
    "Create new event" : "Utwórz nowe wydarzenie",
    "Event" : "Wydarzenie",
    "Today" : "Dzisiaj",
    "Day" : "Dzień",
    "Week" : "Tydzień",
    "Month" : "Miesiąc",
    "Year" : "Rok",
    "List" : "Lista",
    "Appointment link was copied to clipboard" : "Link do spotkania został skopiowany do schowka",
    "Appointment link could not be copied to clipboard" : "Nie udało się skopiować linku do spotkania do schowka",
    "Preview" : "Podgląd",
    "Copy link" : "Kopiuj link",
    "Edit" : "Edytuj",
    "Delete" : "Usuń",
    "Appointment schedules" : "Harmonogramy spotkań",
    "Create new" : "Utwórz nowy",
    "Disable calendar \"{calendar}\"" : "Wyłącz kalendarz \"{calendar}\"",
    "Disable untitled calendar" : "Wyłącz kalendarz bez tytułu",
    "Enable calendar \"{calendar}\"" : "Włącz kalendarz \"{calendar}\"",
    "Enable untitled calendar" : "Włącz kalendarz bez tytułu",
    "An error occurred, unable to change visibility of the calendar." : "Wystąpił błąd, nie można zmienić widoczności kalendarza.",
    "Untitled calendar" : "Kalendarz bez tytułu",
    "Shared with you by" : "Udostępnione Tobie przez",
    "Edit and share calendar" : "Edytuj i udostępnij kalendarz",
    "Edit calendar" : "Edytuj kalendarz",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Zatrzymywanie udostępnienia kalendarza za {countdown} sekundę","Zatrzymywanie udostępnienia kalendarza za {countdown} sekundy","Zatrzymywanie udostępnienia kalendarza za {countdown} sekund","Zatrzymywanie udostępnienia kalendarza za {countdown} sekund"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Usuwanie kalendarza za {countdown} sekundę","Usuwanie kalendarza za {countdown} sekundy","Usuwanie kalendarza za {countdown} sekund","Usunięcie kalendarza za {countdown} sekund"],
    "An error occurred, unable to create the calendar." : "Wystąpił błąd, nie można utworzyć kalendarza.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Wprowadź poprawny link (zaczynający się od http://, https://, webcal://, lub webcals://)",
    "Calendars" : "Kalendarze",
    "Add new" : "Dodaj nowe",
    "New calendar" : "Nowy kalendarz",
    "Name for new calendar" : "Nazwa nowego kalendarza",
    "Creating calendar …" : "Tworzenie kalendarza…",
    "New calendar with task list" : "Nowy kalendarz z listą zadań",
    "New subscription from link (read-only)" : "Nowa subskrypcja z linku (tylko do odczytu)",
    "Creating subscription …" : "Tworzenie subskrypcji…",
    "Add public holiday calendar" : "Dodaj kalendarz świąt państwowych",
    "Add custom public calendar" : "Dodaj personalizowany publiczny kalendarz",
    "Calendar link copied to clipboard." : "Link do kalendarza skopiowany do schowka.",
    "Calendar link could not be copied to clipboard." : "Nie można skopiować linku kalendarza do schowka.",
    "Copy subscription link" : "Kopiuj link do subskrypcji",
    "Copying link …" : "Kopiowanie linku…",
    "Copied link" : "Skopiowano link",
    "Could not copy link" : "Nie można skopiować linku",
    "Export" : "Eksportuj",
    "Untitled item" : "Pozycja bez tytułu",
    "Unknown calendar" : "Kalendarz nieznany",
    "Could not load deleted calendars and objects" : "Nie udało się wczytać usuniętych kalendarzy i obiektów",
    "Could not delete calendar or event" : "Nie udało się usunąć kalendarza lub wydarzenia",
    "Could not restore calendar or event" : "Nie udało się przywrócić kalendarza lub wydarzenia",
    "Do you really want to empty the trash bin?" : "Czy na pewno chcesz opróżnić kosz?",
    "Empty trash bin" : "Opróżnij kosz",
    "Trash bin" : "Kosz",
    "Loading deleted items." : "Wczytuję usunięte pozycje.",
    "You do not have any deleted items." : "Nie masz żadnych usuniętych pozycji.",
    "Name" : "Nazwa",
    "Deleted" : "Usunięto",
    "Restore" : "Przywróć",
    "Delete permanently" : "Usuń trwale",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Pozycje w koszu są usuwane po {numDays} dniu","Pozycje w koszu są usuwane po {numDays} dniach","Pozycje w koszu są usuwane po {numDays} dniach","Pozycje w koszu są usuwane po {numDays} dniach"],
    "Could not update calendar order." : "Nie można zaktualizować kolejności kalendarza.",
    "Shared calendars" : "Udostępnione kalendarze",
    "Deck" : "Tablica",
    "Internal link" : "Link wewnętrzny",
    "A private link that can be used with external clients" : "Prywatny link, którego można używać z klientami zewnętrznymi",
    "Copy internal link" : "Kopiuj link wewnętrzny",
    "An error occurred, unable to publish calendar." : "Wystąpił błąd, nie można opublikować kalendarza.",
    "An error occurred, unable to send email." : "Wystąpił błąd, nie można wysłać wiadomości e-mail.",
    "Embed code copied to clipboard." : "Kod do wstawienia został skopiowany do schowka.",
    "Embed code could not be copied to clipboard." : "Nie można skopiować do schowka kodu do wstawienia.",
    "Unpublishing calendar failed" : "Nie można cofnąć publikacji kalendarza",
    "Share link" : "Udostępnij link",
    "Copy public link" : "Kopiuj link publiczny",
    "Send link to calendar via email" : "Wyślij e-mailem link do kalendarza",
    "Enter one address" : "Wpisz jeden z adresów",
    "Sending email …" : "Wysyłanie e-maila…",
    "Copy embedding code" : "Kopiuj kod osadzania",
    "Copying code …" : "Kopiowanie kodu…",
    "Copied code" : "Skopiowano kod",
    "Could not copy code" : "Nie można skopiować kodu",
    "Delete share link" : "Usuń link udostępnienia",
    "Deleting share link …" : "Usuwanie linku udostępnienia…",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Zespół)",
    "An error occurred while unsharing the calendar." : "Wystąpił błąd podczas wyłączania udostępniania kalendarza.",
    "An error occurred, unable to change the permission of the share." : "Wystąpił błąd, nie można zmienić uprawnień do udostępnienia.",
    "Unshare with {displayName}" : "Zatrzymaj udostępnianie z {displayName}",
    "Share with users or groups" : "Udostępnij użytkownikom lub grupom",
    "No users or groups" : "Brak użytkowników lub grup",
    "Failed to save calendar name and color" : "Nie udało się zapisać nazwy i koloru kalendarza",
    "Calendar name …" : "Nazwa kalendarza  ...",
    "Never show me as busy (set this calendar to transparent)" : "Nigdy nie pokazuj mnie jako zajętego (ustaw ten kalendarz jako przezroczysty)",
    "Share calendar" : "Udostępnij kalendarz",
    "Unshare from me" : "Nie udostępniaj mi",
    "Save" : "Zapisz",
    "No title" : "Brak tytułu",
    "Are you sure you want to delete \"{title}\"?" : "Czy na pewno chcesz usunąć \"{title}\"?",
    "Deleting proposal \"{title}\"" : "Usuwanie propozycji \"{title}\"",
    "Successfully deleted proposal" : "Pomyślnie usunięto propozycję",
    "Failed to delete proposal" : "Nie udało się usunąć propozycji",
    "Failed to retrieve proposals" : "Nie udało się pobrać propozycji",
    "Meeting proposals" : "Propozycje spotkań",
    "A configured email address is required to use meeting proposals" : "Do korzystania z propozycji spotkań wymagany jest skonfigurowany adres e-mail",
    "No active meeting proposals" : "Brak aktywnych propozycji spotkań",
    "View" : "Podgląd",
    "Import calendars" : "Importuj kalendarze",
    "Please select a calendar to import into …" : "Wybierz kalendarz do zaimportowania do…",
    "Filename" : "Nazwa pliku",
    "Calendar to import into" : "Kalendarz do zaimportowania",
    "Cancel" : "Anuluj",
    "_Import calendar_::_Import calendars_" : ["Importuj kalendarz","Importuj kalendarze","Importuj kalendarze","Importuj kalendarze"],
    "Select the default location for attachments" : "Wybierz domyślną lokalizację załączników",
    "Pick" : "Wybierz",
    "Invalid location selected" : "Wybrano nieprawidłową lokalizację",
    "Attachments folder successfully saved." : "Pomyślnie zapisano katalog załączników.",
    "Error on saving attachments folder." : "Błąd podczas zapisywania katalogu załączników.",
    "Attachments folder" : "Katalog z załącznikami",
    "{filename} could not be parsed" : "Nie można przeanalizować {filename}",
    "No valid files found, aborting import" : "Nie znaleziono prawidłowych plików, przerywanie importu",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Pomyślnie zaimportowano %n wydarzenie","Pomyślnie zaimportowano %n wydarzenia","Pomyślnie zaimportowano %n wydarzeń","Pomyślnie zaimportowano %n wydarzeń"],
    "Import partially failed. Imported {accepted} out of {total}." : "Import częściowo nieudany. Zaimportowano {accepted} z {total}.",
    "Automatic" : "Automatycznie",
    "Automatic ({timezone})" : "Automatycznie ({timezone})",
    "New setting was not saved successfully." : "Nowe ustawienie nie zostało pomyślnie zapisane.",
    "Timezone" : "Strefa czasowa",
    "Navigation" : "Nawigacja",
    "Previous period" : "Poprzedni okres",
    "Next period" : "Następny okres",
    "Views" : "Widoki",
    "Day view" : "Widok dnia",
    "Week view" : "Widok tygodnia",
    "Month view" : "Widok miesiąca",
    "Year view" : "Widok roku",
    "List view" : "Widok listy",
    "Actions" : "Akcje",
    "Create event" : "Utwórz wydarzenie",
    "Show shortcuts" : "Pokaż skróty",
    "Editor" : "Edytor",
    "Close editor" : "Zamknij edytor",
    "Save edited event" : "Zapisz edytowane wydarzenie",
    "Delete edited event" : "Usuń edytowane wydarzenie",
    "Duplicate event" : "Zduplikowane wydarzenie",
    "or" : "lub",
    "Calendar settings" : "Ustawienia Kalendarza",
    "At event start" : "Na początku wydarzenia",
    "No reminder" : "Bez przypomnienia",
    "Failed to save default calendar" : "Nie udało się zapisać domyślnego kalendarza",
    "General" : "Ogólne",
    "CalDAV" : "CalDAV",
    "CalDAV URL" : "CalDAV URL",
    "Appearance" : "Wygląd",
    "Birthday calendar" : "Kalendarz urodzin",
    "Tasks in calendar" : "Zadania w kalendarzu",
    "Weekends" : "Weekendy",
    "Week numbers" : "Numery tygodni",
    "Editing" : "Edytowanie",
    "Default reminder" : "Przypomnienie domyślne",
    "Files" : "Pliki",
    "Appointment schedule successfully created" : "Harmonogram spotkań został pomyślnie utworzony",
    "Appointment schedule successfully updated" : "Harmonogram spotkań został pomyślnie zaktualizowany",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minuta","{duration} minuty","{duration} minut","{duration} minut"],
    "0 minutes" : "0 minut",
    "_{duration} hour_::_{duration} hours_" : ["{duration} godzina","{duration} godziny","{duration} godzin","{duration} godzin"],
    "_{duration} day_::_{duration} days_" : ["{duration} dzień","{duration} dni","{duration} dni","{duration} dni"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} tydzień","{duration} tygodnie","{duration} tygodni","{duration} tygodni"],
    "_{duration} month_::_{duration} months_" : ["{duration} miesiąc","{duration} miesiące","{duration} miesięcy","{duration} miesięcy"],
    "_{duration} year_::_{duration} years_" : ["{duration} rok","{duration} lata","{duration} lat","{duration} lat"],
    "To configure appointments, add your email address in personal settings." : "Aby skonfigurować spotkania, dodaj swój adres e-mail w ustawieniach osobistych.",
    "Public – shown on the profile page" : "Publiczny – wyświetlane na stronie profilu",
    "Private – only accessible via secret link" : "Prywatny – dostępne tylko przez tajny link",
    "Appointment schedule saved" : "Harmonogram spotkań zapisany",
    "Create appointment schedule" : "Utwórz harmonogram spotkań",
    "Edit appointment schedule" : "Edytuj harmonogram spotkań",
    "Update" : "Aktualizuj",
    "Appointment name" : "Nazwa spotkania",
    "Location" : "Lokalizacja",
    "Create a Talk room" : "Stwórz pokój do rozmów",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Dla każdej zarezerwowanej wizyty zostanie wygenerowany unikalny link, który zostanie wysłany w wiadomości e-mail z potwierdzeniem",
    "Description" : "Opis",
    "Visibility" : "Widoczne",
    "Duration" : "Czas trwania",
    "Increments" : "Zwiększ",
    "Additional calendars to check for conflicts" : "Dodatkowe kalendarze do sprawdzania konfliktów",
    "Pick time ranges where appointments are allowed" : "Wybierz przedziały czasowe, w których dozwolone są spotkania",
    "to" : "do",
    "Delete slot" : "Usuń przedział czasowy",
    "No times set" : "Nie ustawiono czasu",
    "Add" : "Dodaj",
    "Monday" : "Poniedziałek",
    "Tuesday" : "Wtorek",
    "Wednesday" : "Środa",
    "Thursday" : "Czwartek",
    "Friday" : "Piątek",
    "Saturday" : "Sobota",
    "Sunday" : "Niedziela",
    "Weekdays" : "Dni powszednie",
    "Add time before and after the event" : "Dodaj czas przed i po wydarzeniu",
    "Before the event" : "Przed wydarzeniem",
    "After the event" : "Po wydarzeniu",
    "Planning restrictions" : "Ograniczenia planowania",
    "Minimum time before next available slot" : "Minimalny czas przed następnym dostępnym terminem",
    "Max slots per day" : "Maksymalna liczba terminów na dzień",
    "Limit how far in the future appointments can be booked" : "Ogranicz, jak daleko w przyszłości można rezerwować spotkania",
    "It seems a rate limit has been reached. Please try again later." : "Wygląda na to, że osiągnięto limit zapytań. Spróbuj ponownie później.",
    "Please confirm your reservation" : "Proszę o potwierdzenie rezerwacji",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Wysłaliśmy do Ciebie wiadomość e-mail ze szczegółami. Potwierdź wizytę, korzystając z linku w e-mailu. Możesz teraz zamknąć tę stronę.",
    "Your name" : "Jak się nazywasz",
    "Your email address" : "Twój adres e-mail",
    "Please share anything that will help prepare for our meeting" : "Udostępnij coś, co pomoże przygotować się do spotkania",
    "Could not book the appointment. Please try again later or contact the organizer." : "Nie udało się zarezerwować spotkania. Spróbuj ponownie później lub skontaktuj się z organizatorem.",
    "Back" : "Poprzednia",
    "Book appointment" : "Zarezerwuj spotkanie",
    "Error fetching Talk conversations." : "Błąd w pobieraniu rozmów z Talk.",
    "Conversation does not have a valid URL." : "Konwersacja nie ma poprawnego adresu URL.",
    "Successfully added Talk conversation link to location." : "Pomyślnie dodano lik rozmowy Talk do lokalizacji.",
    "Successfully added Talk conversation link to description." : "Pomyślnie dodano link rozmowy Talk do do opisu.",
    "Failed to apply Talk room." : "Nie udało się zastosować pokoju Talk.",
    "Talk conversation for event" : "Rozpocznij rozmowę dotyczącą wydarzenia",
    "Error creating Talk conversation" : "Błąd przy tworzeniu rozmowy Talk",
    "Select a Talk Room" : "Wybierz Pokój Talk.",
    "Add Talk conversation" : "Dodaj rozmowę Talk",
    "Fetching Talk rooms…" : "Pobieram listę pokojów Talk...",
    "No Talk room available" : "Brak dostępnych pokojów Talk",
    "Select conversation" : "Wybierz rozmowę",
    "on" : "o",
    "at" : "o",
    "before at" : "przed",
    "Notification" : "Powiadomienie",
    "Email" : "E-mail",
    "Audio notification" : "Powiadomienie audio",
    "Other notification" : "Inne powiadomienie",
    "Relative to event" : "W odniesieniu do zdarzenia",
    "On date" : "O czasie",
    "Edit time" : "Edytuj czas",
    "Save time" : "Zapisz czas",
    "Remove reminder" : "Usuń przypomnienie",
    "Add reminder" : "Dodaj przypomnienie",
    "seconds" : "sekund",
    "minutes" : "minut",
    "hours" : "godzin",
    "days" : "dniach",
    "weeks" : "tygodni",
    "Choose a file to add as attachment" : "Wybierz plik, aby dodać jako załącznik",
    "Choose a file to share as a link" : "Wybierz plik do udostępnienia przez link",
    "Attachment {name} already exist!" : "Załącznik {name} już istnieje!",
    "Could not upload attachment(s)" : "Nie można przesłać załącznika(ów)",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Zamierzasz przejść do {host}. Czy na pewno chcesz kontynuować? Link: {link}",
    "Proceed" : "Kontynuuj",
    "No attachments" : "Brak załączników",
    "Add from Files" : "Dodaj z plików",
    "Upload from device" : "Wyślij z urządzenia",
    "Delete file" : "Usuń plik",
    "Confirmation" : "Potwierdzenie",
    "_{count} attachment_::_{count} attachments_" : ["{count} załącznik","{count} załączniki","{count} załączników","{count} załączników"],
    "Suggested" : "Sugeruje",
    "Available" : "Dostępność",
    "Invitation accepted" : "Zaproszenie przyjęte",
    "Accepted {organizerName}'s invitation" : "Zaakceptowano zaproszenie od {organizerName}",
    "Participation marked as tentative" : "Uczestnictwo oznaczone jako niepewne",
    "Invitation is delegated" : "Zaproszenie oddelegowane",
    "Not available" : "Brak dostępności",
    "Invitation declined" : "Zaproszenie odrzucone",
    "Declined {organizerName}'s invitation" : "Odrzucono zaproszenie od {organizerName}",
    "Availability will be checked" : "Dostępność zostanie sprawdzona",
    "Invitation will be sent" : "Zaproszenie zostanie wysłane",
    "Failed to check availability" : "Nie udało się sprawdzić dostępności",
    "Failed to deliver invitation" : "Nie udało się dostarczyć zaproszenia",
    "Awaiting response" : "Oczekiwanie na odpowiedź",
    "Checking availability" : "Sprawdzanie dostępności",
    "Has not responded to {organizerName}'s invitation yet" : "Bez odpowiedzi na zaproszenie od {organizerName}",
    "Suggested times" : "Sugerowane godziny",
    "chairperson" : "przewodniczy",
    "required participant" : "uczestnictwo wymagane",
    "non-participant" : "nie uczestniczy",
    "optional participant" : "opcjonalne uczestnictwo",
    "{organizer} (organizer)" : "{organizer} (organizator)",
    "{attendee} ({role})" : "{attendee}({role})",
    "Availability of attendees, resources and rooms" : "Dostępność uczestników, zasobów i pokoi",
    "Suggestion accepted" : "Sugestia zaakceptowana",
    "Previous date" : "Poprzednia data",
    "Next date" : "Następna data",
    "Legend" : "Legenda",
    "Out of office" : "Biuro nie funkcjonuje",
    "Attendees:" : "Uczestnicy:",
    "local time" : "Czas lokalny",
    "Done" : "Gotowe",
    "Search room" : "Wyszukaj pokój",
    "Room name" : "Nazwa pokoju",
    "Check room availability" : "Sprawdź dostępność pokoju",
    "Free" : "Dostępność",
    "Busy (tentative)" : "Brak dostępności (wstępnie)",
    "Busy" : "Brak dostępności",
    "Unknown" : "Nieznana",
    "Find a time" : "Znajdź czas",
    "The invitation has been accepted successfully." : "Zaproszenie zostało pomyślnie przyjęte.",
    "Failed to accept the invitation." : "Nie udało się zaakceptować zaproszenia.",
    "The invitation has been declined successfully." : "Zaproszenie zostało pomyślnie odrzucone.",
    "Failed to decline the invitation." : "Nie udało się odrzucić zaproszenia.",
    "Your participation has been marked as tentative." : "Twoje uczestnictwo zostało oznaczone jako niepewne.",
    "Failed to set the participation status to tentative." : "Nie udało się ustawić statusu uczestnictwa na niepewne.",
    "Accept" : "Akceptuj",
    "Decline" : "Odrzuć",
    "Tentative" : "Niepewne",
    "No attendees yet" : "Brak uczestników",
    "Please add at least one attendee to use the \"Find a time\" feature." : "Proszę dodaj chociaż jedną osobę mającą uczestniczyć, żeby użyć funkcji \"Znajdź czas\".",
    "Attendees" : "Uczestnicy",
    "Remove group" : "Usuń grupę",
    "Remove attendee" : "Usuń uczestnika",
    "Request reply" : "Poproś o odpowiedź",
    "Chairperson" : "Przewodniczący",
    "Required participant" : "Wymagany uczestnik",
    "Optional participant" : "Opcjonalny uczestnik",
    "Non-participant" : "Nieuczestniczący",
    "_%n member_::_%n members_" : ["%n członek","%n członków","%n członków","%n członków"],
    "Search for emails, users, contacts, contact groups or teams" : "Szukaj mejli, użytkowników, kontaktów, grup kontaktów lub zespołów.",
    "No match found" : "Nie znaleziono pasujących",
    "Note that members of circles get invited but are not synced yet." : "Pamiętaj, że członkowie kręgów są zapraszani, ale nie są jeszcze synchronizowani.",
    "Note that members of contact groups get invited but are not synced yet." : "Pamiętaj, że członkowie grup kontaktów są zapraszani, ale nie są jeszcze synchronizowani.",
    "(organizer)" : "(organizator)",
    "Make {label} the organizer" : "Mianuj {label} organizatorem",
    "Make {label} the organizer and attend" : "Mianuj {label} organizatorem i weź udział",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Aby wysyłać zaproszenia i otrzymywać odpowiedzi, [linkopen]dodaj swój adres e-mail w ustawieniach osobistych[linkclose].",
    "Remove color" : "Usuń kolor",
    "Event title" : "Tytuł wydarzenia",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Nie można zmodyfikować ustawienia całodziennego dla wydarzeń, które są częścią zestawu cyklicznego.",
    "From" : "Od",
    "To" : "Do",
    "Repeat" : "Powtarzaj",
    "Repeat event" : "Powtórz wydarzenie",
    "_time_::_times_" : ["raz","razy","razy","razy"],
    "never" : "nigdy",
    "on date" : "o czasie",
    "after" : "po",
    "End repeat" : "Zakończ powtarzanie",
    "Select to end repeat" : "Wybierz, aby zakończyć powtarzanie",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "To wydarzenie stanowi wyjątek powtarzalności zestawu cyklicznego. Nie można do niego dodać reguły powtarzalności.",
    "first" : "pierwszy",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Zmiany w regule powtarzalności będą miały zastosowanie tylko do tego i wszystkich przyszłych wydarzeń.",
    "Repeat every" : "Powtórz co",
    "By day of the month" : "Według dnia miesiąca",
    "On the" : "Na",
    "_day_::_days_" : ["dzień","dni","dni","dni"],
    "_week_::_weeks_" : ["tydzień","tygodnie","tygodni","tygodnie"],
    "_month_::_months_" : ["miesiąc","miesiące","miesięcy","miesiące"],
    "_year_::_years_" : ["rok","lata","lat","lata"],
    "On specific day" : "O konkretnej dacie",
    "weekday" : "dzień powszedni",
    "weekend day" : "dzień weekendu",
    "Does not repeat" : "Nie powtarza się",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Definicja tego wydarzenia nie jest w pełni obsługiwana przez Nextcloud. W przypadku edycji opcji cyklicznej niektóre powtórzenia mogą zostać utracone.",
    "No rooms or resources yet" : "Nie ma jeszcze pokoi ani zasobów",
    "Resources" : "Zasoby",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} miejsce","{seatingCapacity} miejsca","{seatingCapacity} miejsc","{seatingCapacity} miejsc"],
    "Add resource" : "Dodaj zasób",
    "Has a projector" : "Ma projektor",
    "Has a whiteboard" : "Posiada białą tablicę",
    "Wheelchair accessible" : "Dostęp dla wózków inwalidzkich",
    "Remove resource" : "Usuń zasób",
    "Search for resources or rooms" : "Szukaj zasoby lub pokoje",
    "available" : "dostępny",
    "unavailable" : "niedostępny",
    "Show all rooms" : "Pokaż wszystkie pokoje",
    "Projector" : "Projektor",
    "Whiteboard" : "Biała tablica",
    "Room type" : "Rodzaj pokoju",
    "Any" : "Dowolny",
    "Minimum seating capacity" : "Minimalna ilość miejsc",
    "More details" : "Więcej szczegółów",
    "Update this and all future" : "Zaktualizuj to i wszystkie przyszłe",
    "Update this occurrence" : "Zaktualizuj to wydarzenie",
    "Public calendar does not exist" : "Kalendarz publiczny nie istnieje",
    "Maybe the share was deleted or has expired?" : "Może udostępnienie zostało usunięte lub wygasło?",
    "Remove date" : "Usuń datę",
    "Attendance required" : "Wymagana obecność",
    "Attendance optional" : "Obecność opcjonalna",
    "Remove participant" : "Usuń uczestnika",
    "Yes" : "Tak",
    "No" : "Nie",
    "Maybe" : "Może",
    "None" : "Brak",
    "Select your meeting availability" : "Wybierz swoją dostępność na spotkanie",
    "Create a meeting for this date and time" : "Utwórz spotkanie dla tej daty i godziny",
    "Create" : "Utwórz",
    "No participants or dates available" : "Brak dostępnych uczestników lub dat",
    "from {formattedDate}" : "od {formattedDate}",
    "to {formattedDate}" : "do {formattedDate}",
    "on {formattedDate}" : "w dniu {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "od {formattedDate} o {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "do {formattedDate} o {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "w dniu {formattedDate} o {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} o {formattedTime}",
    "Please enter a valid date" : "Podaj prawidłową datę",
    "Please enter a valid date and time" : "Podaj prawidłową datę i godzinę",
    "Select a time zone" : "Wybierz strefę czasową",
    "Please select a time zone:" : "Wybierz strefę czasową:",
    "Pick a time" : "Wybierz czas",
    "Pick a date" : "Wybierz datę",
    "Type to search time zone" : "Wpisz, aby wyszukać strefę czasową",
    "Global" : "Globalnie",
    "Holidays in {region}" : "Święta w {region}",
    "An error occurred, unable to read public calendars." : "Wystąpił błąd, nie można odczytać publicznych kalendarzy.",
    "An error occurred, unable to subscribe to calendar." : "Wystąpił błąd, nie można subskrybować kalendarza.",
    "Public holiday calendars" : "Kalendarze świąt państwowych",
    "Public calendars" : "Publiczne kalendarze",
    "No valid public calendars configured" : "Nie skonfigurowano żadnych prawidłowych kalendarzy publicznych",
    "Speak to the server administrator to resolve this issue." : "Poproś administrację serwera o rozwiązanie problemu.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Kalendarze świąt państwowych są dostarczane przez Thunderbirda. Dane kalendarza zostaną pobrane z witryny {website}",
    "These public calendars are suggested by the server administrator. Calendar data will be downloaded from the respective website." : "Te publiczne kalendarze są sugerowane przez administratora serwera. Dane kalendarza zostaną pobrane z odpowiedniej strony internetowej.",
    "By {authors}" : "Autorstwa {authors}",
    "Subscribed" : "Zasubskrybowano",
    "Subscribe" : "Subskrybuj",
    "Could not fetch slots" : "Nie udało się pobrać przedziałów",
    "Select a date" : "Wybierz datę",
    "Select slot" : "Wybierz przedział czasowy",
    "No slots available" : "Brak dostępnych terminów",
    "The slot for your appointment has been confirmed" : "Termin Twojego spotkania został potwierdzony",
    "Appointment Details:" : "Szczegóły spotkania:",
    "Time:" : "Czas:",
    "Booked for:" : "Zarezerwowane dla:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Dziękujemy. Twoje spotkanie od {startDate} do {endDate} zostało potwierdzone.",
    "Book another appointment:" : "Umów się na kolejne spotkanie:",
    "See all available slots" : "Zobacz wszystkie dostępne wolne terminy",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Termin na spotkanie od {startDate} do {endDate} nie jest już dostępny.",
    "Please book a different slot:" : "Zarezerwuj inny termin:",
    "Book an appointment with {name}" : "Umów się na spotkanie z {name}",
    "No public appointments found for {name}" : "Nie znaleziono publicznych spotkań dla {name}",
    "Personal" : "Osobiste",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Automatyczne wykrywanie strefy czasowej określiło Twoją strefę czasową jako UTC.\nNajprawdopodobniej wynika to ze środków bezpieczeństwa przeglądarki internetowej.\nUstaw strefę czasową ręcznie w ustawieniach kalendarza.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Skonfigurowana strefa czasowa ({timezoneId}) nie została znaleziona. Powrót do UTC.\nZmień strefę czasową w ustawieniach i zgłoś ten problem.",
    "Show unscheduled tasks" : "Pokaż niezaplanowane zadania",
    "Unscheduled tasks" : "Niezaplanowane zadania",
    "Availability of {displayName}" : "Dostępność {displayName}",
    "Discard event" : "Odrzuć wydarzenie",
    "Edit event" : "Edytuj zdarzenie",
    "Event does not exist" : "Wydarzenie nie istnieje",
    "Duplicate" : "Zduplikuj",
    "Delete this occurrence" : "Usuń to wydarzenie",
    "Delete this and all future" : "Usuń to i wszystkie przyszłe",
    "All day" : "Cały dzień",
    "Modifications wont get propagated to the organizer and other attendees" : "Zmiany nie zostaną przekazane do osoby organizującej ani innych uczestniczących.",
    "Managing shared access" : "Zarządzanie dostępem",
    "Deny access" : "Brak dostępu",
    "Invite" : "Zaproś",
    "Discard changes?" : "Odrzucić zmiany?",
    "Are you sure you want to discard the changes made to this event?" : "Czy na pewno chcesz odrzucić zmiany wprowadzone w tym wydarzeniu?",
    "_User requires access to your file_::_Users require access to your file_" : ["Użytkownik wymaga dostępu do pliku","Użytkownicy wymagają dostępu do pliku","Użytkownicy wymagają dostępu do pliku","Użytkownicy wymagają dostępu do pliku"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Załącznik wymaga uprawnień do udostępniania","Załączniki wymagają uprawnień do udostępniania","Załączniki wymagają uprawnień do udostępniania","Załączniki wymagają uprawnień do udostępniania"],
    "Untitled event" : "Wydarzenie bez tytułu",
    "Close" : "Zamknij",
    "Modifications will not get propagated to the organizer and other attendees" : "Zmiany nie zostaną przekazane do osoby organizującej ani innych uczestniczących.",
    "Meeting proposals overview" : "Przegląd propozycji spotkań",
    "Edit meeting proposal" : "Edytuj propozycję spotkania",
    "Create meeting proposal" : "Utwórz propozycję spotkania",
    "Update meeting proposal" : "Zaktualizuj propozycję spotkania",
    "Saving proposal \"{title}\"" : "Zapisywanie propozycji \"{title}\"",
    "Successfully saved proposal" : "Pomyślnie zapisano propozycję",
    "Failed to save proposal" : "Nie udało się zapisać propozycji",
    "Create a meeting for \"{date}\"? This will create a calendar event with all participants." : "Utworzyć spotkanie dla \"{date}\"? To utworzy wydarzenie w kalendarzu ze wszystkimi uczestnikami.",
    "Creating meeting for {date}" : "Tworzenie spotkania dla {date}",
    "Successfully created meeting for {date}" : "Pomyślnie utworzono spotkanie dla {date}",
    "Failed to create a meeting for {date}" : "Nie udało się utworzyć spotkania dla {date}",
    "Please enter a valid duration in minutes." : "Proszę podać prawidłowy czas trwania w minutach.",
    "Failed to fetch proposals" : "Nie udało się pobrać propozycji",
    "Failed to fetch free/busy data" : "Nie udało się pobrać danych o dostępności",
    "Selected" : "Wybrany",
    "No Description" : "Brak opisu",
    "No Location" : "Brak lokalizacji",
    "Edit this meeting proposal" : "Edytuj tę propozycję spotkania",
    "Delete this meeting proposal" : "Usuń tę propozycję spotkania",
    "Title" : "Tytuł",
    "15 min" : "15 min",
    "30 min" : "30 min.",
    "60 min" : "60 min",
    "90 min" : "90 min",
    "Participants" : "Uczestnicy",
    "Selected times" : "Wybrane godziny",
    "Previous span" : "Poprzedni zakres",
    "Next span" : "Następny zakres",
    "Less days" : "Mniej dni",
    "More days" : "Więcej dni",
    "Loading meeting proposal" : "Ładowanie propozycji spotkania",
    "No meeting proposal found" : "Nie znaleziono propozycji spotkania",
    "Please wait while we load the meeting proposal." : "Proszę czekać, trwa wczytywanie propozycji spotkania.",
    "The link you followed may be broken, or the meeting proposal may no longer exist." : "Podany link może być uszkodzony lub propozycja spotkania mogła już nie istnieć.",
    "Thank you for your response!" : "Dziękujemy za Twoją odpowiedź!",
    "Your vote has been recorded. Thank you for participating!" : "Twój głos został zapisany. Dziękujemy za udział!",
    "Unknown User" : "Nieznany użytkownik",
    "No Title" : "Brak tytułu",
    "No Duration" : "Brak czasu trwania",
    "Select a different time zone" : "Wybierz inną strefę czasową",
    "Submit" : "Wyślij",
    "Subscribe to {name}" : "Subskrybuj dla {name}",
    "Export {name}" : "Eksportuj {name}",
    "Show availability" : "Pokaż dostępność",
    "Anniversary" : "Rocznica",
    "Appointment" : "Spotkanie",
    "Business" : "Biznes",
    "Education" : "Edukacja",
    "Holiday" : "Święto",
    "Meeting" : "Zebranie",
    "Miscellaneous" : "Różne",
    "Non-working hours" : "Godziny wolne od pracy",
    "Not in office" : "Poza biurem",
    "Phone call" : "Zadzwonić",
    "Sick day" : "Dzień chorobowy",
    "Special occasion" : "Specjalna okazja",
    "Travel" : "Podróż",
    "Vacation" : "Urlop",
    "Midnight on the day the event starts" : "Północ dnia rozpoczęcia wydarzenia",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n dzień przed wydarzeniem o {formattedHourMinute}","%n dni przed wydarzeniem o {formattedHourMinute}","%n dni przed wydarzeniem o {formattedHourMinute}","%n dni przed wydarzeniem o {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n tydzień przed wydarzeniem o {formattedHourMinute}","%n tygodnie przed wydarzeniem o {formattedHourMinute}","%n tygodni przed wydarzeniem o {formattedHourMinute}","%n tygodni przed wydarzeniem o {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "w dniu wydarzenia o {formattedHourMinute}",
    "at the event's start" : "na początku wydarzenia",
    "at the event's end" : "na koniec wydarzenia",
    "{time} before the event starts" : "{time} przed rozpoczęciem wydarzenia",
    "{time} before the event ends" : "{time} przed końcem wydarzenia",
    "{time} after the event starts" : "{time} po rozpoczęciu wydarzenia",
    "{time} after the event ends" : "{time} po zakończeniu wydarzenia",
    "on {time}" : "o {time}",
    "on {time} ({timezoneId})" : "o {time} ({timezoneId})",
    "Week {number} of {year}" : "Tydzień {number} w {year}",
    "Daily" : "Codziennie",
    "Weekly" : "Co tydzień",
    "Monthly" : "Co miesiąc",
    "Yearly" : "Co rok",
    "_Every %n day_::_Every %n days_" : ["Co %n dzień","Co %n dni","Co %n dni","Co %n dni"],
    "_Every %n week_::_Every %n weeks_" : ["Co %n tydzień","Co %n tygodnie","Co %n tygodni","Co %n tygodnie"],
    "_Every %n month_::_Every %n months_" : ["Co %n miesiąc","Co %n miesiące","Co %n miesięcy","Co %n miesiące"],
    "_Every %n year_::_Every %n years_" : ["Co %n rok","Co %n lata","Co %n lat","Co %n lata"],
    "_on {weekday}_::_on {weekdays}_" : ["w {weekdays}","w {weekdays}","w {weekdays}","w {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["w dzień {dayOfMonthList}","w dni {dayOfMonthList}","w dni {dayOfMonthList}","w dni {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "w dniu {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {dayOfMonthList}" : "{dayOfMonthList} w {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "za {monthNames} w dniu {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "do {untilDate}",
    "_%n time_::_%n times_" : ["%n raz","%n razy","%n razy","%n razy"],
    "second" : "drugi",
    "third" : "trzeci",
    "fourth" : "czwarty",
    "fifth" : "piąty",
    "second to last" : "przedostatni",
    "last" : "ostatni",
    "Untitled task" : "Zadanie bez tytułu",
    "Please ask your administrator to enable the Tasks App." : "Poproś administrację o włączenie aplikacji Zadania.",
    "You are not allowed to edit this event as an attendee." : "Jako osoba uczestnicząca nie możesz edytować tego wydarzenia.",
    "W" : "T",
    "%n more" : "%n więcej",
    "No events to display" : "Brak wydarzeń do wyświetlenia",
    "All participants declined" : "Wszystkie zaproszone osoby odmówiły",
    "Please confirm your participation" : "Prosimy o potwierdzenie Twojego uczestnictwa",
    "You declined this event" : "Zaproszenie zostało przez Ciebie odrzucone",
    "Your participation is tentative" : "Uczestnictwo zostało przez Ciebie oznaczone jako niepewne",
    "_+%n more_::_+%n more_" : ["+%n więcej","+%n więcej","+%n więcej","+%n więcej"],
    "No events" : "Brak wydarzeń",
    "Create a new event or change the visible time-range" : "Utwórz nowe wydarzenie lub zmień widoczny zakres czasu",
    "Failed to save event" : "Nie udało się zapisać wydarzenia",
    "It might have been deleted, or there was a typo in a link" : "Mogło zostać usunięte lub w linku była literówka",
    "It might have been deleted, or there was a typo in the link" : "Mogło zostać usunięte lub w linku była literówka",
    "Meeting room" : "Pokój spotkań",
    "Lecture hall" : "Sala wykładowa",
    "Seminar room" : "Pokój seminaryjny",
    "Other" : "Inny",
    "When shared show" : "Po udostępnieniu pokaż",
    "When shared show full event" : "Gdy udostępniony pokaż pełne wydarzenie",
    "When shared show only busy" : "Gdy udostępniony pokaż tylko zajęty",
    "When shared hide this event" : "Gdy udostępniony ukryj to wydarzenie",
    "Add a location" : "Dodaj lokalizację",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Dodaj opis\n\n- Czego dotyczy to spotkanie\n- Punkty do omówienia\n- Co muszą przygotować osoby uczestniczące",
    "Status" : "Status",
    "Confirmed" : "Potwierdzone",
    "Canceled" : "Anulowane",
    "Confirmation about the overall status of the event." : "Potwierdzenie ogólnego statusu wydarzenia.",
    "Show as" : "Pokaż jako",
    "Take this event into account when calculating free-busy information." : "Weź to wydarzenie pod kontem sprawdzenia informacji o wolnym czasie.",
    "Categories" : "Kategorie",
    "Categories help you to structure and organize your events." : "Kategorie pomagają uporządkować i organizować wydarzenia.",
    "Search or add categories" : "Wyszukaj lub dodaj kategorie",
    "Add this as a new category" : "Dodaj to jako nową kategorię",
    "Custom color" : "Kolor niestandardowy",
    "Special color of this event. Overrides the calendar-color." : "Specjalny kolor tego wydarzenia. Zastępuje kolor kalendarza.",
    "Error while sharing file" : "Błąd podczas udostępniania pliku",
    "Error while sharing file with user" : "Błąd podczas udostępniania pliku użytkownikowi",
    "Error creating a folder {folder}" : "Błąd podczas tworzenia folderu {folder}",
    "Attachment {fileName} already exists!" : "Załącznik {fileName} już istnieje!",
    "Attachment {fileName} added!" : "Załącznik {fileName} został dodany!",
    "An error occurred during uploading file {fileName}" : "Wystąpił błąd podczas przesyłania pliku {fileName}",
    "An error occurred during getting file information" : "Błąd podczas pobierania informacji o pliku.",
    "Talk conversation for proposal" : "Rozmowa Talk dla propozycji",
    "An error occurred, unable to delete the calendar." : "Wystąpił błąd, nie można usunąć kalendarza.",
    "Imported {filename}" : "Zaimportowano {filename}",
    "This is an event reminder." : "Przypomnienie o wydarzeniu.",
    "Error while parsing a PROPFIND error" : "Wystąpił błąd podczas analizowania błędu PROPFIND",
    "Appointment not found" : "Nie znaleziono spotkania",
    "User not found" : "Nie znaleziono użytkownika",
    "Hidden" : "Ukryty",
    "can edit" : "może edytować",
    "Calendar name …" : "Nazwa kalendarza…",
    "Default attachments location" : "Domyślna lokalizacja załączników",
    "Automatic ({detected})" : "Automatycznie ({detected})",
    "Shortcut overview" : "Przegląd skrótu",
    "CalDAV link copied to clipboard." : "Link CalDAV skopiowany do schowka.",
    "CalDAV link could not be copied to clipboard." : "Nie można skopiować linku CalDAV do schowka.",
    "Enable birthday calendar" : "Włącz kalendarz urodzin",
    "Show tasks in calendar" : "Pokaż zadania w kalendarzu",
    "Enable simplified editor" : "Włącz uproszczony edytor",
    "Limit the number of events displayed in the monthly view" : "Ogranicz liczbę zdarzeń wyświetlanych w widoku miesięcznym",
    "Show weekends" : "Pokaż weekendy",
    "Show week numbers" : "Pokaż numery tygodni",
    "Time increments" : "Przyrosty czasu",
    "Default calendar for incoming invitations" : "Domyślny kalendarz dla przychodzących zaproszeń",
    "Copy primary CalDAV address" : "Kopiuj główny adres CalDAV",
    "Copy iOS/macOS CalDAV address" : "Kopiuj adres CalDAV dla iOS/macOS",
    "Personal availability settings" : "Osobiste ustawienia dostępności",
    "Show keyboard shortcuts" : "Pokaż skróty klawiaturowe",
    "Create a new public conversation" : "Rozpocznij nową publiczną rozmowę",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount}zaproszony/ch, {confirmedCount}potwierdził/o",
    "Successfully appended link to talk room to location." : "Pomyślnie dodano link do pokoju rozmów do lokalizacji.",
    "Successfully appended link to talk room to description." : "Pomyślnie dołączono do opisu link do pokoju rozmów.",
    "Error creating Talk room" : "Błąd podczas tworzenia pokoju w Talku",
    "_%n more guest_::_%n more guests_" : ["%n gość więcej","%n gości więcej","%n gości więcej","%n gości więcej"],
    "The visibility of this event in shared calendars." : "Widoczność tego wydarzenia w udostępnianych kalendarzach."
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
