OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Указанный адрес электронной почты слишком длинный",
    "User-Session unexpectedly expired" : "Сеанс работы пользователя неожиданно завершён",
    "Provided email-address is not valid" : "Указанный адрес электронной почты недействителен",
    "%s has published the calendar »%s«" : "%s опубликовал календарь «%s»",
    "Unexpected error sending email. Please contact your administrator." : "Неожиданная ошибка отправки электронной почты. Сообщите об этом  администратору.",
    "Successfully sent email to %1$s" : "Письмо успешно отправлено по адресу %1$s",
    "Hello," : "Здравствуйте,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Хотим сообщить, что %s опубликовал(а) календарь «%s».",
    "Open »%s«" : "Открыть «%s»",
    "Cheers!" : "Удачи!",
    "Upcoming events" : "Приближающиеся события",
    "No more events today" : "На сегодня больше нет событий",
    "No upcoming events" : "Приближающиеся события отсуствуют",
    "More events" : "Следующие события",
    "%1$s with %2$s" : "%1$s с %2$s",
    "Calendar" : "Календарь",
    "New booking {booking}" : "Новое бронирование {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) заборонировал(а) встречу \"{config_display_name}\"  на {date_time}.",
    "Appointments" : "Мероприятия",
    "Schedule appointment \"%s\"" : "Запланировать встречу «%s»",
    "Schedule an appointment" : "Запланировать встречу",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : "Подготовиться к %s",
    "Follow up for %s" : "Последующие действия для %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Ваша встреча «%s» с %s требует подтверждения",
    "Dear %s, please confirm your booking" : "Уважаемый %s, подтвердите своё бронирование",
    "Confirm" : "Подтвердить",
    "Appointment with:" : "Встреча с:",
    "Description:" : "Описание:",
    "This confirmation link expires in %s hours." : "Срок действия этой ссылки для подтверждения истекает через %s часов.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Если вы всё равно хотите отменить встречу, свяжитесь с её организатором, ответив на это письмо или перейдите на страницу, указанную в профиле.",
    "Your appointment \"%s\" with %s has been accepted" : "Ваша встреча «%s» с %s была подтверждена",
    "Dear %s, your booking has been accepted." : "Уважаемый(-ая) %s, ваше бронирование было подтверждено.",
    "Appointment for:" : "Встреча с:",
    "Date:" : "Дата:",
    "You will receive a link with the confirmation email" : "Вы получите ссылку с подтверждением по электронной почте",
    "Where:" : "Место:",
    "Comment:" : "Комментарий:",
    "You have a new appointment booking \"%s\" from %s" : "У вас новое бронирование встречи «%s» от %s",
    "Dear %s, %s (%s) booked an appointment with you." : "Уважаемый(-ая) %s, %s (%s) забронировал(а) встречу с вами.",
    "%s has proposed a meeting" : "%s предложил(а) встречу",
    "%s has updated a proposed meeting" : "%s обновил(а) предложенную встречу",
    "%s has canceled a proposed meeting" : "%s отменил(а) предложенную встречу",
    "Dear %s, a new meeting has been proposed" : "Уважаемый(ая) %s, новая встреча была предложена",
    "Dear %s, a proposed meeting has been updated" : "Уважаемый(ая) %s, предложенная встреча была обновлена",
    "Dear %s, a proposed meeting has been cancelled" : "Уважаемый(ая) %s, предложенная встреча была отменена",
    "Location:" : "Местонахождение:",
    "Duration:" : "Продолжительность:",
    "%1$s from %2$s to %3$s" : "%1$s с %2$s по %3$s",
    "Dates:" : "Даты:",
    "Respond" : "Ответить",
    "A Calendar app for Nextcloud" : "Приложение Календарь для Nextcloud",
    "A Calendar app for Nextcloud. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Like Contacts, Talk, Tasks, Deck and Circles\n* 🌐 **WebCal Support!** Want to see your favorite team's matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 **Search!** Find your events at ease\n* ☑️ **Tasks!** See tasks or Deck cards with a due date directly in the calendar\n* 🔈 **Talk rooms!** Create an associated Talk room when booking a meeting with just one click\n* 📆 **Appointment booking** Send people a link so they can book an appointment with you [using this app](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Attachments!** Add, upload and view event attachments\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Приложение «Календарь» для Nextcloud. Легко синхронизируйте события с различных устройств и редактируйте их прямо в вашем Nextcloud.\n\n* 🚀 **Интеграция с другими приложениями Nextcloud!** Например: Контакты, Talk, Задачи, Deck и Круги\n* 🌐 **Поддержка WebCal!** Хотите видеть в календаре расписание матчей любимой команды? Легко!\n* 🙋 **Участники!** Приглашайте людей на свои события\n* ⌚ **Свободен/занят!** Узнавайте, когда участники доступны для встречи\n* ⏰ **Напоминания!** Получайте уведомления о событиях в браузере и по электронной почте\n* 🔍 **Поиск!** Быстро находите нужные события\n* ☑️ **Задачи!** Просматривайте задачи и карточки Deck с установленным сроком прямо в календаре\n* 🔈 **Комнаты Talk!** Создавайте комнату в Talk при бронировании встречи одним кликом\n* 📆 **Бронирование встреч** Отправьте ссылку, чтобы другие могли записаться к вам [с помощью этого приложения](https://apps.nextcloud.com/apps/appointments)\n* 📎 **Вложения!** Добавляйте, загружайте и просматривайте файлы, прикреплённые к событиям\n* 🙈 **Мы не изобретаем велосипед!** Приложение основано на проверенных библиотеках: [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) и [fullcalendar](https://github.com/fullcalendar/fullcalendar).",
    "Previous day" : "Предыдущий день",
    "Previous week" : "Предыдущая неделя",
    "Previous year" : "Предыдущий год",
    "Previous month" : "Предыдущий месяц",
    "Next day" : "Следующий день",
    "Next week" : "Следующая неделя",
    "Next year" : "Следующий год",
    "Next month" : "Следующий месяц",
    "Create new event" : "Создать событие",
    "Event" : "Событие",
    "Today" : "Сегодня",
    "Day" : "День",
    "Week" : "Неделя",
    "Month" : "Месяц",
    "Year" : "Год",
    "List" : "Список",
    "Appointment link was copied to clipboard" : "Ссылка на эту встречу скопирована в буфер обмена",
    "Appointment link could not be copied to clipboard" : "Не удалось скопировать в буфер обмена ссылку на эту встречу",
    "Preview" : "Предварительный просмотр",
    "Copy link" : "Копировать ссылку",
    "Edit" : "Редактировать",
    "Delete" : "Удалить",
    "Appointment schedules" : "Расписание встреч",
    "Create new" : "Создать",
    "Disable calendar \"{calendar}\"" : "Отключить календарь \"{calendar}\"",
    "Disable untitled calendar" : "Отключить безымянный календарь",
    "Enable calendar \"{calendar}\"" : "Включить календарь \"{calendar}\"",
    "Enable untitled calendar" : "Включить безымянный календарь",
    "An error occurred, unable to change visibility of the calendar." : "Произошла ошибка, не удалось изменить видимость календаря.",
    "Untitled calendar" : "Календарь без названия",
    "Shared with you by" : "Получено от",
    "Edit and share calendar" : "Редактировать и делиться календарем",
    "Edit calendar" : "Редактировать календарь",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Закрытие общего доступа к календарю через {countdown} секунду","Закрытие общего доступа к календарю через {countdown} секунды","Закрытие общего доступа к календарю через {countdown} секунд","Закрытие общего доступа к календарю через {countdown} секунд"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Календарь будет удалён через {countdown} секунду","Календарь будет удалён через {countdown} секунды","Календарь будет удалён через {countdown} секунд","Календарь будет удалён через {countdown} секунды"],
    "An error occurred, unable to create the calendar." : "Не удалось создать календарь.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Введите верный URL: адрес должен начинаться с http://, https://, webcal:// или webcals://",
    "Calendars" : "Календари",
    "Add new" : "Добавить новое",
    "New calendar" : "Новый календарь",
    "Name for new calendar" : "Имя для нового календаря",
    "Creating calendar …" : "Создание календаря…",
    "New calendar with task list" : "Создать календарь со списком задач",
    "New subscription from link (read-only)" : "Создать подписку по ссылке (только чтение)",
    "Creating subscription …" : "Создание подписки…",
    "Add public holiday calendar" : "Добавить общий календарь праздников",
    "Add custom public calendar" : "Добавить собственный открытый календарь",
    "Calendar link copied to clipboard." : "Ссылка на календарь скопирована в буфер обмена.",
    "Calendar link could not be copied to clipboard." : "Не удалось скопировать ссылку на календарь в буфер обмена.",
    "Copy subscription link" : "Скопировать ссылку на подписку",
    "Copying link …" : "Копирование ссылки…",
    "Copied link" : "Ссылка скопирована",
    "Could not copy link" : "Не удалось скопировать ссылку",
    "Export" : "Экспорт",
    "Untitled item" : "Объект без названия",
    "Unknown calendar" : "Неизвестный календарь",
    "Could not load deleted calendars and objects" : "Не удалось загрузить удалённые календари и объекты",
    "Could not delete calendar or event" : "Не удалось удалить календарь или событие",
    "Could not restore calendar or event" : "Не удалось восстановить календарь или событие",
    "Do you really want to empty the trash bin?" : "Вы действительно хотите очистить корзину ?",
    "Empty trash bin" : "Очистить корзину",
    "Trash bin" : "Корзина",
    "Loading deleted items." : "Загрузка удалённых объектов…",
    "You do not have any deleted items." : "Нет ни одного удалённого объекта.",
    "Name" : "Название",
    "Deleted" : "Удалено",
    "Restore" : "Восстановить",
    "Delete permanently" : "Удалить безвозвратно",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Объекты будут удалены из корзины через {numDays} день","Объекты будут удалены из корзины через {numDays} дня","Объекты будут удалены из корзины через {numDays} дней","Объекты будут удалены из корзины через {numDays} дня"],
    "Could not update calendar order." : "Не удалось обновить порядок календарей.",
    "Shared calendars" : "Общие календари",
    "Deck" : "Карточки",
    "Internal link" : "Внутренняя ссылка",
    "A private link that can be used with external clients" : "Частная ссылка, которую можно использовать с внешними клиентами",
    "Copy internal link" : "Копировать внутреннюю ссылку",
    "An error occurred, unable to publish calendar." : "Произошла ошибка, не удалось опубликовать календарь.",
    "An error occurred, unable to send email." : "Произошла ошибка, не удалось отправить email.",
    "Embed code copied to clipboard." : "Код встравивания скопирован в буфер обмена.",
    "Embed code could not be copied to clipboard." : "Код встравивания не может быть скопирован в буфер обмена.",
    "Unpublishing calendar failed" : "Не удалось закрыть публичный доступ к календарю",
    "Share link" : "Поделиться ссылкой",
    "Copy public link" : "Скопировать общедоступную ссылку",
    "Send link to calendar via email" : "Отправить ссылку на календарь по электронной почте",
    "Enter one address" : "Введите один адрес",
    "Sending email …" : "Отправка сообщения…",
    "Copy embedding code" : "Скопировать код встраивания",
    "Copying code …" : "Копирование кода…",
    "Copied code" : "Код скопирован",
    "Could not copy code" : "Не удалось скопировать код",
    "Delete share link" : "Удалить ссылку",
    "Deleting share link …" : "Удаление ссылки доступа…",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Team)",
    "An error occurred while unsharing the calendar." : "Произошла ошибка при закрытии общего доступа к календарю.",
    "An error occurred, unable to change the permission of the share." : "Произошла ошибка, не удалось изменить разрешения для общего ресурса.",
    "Unshare with {displayName}" : "Отменить общий доступ для {displayName}",
    "Share with users or groups" : "Поделиться с пользователями или группами",
    "No users or groups" : "Пользователи или группы отсутствуют",
    "Failed to save calendar name and color" : "Не удалось сохранить имя и цвет календаря",
    "Calendar name …" : "Название календаря…",
    "Never show me as busy (set this calendar to transparent)" : "Никогда не показывать меня занятым (сделать этот календарь прозрачным)",
    "Share calendar" : "Поделиться календарем",
    "Unshare from me" : "Отписаться",
    "Save" : "Сохранить",
    "No title" : "Без названия",
    "Are you sure you want to delete \"{title}\"?" : "Вы действительно хотите удалить \"{title}\"?",
    "Deleting proposal \"{title}\"" : "Удаление предложения \"{title}\"",
    "Successfully deleted proposal" : "Предложение успешно удалено",
    "Failed to delete proposal" : "Не удалось удалить предложение",
    "Failed to retrieve proposals" : "Не удалось получить предложения",
    "Meeting proposals" : "Предложенные встречи",
    "A configured email address is required to use meeting proposals" : "Для использования предложенных встреч требуется адрес электронной почты.",
    "No active meeting proposals" : "Нет активных предложенных встреч",
    "View" : "Режим просмотра",
    "Import calendars" : "Импортировать календари",
    "Please select a calendar to import into …" : "Выберите календарь для импорта…",
    "Filename" : "Имя файла",
    "Calendar to import into" : "Календарь для импорта",
    "Cancel" : "Отмена",
    "_Import calendar_::_Import calendars_" : ["Импорт календаря","Импорт календарей","Импорт календарей","Импорт календарей"],
    "Select the default location for attachments" : "Выберите расположение для сохранения вложений по умолчанию",
    "Pick" : "Выбрать",
    "Invalid location selected" : "Указано недействительное расположение",
    "Attachments folder successfully saved." : "Параметры расположения вложений сохранены.",
    "Error on saving attachments folder." : "Не удалось задать папку для хранения вложений.",
    "Attachments folder" : "Папка для вложений",
    "{filename} could not be parsed" : "Не удалось проанализировать файл {filename}",
    "No valid files found, aborting import" : "Не найдено файлов верного типа, импорт отменён",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Событие импортировано","Импортировано %n события","Импортировано %n событий","Импортировано %n событий"],
    "Import partially failed. Imported {accepted} out of {total}." : "Импорт завершен частично. Импортировано {accepted} из {total}.",
    "Automatic" : "Автоматически",
    "Automatic ({timezone})" : "Автоматически ({timezone})",
    "New setting was not saved successfully." : "Не удалось сохранить параметры.",
    "Timezone" : "Часовой пояс",
    "Navigation" : "Навигация",
    "Previous period" : "Предыдущий период",
    "Next period" : "Следующий период",
    "Views" : "Просмотров",
    "Day view" : "Просмотров за день",
    "Week view" : "Просмотров за неделю",
    "Month view" : "Просмотров за месяц",
    "Year view" : "Просмотр за год",
    "List view" : "Вид списком",
    "Actions" : "Действия",
    "Create event" : "Создать событие",
    "Show shortcuts" : "Показать горячие клавиши",
    "Editor" : "Редактор",
    "Close editor" : "Закрыть редактор",
    "Save edited event" : "Сохранить изменённое событие",
    "Delete edited event" : "Удалить изменённое событие",
    "Duplicate event" : "Дублировать событие",
    "or" : "или",
    "Calendar settings" : "Параметры календаря",
    "At event start" : "В начале мероприятия",
    "No reminder" : "Не напоминать",
    "Failed to save default calendar" : "Не удалось задать календарь по умолчанию",
    "General" : "Основные",
    "Availability settings" : "Параметры доступности",
    "CalDAV" : "CalDAV",
    "Access Nextcloud calendars from other apps and devices" : "Доступ к календарям Nextcloud из других приложений и с других устройств",
    "CalDAV URL" : "Адрес CalDAV",
    "Server Address for iOS and macOS" : "Адрес сервера для  iOS и macOS",
    "Appearance" : "Внешний вид",
    "Birthday calendar" : "Календарь дней рождения",
    "Tasks in calendar" : "Задачи в календаре",
    "Weekends" : "Выходные",
    "Week numbers" : "Номера недель",
    "Limit number of events shown in Month view" : "Ограничить количество событий в месячном представлении",
    "Editing" : "Редактирование",
    "Default reminder" : "Напоминание по умолчанию",
    "Simple event editor" : "Простой редактор событий",
    "\"More details\" opens the detailed editor" : "При нажатии «Подробнее» открывать расширенный редактор",
    "Files" : "Файлы",
    "Appointment schedule successfully created" : "Рассписание встреч создано",
    "Appointment schedule successfully updated" : "Расписание встреч обновлено",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} минута","{duration} минуты","{duration} минут","{duration} минут"],
    "0 minutes" : "0 минут",
    "_{duration} hour_::_{duration} hours_" : ["{duration} час","{duration} часа","{duration} часов","{duration} часов"],
    "_{duration} day_::_{duration} days_" : ["{duration} день ","{duration} дня","{duration} дней","{duration} дней"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} неделя","{duration} недели","{duration} недель","{duration} недель"],
    "_{duration} month_::_{duration} months_" : ["{duration} месяц","{duration} месяца","{duration} месяцев","{duration} месяцев"],
    "_{duration} year_::_{duration} years_" : ["{duration} год","{duration} года","{duration} лет","{duration} лет"],
    "To configure appointments, add your email address in personal settings." : "Для конфигурации встреч, добавьте свой адрес электронной почты в личных настройках.",
    "Public – shown on the profile page" : "Публичный - отображается на странице профиля",
    "Private – only accessible via secret link" : "Приватный - доступен только по секретной ссылке",
    "Appointment schedule saved" : "Расписание встреч сохранено",
    "Create appointment schedule" : "Создать расписание встреч",
    "Edit appointment schedule" : "Редактировать расписание",
    "Update" : "Обновить",
    "Appointment name" : "Название встречи",
    "Location" : "Местоположение",
    "Create a Talk room" : "Создать обсуждение",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Для каждой забронированной встречи будет сгенерирована уникальная ссылка, которая будет отправлена по электронной почте с подтверждением",
    "Description" : "Описание",
    "Visibility" : "Видимость",
    "Duration" : "Продолжительность",
    "Increments" : "Повышения",
    "Additional calendars to check for conflicts" : "Дополнительные календари для проверки на наличие конфликтов",
    "Pick time ranges where appointments are allowed" : "Выберите диапазон времени, когда разрешено назначать встречи",
    "to" : "по",
    "Delete slot" : "Удалить слот",
    "No times set" : "Время не установлено",
    "Add" : "Добавить",
    "Monday" : "Понедельник",
    "Tuesday" : "Вторник",
    "Wednesday" : "Среда",
    "Thursday" : "Четверг",
    "Friday" : "Пятница",
    "Saturday" : "Суббота",
    "Sunday" : "Воскресенье",
    "Weekdays" : "Дни недели",
    "Add time before and after the event" : "Добавить время до и после мероприятия",
    "Before the event" : "До начала мероприятия",
    "After the event" : "После мероприятия",
    "Planning restrictions" : "Ограничения при планировании",
    "Minimum time before next available slot" : "Минимальное время до следующего доступного слота",
    "Max slots per day" : "Максимум слотов в день",
    "Limit how far in the future appointments can be booked" : "Лимит на то, как далеко в будущем можно записываться на встречу",
    "It seems a rate limit has been reached. Please try again later." : "Похоже, был достигнут лимит частоты запросов. Повторите попытку позже.",
    "Please confirm your reservation" : "Подтвердите своё бронирование",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Мы отправили вам электронное письмо с подробной информацией. Пожалуйста, подтвердите свою встречу, используя ссылку в письме. Теперь вы можете закрыть эту страницу.",
    "Your name" : "Ваше имя",
    "Your email address" : "Ваш адрес электронной почты",
    "Please share anything that will help prepare for our meeting" : "Пожалуйста, поделитесь с нами тем, что поможет подготовиться к нашей встрече",
    "Could not book the appointment. Please try again later or contact the organizer." : "Не удалось забронировать встречу. Повторите попытку позже или свяжитесь с организатором.",
    "Back" : "Назад",
    "Book appointment" : "Записаться на прием",
    "Error fetching Talk conversations." : "Ошибка получения списка обсуждений Talk",
    "Conversation does not have a valid URL." : "Ссылка на обсуждение некорректна",
    "Successfully added Talk conversation link to location." : "Ссылка на обсуждение в приложении Конференции добавлена в местоположение события.",
    "Successfully added Talk conversation link to description." : "Ссылка на обсуждение в приложении Конференции добавлена в описание события.",
    "Failed to apply Talk room." : "Не удалось применить Talk room.",
    "Talk conversation for event" : "Обсуждение события в приложении Конференции",
    "Error creating Talk conversation" : "Ошибка создания обсуждения в приложении Конференции",
    "Select a Talk Room" : "Выберите комнату в приложении Конференции",
    "Add Talk conversation" : "Добавить ссылку на обсуждение в приложении Конференции",
    "Fetching Talk rooms…" : "Получение списка комнат приложения Конференции",
    "No Talk room available" : "В приложении Конференции нет доступных комнат",
    "Create public conversation" : "Создать открытое обсуждение",
    "Select conversation" : "Выберите обсуждение",
    "on" : "в",
    "at" : "в",
    "before at" : "ранее в",
    "Notification" : "Уведомление",
    "Email" : "Эл. почта",
    "Audio notification" : "Звуковое уведомление",
    "Other notification" : "Другое уведомление",
    "Relative to event" : "Относительно события",
    "On date" : "В указанную дату",
    "Edit time" : "Редактировать время",
    "Save time" : "Сохранить время",
    "Remove reminder" : "Удалить напоминание",
    "Add reminder" : "Добавить напоминание",
    "seconds" : "секунд",
    "minutes" : "минут",
    "hours" : "часов",
    "days" : "дней",
    "weeks" : "недель",
    "Choose a file to add as attachment" : "Выбрать файл для вложения",
    "Choose a file to share as a link" : "Выберите файл для публикации ссылкой",
    "Attachment {name} already exist!" : "Файл вложения «{name}» уже существует.",
    "Could not upload attachment(s)" : "Не удалось загрузить вложение (вложения)",
    "You are about to navigate to {link}. Are you sure to proceed?" : "Вы собираетесь перейти к {link}. Продолжить?",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Вы собираетесь перейти к {host}. Продолжить? Ссылка: {link}",
    "Proceed" : "Перейти",
    "No attachments" : "Нет ни одного вложения",
    "Add from Files" : "Добавить из файлов",
    "Upload from device" : "Загрузить с устройства",
    "Delete file" : "Удалить файл",
    "Confirmation" : "Подтверждение",
    "_{count} attachment_::_{count} attachments_" : ["{count} вложение","{count} вложения","{count} вложений","{count} вложений"],
    "Suggested" : "Предложенный",
    "Available" : "Доступный",
    "Invitation accepted" : "Приглашение принято",
    "Accepted {organizerName}'s invitation" : "Принято приглашение от {organizerName}",
    "Participation marked as tentative" : "Участие обозначено как «под вопросом»",
    "Invitation is delegated" : "Приглашение делегировано",
    "Not available" : "Не доступен",
    "Invitation declined" : "Приглашение отклонено",
    "Declined {organizerName}'s invitation" : "Отклонено приглашение от {organizerName}",
    "Availability will be checked" : "Доступность будет проверена",
    "Invitation will be sent" : "Приглашение будет отправлено",
    "Failed to check availability" : "Не удалось проверить наличие",
    "Failed to deliver invitation" : "Не удалось доставить приглашение",
    "Awaiting response" : "Ожидание ответа",
    "Checking availability" : "Проверка доступности",
    "Has not responded to {organizerName}'s invitation yet" : "Ответ на приглашение от {organizerName} ещё не отправлен",
    "Suggested times" : "Предложенные варианты времени",
    "chairperson" : "Председатель",
    "required participant" : "Обязательный участник",
    "non-participant" : "Не является участником",
    "optional participant" : "Необязательный участник",
    "{organizer} (organizer)" : "{organizer} (организатор)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Selected slot" : "Выбраный слот",
    "Availability of attendees, resources and rooms" : "Доступность участников, ресурсов и комнат",
    "Suggestion accepted" : "Предложение принято",
    "Previous date" : "Предыдущая дата",
    "Next date" : "Следующая дата",
    "Legend" : "Легенда",
    "Out of office" : "Вне офиса",
    "Attendees:" : "Участники:",
    "local time" : "Местное время",
    "Done" : "Выполненные",
    "Search room" : "Поиск комнаты",
    "Room name" : "Название комнаты",
    "Check room availability" : "Проверить наличие номеров",
    "Free" : "Свободен",
    "Busy (tentative)" : "Занят (под вопросом)",
    "Busy" : "Занят",
    "Unknown" : "Неизвестно",
    "Find a time" : "Найди время",
    "The invitation has been accepted successfully." : "Приглашение принято.",
    "Failed to accept the invitation." : "Не удалось принять приглашение.",
    "The invitation has been declined successfully." : "Приглашение отклонено.",
    "Failed to decline the invitation." : "Не удалось отклонить приглашение.",
    "Your participation has been marked as tentative." : "Выше участие было обозначено как «под вопросом».",
    "Failed to set the participation status to tentative." : "Не удалось обозначить свое участие как «под вопросом».",
    "Accept" : "Принять",
    "Decline" : "Отклонить",
    "Tentative" : "Под вопросом",
    "No attendees yet" : "Ещё нет участников",
    "{confirmedCount} confirmed, {waitingCount} awaiting response" : "Подтвердили: {confirmedCount}, ожидание ответа: {waitingCount}",
    "Please add at least one attendee to use the \"Find a time\" feature." : "Добавьте хотя бы одного участника, чтобы использовать функцию «Найти время».",
    "Attendees" : "Участники",
    "_%n more attendee_::_%n more attendees_" : ["Ещё %n участник","Ещё %n участника ","Ещё %n участников","Ещё %n участников"],
    "Remove group" : "Удалить группу",
    "Remove attendee" : "Удалить участника",
    "Request reply" : "Запросить ответ",
    "Chairperson" : "Председатель",
    "Required participant" : "Обязательный участник",
    "Optional participant" : "Необязательный участник",
    "Non-participant" : "Не участвует",
    "_%n member_::_%n members_" : ["%n участник","%n участника","%n участников","%n участника"],
    "Search for emails, users, contacts, contact groups or teams" : "Поиск почтовых адресов (email), пользователей, контактов, групп контактов или команд",
    "No match found" : "Соответствий не найдено",
    "Note that members of circles get invited but are not synced yet." : "Обратите внимание, что участники кругов получают приглашения, но еще не синхронизированы.",
    "Note that members of contact groups get invited but are not synced yet." : "Обратите внимание, что члены контактных групп приглашаются, но еще не синхронизированы.",
    "(organizer)" : "(организатор)",
    "Make {label} the organizer" : "Сделать {label} организатором",
    "Make {label} the organizer and attend" : "Сделайте {label} организатором и примите участие",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Чтобы отправлять приглашения и обрабатывать ответы, [linkopen]добавьте свой адрес электронной почты в личные настройки[linkclose].",
    "Remove color" : "Убрать отметку цветом",
    "Event title" : "Название события",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Изменение параметра «весь день» для повторяющегося события не поддерживается.",
    "From" : "От",
    "To" : "По",
    "Your Time" : "Ваше время",
    "Repeat" : "Повтор",
    "Repeat event" : "Повторять событие",
    "_time_::_times_" : ["раз","раз","раз","раз"],
    "never" : "никогда",
    "on date" : "в указанную дату",
    "after" : "после",
    "End repeat" : "Прекратить повтор",
    "Select to end repeat" : "Выбрать до последнего повторения",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Невозможно задать правила повторения этого события, так как оно является исключением из правил повтора исходного события.",
    "first" : "первый",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Изменение правила повторения повлияет только на это и все будущие повторения события.",
    "Repeat every" : "Повторять каждые",
    "By day of the month" : "В указанные дни месяца",
    "On the" : "По",
    "_day_::_days_" : ["день","дня","дней","дни"],
    "_week_::_weeks_" : ["неделя","недель","недель","недели"],
    "_month_::_months_" : ["месяц","месяца","месяцев","месяца"],
    "_year_::_years_" : ["год","года","лет","года"],
    "On specific day" : "В определенный день",
    "weekday" : "рабочий день",
    "weekend day" : "выходной день",
    "Does not repeat" : "Не повторять",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Заданные правила повторения этого события не полностью поддерживается Nextcloud. При изменении правил, некоторые повторения могут быть потеряны.",
    "No rooms or resources yet" : "Комнаты или ресурсы пока не назначены",
    "Resources" : "Ресурсы",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} место","{seatingCapacity} места","{seatingCapacity} мест","{seatingCapacity} мест"],
    "Add resource" : "Добавить ресурс",
    "Has a projector" : "Есть проектор",
    "Has a whiteboard" : "Имеет доску для записей",
    "Wheelchair accessible" : "Доступно для кресла-коляски",
    "Remove resource" : "Удалить ресурс",
    "Search for resources or rooms" : "Поиск ресурсов или помещений",
    "available" : "доступный",
    "unavailable" : "недоступен",
    "Show all rooms" : "Показать все комнаты",
    "Projector" : "Проектор",
    "Whiteboard" : "Доска",
    "Room type" : "Тип комнаты",
    "Any" : "Любой",
    "Minimum seating capacity" : "Минимальная вместимость",
    "More details" : "Подробнее",
    "Update this and all future" : "Обновить это и все будущие повторния",
    "Update this occurrence" : "Обновить это повторение",
    "Public calendar does not exist" : "Общедоступный календарь не существует",
    "Maybe the share was deleted or has expired?" : "Возможно общий ресурс был удалён или истёк срок действия доступа.",
    "Remove date" : "Удалить дату",
    "Attendance required" : "Участие требуется",
    "Attendance optional" : "Участие опционально",
    "Remove participant" : "Исключить участника",
    "Yes" : "Да",
    "No" : "Нет",
    "Maybe" : "Возможно",
    "None" : "Отсутствует",
    "Select your meeting availability" : "Выберите вашу доступность для встречи",
    "Create a meeting for this date and time" : "Создать встречу на эту дату и время",
    "Create" : "Создать",
    "No participants or dates available" : "Нет доступных участников или дат",
    "from {formattedDate}" : "с {formattedDate}",
    "to {formattedDate}" : "по {formattedDate}",
    "on {formattedDate}" : " {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "с {formattedDate} в {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "до {formattedDate} в {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "{formattedDate} в {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} в {formattedTime}",
    "Please enter a valid date" : "Введите верную дату",
    "Please enter a valid date and time" : "Введите верную дату и время",
    "Select a time zone" : "Выберите часовой пояс",
    "Please select a time zone:" : "Выберите часовой пояс:",
    "Pick a time" : "Выберите время",
    "Pick a date" : "Выберите дату",
    "Type to search time zone" : "Начните вводить название часового поиска",
    "Global" : "Общие",
    "Holidays in {region}" : "Праздники в {region}",
    "An error occurred, unable to read public calendars." : "Произошла ошибка, невозможно прочитать публичные календари.",
    "An error occurred, unable to subscribe to calendar." : "Произошла ошибка, не удалось подписаться на календарь.",
    "Public holiday calendars" : "Общие календари праздников",
    "Public calendars" : "Публичные календари",
    "No valid public calendars configured" : "Не настроено ни одного допустимого публичного календаря.",
    "Speak to the server administrator to resolve this issue." : "Обратитесь к администратору сервера для решения этой проблемы.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Общие календари праздников предоставляются Thunderbird. Данные календаря будут загружены с {website}",
    "These public calendars are suggested by the server administrator. Calendar data will be downloaded from the respective website." : "Эти публичные календари предлагаются администратором сервера. Данные календаря будут загружены с соответствующего веб-сайта.",
    "By {authors}" : "{authors}",
    "Subscribed" : "Подписано",
    "Subscribe" : "Подписаться",
    "Could not fetch slots" : "Не удалось получить слоты",
    "Select a date" : "Выберите дату",
    "Select slot" : "Выбрать слот",
    "No slots available" : "Нет свободных мест",
    "The slot for your appointment has been confirmed" : "Время вашей встречи было подтверждено",
    "Appointment Details:" : "Детали встречи:",
    "Time:" : "Время:",
    "Booked for:" : "Забронировано для:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Спасибо. Ваше бронирование с {startDate} по {endDate} подтверждено.",
    "Book another appointment:" : "Записаться на другую встречу:",
    "See all available slots" : "Посмотреть все доступные слоты",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Слот для вашей встречи с {startDate} по {endDate} больше не доступен.",
    "Please book a different slot:" : "Пожалуйста, забронируйте другое время:",
    "Book an appointment with {name}" : "Записаться на встречу к {name}",
    "No public appointments found for {name}" : "Не найдено ни одной публичной встречи для {name}",
    "Personal" : "Личный",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Автоматическое определение часового пояса определило ваш часовой пояс как UTC. Скорее всего, это результат мер безопасности вашего веб-браузера. Пожалуйста, установите часовой пояс вручную в настройках календаря.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Настроенный вами часовой пояс ({timezoneId}) не найден. Возвращение к UTC. Пожалуйста, измените свой часовой пояс в настройках и сообщите об этой проблеме.",
    "Show unscheduled tasks" : "Показать незапланированные задачи",
    "Unscheduled tasks" : "Незапланированные задачи",
    "Availability of {displayName}" : "Доступность {displayName}",
    "Discard event" : "Сбросить событие",
    "Edit event" : "Редактировать событие",
    "Event does not exist" : "Событие не существует",
    "Duplicate" : "Дублировать",
    "Delete this occurrence" : "Удалить это повторение",
    "Delete this and all future" : "Удалить это и все будущие повторения",
    "All day" : "Весь день",
    "Modifications wont get propagated to the organizer and other attendees" : "Изменения не будут распространены на организатора и других участников",
    "Managing shared access" : "Управление общим доступом ",
    "Deny access" : "Закрыть доступ",
    "Invite" : "Приглашение",
    "Discard changes?" : "Сбросить изменения?",
    "Are you sure you want to discard the changes made to this event?" : "Вы действительно хотите сбросить изменения в этом событии?",
    "_User requires access to your file_::_Users require access to your file_" : ["Пользователю требуется доступ к вашему файлу","Пользователям требуется доступ к вашему файлу","Пользователям требуется доступ к вашему файлу","Пользователям требуется доступ к вашему файлу"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Вложение, требующие общего доступа","Вложения, требующие общего доступа","Вложения, требующие общего доступа","Вложения, требующие общего доступа"],
    "Untitled event" : "Событие без названия",
    "Close" : "Закрыть",
    "Modifications will not get propagated to the organizer and other attendees" : "Изменения не будут распространены на организатора и других участников",
    "Meeting proposals overview" : "Обзор предложенных встреч",
    "Edit meeting proposal" : "Изменить предложение о встрече",
    "Create meeting proposal" : "Создать предложение о встрече",
    "Update meeting proposal" : "Обновить предложение о встрече",
    "Saving proposal \"{title}\"" : "Сохранение предложения «{title}»",
    "Successfully saved proposal" : "Предложение успешно сохранено",
    "Failed to save proposal" : "Не удалось сохранить предложение",
    "Create a meeting for \"{date}\"? This will create a calendar event with all participants." : "Создать встречу на \"{date}\"? Это создаст событие в календаре для всех участников.",
    "Creating meeting for {date}" : "Создать встречу на {date}",
    "Successfully created meeting for {date}" : "Встреча на {date} успешно создана",
    "Failed to create a meeting for {date}" : "Не удалось создать встречу на {date}",
    "Please enter a valid duration in minutes." : "Пожалуйста, введите допустимую длительность в минутах",
    "Failed to fetch proposals" : "Не удалось получить предложения",
    "Failed to fetch free/busy data" : "Не удалось получить информацию о занятости",
    "Selected" : "Выбрано",
    "No Description" : "Нет описания",
    "No Location" : "Нет местоположения",
    "Edit this meeting proposal" : "Изменить это предложение о встрече",
    "Delete this meeting proposal" : "Удалить это предложение о встрече",
    "Title" : "Название",
    "15 min" : "15 мин",
    "30 min" : "30 мин",
    "60 min" : "60 мин",
    "90 min" : "90 мин",
    "Participants" : "Участники",
    "Selected times" : "Выбранное время",
    "Previous span" : "Предыдущий интервал",
    "Next span" : "Следующий интервал",
    "Less days" : "Меньше дней",
    "More days" : "Больше дней",
    "Loading meeting proposal" : "Загрузка предложения о встрече",
    "No meeting proposal found" : "Предложений о встрече не найдено",
    "Please wait while we load the meeting proposal." : "Пожалуйста подождите, пока предложение о встрече загрузится",
    "The link you followed may be broken, or the meeting proposal may no longer exist." : "Ссылка, по которой Вы перешли, не работает, или предложения о встрече больше не существует.",
    "Thank you for your response!" : "Спасибо за ваш ответ!",
    "Your vote has been recorded. Thank you for participating!" : "Ваш голос учтён. Спасибо за участие!",
    "Unknown User" : "Неизвестный пользователь",
    "No Title" : "Нет названия",
    "No Duration" : "Нет длительности",
    "Select a different time zone" : "Выберите другой часовой пояс",
    "Submit" : "Отправить ответ",
    "Subscribe to {name}" : "Подписаться на {name}",
    "Export {name}" : "Экспортировать {name}",
    "Show availability" : "Показать доступность",
    "Anniversary" : "Годовщина",
    "Appointment" : "Встреча",
    "Business" : "Работа",
    "Education" : "Образование",
    "Holiday" : "Отпуск",
    "Meeting" : "Встреча",
    "Miscellaneous" : "Разное",
    "Non-working hours" : "Не рабочие часы",
    "Not in office" : "Не в офисе",
    "Phone call" : "Телефонный звонок",
    "Sick day" : "Больничный",
    "Special occasion" : "Особый случай",
    "Travel" : "Путешествие",
    "Vacation" : "Отпуск",
    "Midnight on the day the event starts" : "Полночь в день начала мероприятия",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n день до мероприятия в {formattedHourMinute}","%n дня до мероприятия в {formattedHourMinute}","%n дней до мероприятия в {formattedHourMinute}","%nдней до мероприятия в {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n неделя до мероприятия в {formattedHourMinute}","%n недели до мероприятия в {formattedHourMinute}","%n недель до мероприятия в {formattedHourMinute}","%n недель до мероприятия в {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "в день мероприятия в {formattedHourMinute}",
    "at the event's start" : "во время начала события",
    "at the event's end" : "во время окончания события",
    "{time} before the event starts" : "{time} до времени начала события",
    "{time} before the event ends" : "{time} до времени окончания события",
    "{time} after the event starts" : "{time} после времени начала события",
    "{time} after the event ends" : "{time} до времени окончания события",
    "on {time}" : "в {time}",
    "on {time} ({timezoneId})" : "в {time} ({timezoneId})",
    "Week {number} of {year}" : "{number} неделя {year} года",
    "Daily" : "Ежедневно",
    "Weekly" : "Еженедельно",
    "Monthly" : "Ежемесячно",
    "Yearly" : "Ежегодно",
    "_Every %n day_::_Every %n days_" : ["Каждый %n день","Каждые %n дня","Каждые %n дней","Каждые %n дня"],
    "_Every %n week_::_Every %n weeks_" : ["Каждую %n неделю","Каждые %n недели","Каждые %n недель","Каждые %n недели"],
    "_Every %n month_::_Every %n months_" : ["Каждый %n месяц","Каждые %n месяца","Каждый %n месяцев","Каждые %n месяца"],
    "_Every %n year_::_Every %n years_" : ["Каждый %n год","Каждые %n года","Каждые %n лет","Каждые %n года"],
    "_on {weekday}_::_on {weekdays}_" : ["по {weekday}","по {weekday}","по {weekday}","по {weekday}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : [" {dayOfMonthList}"," {dayOfMonthList}"," {dayOfMonthList}"," {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "по {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {dayOfMonthList}" : "в {monthNames} {dayOfMonthList} числа",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "в {monthNames} по {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "до {untilDate}",
    "_%n time_::_%n times_" : ["%n раз","%n раза","%n раз","%n раза"],
    "second" : "секунду",
    "third" : "третий",
    "fourth" : "четвёртый",
    "fifth" : "пятый",
    "second to last" : "предпоследний",
    "last" : "последний",
    "Untitled task" : "Задача без названия",
    "Please ask your administrator to enable the Tasks App." : "Попросите администратора сервера активировать приложение «Задачи».",
    "You are not allowed to edit this event as an attendee." : "Вам не разрешается редактировать это мероприятие как участнику",
    "W" : "Н",
    "%n more" : "и ещё %n",
    "No events to display" : "Отсутствуют события для показа",
    "All participants declined" : "Все  участники отклонили событие",
    "Please confirm your participation" : "Пожалуйста, подтвердите свое участие",
    "You declined this event" : "Вы отменили это событие",
    "Your participation is tentative" : "Ваше участие пока под вопросом",
    "_+%n more_::_+%n more_" : ["+ ещё %n","+ ещё %n","+ ещё %n","+ ещё %n"],
    "No events" : "Нет ни одного события",
    "Create a new event or change the visible time-range" : "Создать событие или изменить интервал видимости",
    "Failed to save event" : "Не удалось сохранить событие",
    "It might have been deleted, or there was a typo in a link" : "Возможно, оно было удалено или вы выполнили переход по неверной ссылке",
    "It might have been deleted, or there was a typo in the link" : "Возможно, оно было удалено или вы выполнили переход по неверной ссылке",
    "Meeting room" : "Комната для переговоров",
    "Lecture hall" : "Лекционный зал",
    "Seminar room" : "Комната для семинаров",
    "Other" : "Другое",
    "When shared show" : "Показывать при публикации",
    "When shared show full event" : "Показывать подробно при публикации",
    "When shared show only busy" : "Показывать только занятость при публикации",
    "When shared hide this event" : "Скрыть это событие при публикации",
    "The visibility of this event in read-only shared calendars." : "Видимость этого события в опубликованных календарях, доступных только для чтения.",
    "Add a location" : "Добавить местоположение",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Добавьте описание\n\n- Для чего данное событие\n- Агенда\n- Как участникам подготовиться к событию",
    "Status" : "Состояние",
    "Confirmed" : "Подтверждено",
    "Canceled" : "Отменена",
    "Confirmation about the overall status of the event." : "Подтверждение об общем статусе события.",
    "Show as" : "Показать как",
    "Take this event into account when calculating free-busy information." : "Учитывать это событие при учёте свободного времени.",
    "Categories" : "Категории",
    "Categories help you to structure and organize your events." : "Категории позволяют структурировать и упорядочивать свои события.",
    "Search or add categories" : "Поиск и добавление категорий",
    "Add this as a new category" : "Добавить как новую категорию",
    "Custom color" : "Свой цвет",
    "Special color of this event. Overrides the calendar-color." : "Задать свой цвет события, отличающийся от цвета календаря",
    "Error while sharing file" : "Ошибка сохранения файла",
    "Error while sharing file with user" : "Ошибка при обмене файлом с пользователем",
    "Error creating a folder {folder}" : "Ошибка при создании папки {folder}",
    "Attachment {fileName} already exists!" : "Вложение {fileName} уже существует!",
    "Attachment {fileName} added!" : "Вложение {fileName} добавлено!",
    "An error occurred during uploading file {fileName}" : "Произошла ошибка при загрузке файла {fileName}",
    "An error occurred during getting file information" : "Произошла ошибка при получении информации о файле",
    "Talk conversation for proposal" : "Обсуждение предложения в приложении Конференции",
    "An error occurred, unable to delete the calendar." : "Произошла ошибка, не удалось удалить календарь.",
    "Imported {filename}" : "Файл {filename} импортирован",
    "This is an event reminder." : "Это напоминание о событии.",
    "Error while parsing a PROPFIND error" : "Ошибка при анализе ошибки PROPFIND",
    "Appointment not found" : "Встреча не найдена",
    "User not found" : "Пользователь не найден",
    "Hidden" : "Скрыто",
    "can edit" : "может ред.",
    "Calendar name …" : "Название календаря ...",
    "Default attachments location" : "Расположение сохранения вложений по умолчанию",
    "Automatic ({detected})" : "Автоматически ({detected})",
    "Shortcut overview" : "Обзор ссылок",
    "CalDAV link copied to clipboard." : "Ссылка CalDAV скопирована в буфер обмена.",
    "CalDAV link could not be copied to clipboard." : "Не удалось скопировать ссылку CalDAV в буфер обмена.",
    "Enable birthday calendar" : "Включить календарь дней рождения",
    "Show tasks in calendar" : "Показывать задачи в календаре",
    "Enable simplified editor" : "Использовать упрощённый редактор",
    "Limit the number of events displayed in the monthly view" : "Ограничьте количество событий, отображаемых в ежемесячном представлении",
    "Show weekends" : "Показывать выходные",
    "Show week numbers" : "Показывать номера недель",
    "Time increments" : "Шаг изменения времени",
    "Default calendar for incoming invitations" : "Календарь для полученных приглашений по умолчанию",
    "Copy primary CalDAV address" : "Скопировать основной адрес CalDAV",
    "Copy iOS/macOS CalDAV address" : "Скопировать адрес CalDAV для iOS/macOS",
    "Personal availability settings" : "Личные настройки доступности",
    "Show keyboard shortcuts" : "Показать горячие клавиши клавиатуры",
    "Create a new public conversation" : "Создать новую публичную беседу",
    "{invitedCount} invited, {confirmedCount} confirmed" : "Приглашено: {invitedCount}, подтвердили участие: {confirmedCount}",
    "Successfully appended link to talk room to location." : "Ссылка на переговорную комнату успешно добавлена.",
    "Successfully appended link to talk room to description." : "Ссылка на комнату приложения Talk добавлена в описание.",
    "Error creating Talk room" : "Не удалось создать комнату в приложении Talk.",
    "_%n more guest_::_%n more guests_" : ["Ещё 1 гость","Ещё %n гостя","Ещё %n гостей","Ещё %n гостей"],
    "The visibility of this event in shared calendars." : "Видимость этого события в опубликованных календарях. "
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
