OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "A sessão de utilizador expirou inesperadamente",
    "Provided email-address is not valid" : "O endereço de e-mail que inseriu não é válido",
    "%s has published the calendar »%s«" : "%s publicou o calendário »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Ocorreu um erro ao enviar o email. Por favor contacte o seu administrador",
    "Successfully sent email to %1$s" : "A mensagem enviada com sucesso para %1$s ",
    "Hello," : "Olá,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Queremos informa-lo que %s publicou o calendário »%s«.",
    "Open »%s«" : "Abrir »%s«",
    "Cheers!" : "Parabéns!",
    "Upcoming events" : "Próximos eventos",
    "More events" : "Mais eventos",
    "Calendar" : "Calendário",
    "New booking {booking}" : "Novo agendamento {booking}",
    "Appointments" : "Reuniões",
    "Schedule appointment \"%s\"" : "Marcar reunião \"%s\"",
    "Schedule an appointment" : "Marcar uma reunião",
    "Prepare for %s" : "Prepare-se para %s",
    "Follow up for %s" : "Acompanhamento para %s",
    "Your appointment \"%s\" with %s needs confirmation" : "O seu agendamento \"%s\" com %sprecisa de confirmação",
    "Dear %s, please confirm your booking" : "Caro %s, por favor confirme o seu agendamento",
    "Confirm" : "Confirmar",
    "Description:" : "Descrição:",
    "This confirmation link expires in %s hours." : "Esta ligação de confirmação expira em %s horas.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Se deseja cancelar a sua marcação, deve contactar o seu coordenador respondendo a esta mensagem ou pode visitar a sua página de perfil.",
    "Your appointment \"%s\" with %s has been accepted" : "O seu agendamento \"%s\" com %s foi aceite.",
    "Dear %s, your booking has been accepted." : "Caro/a %s, o seu agendamento foi aceite.",
    "Appointment for:" : "Agendamento para:",
    "Date:" : "Data:",
    "Where:" : "Local:",
    "Comment:" : "Comentário:",
    "You have a new appointment booking \"%s\" from %s" : "Tem uma nova reserva de marcação \"%s\" de %s",
    "Location:" : "Localização:",
    "Duration:" : "Duração:",
    "A Calendar app for Nextcloud" : "Uma aplicação de calendário para o Nextcloud",
    "Previous day" : "Dia anterior",
    "Previous week" : "Semana anterior",
    "Previous month" : "Mês anterior",
    "Next day" : "Dia seguinte",
    "Next week" : "Próxima semana",
    "Next month" : "Próximo mês",
    "Today" : "Hoje",
    "Day" : "Dia",
    "Week" : "Semana",
    "Month" : "Mês",
    "Year" : "Year",
    "List" : "Lista",
    "Appointment link was copied to clipboard" : "Hiperligação da reunião copiada para a área de transferência",
    "Appointment link could not be copied to clipboard" : "Não é possível copiar a hiperligação da reunião para a área de transferência",
    "Preview" : "Pré-visualizar",
    "Copy link" : "Copiar hiperligação",
    "Edit" : "Editar",
    "Delete" : "Eliminar",
    "Create new" : "Criar novo",
    "Disable calendar \"{calendar}\"" : "Desativar calendário \"{calendar}\"",
    "Disable untitled calendar" : "Desativar calendário sem título",
    "Enable calendar \"{calendar}\"" : "Ativar calendário \"{calendar}\"",
    "Enable untitled calendar" : "Ativar calendário sem título",
    "An error occurred, unable to change visibility of the calendar." : "Ocorreu um erro, incapaz de alterar a visibilidade do calendário.",
    "Untitled calendar" : "Calendário sem titulo",
    "Shared with you by" : "Partilhado consigo por",
    "Edit and share calendar" : "Editar e partilhar calendário",
    "Edit calendar" : "Editar calendário",
    "An error occurred, unable to create the calendar." : "Ocorreu um erro que impede que o calendário seja criado",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Por favor introduza uma ligação válida (começada por http://, https://, webcal://, ou webcals://)",
    "Calendars" : "Calendários",
    "Add new" : "Adicionar nova",
    "New calendar" : "Novo calendário",
    "Name for new calendar" : "Nome para o novo calendário",
    "Creating calendar …" : "A criar o calendário …",
    "New calendar with task list" : "Novo calendário com lista de tarefas",
    "Creating subscription …" : "A criar subscrição ...",
    "Calendar link copied to clipboard." : "Hiperligação do calendário copiado para a área de transferência.",
    "Calendar link could not be copied to clipboard." : "Link do calendário não pôde se copiado para a área de transferência.",
    "Copy subscription link" : "Copiar ligação da subscrição",
    "Copying link …" : "Copiar ligação …",
    "Copied link" : "Ligação copiada",
    "Could not copy link" : "Não foi possível copiar a ligação",
    "Export" : "Exportar",
    "Untitled item" : "Item sem título ",
    "Unknown calendar" : "Calendário desconhecido",
    "Could not load deleted calendars and objects" : "Não foi possível carregar calendários e objetos apagados ",
    "Could not restore calendar or event" : "Não foi possível restaurar o calendário ou evento ",
    "Do you really want to empty the trash bin?" : "Tem a certeza que pretende esvaziar a reciclagem?",
    "Empty trash bin" : "Esvaziar a reciclagem",
    "Trash bin" : "Reciclagem",
    "Loading deleted items." : "A carregar itens excluídos.",
    "You do not have any deleted items." : "Não tem qualquer item apagado. ",
    "Name" : "Nome",
    "Deleted" : "Eliminado",
    "Restore" : "Restaurar",
    "Delete permanently" : "Eliminar permanentemente",
    "Could not update calendar order." : "Não foi possível atualizar a ordenação do calendário.",
    "Deck" : "Quadro",
    "Internal link" : "Ligação interna",
    "Copy internal link" : "Copiar ligação interna",
    "An error occurred, unable to publish calendar." : "Ocorreu um erro, não foi possível publicar o calendário.",
    "An error occurred, unable to send email." : "Ocorreu um erro, não foi possível enviar o email.",
    "Embed code copied to clipboard." : "Código de incorporação copiado para a área de transferência.",
    "Embed code could not be copied to clipboard." : "Não é possível copiar o código de incorporação",
    "Unpublishing calendar failed" : "Erro ao remover a publicação do calendário",
    "Share link" : "Partilhar hiperligação",
    "Copy public link" : "Copiar ligação publica",
    "Send link to calendar via email" : "Enviar ligação por correio eletrónico",
    "Enter one address" : "Introduza um endereço",
    "Sending email …" : "A enviar o email …",
    "Copy embedding code" : "Copiar código embebido",
    "Copying code …" : "A copiar código...",
    "Copied code" : "Código copiado",
    "Could not copy code" : "Não foi possível copiar o código",
    "Delete share link" : "Apagar hiperligação de partilha",
    "Deleting share link …" : "A apagar hiperligação de partilha",
    "Unshare with {displayName}" : "Cancelar partilha com {displayName}",
    "Share with users or groups" : "Partilhe com os utilizadores ou grupos",
    "No users or groups" : "Sem utilizadores ou grupos",
    "Share calendar" : "Partilhar calendário",
    "Unshare from me" : "Cancelar partilha",
    "Save" : "Guardar",
    "View" : "Ver",
    "Import calendars" : "Importar calendários",
    "Please select a calendar to import into …" : "Selecione o calendário para onde importar ...",
    "Filename" : "Nome do ficheiro",
    "Calendar to import into" : "Calendário para o qual importar",
    "Cancel" : "Cancelar",
    "_Import calendar_::_Import calendars_" : ["Importar calendário","Importar calendários","Importar calendários"],
    "{filename} could not be parsed" : "{filename} não pôde ser processado",
    "No valid files found, aborting import" : "A importação foi cancelada pois não foram encontrados ficheiros válidos",
    "Import partially failed. Imported {accepted} out of {total}." : "A importação falhou parcialmente. Importados {accepted} de um total de {total}.",
    "Automatic" : "Automático",
    "Automatic ({timezone})" : "Automático ({timezone})",
    "New setting was not saved successfully." : "Erro a gravar a nova configuração.",
    "Navigation" : "Navegação",
    "Previous period" : "Período anterior",
    "Next period" : "Próximo período",
    "Views" : "Vistas",
    "Day view" : "Vista diária",
    "Week view" : "Vista semanal",
    "Month view" : "Vista mensal",
    "List view" : "Vista em lista",
    "Actions" : "Ações",
    "Create event" : "Criar evento",
    "Show shortcuts" : "Mostrar atalhos de teclado",
    "Editor" : "Editor",
    "Close editor" : "Fechar editor",
    "Save edited event" : "Gravar evento editado",
    "Delete edited event" : "Apagar evento editado",
    "Duplicate event" : "Duplicar evento",
    "or" : "ou",
    "Calendar settings" : "Configurações do calendário",
    "No reminder" : "Nenhum lembrete",
    "General" : "Geral",
    "Appearance" : "Aspeto",
    "Editing" : "A editar",
    "Default reminder" : "Lembrete padrão",
    "Files" : "Ficheiros",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minuto","{duration} minutos","{duration} minutos"],
    "0 minutes" : "0 minutos",
    "_{duration} hour_::_{duration} hours_" : ["{duration} hora","{duration} horas","{duration} horas"],
    "_{duration} day_::_{duration} days_" : ["{duration} dia","{duration} dias","{duration} dias"],
    "_{duration} month_::_{duration} months_" : ["{duration} mês","{duration} meses","{duration} meses"],
    "_{duration} year_::_{duration} years_" : ["{duration} ano","{duration} anos","{duration} anos"],
    "To configure appointments, add your email address in personal settings." : "Para configurar reuniões, adicione seu o endereço de e-mail nas configurações pessoais.",
    "Public – shown on the profile page" : "Público - mostrado na página de perfil",
    "Private – only accessible via secret link" : "Privado - acessível apenas por ligação secreta",
    "Update" : "Atualizar",
    "Appointment name" : "Nome da marcação",
    "Location" : "Localização:",
    "Description" : "Descrição",
    "Visibility" : "Visibilidade",
    "Duration" : "Duração",
    "Increments" : "Incrementos",
    "Additional calendars to check for conflicts" : "Calendários adicionais para verificar conflitos",
    "Pick time ranges where appointments are allowed" : "Escolha os intervalos de tempo onde as reuniões são permitidas",
    "to" : "Para",
    "Delete slot" : "Delete slot",
    "No times set" : "Nenhum horário definido",
    "Add" : "Adicionar",
    "Monday" : "Segunda",
    "Tuesday" : "Terça",
    "Wednesday" : "Quarta",
    "Thursday" : "Quinta",
    "Friday" : "Sexta",
    "Saturday" : "Sábado",
    "Sunday" : "Domingo",
    "Weekdays" : "Weekdays",
    "Add time before and after the event" : "Adicionar um tempo antes e depois do evento",
    "Before the event" : "Antes do evento",
    "After the event" : "Depois do evento",
    "Planning restrictions" : "Restrições de planeamento",
    "Please confirm your reservation" : "Por favor confirme a sua reserva",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Enviamos-lhe um e-mail com os detalhes. Por favor confirme a sua reunião utilizando a ligação do e-mail. Pode fechar esta página.",
    "Your name" : "O seu nome",
    "Your email address" : "O seu endereço de email",
    "Please share anything that will help prepare for our meeting" : "Por favor partilhe qualquer coisa que ajude na preparação da nossa reunião",
    "Could not book the appointment. Please try again later or contact the organizer." : "Não foi possível agendar a reunião. Tente novamente mais tarde ou entre em contacto com o organizador.",
    "Back" : "Voltar",
    "on" : "em",
    "at" : "às",
    "before at" : "antes em",
    "Notification" : "Notificação",
    "Email" : "E-mail",
    "Audio notification" : "Notificação de áudio",
    "Other notification" : "Outras notificações",
    "Relative to event" : "Relativo ao evento",
    "On date" : "Na data",
    "Edit time" : "Editar horário",
    "Save time" : "Gravar horário",
    "Remove reminder" : "Apagar lembrete",
    "Add reminder" : "Adicionar lembrete ",
    "seconds" : "segundos",
    "minutes" : "minutos",
    "hours" : "horas",
    "days" : "dias",
    "weeks" : "semanas",
    "Choose a file to add as attachment" : "Escolha um ficheiro para adicionar como anexo",
    "Proceed" : "Prosseguir",
    "Delete file" : "Apagar ficheiro",
    "Suggested" : "Sugerido",
    "Available" : "Disponível",
    "Invitation accepted" : "Convite aceite",
    "Accepted {organizerName}'s invitation" : "Aceite convite de {organizerName}",
    "Participation marked as tentative" : "Participação marcada como tentativa",
    "Not available" : "Indisponível",
    "Invitation declined" : "Convite recusado",
    "Checking availability" : "A verificar disponibilidade",
    "Out of office" : "Fora do escritório",
    "Attendees:" : "Participantes:",
    "Done" : "Concluído",
    "Room name" : "Nome da sala",
    "Free" : "Livre",
    "Busy" : "Ocupado",
    "Unknown" : "Desconhecido",
    "The invitation has been accepted successfully." : "O convite foi aceite com sucesso.",
    "Failed to accept the invitation." : "Falha ao aceitar o convite.",
    "The invitation has been declined successfully." : "O convite foi recusado com sucesso.",
    "Accept" : "Aceitar",
    "Decline" : "Recusar",
    "Tentative" : "Tentativa",
    "Attendees" : "Participantes",
    "From" : "De",
    "To" : "Para",
    "Repeat" : "Repetir",
    "never" : "nunca",
    "after" : "depois",
    "first" : "primeiro",
    "Repeat every" : "Repetir a cada",
    "By day of the month" : "Por dia do mês",
    "On the" : "No",
    "_day_::_days_" : ["dia","dias","dias"],
    "_week_::_weeks_" : ["semana","semanas","semanas"],
    "_month_::_months_" : ["mês","meses","meses"],
    "_year_::_years_" : ["ano","anos","anos"],
    "weekday" : "dia da semana",
    "weekend day" : "dia do fim-de-semana",
    "Resources" : "Recursos",
    "available" : "disponível",
    "Yes" : "Sim",
    "No" : "Não",
    "None" : "Nenhum",
    "Create" : "Criar",
    "Pick a date" : "Escolha uma data",
    "Global" : "Global",
    "Subscribed" : "Subscrito",
    "Subscribe" : "Subscrever",
    "Personal" : "Pessoal",
    "Edit event" : "Editar evento",
    "All day" : "Todo o dia",
    "Invite" : "Convite",
    "Untitled event" : "Evento sem título",
    "Close" : "Fechar",
    "Selected" : "Selecionado",
    "Title" : "Título",
    "Participants" : "Participantes",
    "Submit" : "Submeter",
    "Anniversary" : "Aniversário",
    "Miscellaneous" : "Diversos",
    "Week {number} of {year}" : "Semana {number} do {year}",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "second" : "segundo",
    "third" : "terceiro",
    "fourth" : "quarto",
    "fifth" : "quinto",
    "second to last" : "do segundo ao último",
    "last" : "ultimo",
    "Untitled task" : "Untitled task",
    "Other" : "Outro",
    "When shared show full event" : "Quando partilhado, mostrar evento completo",
    "When shared show only busy" : "Quando partilhado, mostrar apenas ocupados",
    "When shared hide this event" : "Quando partilhado, ocultar este evento",
    "Status" : "Estado",
    "Confirmed" : "Confirmado",
    "Canceled" : "Cancelado",
    "Categories" : "Categorias",
    "Error while sharing file" : "Erro ao partilhar ficheiro",
    "An error occurred, unable to delete the calendar." : "Ocorreu um erro que impede que o calendário seja apagado",
    "User not found" : "Utilizador não encontrado",
    "Hidden" : "Escondido",
    "can edit" : "pode editar",
    "Calendar name …" : "Nome do calendário…",
    "Automatic ({detected})" : "Automático ({detected})",
    "Shortcut overview" : "Visão geral de atalhos",
    "CalDAV link copied to clipboard." : "Ligação CalDAV copiada para a área de transferência.",
    "CalDAV link could not be copied to clipboard." : "Não foi possível copiar a ligação CalDAV para a área de transferência.",
    "Enable birthday calendar" : "Ativar calendário de aniversários",
    "Show tasks in calendar" : "Mostrar tarefas no calendário",
    "Enable simplified editor" : "Ativar editor simplificado",
    "Show weekends" : "Mostrar fins-de-semana",
    "Show week numbers" : "Mostrar o número das semanas",
    "Time increments" : "Incrementos de tempo",
    "Copy primary CalDAV address" : "Copiar endereço CalDAV primário",
    "Copy iOS/macOS CalDAV address" : "Copiar endereço iOS/macOS CalDAV",
    "Personal availability settings" : "Configurações de disponibilidade pessoal",
    "Show keyboard shortcuts" : "Mostrar atalhos de teclado"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
