OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Alamat email yang diberikan terlalu panjang",
    "User-Session unexpectedly expired" : "Sesi-Pengguna kedaluwarsa secara tidak terduga",
    "Provided email-address is not valid" : "Alamat email tidak valid",
    "%s has published the calendar »%s«" : "%s telah mempublikasikan kalender »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Galat saat mengirim email. Silakan hubungi administrator Anda.",
    "Successfully sent email to %1$s" : "Berhasil mengirim email ke %1$s",
    "Hello," : "Halo,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Kami ingin menginformasikan Anda bahwa %s telah mempublikasikan kalender »%s«.",
    "Open »%s«" : "Buka »%s«",
    "Cheers!" : "Horee!",
    "Upcoming events" : "Acara mendatang",
    "No more events today" : "Tidak ada acara lagi hari ini",
    "No upcoming events" : "Tdak ada acara mendatang",
    "More events" : "Lebih banyak acara",
    "%1$s with %2$s" : "%1$sdengan %2$s",
    "Calendar" : "Kalender",
    "New booking {booking}" : "Pemesanan baru (pemesanan)",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) memesan janji temu \"{config_display_name}\" pada {date_time}.",
    "Appointments" : "Janji temu",
    "Schedule appointment \"%s\"" : "Jadwalkan janji temu \"%s\"",
    "Schedule an appointment" : "Jadwalkan janji temu",
    "Prepare for %s" : "Bersiaplah untuk %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Janji temu Anda \"%s\" dengan %s membutuhkan konfirmasi ",
    "Dear %s, please confirm your booking" : "Kepada %s, mohon konfirmasi pemesanan Anda",
    "Confirm" : "Konfirmasi",
    "This confirmation link expires in %s hours." : "Tautan konfirmasi ini akan kedaluwarsa dalam %s jam.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Jika Anda ingin membatalkan janji temu, mohon hubungi penyelenggara Anda dengan membalas email ini atau mengunjungi halaman profil mereka",
    "Your appointment \"%s\" with %s has been accepted" : "Janji temu \"%s\" dengan %stelah diterima",
    "Dear %s, your booking has been accepted." : "Kepada %s, pemesanan Anda telah diterima.",
    "Appointment for:" : "Janji temu untuk:",
    "Date:" : "Tanggal:",
    "You will receive a link with the confirmation email" : "Anda akan menerima tautan dengan email konfirmasi",
    "Where:" : "Tempat:",
    "Comment:" : "Komentar:",
    "You have a new appointment booking \"%s\" from %s" : "Anda memiliki pemesanan janji temu baru \"%s\" dari %s",
    "Dear %s, %s (%s) booked an appointment with you." : "Kepada %s, %s (%s) memesan janji temu dengan Anda.",
    "Location:" : "Lokasi:",
    "A Calendar app for Nextcloud" : "Aplikasi Kalender untuk Nextcloud",
    "Previous day" : "Hari sebelum",
    "Previous week" : "Minggu sebelum",
    "Previous year" : "Tahun lalu",
    "Previous month" : "Bulan sebelum",
    "Next day" : "Hari setelah",
    "Next week" : "Minggu setelah",
    "Next year" : "Tahun depan",
    "Next month" : "Bulan setelah",
    "Create new event" : "Buat acara baru",
    "Event" : "Acara",
    "Today" : "Hari Ini",
    "Day" : "Hari",
    "Week" : "Minggu",
    "Month" : "Bulan",
    "Year" : "Tahun",
    "List" : "daftar",
    "Appointment link was copied to clipboard" : "Tautan janji temu disalin ke papan klip",
    "Appointment link could not be copied to clipboard" : "Tautan janji temu tidak dapat disalin ke papan klip",
    "Preview" : "Pratinjau",
    "Copy link" : "Salin tautan",
    "Edit" : "Sunting",
    "Delete" : "Hapus",
    "Create new" : "Buat",
    "Disable calendar \"{calendar}\"" : "Nonaktifkan kalender \"{calendar}\"",
    "Disable untitled calendar" : "Nonaktifkan kalender tanpa judul",
    "Enable calendar \"{calendar}\"" : "Aktifkan kalender \"{calendar}\"",
    "Enable untitled calendar" : "Aktifkan kalender tanpa judul",
    "An error occurred, unable to change visibility of the calendar." : "Terjadi galat, tidak dapat mengubah visibilitas kalender.",
    "Untitled calendar" : "Kalender tanpa judul",
    "Shared with you by" : "Dibagikan dengan Anda oleh",
    "Edit and share calendar" : "Edit dan bagikan kalender",
    "Edit calendar" : "Edit kalender",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Batal berbagi kalender dalam {countdown} detik"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Menghapus kalender dalam {countdown} detik"],
    "An error occurred, unable to create the calendar." : "Terjadi galat, tidak dapat membuat kalender.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Silakan isi tautan valid (dimulai dengan http://, https://, webcal://, or webcals://)",
    "Calendars" : "Kalender",
    "Add new" : "Tambahkan baru",
    "New calendar" : "Kalender baru",
    "Name for new calendar" : "Nama untuk kalender baru",
    "Creating calendar …" : "Membuat kalender …",
    "New calendar with task list" : "Kalender baru dengan daftar tugas",
    "New subscription from link (read-only)" : "Langganan baru dengan tautan (baca-saja)",
    "Creating subscription …" : "Membuat langganan …",
    "Add public holiday calendar" : "Tambahkan kalender hari libur nasional",
    "Add custom public calendar" : "Tambahkan kalender publik khusus",
    "Calendar link copied to clipboard." : "Tautan kalender disalin ke papan klip.",
    "Calendar link could not be copied to clipboard." : "Tautan kalender tidak dapat disalin ke papan klip.",
    "Copy subscription link" : "Salin tautan berlangganan",
    "Copying link …" : "Menyalin tautan …",
    "Copied link" : "Tautan tersalin",
    "Could not copy link" : "Tidak dapat menyalin tautan",
    "Export" : "Ekspor",
    "Untitled item" : "Item tanpa judul",
    "Unknown calendar" : "Kalender tidak diketahui",
    "Could not load deleted calendars and objects" : "Tidak dapat memuat kalender dan objek yang dihapus",
    "Could not restore calendar or event" : "Tidak dapat memulihkan kalender atau acara",
    "Do you really want to empty the trash bin?" : "Apakah Anda benar-benar ingin mengosongkan keranjang sampah?",
    "Empty trash bin" : "Kosongkan tempat sampah",
    "Trash bin" : "Keranjang sampah",
    "Loading deleted items." : "Memuat item yang dihapus.",
    "You do not have any deleted items." : "Anda tidak memiliki item yang dihapus.",
    "Name" : "Nama",
    "Deleted" : "Dihapus",
    "Restore" : "Pulihkan",
    "Delete permanently" : "Hapus secara permanen",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Item dalam keranjang sampah dihapus setelah {numDays} hari"],
    "Could not update calendar order." : "Tidak dapat membarui urutan kalender.",
    "Deck" : "Longgok",
    "An error occurred, unable to publish calendar." : "Terjadi galat, tidak dapat menerbitkan kalender.",
    "An error occurred, unable to send email." : "Terjadi galat, tidak dapat mengirim email.",
    "Embed code copied to clipboard." : "Kode tersemat disalin ke papan klip",
    "Embed code could not be copied to clipboard." : "Kode tersemat tidak dapat disalin ke papan klip.",
    "Unpublishing calendar failed" : "Gagal membatalkan penerbitan kalender",
    "Share link" : "Bagikan tautan",
    "Copy public link" : "Salin tautan publik",
    "Send link to calendar via email" : "Kirim tautan kalender via email",
    "Sending email …" : "Mengirim email …",
    "Copy embedding code" : "Salin kode penyemat",
    "Copying code …" : "Menyalin kode …",
    "Copied code" : "Kode tersalin",
    "Could not copy code" : "Tidak dapat menyalin kode",
    "Delete share link" : "Hapus tautan berbagi",
    "Deleting share link …" : "Menghapus tautan berbagi …",
    "An error occurred while unsharing the calendar." : "Terjadi kesalahan saat membatalkan pembagian kalender. ",
    "An error occurred, unable to change the permission of the share." : "Terjadi galat, tidak dapat mengubah hak akses berbagi.",
    "Unshare with {displayName}" : "Batal berbagi dengan {displayName}",
    "Share with users or groups" : "Berbagi dengan pengguna atau grup",
    "No users or groups" : "Tidak ada pengguna atau grup",
    "Save" : "Simpan",
    "View" : "Tampilan",
    "Import calendars" : "Impor kalender",
    "Filename" : "Nama berkas",
    "Cancel" : "Batal",
    "_Import calendar_::_Import calendars_" : ["Impor kalender"],
    "Invalid location selected" : "Lokasi yang tidak valid dipilih",
    "Attachments folder successfully saved." : "Folder lampiran berhasil disimpan.",
    "Error on saving attachments folder." : "Kesalahan saat menyimpan folder lampiran.",
    "Attachments folder" : "Folder lampiran",
    "No valid files found, aborting import" : "Berkas valid tidak ditemukan, impor dibatalkan",
    "Import partially failed. Imported {accepted} out of {total}." : "Sebagian impor gagal. Dari {total} hanya {accepted} berhasil impor.",
    "Automatic" : "Otomatis",
    "Automatic ({timezone})" : "Otomatis ({timezone})",
    "New setting was not saved successfully." : "Setelan baru tidak berhasil tersimpan.",
    "Navigation" : "Navigasi",
    "Previous period" : "Periode sebelum",
    "Next period" : "Periode sesudah",
    "Views" : "Tampilan",
    "Day view" : "Tampilan hari",
    "Week view" : "Tampilan minggu",
    "Month view" : "Tampilan bulan",
    "List view" : "Tampilan lis",
    "Actions" : "Tindakan",
    "Create event" : "Buat acara",
    "Show shortcuts" : "Tampilkan pintasan",
    "or" : "atau",
    "General" : "Umum",
    "Appearance" : "Tampilan",
    "Editing" : "Pengeditan",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} menit"],
    "_{duration} hour_::_{duration} hours_" : ["{duration} jam"],
    "To configure appointments, add your email address in personal settings." : "Untuk mengonfigurasi janji temu, tambahkan alamat email Anda di pengaturan pribadi.",
    "Update" : "Perbarui",
    "Location" : "Lokasi",
    "Description" : "Deskrisi",
    "to" : "untuk",
    "Add" : "Masukkan",
    "Monday" : "Senin",
    "Tuesday" : "Selasa",
    "Wednesday" : "Rabu",
    "Thursday" : "Kamis",
    "Friday" : "Jumat",
    "Saturday" : "Sabtu",
    "Sunday" : "Minggu",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Kami telah mengirim email dengan detailnya. Mohon konfirmasikan janji temu Anda menggunakan tautan dalam email tersebut. Anda dapat menutup halaman ini sekarang.",
    "Your email address" : "Alamat email Anda",
    "Could not book the appointment. Please try again later or contact the organizer." : "Tidak dapat memesan janji temu. Mohon coba lagi nanti atau hubungi penyelenggara.",
    "on" : "pada",
    "at" : "di",
    "Notification" : "Notifikasi",
    "Email" : "Email",
    "Audio notification" : "Notifikasi audio",
    "Other notification" : "Notifikasi lain",
    "Relative to event" : "Relatif terhadap acara",
    "On date" : "Pada tanggal",
    "Edit time" : "Edit waktu",
    "Save time" : "Simpan waktu",
    "Remove reminder" : "Buang pengingat",
    "seconds" : "detik",
    "minutes" : "menit",
    "hours" : "jam",
    "days" : "hari",
    "weeks" : "minggu",
    "Choose a file to add as attachment" : "Pilih berkas untuk ditambahkan sebagai lampiran",
    "Delete file" : "Hapus berkas",
    "Not available" : "Tidak tersedia",
    "Availability of attendees, resources and rooms" : "Ketersediaan peserta, sumber daya, dan ruangan",
    "Out of office" : "Keluar kantor",
    "Done" : "Selesai",
    "Room name" : "Nama ruang",
    "Free" : "Luang",
    "Busy (tentative)" : "Sibuk (tentatif)",
    "Busy" : "Sibuk",
    "Unknown" : "Tidak diketahui",
    "The invitation has been accepted successfully." : "Undangan berhasil diterima.",
    "Failed to accept the invitation." : "Gagal menerima undangan.",
    "The invitation has been declined successfully." : "Undangan berhasil ditolak.",
    "Failed to decline the invitation." : "Gagal menolak undangan.",
    "Your participation has been marked as tentative." : "Partisipasi Anda telah ditandai sebagai belum pasti.",
    "Failed to set the participation status to tentative." : "Gagal menyetel status partisipasi menjadi belum pasti.",
    "Accept" : "Terima",
    "Decline" : "Tolak",
    "Tentative" : "Tentatif",
    "No attendees yet" : "Belum ada peserta",
    "Attendees" : "Peserta",
    "Remove group" : "Hapus grup",
    "Remove attendee" : "Hapus peserta",
    "Required participant" : "Partisipan wajib",
    "Optional participant" : "Partisipan opsional",
    "Non-participant" : "Bukan partisipan",
    "No match found" : "Tidak ditemukan kecocokan",
    "Note that members of circles get invited but are not synced yet." : "Perhatikan bahwa anggota kelompok diundang tapi belum tersinkronisasi.",
    "(organizer)" : "(penyelenggara)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Untuk mengirim undangan dan mengurus respons, [linkopen]tambahkan alamat email Anda di pengaturan pribadi[linkclose].",
    "Remove color" : "Hapus warna",
    "Event title" : "Judul acara",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Tidak dapat mengubah pengaturan sehari penuh untuk acara yang merupakan bagian dari set pengulangan.",
    "Repeat" : "Ulang",
    "never" : "tidak pernah",
    "on date" : "pada tanggal",
    "after" : "setelah",
    "End repeat" : "Akhiri perulangan",
    "Select to end repeat" : "Pilih untuk mengakhiri perulangan",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Acara ini merupakan pengecualian pengulangan dari set pengulangan. Anda tidak dapat menambahkan aturan pengulangan pada acara ini.",
    "first" : "pertama",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Perubahan pada aturan pengulangan hanya akan diterapkan untuk acara ini dan semua acara selanjutnya.",
    "Repeat every" : "Ulang setiap",
    "By day of the month" : "Berdasarkan hari pada bulan",
    "On the" : "Pada",
    "_day_::_days_" : ["hari"],
    "_week_::_weeks_" : ["minggu"],
    "_month_::_months_" : ["bulang"],
    "_year_::_years_" : ["tahun"],
    "weekday" : "akhir pekan",
    "weekend day" : "akhir pekan",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Penentuan perulangan acara ini tidak sepenuhnya didukung oleh Nextcloud. Jika Anda mengedit opsi pengulangan, pengulangan tertentu mungkin hilang.",
    "Resources" : "Sumber daya",
    "Public calendar does not exist" : "Kalender publik tidak eksis",
    "Maybe the share was deleted or has expired?" : "Mungkin yang dibagikan terhapus atau kadaluwarsa?",
    "None" : "Tidak ada",
    "Create" : "Buat",
    "on {formattedDate}" : "dalam {formattedDate}",
    "Please enter a valid date" : "Silakan isi tanggal valid",
    "Please enter a valid date and time" : "Silakan isi tanggal dan waktu valid",
    "Pick a time" : "Pilih waktu",
    "Pick a date" : "Pilih tanggal",
    "An error occurred, unable to read public calendars." : "Terjadi kesalahan, tidak dapat membaca kalender umum.",
    "An error occurred, unable to subscribe to calendar." : "Terjadi kesalahan, tidak dapat berlangganan kalender.",
    "Speak to the server administrator to resolve this issue." : "Hubungi administrator server untuk menyelesaikan masalah ini.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Kalender hari libur nasional disediakan oleh Thunderbird. Data kalender akan diunduh dari {website}",
    "Subscribe" : "Berlangganan",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Terima kasih. Pemesanan Anda dari {startDate} hingga  {endDate} telah dikonfirmasi.",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Slot untuk janji temu Anda dari {startDate} hingga {endDate} tidak lagi tersedia.",
    "Personal" : "Pribadi",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Deteksi zona waktu otomatis menetapkan UTC sebagai zona waktu Anda. Hal ini kemungkinan besar disebabkan oleh langkah keamanan peramban web Anda. Harap setel zona waktu Anda secara manual di pengaturan kalender.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Zona waktu Anda yang terkonfigurasi ({timezoneId}) tidak ditemukan. Kembali ke UTC.\nHarap ubah zona waktu Anda di pengaturan dan laporkan masalah ini.",
    "Edit event" : "Sunting agenda",
    "All day" : "Sepanjang hari",
    "Untitled event" : "Acara tanpa judul",
    "Close" : "Tutup",
    "Subscribe to {name}" : "Berlangganan ke {name}",
    "Anniversary" : "Hari jadi",
    "Appointment" : "Janji",
    "Business" : "Bisnis",
    "Education" : "Edukasi",
    "Holiday" : "Hari raya",
    "Meeting" : "Rapat",
    "Miscellaneous" : "Lain-lain",
    "Non-working hours" : "Luar waktu kerja",
    "Not in office" : "Tidak ada di kantor",
    "Phone call" : "Panggilan telepon",
    "Sick day" : "Hari sakit",
    "Special occasion" : "Acara khusus",
    "Travel" : "Perjalanan",
    "Vacation" : "Liburan",
    "Midnight on the day the event starts" : "Tengah malam pada hari acara dimulai",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n hari sebelum acara {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n pekan sebelum acara {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "Pada hari acara {formattedHourMinute}",
    "at the event's start" : "pada awal acara",
    "at the event's end" : "pada akhir acara",
    "{time} before the event starts" : "{time} sebelum acara berlangsung",
    "{time} before the event ends" : "{time} sebelum acara berakhir",
    "{time} after the event starts" : "{time} setelah acara berlangsung",
    "{time} after the event ends" : "{time} setelah acara berakhir",
    "on {time}" : "pada {time}",
    "on {time} ({timezoneId})" : "pada {time} ({timezoneId})",
    "Week {number} of {year}" : "Pekan {number} tahun {year}",
    "Daily" : "Harian",
    "Weekly" : "Mingguan",
    "Monthly" : "Bulanan",
    "Yearly" : "Tahunan",
    "_Every %n day_::_Every %n days_" : ["Setiap %n hari"],
    "_Every %n week_::_Every %n weeks_" : ["Setiap %n pekan"],
    "_Every %n month_::_Every %n months_" : ["Setiap %n bulan"],
    "_Every %n year_::_Every %n years_" : ["Setiap %n tahun"],
    "_on {weekday}_::_on {weekdays}_" : ["pada {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["pada hari {dayOfMonthList}"],
    "until {untilDate}" : "sampai {untilDate}",
    "_%n time_::_%n times_" : ["%n kali"],
    "second" : "detik",
    "third" : "ke-3",
    "fourth" : "ke-4",
    "fifth" : "ke-5",
    "second to last" : "kedua terakhir",
    "last" : "terakhir",
    "Untitled task" : "Tugas tanpa judul",
    "Please ask your administrator to enable the Tasks App." : "Silakan tanya administrator Anda untuk mengaktifkan aplikasi Tugas.",
    "_+%n more_::_+%n more_" : ["+%n lagi"],
    "Other" : "Lainnya",
    "Add a location" : "Tambah lokasi",
    "Status" : "Status",
    "Confirmed" : "Terkonfirmasi",
    "Confirmation about the overall status of the event." : "Konfirmasi tentang status keseluruhan acara.",
    "Show as" : "Tampilkan sebagai",
    "Take this event into account when calculating free-busy information." : "Pertimbangkan acara ini saat perhitungan waktu luang dan sibuk.",
    "Categories" : "Kategori",
    "Categories help you to structure and organize your events." : "Kategori membantu Anda menyusun dan mengatur acara.",
    "Search or add categories" : "Cari atau tambah kategori",
    "Add this as a new category" : "Tambah sebagai kategori baru",
    "Custom color" : "Warna khusus",
    "Special color of this event. Overrides the calendar-color." : "Warna spesial dari acara ini. Mengganti warna kalender.",
    "An error occurred, unable to delete the calendar." : "Terjadi galat, tidak dapat menghapus kalender.",
    "This is an event reminder." : "Ini adalah pengingat acara.",
    "Hidden" : "Sembunyi",
    "can edit" : "dapat edit",
    "Automatic ({detected})" : "Otomatis ({detected})",
    "Shortcut overview" : "Ikhtisar pintasan",
    "CalDAV link copied to clipboard." : "Tautan CalDAV disalin ke papan klip",
    "CalDAV link could not be copied to clipboard." : "Tautan CalDAV tidak dapat disalin ke papan klip",
    "Enable birthday calendar" : "Aktifkan kalender ulang tahun",
    "Show tasks in calendar" : "Tampilkan tugas dalam kalender",
    "Enable simplified editor" : "Aktifkan editor serderhana",
    "Show weekends" : "Tampilkan akhir pekan",
    "Show week numbers" : "Tampilkan nomor pekan",
    "Copy primary CalDAV address" : "Salin alamat utama CalDAV",
    "Copy iOS/macOS CalDAV address" : "Salin alamat CalDAV iOS/macOS",
    "Show keyboard shortcuts" : "Tampilkan pintasan papan kunci",
    "Successfully appended link to talk room to description." : "Berhasil menambahkan tautan ruang Talk pada deskripsi.",
    "Error creating Talk room" : "Galat membuat ruangan Talk",
    "The visibility of this event in shared calendars." : "Visibilitas acara ini di kalender yang dibagikan."
},
"nplurals=1; plural=0;");
