OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "입력한 이메일 주소가 너무 깁니다",
    "User-Session unexpectedly expired" : "사용자 세션이 예기치 않게 만료되었습니다.",
    "Provided email-address is not valid" : "지정한 파일이 사진이 아님",
    "%s has published the calendar »%s«" : "%s 님이 달력 \"%s\"을(를) 공개했습니다",
    "Unexpected error sending email. Please contact your administrator." : "재설정 메일을 보낼 수 없습니다. 관리자에게 문의하십시오.",
    "Successfully sent email to %1$s" : "%1$s에게 이메일을 성공적으로 발송했습니다.",
    "Hello," : "안녕하세요,",
    "We wanted to inform you that %s has published the calendar »%s«." : "%s 님이 달력 \"%s\"을(를) 공개했음을 알려 드립니다.",
    "Open »%s«" : "%s 열기",
    "Cheers!" : "감사합니다!",
    "Upcoming events" : "곧 있을 일정",
    "No more events today" : "오늘 더 이상 일정이 없음",
    "No upcoming events" : "다가오는 일정 없음",
    "More events" : "일정 더 보기",
    "%1$s with %2$s" : "%2$s이(가) 참여하는 %1$s",
    "Calendar" : "달력",
    "New booking {booking}" : "새로운 예약 {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) 이(가) \"{config_display_name}\"을(를) {date_time}에 예약했습니다.",
    "Appointments" : "일정들",
    "Schedule appointment \"%s\"" : "약속 \"%s\" 잡기",
    "Schedule an appointment" : "약속 잡기",
    "Prepare for %s" : "%s 준비",
    "Your appointment \"%s\" with %s needs confirmation" : "%s님과의 약속 \"%s\"에 대해 확인이 필요합니다",
    "Dear %s, please confirm your booking" : "%s님, 예약을 확인해 주십시오",
    "Confirm" : "확인",
    "Appointment with:" : "약속 상대:",
    "Description:" : "설명:",
    "This confirmation link expires in %s hours." : "이 확인 링크는 %s시간 후 만료됩니다.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "약속을 취소하고자 할 경우 이 이메일 또는 프로필 페이지를 통해 조직 관리자에게 문의하십시오.",
    "Your appointment \"%s\" with %s has been accepted" : "%s님과의 약속 \"%s\"이(가) 수락되었습니다",
    "Dear %s, your booking has been accepted." : "%s님, 예약이 수락되었습니다.",
    "Appointment for:" : "약속 주제:",
    "Date:" : "날짜:",
    "You will receive a link with the confirmation email" : "링크가 동봉된 확인 이메일을 수신할 것입니다",
    "Where:" : "장소:",
    "Comment:" : "댓글:",
    "You have a new appointment booking \"%s\" from %s" : "%s님으로부터 약속 \"%s\"에 대한 새로운 예약이 있습니다",
    "Dear %s, %s (%s) booked an appointment with you." : "%s님,  %s(%s)님께서 귀하와 약속을 예약했습니다.",
    "Location:" : "위치:",
    "A Calendar app for Nextcloud" : "Nextcloud 달력 앱",
    "Previous day" : "이전날",
    "Previous week" : "이전주",
    "Previous year" : "전년도",
    "Previous month" : "이전달",
    "Next day" : "다음날",
    "Next week" : "다음주",
    "Next year" : "다음 년도",
    "Next month" : "다음달",
    "Create new event" : "새 일정 생성",
    "Event" : "일정",
    "Today" : "오늘",
    "Day" : "일",
    "Week" : "주",
    "Month" : "달",
    "Year" : "년",
    "List" : "목록",
    "Appointment link was copied to clipboard" : "예약 링크가 클립보드에 복사되었습니다",
    "Appointment link could not be copied to clipboard" : "예약 링크를 클립보드에 복사하지 못했습니다",
    "Preview" : "미리 보기",
    "Copy link" : "링크 복사",
    "Edit" : "수정",
    "Delete" : "삭제",
    "Appointment schedules" : "약속 일정",
    "Create new" : "새로 만들기",
    "Disable calendar \"{calendar}\"" : "달력 \"{calendar}\" 비활성화",
    "Disable untitled calendar" : "제목 없는 달력 비활성화",
    "Enable calendar \"{calendar}\"" : "달력 \"{calendar}\" 활성화",
    "Enable untitled calendar" : "제목 없는 달력 활성화",
    "An error occurred, unable to change visibility of the calendar." : "오류가 발생하여 달력의 공개 설정을 변경할 수 없습니다.",
    "Untitled calendar" : "제목없는 달력",
    "Shared with you by" : "다음을 이용해 나와 공유됨 : ",
    "Edit and share calendar" : "달력 편집 및 공유",
    "Edit calendar" : "달력 편집",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["{countdown}초 후 달력 공유 해제"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["{countdown}초 후 달력 삭제"],
    "An error occurred, unable to create the calendar." : "오류가 발생하여 달력을 만들 수 없습니다.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "올바른 링크를 입력해 주십시오 (http://, https://, wdbcal://, 혹은 webcals:// 로 시작합니다.)",
    "Calendars" : "달력",
    "Add new" : "새로 추가",
    "New calendar" : "새 달력",
    "Name for new calendar" : "새 달력 이름",
    "Creating calendar …" : "달력 생성중 …",
    "New calendar with task list" : "작업 목록이 포함된 새 달력",
    "New subscription from link (read-only)" : "링크를 통해 새로 구독하기 (읽기 전용)",
    "Creating subscription …" : "구독 생성 ...",
    "Add public holiday calendar" : "공개 휴일 달력 추가",
    "Add custom public calendar" : "사용자 지정 공개 달력 추가",
    "Calendar link copied to clipboard." : "달력의 링크를 클립보드에 복사했습니다.",
    "Calendar link could not be copied to clipboard." : "달력의 링크를 클립보드에 복사할 수 없습니다.",
    "Copy subscription link" : "구독 링크 복사",
    "Copying link …" : "링크 복사중 …",
    "Copied link" : "링크 복사됨",
    "Could not copy link" : "링크를 복사할 수 없음",
    "Export" : "내보내기",
    "Untitled item" : "제목 없는 항목",
    "Unknown calendar" : "제목 없는 달력",
    "Could not load deleted calendars and objects" : "삭제된 달력과 요소들을 불러올 수 없음",
    "Could not restore calendar or event" : "달력과 일정을 복구할 수 없음",
    "Do you really want to empty the trash bin?" : "휴지통을 정말 비웁니까?",
    "Empty trash bin" : "휴지통 비우기",
    "Trash bin" : "휴지통",
    "Loading deleted items." : "삭제된 항목 불러오는 중",
    "You do not have any deleted items." : "삭제된 항목이 없습니다.",
    "Name" : "이름",
    "Deleted" : "삭제됨",
    "Restore" : "복원",
    "Delete permanently" : "영구히 삭제",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["휴지통에 있는 항목은 {numDays}일 수 완전히 삭제됩니다"],
    "Could not update calendar order." : "달력 순서를 갱신할 수 없습니다.",
    "Deck" : "덱",
    "Internal link" : "내부 링크",
    "A private link that can be used with external clients" : "개인 링크를 외부 클라이언트에서 사용할 수 있습니다",
    "Copy internal link" : "내부 링크 복사",
    "An error occurred, unable to publish calendar." : "오류 발생, 달력을 공개할 수 없음",
    "An error occurred, unable to send email." : "오류 발생, 이메일로 보낼 수 없음",
    "Embed code copied to clipboard." : "삽입 코드가 클립보드에 복사됨",
    "Embed code could not be copied to clipboard." : "삽입 코드를 클립보드에 복사할 수 없음",
    "Unpublishing calendar failed" : "달력 공개 중단 실패",
    "Share link" : "링크 공유",
    "Copy public link" : "공개 링크 복사",
    "Send link to calendar via email" : "이메일로 달력 링크 보내기",
    "Enter one address" : "주소 입력",
    "Sending email …" : "이메일로 보내는중 …",
    "Copy embedding code" : "삽입 코드 복사",
    "Copying code …" : "코드 복사중 …",
    "Copied code" : "코드 복사됨",
    "Could not copy code" : "코드를 복사할 수 없음",
    "Delete share link" : "공유 링크 삭제",
    "Deleting share link …" : "공유링크 삭제 …",
    "An error occurred while unsharing the calendar." : "달력 공유 해제 중 오류 발생",
    "An error occurred, unable to change the permission of the share." : "오류가 발생하여 공유 권한을 변경할 수 없습니다.",
    "Unshare with {displayName}" : "{displayName}과 공유 중단",
    "Share with users or groups" : "사용자 및 그룹과 공유",
    "No users or groups" : "사용자나 그룹 없음",
    "Failed to save calendar name and color" : "달력 이름 및 색상 저장 실패",
    "Share calendar" : "달력 공유",
    "Unshare from me" : "나의 공유 해제",
    "Save" : "저장",
    "No title" : "제목 없음",
    "View" : "보기",
    "Import calendars" : "달력 가져오기",
    "Please select a calendar to import into …" : "다음으로 가져올 달력을 선택해 주십시오 ...",
    "Filename" : "파일 이름",
    "Calendar to import into" : "다음으로 가져올 달력",
    "Cancel" : "취소",
    "_Import calendar_::_Import calendars_" : ["달력 가져오기"],
    "Select the default location for attachments" : "첨부파일에 대한 기본 위치를 지정하십시오",
    "Invalid location selected" : "잘못된 위치가 선택됨",
    "Attachments folder successfully saved." : "첨부파일 폴더가 성공적으로 저장됨.",
    "Error on saving attachments folder." : "첨부파일 폴더 설정 저장 중 오류 발생",
    "Attachments folder" : "첨부 파일 폴더",
    "{filename} could not be parsed" : "{filename} 분석할 수 없음",
    "No valid files found, aborting import" : "올바른 파일을 발견할 수 없음, 가져오기 취소",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["%n개의 일정을 성공적으로 가져옴"],
    "Import partially failed. Imported {accepted} out of {total}." : "가져오기가 부분적으로 실패했습니다. {total} 중 {accepted} 가져옴.",
    "Automatic" : "자동",
    "Automatic ({timezone})" : "자동({timezone})",
    "New setting was not saved successfully." : "새로운 설정이 저장되지 않았습니다.",
    "Timezone" : "시간대",
    "Navigation" : "탐색",
    "Previous period" : "이전 기간",
    "Next period" : "다음 기간",
    "Views" : "보기",
    "Day view" : "일간",
    "Week view" : "주간",
    "Month view" : "월간",
    "Year view" : "연도별 보기",
    "List view" : "목록 보기",
    "Actions" : "동작",
    "Create event" : "일정 만들기",
    "Show shortcuts" : "단축키 표시",
    "Editor" : "편집기",
    "Close editor" : "편집기 닫기",
    "Save edited event" : "수정된 일정 저장",
    "Delete edited event" : "수정된 일정 삭제",
    "Duplicate event" : "일정 복제",
    "or" : "또는",
    "Calendar settings" : "달력 설정",
    "No reminder" : "알림 없음",
    "General" : "일반",
    "Appearance" : "외형",
    "Editing" : "글 수정",
    "Default reminder" : "기본 알림",
    "Files" : "파일",
    "Appointment schedule successfully created" : "약속 일정이 성공적으로 생성되었습니다",
    "Appointment schedule successfully updated" : "약속 일정이 성공적으로 갱신되었습니다",
    "_{duration} minute_::_{duration} minutes_" : ["{duration}분"],
    "0 minutes" : "0분",
    "_{duration} hour_::_{duration} hours_" : ["{duration}시간"],
    "_{duration} day_::_{duration} days_" : ["{duration}일"],
    "_{duration} week_::_{duration} weeks_" : ["{duration}주"],
    "_{duration} month_::_{duration} months_" : ["{duration}개월"],
    "_{duration} year_::_{duration} years_" : ["{duration}년"],
    "To configure appointments, add your email address in personal settings." : "약속을 설정하기 위해 개인 설정에서 이메일 주소를 추가하십시오",
    "Public – shown on the profile page" : "공개 - 프로필 페이지에 표시됩니다",
    "Private – only accessible via secret link" : "개인 - 비밀 링크를 통해서만 접근할 수 있습니다",
    "Appointment schedule saved" : "약속 일정이 저장되었습니다",
    "Create appointment schedule" : "약속 일정 생성",
    "Edit appointment schedule" : "약속 일정 수정",
    "Update" : "업데이트",
    "Appointment name" : "약속 이름",
    "Location" : "위치",
    "Create a Talk room" : "대화방 만들기",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "예약된 약속마다 고유의 링크가 생성되며 이는 확인 이메일을 통해 전송됩니다",
    "Description" : "설명",
    "Visibility" : "표시 여부",
    "Duration" : "길이",
    "Increments" : "시간 단위",
    "Additional calendars to check for conflicts" : "충돌 확인을 위한 별도의 달력",
    "Pick time ranges where appointments are allowed" : "약속을 잡을 수 있는 시간의 범위를 지정하십시오",
    "to" : "부터",
    "Delete slot" : "시간대 삭제",
    "No times set" : "지정된 시간 없음",
    "Add" : "추가",
    "Monday" : "월요일",
    "Tuesday" : "화요일",
    "Wednesday" : "수요일",
    "Thursday" : "목요일",
    "Friday" : "금요일",
    "Saturday" : "토요일",
    "Sunday" : "일요일",
    "Add time before and after the event" : "일정 이전 및 이후 시간을 추가하십시오",
    "Before the event" : "일정 전",
    "After the event" : "일정 후",
    "Planning restrictions" : "계획 수립 제한 사항",
    "Minimum time before next available slot" : "다음 약속까지 최소 여유 시간",
    "Max slots per day" : "일일 최대 약속 수",
    "Limit how far in the future appointments can be booked" : "약속을 잡을 수 있는 날짜 범위를 제한합니다",
    "Please confirm your reservation" : "예약을 확인하십시오",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "세부사항을 포함한 이메일을 전송했습니다. 이메일을 통해 약속을 확인하십시오. 이제 이 창을 닫아도 됩니다.",
    "Your name" : "내 이름",
    "Your email address" : "내 이메일 주소",
    "Please share anything that will help prepare for our meeting" : "약속 준비에 필요한 모든 사항을 공유해 주십시오",
    "Could not book the appointment. Please try again later or contact the organizer." : "예약할 수 없음. 잠시 후 다시 시도하거나 중재자에게 문의하십시오.",
    "Back" : "뒤로",
    "Book appointment" : "약속 잡기",
    "Select conversation" : "대화 선택",
    "on" : "다음 시간/위치에: ",
    "at" : "다음 시간/위치에: ",
    "before at" : "다음 이전에: ",
    "Notification" : "알림",
    "Email" : "이메일",
    "Audio notification" : "소리 알림",
    "Other notification" : "다른 알림",
    "Relative to event" : "일정과 관련된",
    "On date" : "날짜",
    "Edit time" : "시간 편집",
    "Save time" : "시간 저장",
    "Remove reminder" : "알림 삭제",
    "Add reminder" : "알림 추가",
    "seconds" : "초",
    "minutes" : "분",
    "hours" : "시간",
    "days" : "일",
    "weeks" : "주",
    "Choose a file to add as attachment" : "첨부할 파일을 선택하세요.",
    "Choose a file to share as a link" : "공유할 링크 파일을 선택하세요.",
    "Attachment {name} already exist!" : "첨부파일 {name}은(는) 이미 존재합니다",
    "Could not upload attachment(s)" : "첨부파일을 업로드할 수 없음",
    "Proceed" : "진행",
    "No attachments" : "첨부파일 없음",
    "Add from Files" : "파일 앱에서 추가하기",
    "Upload from device" : "이 장치에서 업로드하다",
    "Delete file" : "파일 삭제",
    "Confirmation" : "확인",
    "_{count} attachment_::_{count} attachments_" : ["{count}개의 첨부파일"],
    "Suggested" : "제안됨",
    "Available" : "사용 가능",
    "Invitation accepted" : "초대가 수락됨",
    "Accepted {organizerName}'s invitation" : "{organizerName}의 초대가 수락됨",
    "Participation marked as tentative" : "잠정적인 참여",
    "Invitation is delegated" : "초대가 위임됨",
    "Not available" : "사용할 수 없음",
    "Invitation declined" : "초대가 거절됨",
    "Declined {organizerName}'s invitation" : "{organizerName}의 초대가 거절됨",
    "Checking availability" : "시간 조율 설정 확인 중",
    "Has not responded to {organizerName}'s invitation yet" : "{organizerName}의 초대에 아직 응답하지 않음",
    "{organizer} (organizer)" : "{organizer} (주회자)",
    "Availability of attendees, resources and rooms" : "참석 가능한 시간대 및 자원, 호실 사용 가능 여부 확인",
    "Out of office" : "자리에 없음",
    "Attendees:" : "참석자:",
    "Done" : "완료",
    "Room name" : "방 번호",
    "Free" : "바쁘지 않음",
    "Busy (tentative)" : "바쁨 (잠정적으로)",
    "Busy" : "바쁨",
    "Unknown" : "알 수 없음",
    "The invitation has been accepted successfully." : "초대가 성공적으로 수락됨",
    "Failed to accept the invitation." : "초대를 수락할 수 없음",
    "The invitation has been declined successfully." : "초대가 성공적으로 거절됨",
    "Failed to decline the invitation." : "초대를 거절할 수 없음",
    "Your participation has been marked as tentative." : "내 참여가 잠정 참여로 표시됐습니다.",
    "Failed to set the participation status to tentative." : "잠정 참여로 지정하기 실패",
    "Accept" : "수락",
    "Decline" : "거절",
    "Tentative" : "예정됨",
    "No attendees yet" : "아직 참석자가 없습니다.",
    "Attendees" : "참석자",
    "Remove group" : "그룹 지우기",
    "Remove attendee" : "참석자 삭제",
    "Chairperson" : "회장",
    "Required participant" : "필수 참가자",
    "Optional participant" : "선택적 참가자",
    "Non-participant" : "미참가자",
    "_%n member_::_%n members_" : ["%n명"],
    "No match found" : "일치하는 항목 없음",
    "Note that members of circles get invited but are not synced yet." : "서클의 회원이 초대되었으나 아직 동기화되지 않았습니다.",
    "(organizer)" : "(주최자)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "초대장을 보내거나 답장을 관리하려면, [linkopen] 개인 설정에서 이메일 주소를 추가하십시오[linkclose].",
    "Remove color" : "색깔 삭제",
    "Event title" : "일정 제목",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "반복하는 이 일정의 \"하루 종일\" 여부를 수정할 수 없습니다.",
    "From" : "시작",
    "To" : "종료",
    "Repeat" : "반복",
    "_time_::_times_" : ["회"],
    "never" : "없음",
    "on date" : "지정한 날짜에",
    "after" : "이후",
    "End repeat" : "반복 종료",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "이 일정은 특정 반복 일정의 예외로 지정되어 있습니다. 이 일정에 다른 반복 규칙을 지정할 수 없습니다.",
    "first" : "첫 번째",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "반복 규칙은 이번 및 그 이후의 일정에만 적용됩니다.",
    "Repeat every" : "반복 주기",
    "By day of the month" : "일자 지정",
    "On the" : "조건 지정",
    "_day_::_days_" : ["일"],
    "_week_::_weeks_" : ["주"],
    "_month_::_months_" : ["개월"],
    "_year_::_years_" : ["년"],
    "weekday" : "주중",
    "weekend day" : "주말",
    "Does not repeat" : "반복하지 않음",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Nextcloud에서 이 일정의 반복 설정 방식을 완전히 지원하지 않습니다. 반복 설정을 편집할 경우, 현재의 반복 설정이 사라질 수 있습니다.",
    "No rooms or resources yet" : "호실 혹은 비품 없음",
    "Resources" : "자원",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity}석"],
    "Add resource" : "비품 추가",
    "Has a projector" : "프로젝터 있음",
    "Has a whiteboard" : "화이트보드 있음",
    "Wheelchair accessible" : "휠체어 사용 가능",
    "Remove resource" : "비품 삭제",
    "Search for resources or rooms" : "비품 혹은 호실 검색",
    "available" : "사용 가능",
    "unavailable" : "사용 불가",
    "Projector" : "프로젝터",
    "Whiteboard" : "화이트보드",
    "Room type" : "호실 종류",
    "Minimum seating capacity" : "최소 좌석 수",
    "Update this and all future" : "이후 모든 일정 업데이트",
    "Update this occurrence" : "이 일정 업데이트",
    "Public calendar does not exist" : "공용 달력이 존재하지 않음",
    "Maybe the share was deleted or has expired?" : "공유가 삭제되었거나 만료되었을 수 있습니다.",
    "Yes" : "예",
    "No" : "아니오",
    "Maybe" : "아마도",
    "None" : "없음",
    "Create" : "생성",
    "from {formattedDate}" : "{formattedDate} 부터",
    "to {formattedDate}" : "{formattedDate} 까지",
    "on {formattedDate}" : "{formattedDate}에",
    "from {formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime} 부터",
    "to {formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime} 까지",
    "on {formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime} 에",
    "{formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime}",
    "Please enter a valid date" : "올바른 날짜를 입력하세요.",
    "Please enter a valid date and time" : "올바른 날짜와 시간을 입력하세요.",
    "Please select a time zone:" : "시간대를 선택하세요.",
    "Pick a time" : "시간 선택",
    "Pick a date" : "날짜 선택",
    "Type to search time zone" : "시간대를 찾기 위해 입력하세요.",
    "Global" : "국제",
    "Holidays in {region}" : "{region}의 휴일",
    "An error occurred, unable to read public calendars." : "오류가 발생하여 공개 달력을 읽을 수 없습니다.",
    "An error occurred, unable to subscribe to calendar." : "오류가 발생하여 달력을 구독할 수 없습니다.",
    "Public holiday calendars" : "공개 휴일 달력",
    "Public calendars" : "공개 달력",
    "No valid public calendars configured" : "설정된 유효한 달력 없음",
    "Speak to the server administrator to resolve this issue." : "이 문제를 해결하기 위해 서버 관리자에게 문의하십시오",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "공개 휴일 달력은 Thunderbird에서 제공합니다. 달력의 데이터는 {website}(으)로부터 다운로드합니다",
    "By {authors}" : "{authors} 작성",
    "Subscribed" : "구독함",
    "Subscribe" : "구독",
    "Could not fetch slots" : "슬롯을 불러올 수 없음",
    "Select a date" : "날짜 선택",
    "Select slot" : "슬롯 선택",
    "No slots available" : "사용 가능한 슬롯 없음",
    "The slot for your appointment has been confirmed" : "약속에 대한 슬롯이 확인되었습니다",
    "Appointment Details:" : "약속에 대한 상세 정보:",
    "Time:" : "시간:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "감사합니다. {startDate}에서 {endDate}까지의 예약이 확인되었습니다.",
    "Book another appointment:" : "다른 약속 예약하기:",
    "See all available slots" : "사용 가능한 슬롯 모두 보기",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "{starDate}에서 {endDate}까지의 슬롯은 더 이상 사용할 수 없습니다.",
    "Please book a different slot:" : "다른 슬롯에 예약하십시오:",
    "Book an appointment with {name}" : "{name}님과의 약속 잡기",
    "Personal" : "개인",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "자동으로 감지된 귀하의 시간대가 UTC입니다.\n이 웹 브라우저의 보안 설정이 원인일 수 있습니다.\n달력 설정에서 수동으로 시간대를 설정해 주십시오.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "설정된 시간대 ({timezoneId}) 을(를) 찾을 수 없습니다. UTC로 설정됩니다.\n설정에서 시간대를 변경하고 이 문제를 보고해 주십시오.",
    "Edit event" : "일정 편집",
    "Event does not exist" : "일정이 존재하지 않음",
    "Duplicate" : "복제",
    "Delete this occurrence" : "이 일정 삭제",
    "Delete this and all future" : "이후 모든 일정 삭제",
    "All day" : "하루 종일",
    "Deny access" : "접근 거부",
    "Invite" : "초대",
    "_User requires access to your file_::_Users require access to your file_" : ["사용자가 내 파일에 대한 접근을 요구합니다"],
    "Untitled event" : "제목없는 일정",
    "Close" : "닫기",
    "Title" : "제목",
    "30 min" : "30분",
    "Participants" : "참가자",
    "Submit" : "제출",
    "Subscribe to {name}" : "{name} 구독",
    "Export {name}" : "{name} 내보내기",
    "Anniversary" : "기념일",
    "Appointment" : "일정",
    "Business" : "사업",
    "Education" : "교육",
    "Holiday" : "휴일",
    "Meeting" : "회의",
    "Miscellaneous" : "기타",
    "Non-working hours" : "비번인 시간",
    "Not in office" : "자리에 없음",
    "Phone call" : "전화 연락",
    "Sick day" : "병가",
    "Travel" : "여행",
    "Vacation" : "휴가",
    "Midnight on the day the event starts" : "자정에 일정이 시작됨",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["{formattedHourMinute}에 진행되는 일정의 %n일 전"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : [" {formattedHourMinute}에 진행되는 일정의 %n주 전 "],
    "on the day of the event at {formattedHourMinute}" : "{formattedHourMinute}에 진행되는 일정 당일",
    "at the event's start" : "일정의 시작에",
    "at the event's end" : "일정의 끝에",
    "{time} before the event starts" : "일정 시작 {time} 전",
    "{time} before the event ends" : "일정 종료 {time} 전",
    "{time} after the event starts" : "일정 시작 {time} 후",
    "{time} after the event ends" : "일정 종료 {time} 후",
    "on {time}" : "{time} 후",
    "on {time} ({timezoneId})" : "{time} ({timezoneId}) 후",
    "Week {number} of {year}" : "{year}년 제 {number}주",
    "Daily" : "매일",
    "Weekly" : "매주",
    "Monthly" : "매달",
    "Yearly" : "매년",
    "_Every %n day_::_Every %n days_" : ["%n 일 마다"],
    "_Every %n week_::_Every %n weeks_" : ["%n 주 마다"],
    "_Every %n month_::_Every %n months_" : ["%n 개월 마다"],
    "_Every %n year_::_Every %n years_" : ["%n 년 마다"],
    "_on {weekday}_::_on {weekdays}_" : ["{weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["{dayOfMonthList}일"],
    "on the {ordinalNumber} {byDaySet}" : "{ordinalNumber} {byDaySet}",
    "in {monthNames} on the {dayOfMonthList}" : "{monthNames} {dayOfMonthList}일",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "{monthNames} {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "{untilDate} 까지",
    "_%n time_::_%n times_" : ["%n회"],
    "second" : "두 번째",
    "third" : "세 번째",
    "fourth" : "네 번째",
    "fifth" : "다섯 번째",
    "second to last" : "끝에서 두 번째",
    "last" : "마지막",
    "Untitled task" : "제목없는 작업",
    "Please ask your administrator to enable the Tasks App." : "관리자에게 Tasks 앱 활성화를 요청하세요.",
    "%n more" : "%n 더",
    "No events to display" : "표시할 일정 없음",
    "_+%n more_::_+%n more_" : ["+%n 더"],
    "No events" : "일정 없음",
    "Create a new event or change the visible time-range" : "새로운 일정을 만들거나 시간 범위를 변경하십시오",
    "It might have been deleted, or there was a typo in a link" : "삭제되었거나 오타가 있는 링크입니다",
    "It might have been deleted, or there was a typo in the link" : "삭제되었거나 오타가 있는 링크입니다",
    "Meeting room" : "회의실",
    "Lecture hall" : "강의실",
    "Seminar room" : "세미나실",
    "Other" : "기타",
    "When shared show full event" : "전체 일정 공유",
    "When shared show only busy" : "바쁨/한가함만 공유",
    "When shared hide this event" : "일정 공유하지 않음",
    "Add a location" : "위치 추가",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "설명을 입력하세요\n\n- 회의 목적\n- 안건 목록\n- 참석자들이 준비해야 할 것들",
    "Status" : "상태",
    "Confirmed" : "확인됨",
    "Canceled" : "취소됨",
    "Confirmation about the overall status of the event." : "일정의 전반적 상태에 대해 자세히 확인",
    "Show as" : "다음으로 표시: ",
    "Categories" : "분류",
    "Categories help you to structure and organize your events." : "카테고리는 일정을 만들고 조직할 때 도움이 됩니다.",
    "Search or add categories" : "카테고리를 찾거나 추가하기",
    "Add this as a new category" : "새 카테고리로 추가",
    "Custom color" : "사용자 지정 색상",
    "Special color of this event. Overrides the calendar-color." : "이 일정만의 색깔. 달력 색깔을 무시함.",
    "Error while sharing file" : "파일 공유하는 도중 오류",
    "Error while sharing file with user" : "사용자와 파일을 공유하는 중 오류 발생",
    "Attachment {fileName} already exists!" : "첨부파일 {name}은(는) 이미 존재합니다",
    "An error occurred during getting file information" : "정보를 불러오는 중 오류 발생",
    "An error occurred, unable to delete the calendar." : "오류가 발생하여 달력을 삭제할 수 없습니다.",
    "Imported {filename}" : "{filename} 가져옴",
    "This is an event reminder." : "일정에 대한 알림입니다.",
    "Appointment not found" : "약속을 찾을 수 없음",
    "User not found" : "사용자를 찾을 수 없음",
    "Hidden" : "숨겨짐",
    "can edit" : "편집 가능",
    "Calendar name …" : "달력 이름 ...",
    "Default attachments location" : "기본 첨부파일 위치",
    "Automatic ({detected})" : "자동 ({detected})",
    "Shortcut overview" : "바로가기 개요",
    "CalDAV link copied to clipboard." : "CalDAV 링크를 클립보드에 복사했습니다.",
    "CalDAV link could not be copied to clipboard." : "CalDAV 링크를 클립보드에 복사할 수 없습니다.",
    "Enable birthday calendar" : "생일 달력 활성화",
    "Show tasks in calendar" : "달력에 작업 보이기",
    "Enable simplified editor" : "간편한 편집기 활성화",
    "Limit the number of events displayed in the monthly view" : "월간 보기에서 표시되는 일정의 수 제한",
    "Show weekends" : "공휴일 보기",
    "Show week numbers" : "주 번호 보이기",
    "Time increments" : "시간 단위",
    "Copy primary CalDAV address" : "주 CalDAV 주소 복사하기",
    "Copy iOS/macOS CalDAV address" : "iOS/macOS CalDAV 주소 복사하기",
    "Personal availability settings" : "개인별 시간 조율 설정",
    "Show keyboard shortcuts" : "키보드 단축키 표시",
    "Successfully appended link to talk room to location." : "위치에 대화방 링크를 성공적으로 추가함",
    "Successfully appended link to talk room to description." : "설명에 대화방 링크를 성공적으로 추가함",
    "Error creating Talk room" : "대화방 생성 오류",
    "The visibility of this event in shared calendars." : "공유 달력에서 이 일정의 표시 여부"
},
"nplurals=1; plural=0;");
