OC.L10N.register(
    "calendar",
    {
    "Cheers!" : "Չը՛խկ",
    "Calendar" : "Օրացույց",
    "Today" : "Այսօր",
    "Day" : "Օր",
    "Week" : "Շաբաթ",
    "Month" : "Ամիս",
    "Copy link" : "Պատճենել հղումը",
    "Edit" : "մշակել",
    "Delete" : "Ջնջել",
    "Export" : "Արտահանում",
    "Name" : "Անուն",
    "Deleted" : "Ջնջված",
    "Restore" : "Վերականգնել",
    "Delete permanently" : "Ջնջել ընդմիշտ",
    "Share link" : "Կիսվել հղմամբ",
    "Share with users or groups" : "Կիսվել օգտատերերի կամ խմբերի հետ",
    "Save" : "Պահպանել",
    "Cancel" : "Չեղարկել",
    "General" : "Ընդհանուր",
    "Update" : "Թարմացնել",
    "Location" : "Տեղակայություն",
    "Description" : "Նկարագրություն",
    "Add" : "Ավելացնել",
    "Monday" : "Երկուշաբթի",
    "Tuesday" : "Երեքշաբթի",
    "Wednesday" : "Չորեքշաբթի",
    "Thursday" : "Հինգշաբթի",
    "Friday" : "Ուրբաթ",
    "Saturday" : "Շաբաթ",
    "Sunday" : "Կիրակի",
    "Notification" : "Ծանուցում",
    "Email" : "Էլ․փոստ",
    "seconds" : "վայրկյան",
    "minutes" : "րոպե",
    "hours" : "ժամ",
    "days" : "օր",
    "Unknown" : "Անհայտ",
    "Attendees" : "Մասնակիցներ",
    "Repeat" : "Կրկնել",
    "never" : "երբեք",
    "after" : "հետո",
    "Yes" : "Այո",
    "No" : "Ոչ",
    "Global" : "Ընդհանուր",
    "Personal" : "Անձնական",
    "Edit event" : "Խմբագրել դեպքը",
    "Close" : "Փակել",
    "Daily" : "Օրական",
    "Weekly" : "Շաբաթական",
    "second" : "երկրորդ",
    "Other" : "Այլ",
    "Confirmed" : "Հաստատված",
    "can edit" : "կարող է խմբագրել"
},
"nplurals=2; plural=(n != 1);");
